
/* niff to gfx converter v1.2 */

/* ============================================================
          Header Area
 ============================================================ */

#ifndef __ND_COMMONS__
#define __ND_COMMONS__

/* ------------------ macros */

#define SEGTOP(sno) ((u32)(sno)<<24)
#define SEGADRS(sno,adrs) (SEGTOP(sno)|((u32)(adrs)&0x00ffffff))

/* ------------------ geometric animation */

enum{
  /* NDR_ANIM_CHANNEL.kind */
  NDC_ANIMKIND_TRS_X  = 0x00,
  NDC_ANIMKIND_TRS_Y  = 0x01,
  NDC_ANIMKIND_TRS_Z  = 0x02,
  NDC_ANIMKIND_ROT_X  = 0x03,
  NDC_ANIMKIND_ROT_Y  = 0x04,
  NDC_ANIMKIND_ROT_Z  = 0x05,
  NDC_ANIMKIND_SCL_X  = 0x06,
  NDC_ANIMKIND_SCL_Y  = 0x07,
  NDC_ANIMKIND_SCL_Z  = 0x08
};

typedef struct {
  u16 kind;
  s16 start;
  s16 end;
  s16 nkey;
  s16 *key;
  float *value;
} NDR_ANIM_CHANNEL;

typedef struct {
  NDR_ANIM_CHANNEL *chlist;
  u16 nch;
  u16 total;
} NDR_ANIM;

/* ------------------ shape */

typedef struct{
  s16 *key;
  s16 *tblno;
  u16 nkey;
  u16 nelem;
} NDR_DEFORM;

typedef struct{
  Gfx *gfx;
  Vtx *vtx;
  u16 nvtx;
  u16 vtxsegno;

  /* using texture segment */
  u8 *img;
  u16 *tlut;
  u16 imgsegno, tlutsegno;

  /* shape deform data link */
  s16 *shaperef;
  NDR_DEFORM *vtx_deform;
  NDR_DEFORM *vtxcol_deform;
  NDR_DEFORM *vtxnv_deform;

} NDR_SHAPE;

/* ------------------ object */

enum{
  /* object types */
  NDC_TYPE_NULL = 0x01,
  NDC_TYPE_3D = 0x02,
  NDC_TYPE_BILLBOARD = 0x03,

  /* ColorCombine Mode */
  NDC_CC_COMBINED = 0x00,
  NDC_CC_TEX0 = 0x01,
  NDC_CC_TEX1 = 0x02,
  NDC_CC_PRIMITIVE = 0x03,
  NDC_CC_SHADE = 0x04,
  NDC_CC_ENV = 0x05,
  NDC_CC_KEY_CENTER = 0x10,
  NDC_CC_KEY_SCALE = 0x11,
  NDC_CC_COMBINED_ALPHA = 0x06,
  NDC_CC_TEX0_ALPHA = 0x07,
  NDC_CC_TEX1_ALPHA = 0x08,
  NDC_CC_PRIMITIVE_ALPHA = 0x09,
  NDC_CC_SHADE_ALPHA = 0x0a,
  NDC_CC_ENV_ALPHA = 0x0b,
  NDC_CC_LOD = 0x0c,
  NDC_CC_PRIM_LOD = 0x0d,
  NDC_CC_NOISE = 0x12,
  NDC_CC_K4 = 0x14,
  NDC_CC_K5 = 0x15,
  NDC_CC_1 = 0x0e,
  NDC_CC_0 = 0x0f,

  /* Render Mode(complexed) */
  NDC_RM_AA_EN                     = 0x80000000,
  NDC_RM_Z_CMP                     = 0x40000000,
  NDC_RM_Z_UPD                     = 0x20000000,
  NDC_RM_IM_RD                     = 0x10000000,
  NDC_RM_CVG_DST                   = 0x0c000000,
    NDC_RM_CVG_DST_CLAMP           = 0x00000000,
    NDC_RM_CVG_DST_WRAP            = 0x04000000,
    NDC_RM_CVG_DST_FULL            = 0x08000000,
    NDC_RM_CVG_DST_SAVE            = 0x0c000000,
  NDC_RM_CLR_ON_CVG                = 0x02000000,
  NDC_RM_CVG_X_ALPHA               = 0x01000000,
  NDC_RM_ALPHA_CVG_SEL             = 0x00800000,
  NDC_RM_FORCE_BL                  = 0x00400000,
  NDC_RM_ZMODE                     = 0x00300000,
    NDC_RM_ZMODE_OPA               = 0x00000000,
    NDC_RM_ZMODE_INTER             = 0x00100000,
    NDC_RM_ZMODE_XLU               = 0x00200000,
    NDC_RM_ZMODE_DEC               = 0x00300000,
  NDC_RM_ALPHA_COMPARE             = 0x000c0000,
    NDC_RM_ALPHA_COMPARE_NONE      = 0x00000000,
    NDC_RM_ALPHA_COMPARE_THRESHOLD = 0x00040000,
    NDC_RM_ALPHA_COMPARE_DITHER    = 0x00080000,
  NDC_RM_DITHER_ALPHA              = 0x00030000,
    NDC_RM_DITHER_ALPHA_PATTERN    = 0x00000000,
    NDC_RM_DITHER_ALPHA_NOPATTERN  = 0x00010000,
    NDC_RM_DITHER_ALPHA_NOISE      = 0x00020000,
    NDC_RM_DITHER_ALPHA_DISABLE    = 0x00030000,
  NDC_RM_BLENDER_MUX0              = 0x0000ff00,
  NDC_RM_BLENDER_MUX1              = 0x000000ff,

  /* NDR_OBJ.regflag(bit assign) */
  NDC_REGF_2CYC        = 0x4000
};

typedef struct{
  float tx, ty, tz;
  float rx, ry, rz;
  float sx, sy, sz;
} TRX;

typedef struct ndr_objTag{

  /* object propaties */
  u16 type, gid;
  u32 prio;
  TRX trx;

  /* resourse index */
  s16 shape;

  /* RSP, RDP status register setting */
  u16 regflag;
  u32 geommode;
  u32 rdmode;
  u32 primcol;
  u8 cc1[8], cc2[8];

  /* geometric animation setting */
  s16 geom_anim;
  u16 loop;
  u16 framerate;
  u32 order;

  /* children links */
  s16 bb_obj[2];
  u16 nchild;
  u16 *child;

} NDR_OBJ;

/* ------------------ scene */

typedef struct{
  TRX trx;
  u16 objno;
} NDR_SCN_INST_OBJ;

typedef struct{
  int type;
  u32 color;
  float x, y, z;
  float a1,a2;
} NDR_SCN_LIGHT;

typedef struct{
  struct{
    u16 near, far;
    u8 r,g,b,a;
  }fog;
  struct{
    u32 mode;
    float fovy, aspect, scale;
    u16 top, bottom, left, right, near, far;
    u16 eye_inst, upper_inst, lookat_inst;
  }cam;
  struct{
    u32 amb_color;
    int nlight;
    NDR_SCN_LIGHT *light;
  }light;
  u16 fill_col, fill_depth;
  NDR_SCN_INST_OBJ *entryobj;
  u16 nentobj;
} NDR_SCENE;

typedef struct{
  NDR_SCENE *scene;
  float convert_scale;

  NDR_OBJ **obj;
  NDR_SHAPE **shape;
  NDR_ANIM **anim;
  s16 **rawvtx;
  u32 **rawvtxcol;
  s8 **rawvtxnv;

  u16 nobj;
  u16 nanim;
  u16 nshape;
  u16 nrawvtx;
  u16 nrawvtxcol;
  u16 nrawvtxnv;
} NDR_RESINFO;

#endif    /* #ifndef __ND_COMMONS__ */

#ifdef PREVIEW_TYPE
#undef PREVIEW_TYPE
#endif  /* #ifdef PREVIEW_TYPE */

#ifdef RESINFO_NAME
#undef RESINFO_NAME
#endif  /* #ifdef RESINFO_NAME */

#define PREVIEW_TYPE 28
extern NDR_RESINFO resinfo_CornGroup;
#define RESINFO_NAME resinfo_CornGroup

static Gfx _CornGroup_aligner0[] = { gsSPEndDisplayList() };

/* ============================================================
          TLUT
 ============================================================ */
static u16 tlut_CornGroup[] = {
/* name:cornflake5  offset:0x00000000  length:32 bytes. */
0xff62,0xffe8,0xffea,0xfede,
0xfe9c,0xffa6,0xfff0,0xff20,
0xfe1c,0xfe1a,0xf59c,0xf59a,
0xed5a,0xff66,0x0000,0x0000,
};

/* ============================================================
          Bitmap
 ============================================================ */
static u8 bmp_CornGroup[] = {
/* name:cornflake5  type:CIDX  pixel/bit: 4 bits
  offset:0x00000000  length:512 bytes. */
0x01,0x21,0x34,0x55,0x44,0x35,0x31,0x66,
0x03,0x77,0x84,0x73,0x32,0x77,0x43,0x43,
0x37,0x77,0x07,0x33,0x07,0x93,0x81,0x62,
0x77,0x87,0x17,0x37,0x31,0x58,0x06,0x54,
0x75,0x33,0x20,0x93,0x53,0x80,0x33,0x53,
0x35,0x87,0x53,0x47,0xa0,0x58,0x52,0x03,
0x43,0x83,0x57,0x99,0x8b,0x76,0x63,0xa3,
0x73,0xbb,0x89,0x72,0x7b,0x8c,0x94,0x45,
0x33,0x83,0x35,0x78,0x33,0x31,0x18,0x32,
0x20,0x98,0x07,0x82,0x5a,0x73,0x98,0x40,
0x52,0x13,0x81,0x00,0x62,0x78,0x88,0x83,
0x38,0x47,0x62,0x83,0x38,0x53,0x31,0x07,
0x66,0x58,0x87,0x30,0x22,0x39,0x06,0x58,
0x93,0x49,0x30,0x89,0x39,0x3a,0x01,0x00,
0x62,0x75,0x10,0x43,0x00,0x38,0xd6,0x13,
0x41,0x7b,0x83,0x93,0x27,0xdd,0x83,0x31,
0x25,0x31,0x62,0x03,0x30,0x20,0xa8,0x8b,
0x35,0x3a,0x52,0x73,0x20,0x16,0x34,0x35,
0x87,0x80,0x50,0x34,0x32,0x60,0x87,0x74,
0x98,0x43,0x35,0x48,0x78,0x06,0x79,0x33,
0x81,0x04,0x71,0x04,0x82,0x13,0x35,0x03,
0x99,0x51,0x3b,0x99,0x99,0x01,0x38,0x15,
0x02,0x04,0x06,0x18,0x93,0x74,0x33,0x35,
0x39,0x05,0x89,0x57,0x43,0x83,0x98,0x51,
0x77,0x88,0x76,0x08,0x34,0x44,0x38,0x36,
0x23,0x88,0x88,0x34,0x35,0x98,0x94,0x33,
0x27,0x75,0x70,0x30,0x53,0x45,0x20,0x86,
0x23,0x8b,0x55,0x8b,0x44,0x85,0x34,0x97,
0x17,0x22,0x54,0x35,0x08,0x45,0x20,0x93,
0x34,0x58,0x37,0x98,0x39,0x97,0x88,0x33,
0x57,0x50,0x38,0x98,0x98,0x84,0x38,0x93,
0x73,0x03,0xb8,0x93,0x57,0xb3,0x03,0x73,
0x54,0x88,0x35,0x09,0x31,0x59,0x94,0x31,
0x17,0x10,0x81,0x09,0x88,0x82,0x08,0x37,
0x03,0x38,0x56,0x18,0x56,0x78,0x03,0x93,
0x83,0x27,0x31,0x08,0x8c,0x70,0x8a,0x71,
0x35,0x54,0x75,0x0a,0x0d,0x31,0x62,0x83,
0x70,0x8c,0x88,0x85,0x09,0x99,0x35,0x00,
0x45,0x77,0x73,0x4c,0x88,0x31,0x65,0x81,
0x62,0xa7,0x08,0x45,0x34,0x39,0x76,0x63,
0x44,0x94,0x33,0x80,0xd7,0x98,0x38,0x80,
0x61,0x86,0x68,0x9a,0x97,0x79,0x32,0x23,
0xa8,0x87,0x10,0x81,0x21,0x34,0x80,0x89,
0x38,0x81,0x79,0x07,0x93,0x48,0x88,0x33,
0x66,0x03,0x07,0x83,0x07,0x35,0x77,0x43,
0x44,0x9a,0x98,0x15,0xb8,0x70,0x53,0x0a,
0x62,0x77,0x87,0x17,0x37,0x31,0x58,0x06,
0x54,0x93,0x79,0x38,0x30,0x87,0x79,0xad,
0x13,0x35,0x87,0x53,0x47,0xa0,0x58,0x52,
0x03,0x45,0x78,0x08,0x02,0x38,0xac,0x72,
0xa3,0x73,0xbb,0x89,0x72,0x7b,0x8c,0x94,
0x45,0x84,0xbc,0xcc,0x85,0x3a,0x03,0x83,
0x32,0x20,0x98,0x07,0x82,0x5a,0x73,0x98,
0x47,0x38,0x9c,0x38,0xb8,0xca,0x89,0x43,
0x93,0x38,0x47,0x62,0x83,0x38,0x53,0x31,
0x07,0x55,0x3c,0xc9,0x3c,0x82,0x89,0x07,
0x08,0x93,0x49,0x30,0x89,0x39,0x3a,0x01,
0x00,0xac,0xb3,0x99,0x4b,0x81,0x88,0x51,
0x13,0x31,0x7b,0x83,0x93,0x27,0xdd,0x83,
0x35,0x8b,0x35,0x39,0x89,0xb8,0x33,0x30,
0x8b,0x35,0x3a,0x52,0x73,0x20,0x16,0x34,
0x35,0x59,0x80,0x79,0x90,0x38,0x26,0x37,
0x74,0x89,0x98,0x31,0x38,0x08,0x06,0x79,
0x93,0x38,0x99,0x44,0x93,0x43,0x01,0x71,
/* name:milk2  type:RGBA  pixel/bit: 16 bits
  offset:0x00000200  length:2048 bytes. */
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xe2,0xff,0xac,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xfe,0x9e,0xed,0x18,0xed,0x18,0xc4,0x58,
0xff,0xf6,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xf0,0xc4,0x58,0xff,0xe2,0xfe,0x9e,
0xff,0xfe,0xff,0xf0,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xf0,0xff,0xf0,0xff,0xf6,
0xff,0xfe,0xff,0xf0,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xfe,0xe4,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xe2,0xff,0xf0,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xfe,0x9e,0xff,0xe2,0xff,0xac,
0xfe,0x9e,0xff,0xfa,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xf6,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfa,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfa,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xf0,0xfe,0x9e,0xff,0xf0,
0xff,0xe2,0xfe,0x1a,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfa,0xff,0xfe,0xff,0xf0,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xf5,0xe0,0xed,0x18,0xfe,0x9e,
0xff,0xf0,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xac,
0xff,0xfe,0xfe,0xe4,0xfe,0xe4,0xff,0xfe,
0xff,0xfe,0xff,0xac,0xff,0xac,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xe2,0xfe,0x1a,0xfe,0x9e,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xfe,0x1a,0xff,0xac,0xff,0xac,0xff,0xf0,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xfe,0x1a,0xfe,0x1a,
0xfe,0x1a,0xff,0xac,0xff,0xfe,0xff,0xf0,
0xfe,0xe4,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xe2,0xfe,0xe4,
0xff,0xf6,0xff,0xfe,0xff,0xfe,0xfe,0x1a,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xf6,0xff,0xf6,0xff,0xf0,0xfe,0x1a,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xfe,0x1a,0xed,0x18,0xfe,0x1a,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xf5,0xe0,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xdd,0x60,
0xc4,0x58,0xff,0xfe,0xe5,0xa4,0xff,0xf0,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xf6,
0xff,0xf0,0xfe,0xe4,0xff,0xfe,0xff,0xfe,
0xff,0xac,0xff,0xe2,0xfe,0xe4,0xff,0xf6,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xe5,0xa4,0xed,0x18,
0xe5,0xa4,0xff,0xfe,0xdd,0x60,0xf5,0xe0,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xf6,
0xff,0xf6,0xff,0xfa,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xfe,0x9e,0xfe,0x1a,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xac,
0xff,0xfe,0xff,0xfa,0xc4,0x58,0xfe,0x1a,
0xff,0xac,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xf0,0xff,0xfe,
0xff,0xfa,0xfe,0xae,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xe2,0xc4,0x58,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xfe,0xae,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfa,
0xfe,0x1a,0xe5,0xa4,0xff,0xfe,0xff,0xfe,
0xff,0xfa,0xff,0xfe,0xe5,0xa4,0xfe,0xe4,
0xff,0xf0,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xf0,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xf6,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
/* name:eff_fuchi  type:RGBA  pixel/bit: 32 bits
  offset:0x00000a00  length:4096 bytes. */
0x21,0x10,0x08,0x00,0x21,0x10,0x08,0x00,
0x4a,0x18,0x08,0x00,0x5a,0x21,0x08,0x00,
0x73,0x21,0x08,0x00,0x8c,0x29,0x08,0x00,
0x8c,0x29,0x08,0x00,0xa5,0x31,0x08,0x00,
0xa5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0x8c,0x29,0x08,0x00,
0x73,0x21,0x08,0x00,0x5a,0x21,0x08,0x00,
0x4a,0x18,0x08,0x00,0x21,0x10,0x08,0x00,
0x21,0x10,0x08,0x00,0x4a,0x18,0x08,0x00,
0x5a,0x21,0x08,0x00,0x73,0x21,0x08,0x00,
0x8c,0x29,0x08,0x00,0xa5,0x31,0x08,0x00,
0xb5,0x31,0x08,0x00,0xb5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xa5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0x73,0x21,0x08,0x00,
0x5a,0x21,0x08,0x00,0x4a,0x18,0x08,0x00,
0x4a,0x18,0x08,0x00,0x5a,0x21,0x08,0x00,
0x73,0x21,0x08,0x00,0x8c,0x29,0x08,0x00,
0xa5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x08,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xa5,0x31,0x08,0x00,
0xa5,0x31,0x08,0x00,0x8c,0x29,0x08,0x00,
0x73,0x21,0x08,0x00,0x5a,0x21,0x08,0x00,
0x5a,0x21,0x08,0x00,0x73,0x21,0x08,0x00,
0x8c,0x29,0x08,0x00,0xa5,0x31,0x08,0x00,
0xb5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x64,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0x73,0x21,0x08,0x00,
0x73,0x21,0x08,0x00,0x8c,0x29,0x08,0x00,
0xa5,0x31,0x08,0x00,0xb5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x2c,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x18,
0xe7,0x73,0x08,0xd7,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x04,0xe7,0x73,0x08,0x10,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xb5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0x8c,0x29,0x08,0x00,
0x8c,0x29,0x08,0x00,0x8c,0x29,0x08,0x00,
0xa5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0xa3,0xe7,0x73,0x08,0x3c,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x58,
0xe7,0x94,0x08,0xff,0xe7,0x94,0x08,0x20,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x08,
0xe7,0x73,0x08,0xa3,0xe7,0x73,0x08,0x0c,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0x8c,0x29,0x08,0x00,
0x8c,0x29,0x08,0x00,0xa5,0x31,0x08,0x00,
0xb5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x70,0xe7,0x94,0x08,0xf3,
0xe7,0x94,0x08,0x3c,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x97,
0xe7,0x94,0x08,0xff,0xe7,0x94,0x08,0x68,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x0c,0xe7,0x94,0x08,0xc3,
0xe7,0x73,0x08,0xbb,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0xb5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x2c,0xe7,0x94,0x08,0xff,
0xe7,0x94,0x08,0xf3,0xef,0xad,0x08,0x3c,
0xef,0xad,0x08,0x00,0xef,0xad,0x08,0xd7,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xab,
0xe7,0x94,0x08,0x00,0xef,0xad,0x08,0x18,
0xe7,0x94,0x08,0xd3,0xe7,0x94,0x08,0xff,
0xe7,0x94,0x08,0x6c,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xb5,0x31,0x08,0x00,
0xa5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xef,0xad,0x08,0xe7,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xf3,
0xef,0xad,0x08,0x54,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xf3,
0xef,0xad,0x08,0x2c,0xef,0xad,0x08,0xdb,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xff,
0xe7,0x94,0x08,0x24,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x2c,
0xe7,0x73,0x08,0xa3,0xe7,0x73,0x08,0x68,
0xe7,0x94,0x08,0x28,0xe7,0x94,0x08,0x00,
0xef,0xad,0x08,0x00,0xef,0xad,0x08,0xa7,
0xef,0xad,0x08,0xff,0xf7,0xce,0x08,0xad,
0xef,0xad,0x08,0x63,0xf7,0xce,0x08,0x28,
0xf7,0xce,0x08,0x05,0xf7,0xce,0x08,0x28,
0xf7,0xce,0x08,0x5e,0xef,0xad,0x08,0xad,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xd7,
0xef,0xad,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x30,
0xe7,0x73,0x08,0x70,0xe7,0x73,0x08,0x30,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x54,0xe7,0x94,0x08,0xfb,
0xe7,0x94,0x08,0xff,0xe7,0x94,0x08,0xe7,
0xef,0xad,0x08,0xa3,0xef,0xad,0x08,0x9f,
0xf7,0xce,0x08,0x74,0xf7,0xce,0x08,0x03,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x03,
0xef,0xad,0x08,0x74,0xef,0xad,0x08,0x9c,
0xef,0xad,0x08,0x70,0xe7,0x94,0x08,0xaf,
0xe7,0x94,0x08,0xef,0xe7,0x94,0x08,0xff,
0xe7,0x73,0x08,0x70,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x94,0x08,0x54,
0xe7,0x94,0x08,0xfb,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xff,0xf7,0xce,0x08,0x74,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x74,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xff,
0xe7,0x94,0x08,0xff,0xe7,0x94,0x08,0x70,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x94,0x08,0x00,
0xef,0xad,0x08,0x54,0xef,0xad,0x08,0xfb,
0xef,0xad,0x08,0xad,0xf7,0xce,0x08,0x03,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x03,
0xef,0xad,0x08,0xad,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0x70,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x00,
0xef,0xad,0x08,0x00,0xef,0xad,0x08,0x5c,
0xf7,0xce,0x08,0x63,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x63,0xef,0xad,0x08,0x87,
0xef,0xad,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x94,0x08,0x24,0xe7,0x94,0x08,0x6c,
0xef,0xad,0x08,0xb3,0xef,0xad,0x08,0xf3,
0xf7,0xce,0x08,0x28,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x28,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xcf,0xe7,0x94,0x08,0x80,
0xe7,0x94,0x08,0x34,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x14,
0xe7,0x73,0x08,0x8b,0xe7,0x73,0x08,0xdb,
0xe7,0x94,0x08,0xff,0xe7,0x94,0x08,0xff,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xff,
0xf7,0xce,0x08,0x05,0xf7,0xce,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x05,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xff,0xe7,0x94,0x08,0xff,
0xe7,0x94,0x08,0xff,0xe7,0x73,0x08,0xe3,
0xe7,0x73,0x08,0x8f,0xe7,0x73,0x08,0x14,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x08,0xe7,0x73,0x08,0x44,
0xe7,0x94,0x08,0x87,0xe7,0x94,0x08,0xcf,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xff,
0xf7,0xce,0x08,0x28,0xf7,0xce,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x28,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xff,0xe7,0x94,0x08,0xe3,
0xe7,0x94,0x08,0x97,0xe7,0x73,0x08,0x4c,
0xe7,0x73,0x08,0x08,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x00,
0xef,0xad,0x08,0x18,0xef,0xad,0x08,0x74,
0xf7,0xce,0x08,0x63,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x63,0xef,0xad,0x08,0x9f,
0xef,0xad,0x08,0x30,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x18,0xef,0xad,0x08,0xd7,
0xef,0xad,0x08,0xad,0xf7,0xce,0x08,0x03,
0xf7,0xce,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x03,
0xef,0xad,0x08,0xad,0xef,0xad,0x08,0xe7,
0xe7,0x94,0x08,0x28,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x94,0x08,0x18,
0xe7,0x94,0x08,0xd7,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xff,0xf7,0xce,0x08,0x74,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xef,0x08,0x00,
0xf7,0xef,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x74,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xff,
0xe7,0x94,0x08,0xe7,0xe7,0x94,0x08,0x28,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x18,0xe7,0x94,0x08,0xd7,
0xe7,0x94,0x08,0xff,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xf7,0xef,0xad,0x08,0xcb,
0xf7,0xce,0x08,0x74,0xf7,0xce,0x08,0x03,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x00,
0xf7,0xce,0x08,0x00,0xf7,0xce,0x08,0x03,
0xf7,0xce,0x08,0x74,0xef,0xad,0x08,0xbc,
0xef,0xad,0x08,0xcf,0xef,0xad,0x08,0xff,
0xe7,0x94,0x08,0xff,0xe7,0x94,0x08,0xe7,
0xe7,0x73,0x08,0x28,0xe7,0x73,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x0c,
0xe7,0x73,0x08,0xd3,0xe7,0x73,0x08,0xc7,
0xe7,0x94,0x08,0x87,0xe7,0x94,0x08,0x48,
0xef,0xad,0x08,0x0c,0xef,0xad,0x08,0x8f,
0xef,0xad,0x08,0xff,0xf7,0xce,0x08,0xad,
0xef,0xad,0x08,0x63,0xf7,0xce,0x08,0x28,
0xf7,0xce,0x08,0x05,0xf7,0xce,0x08,0x28,
0xf7,0xce,0x08,0x63,0xef,0xad,0x08,0xad,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xbb,
0xef,0xad,0x08,0x00,0xe7,0x94,0x08,0x10,
0xe7,0x94,0x08,0x50,0xe7,0x73,0x08,0x8f,
0xe7,0x73,0x08,0xb7,0xe7,0x73,0x08,0x28,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xa5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x20,
0xe7,0x73,0x08,0x0c,0xe7,0x73,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0xcf,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xb7,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0x80,0xef,0xad,0x08,0xff,
0xef,0xad,0x08,0xff,0xe7,0x94,0x08,0xf7,
0xe7,0x94,0x08,0x0c,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x08,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0x8c,0x29,0x08,0x00,0xb5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x10,0xe7,0x94,0x08,0xff,
0xef,0xad,0x08,0xff,0xe7,0x94,0x08,0x8f,
0xef,0xad,0x08,0x04,0xe7,0x94,0x08,0xef,
0xef,0xad,0x08,0xff,0xef,0xad,0x08,0xc7,
0xef,0xad,0x08,0x00,0xe7,0x94,0x08,0x54,
0xe7,0x94,0x08,0xfb,0xe7,0x94,0x08,0xff,
0xe7,0x94,0x08,0x54,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xb5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0xa5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x54,0xe7,0x94,0x08,0xff,
0xe7,0x94,0x08,0x8f,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0xaf,
0xef,0xad,0x08,0xff,0xe7,0x94,0x08,0x80,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x94,0x08,0x44,0xe7,0x94,0x08,0xf3,
0xe7,0x73,0x08,0x9b,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xb5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0x8c,0x29,0x08,0x00,
0xa5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x97,0xe7,0x73,0x08,0x8f,
0xe7,0x94,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x70,
0xe7,0x94,0x08,0xff,0xe7,0x94,0x08,0x3c,
0xe7,0x94,0x08,0x00,0xe7,0x94,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x38,
0xe7,0x73,0x08,0xcf,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0x8c,0x29,0x08,0x00,
0x73,0x21,0x08,0x00,0x8c,0x29,0x08,0x00,
0xa5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x68,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x30,
0xe7,0x73,0x08,0xef,0xe7,0x73,0x08,0x04,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x28,0xe7,0x73,0x08,0x1c,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xa5,0x31,0x08,0x00,
0xa5,0x31,0x08,0x00,0x8c,0x29,0x08,0x00,
0x5a,0x21,0x08,0x00,0x73,0x21,0x08,0x00,
0x8c,0x29,0x08,0x00,0xa5,0x31,0x08,0x00,
0xb5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x93,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xe7,0x73,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0x73,0x21,0x08,0x00,
0x4a,0x18,0x08,0x00,0x5a,0x21,0x08,0x00,
0x73,0x21,0x08,0x00,0x8c,0x29,0x08,0x00,
0xa5,0x31,0x08,0x00,0xb5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x20,0xde,0x52,0x08,0x00,
0xe7,0x73,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xb5,0x31,0x08,0x00,
0xa5,0x31,0x08,0x00,0x8c,0x29,0x08,0x00,
0x73,0x21,0x08,0x00,0x5a,0x21,0x08,0x00,
0x21,0x10,0x08,0x00,0x4a,0x18,0x08,0x00,
0x5a,0x21,0x08,0x00,0x73,0x21,0x08,0x00,
0x8c,0x29,0x08,0x00,0xa5,0x31,0x08,0x00,
0xb5,0x31,0x08,0x00,0xb5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xde,0x52,0x08,0x00,0xde,0x52,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xa5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0x73,0x21,0x08,0x00,
0x5a,0x21,0x08,0x00,0x4a,0x18,0x08,0x00,
0x21,0x10,0x08,0x00,0x4a,0x18,0x08,0x00,
0x4a,0x18,0x08,0x00,0x5a,0x21,0x08,0x00,
0x73,0x21,0x08,0x00,0x8c,0x29,0x08,0x00,
0xa5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0xb5,0x31,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xde,0x52,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xb5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0xa5,0x31,0x08,0x00,0x8c,0x29,0x08,0x00,
0x73,0x21,0x08,0x00,0x5a,0x21,0x08,0x00,
0x4a,0x18,0x08,0x00,0x4a,0x18,0x08,0x00,
0x00,0x00,0x00,0x00,0x21,0x10,0x08,0x00,
0x21,0x10,0x08,0x00,0x4a,0x18,0x08,0x00,
0x5a,0x21,0x08,0x00,0x73,0x21,0x08,0x00,
0x73,0x21,0x08,0x00,0x8c,0x29,0x08,0x00,
0xa5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0xb5,0x31,0x08,0x00,0xb5,0x31,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xd6,0x39,0x08,0x00,
0xd6,0x39,0x08,0x00,0xb5,0x31,0x08,0x00,
0xb5,0x31,0x08,0x00,0xa5,0x31,0x08,0x00,
0x8c,0x29,0x08,0x00,0x8c,0x29,0x08,0x00,
0x73,0x21,0x08,0x00,0x73,0x21,0x08,0x00,
0x5a,0x21,0x08,0x00,0x4a,0x18,0x08,0x00,
0x21,0x10,0x08,0x00,0x21,0x10,0x08,0x00,
};

static Gfx _CornGroup_aligner1[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_368_[] = {
  {     0,    24,    81,0, 0x0000,0x0000, 0xff,0xff,0xc6,0xff }, /*     0 */
  {     0,   -11,    35,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*     1 */
  {    57,    24,    57,0, 0x0000,0x0000, 0xe2,0xff,0xc6,0xff }, /*     2 */
  {    57,    24,    57,0, 0x0000,0x0000, 0xe2,0xff,0xc6,0xff }, /*     3 */
  {    35,   -11,     0,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*     4 */
  {    81,    24,     0,0, 0x0000,0x0000, 0xc5,0xff,0xc5,0xff }, /*     5 */
  {    81,    24,     0,0, 0x0000,0x0000, 0xc5,0xff,0xc5,0xff }, /*     6 */
  {    35,   -11,     0,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*     7 */
  {    57,    24,   -57,0, 0x0000,0x0000, 0xc3,0xff,0xff,0xff }, /*     8 */
  {    57,    24,   -57,0, 0x0000,0x0000, 0xc3,0xff,0xff,0xff }, /*     9 */
  {     0,   -11,   -35,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    10 */
  {     0,    24,   -81,0, 0x0000,0x0000, 0xcc,0xe5,0xff,0xff }, /*    11 */
  {     0,    24,   -81,0, 0x0000,0x0000, 0xcc,0xe5,0xff,0xff }, /*    12 */
  {     0,   -11,   -35,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    13 */
  {   -57,    24,   -57,0, 0x0000,0x0000, 0xca,0xca,0xff,0xff }, /*    14 */
  {   -57,    24,   -57,0, 0x0000,0x0000, 0xca,0xca,0xff,0xff }, /*    15 */
  {   -35,   -11,     0,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    16 */
  {   -81,    24,     0,0, 0x0000,0x0000, 0xff,0xc6,0xc6,0xff }, /*    17 */
  {   -81,    24,     0,0, 0x0000,0x0000, 0xff,0xc6,0xc6,0xff }, /*    18 */
  {   -35,   -11,     0,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    19 */
  {   -57,    24,    57,0, 0x0000,0x0000, 0xff,0xe4,0xc9,0xff }, /*    20 */
  {   -57,    24,    57,0, 0x0000,0x0000, 0xff,0xe4,0xc9,0xff }, /*    21 */
  {     0,   -11,    35,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    22 */
  {     0,    24,    81,0, 0x0000,0x0000, 0xff,0xff,0xc6,0xff }, /*    23 */
  {   -57,    24,    57,0, 0x0000,0x0000, 0xff,0xe4,0xc9,0xff }, /*    24 */
  {   -25,   -11,    25,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    25 */
  {     0,   -11,    35,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    26 */
  {   -35,   -11,     0,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    27 */
  {   -25,   -11,    25,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    28 */
  {   -57,    24,    57,0, 0x0000,0x0000, 0xff,0xe4,0xc9,0xff }, /*    29 */
  {   -57,    24,   -57,0, 0x0000,0x0000, 0xca,0xca,0xff,0xff }, /*    30 */
  {   -25,   -11,   -25,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    31 */
  {   -35,   -11,     0,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    32 */
  {     0,   -11,   -35,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    33 */
  {   -25,   -11,   -25,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    34 */
  {   -57,    24,   -57,0, 0x0000,0x0000, 0xca,0xca,0xff,0xff }, /*    35 */
  {    57,    24,   -57,0, 0x0000,0x0000, 0xc3,0xff,0xff,0xff }, /*    36 */
  {    25,   -11,   -25,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    37 */
  {     0,   -11,   -35,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    38 */
  {    35,   -11,     0,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    39 */
  {    25,   -11,   -25,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    40 */
  {    57,    24,   -57,0, 0x0000,0x0000, 0xc3,0xff,0xff,0xff }, /*    41 */
  {    57,    24,    57,0, 0x0000,0x0000, 0xe2,0xff,0xc6,0xff }, /*    42 */
  {    25,   -11,    25,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    43 */
  {    35,   -11,     0,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    44 */
  {     0,   -11,    35,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    45 */
  {    25,   -11,    25,0, 0x0000,0x0000, 0xff,0xff,0xff,0xff }, /*    46 */
  {    57,    24,    57,0, 0x0000,0x0000, 0xe2,0xff,0xc6,0xff }, /*    47 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_368_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0, TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0),
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_ON),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP2Triangles( 24, 25, 26,  0, 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 16, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP2Triangles(  4,  5,  6,  0,  7,  8,  9,  0),
  gsSP2Triangles( 10, 11, 12,  0, 13, 14, 15,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_368_ = {
  gfx_Shape_of___POLYHEDRON_368_,
  vtx_Shape_of___POLYHEDRON_368_, 48, 5,
  bmp_CornGroup,
  tlut_CornGroup,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _CornGroup_aligner2[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_373_[] = {
  {   -24,     8,   -38,0, 0x0000,0x0000, 0xbc,0xda,0x9d,0xff }, /*     0 */
  {    28,     8,   -39,0, 0x0000,0x0000, 0x35,0xd2,0x97,0xff }, /*     1 */
  {   -47,     8,    18,0, 0x0000,0x0000, 0x8a,0xe4,0x22,0xff }, /*     2 */
  {    28,     8,   -39,0, 0x0000,0x0000, 0x35,0xd2,0x97,0xff }, /*     3 */
  {    54,     8,     0,0, 0x0000,0x0000, 0x78,0xd8,0xfa,0xff }, /*     4 */
  {   -47,     8,    18,0, 0x0000,0x0000, 0x8a,0xe4,0x22,0xff }, /*     5 */
  {    21,    35,   -21,0, 0x061c,0x061c, 0xff,0xff,0xff,0xff }, /*     6 */
  {    21,    35,    21,0, 0x061c,0x01e3, 0xff,0xff,0xff,0xff }, /*     7 */
  {    54,     8,     0,0, 0x0970,0x0400, 0xff,0xff,0xff,0xff }, /*     8 */
  {   -21,    22,    21,0, 0x01e3,0x01e3, 0xff,0xff,0xff,0xff }, /*     9 */
  {   -47,     8,    18,0, 0xff46,0x021c, 0xd2,0xd2,0xd2,0xff }, /*    10 */
  {     0,     8,    54,0, 0x0400,0xfe90, 0xab,0xab,0xab,0xff }, /*    11 */
  {   -21,    22,    21,0, 0x01e3,0x01e3, 0xff,0xff,0xff,0xff }, /*    12 */
  {     0,     8,    54,0, 0x0400,0xfe90, 0xab,0xab,0xab,0xff }, /*    13 */
  {    21,    35,    21,0, 0x061c,0x01e3, 0xff,0xff,0xff,0xff }, /*    14 */
  {     0,     8,    54,0, 0x0400,0xfe90, 0xab,0xab,0xab,0xff }, /*    15 */
  {    38,     8,    38,0, 0x07d8,0x0027, 0xe0,0xe0,0xe0,0xff }, /*    16 */
  {    21,    35,    21,0, 0x061c,0x01e3, 0xff,0xff,0xff,0xff }, /*    17 */
  {   -21,    22,   -21,0, 0x01e3,0x061c, 0xff,0xff,0xff,0xff }, /*    18 */
  {   -21,    22,    21,0, 0x01e3,0x01e3, 0xff,0xff,0xff,0xff }, /*    19 */
  {    21,    35,    21,0, 0x061c,0x01e3, 0xff,0xff,0xff,0xff }, /*    20 */
  {    21,    35,    21,0, 0x061c,0x01e3, 0xff,0xff,0xff,0xff }, /*    21 */
  {    21,    35,   -21,0, 0x061c,0x061c, 0xff,0xff,0xff,0xff }, /*    22 */
  {   -21,    22,   -21,0, 0x01e3,0x061c, 0xff,0xff,0xff,0xff }, /*    23 */
  {   -47,     8,    18,0, 0xff46,0x021c, 0xd2,0xd2,0xd2,0xff }, /*    24 */
  {   -21,    22,    21,0, 0x01e3,0x01e3, 0xff,0xff,0xff,0xff }, /*    25 */
  {   -21,    22,   -21,0, 0x01e3,0x061c, 0xff,0xff,0xff,0xff }, /*    26 */
  {    21,    35,    21,0, 0x061c,0x01e3, 0xff,0xff,0xff,0xff }, /*    27 */
  {    38,     8,    38,0, 0x07d8,0x0027, 0xe0,0xe0,0xe0,0xff }, /*    28 */
  {    54,     8,     0,0, 0x0970,0x0400, 0xff,0xff,0xff,0xff }, /*    29 */
  {    21,    35,   -21,0, 0x061c,0x061c, 0xff,0xff,0xff,0xff }, /*    30 */
  {    54,     8,     0,0, 0x0970,0x0400, 0xff,0xff,0xff,0xff }, /*    31 */
  {    28,     8,   -39,0, 0x06df,0x0801, 0xff,0xff,0xff,0xff }, /*    32 */
  {    28,     8,   -39,0, 0x06df,0x0801, 0xff,0xff,0xff,0xff }, /*    33 */
  {   -24,     8,   -38,0, 0x0181,0x07d8, 0xd3,0xd3,0xd3,0xff }, /*    34 */
  {    21,    35,   -21,0, 0x061c,0x061c, 0xff,0xff,0xff,0xff }, /*    35 */
  {   -24,     8,   -38,0, 0x0181,0x07d8, 0xd3,0xd3,0xd3,0xff }, /*    36 */
  {   -21,    22,   -21,0, 0x01e3,0x061c, 0xff,0xff,0xff,0xff }, /*    37 */
  {    21,    35,   -21,0, 0x061c,0x061c, 0xff,0xff,0xff,0xff }, /*    38 */
  {   -47,     8,    18,0, 0xff46,0x021c, 0xd2,0xd2,0xd2,0xff }, /*    39 */
  {   -21,    22,   -21,0, 0x01e3,0x061c, 0xff,0xff,0xff,0xff }, /*    40 */
  {   -24,     8,   -38,0, 0x0181,0x07d8, 0xd3,0xd3,0xd3,0xff }, /*    41 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_373_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH|G_LIGHTING ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, 1, 1, 0, SHADE, 0, 0, 0, 0, 1),
  gsSPVertex( SEGADRS(5, 0), 6, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSPClearGeometryMode( G_LIGHTING ),
  gsDPPipeSync(),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0, TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0),
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_RGBA16 ),
  gsDPLoadTLUT_pal16( 0, SEGADRS(7, 0) ),
  gsDPLoadMultiBlock_4b( SEGADRS(6,0), 0, 0,
    G_IM_FMT_CI, 32, 32, 0,
    0, 0, 5, 5, 0, 0 ),
  gsSPVertex( SEGADRS(5, 96), 26, 6 ),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP2Triangles( 24, 25, 26,  0, 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 10, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_373_ = {
  gfx_Shape_of___POLYHEDRON_373_,
  vtx_Shape_of___POLYHEDRON_373_, 42, 5,
  bmp_CornGroup,
  tlut_CornGroup,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _CornGroup_aligner3[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_378_[] = {
  {   -47,    15,    47,0, 0x012b,0x012b, 0xff,0xff,0xff,0xff }, /*     0 */
  {     0,    15,    66,0, 0x03ff,0x0000, 0xff,0xff,0xff,0xff }, /*     1 */
  {    47,    15,    47,0, 0x06d4,0x012b, 0xff,0xff,0xff,0xff }, /*     2 */
  {   -47,    15,    47,0, 0x012b,0x012b, 0xff,0xff,0xff,0xff }, /*     3 */
  {    47,    15,    47,0, 0x06d4,0x012b, 0xff,0xff,0xff,0xff }, /*     4 */
  {    66,    15,     0,0, 0x0800,0x0400, 0xff,0xff,0xff,0xff }, /*     5 */
  {    66,    15,     0,0, 0x0800,0x0400, 0xff,0xff,0xff,0xff }, /*     6 */
  {   -66,    15,     0,0, 0x0000,0x03ff, 0xff,0xff,0xff,0xff }, /*     7 */
  {   -47,    15,    47,0, 0x012b,0x012b, 0xff,0xff,0xff,0xff }, /*     8 */
  {    66,    15,     0,0, 0x0800,0x0400, 0xff,0xff,0xff,0xff }, /*     9 */
  {   -47,    15,   -47,0, 0x012b,0x06d4, 0xff,0xff,0xff,0xff }, /*    10 */
  {   -66,    15,     0,0, 0x0000,0x03ff, 0xff,0xff,0xff,0xff }, /*    11 */
  {    66,    15,     0,0, 0x0800,0x0400, 0xff,0xff,0xff,0xff }, /*    12 */
  {    47,    15,   -47,0, 0x06d4,0x06d4, 0xff,0xff,0xff,0xff }, /*    13 */
  {   -47,    15,   -47,0, 0x012b,0x06d4, 0xff,0xff,0xff,0xff }, /*    14 */
  {    47,    15,   -47,0, 0x06d4,0x06d4, 0xff,0xff,0xff,0xff }, /*    15 */
  {     0,    15,   -66,0, 0x03ff,0x0800, 0xff,0xff,0xff,0xff }, /*    16 */
  {   -47,    15,   -47,0, 0x012b,0x06d4, 0xff,0xff,0xff,0xff }, /*    17 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_378_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0, TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0),
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,512), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    0, 0, 5, 5, 0, 0 ),
  gsSPVertex( SEGADRS(5, 0), 18, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_378_ = {
  gfx_Shape_of___POLYHEDRON_378_,
  vtx_Shape_of___POLYHEDRON_378_, 18, 5,
  bmp_CornGroup,
  tlut_CornGroup,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _CornGroup_aligner4[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_383_[] = {
  {  -166,    15,  -166,0, 0x0000,0x0800, 0x00,0x7f,0x00,0x7f }, /*     0 */
  {   166,    15,   166,0, 0x0800,0x0000, 0x59,0x00,0x59,0x7f }, /*     1 */
  {   166,    15,  -166,0, 0x0800,0x0800, 0x59,0x00,0xa7,0x7f }, /*     2 */
  {  -166,    15,  -166,0, 0x0000,0x0800, 0x00,0x7f,0x00,0x7f }, /*     3 */
  {  -166,    15,   166,0, 0x0000,0x0000, 0xa7,0x00,0x59,0x7f }, /*     4 */
  {   166,    15,   166,0, 0x0800,0x0000, 0x59,0x00,0x59,0x7f }, /*     5 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_383_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_LIGHTING ),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0, TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0),
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,2560), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_32b, 32, 32, 0,
    2, 2, 5, 5, 0, 0 ),
  gsSPVertex( SEGADRS(5, 0), 6, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_383_ = {
  gfx_Shape_of___POLYHEDRON_383_,
  vtx_Shape_of___POLYHEDRON_383_, 6, 5,
  bmp_CornGroup,
  tlut_CornGroup,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

/* ============================================================
          Object Structure Area
 ============================================================ */
/* Object #0 */
static NDR_OBJ _dummy_obj={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #1 */
u16 _CornGroup_link[]={ 1, 3, 5, 7 };
static NDR_OBJ _CornGroup={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 4, _CornGroup_link
};

/* Object #2 */
u16 _bowlGroup_link[]={ 1 };
static NDR_OBJ _bowlGroup={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 1, _bowlGroup_link
};

/* Object #3 */
static NDR_OBJ _bowl={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  0,
  0x0000, 0x00000001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #4 */
u16 _corn_Group_link[]={ 1 };
static NDR_OBJ _corn_Group={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 1, _corn_Group_link
};

/* Object #5 */
static NDR_OBJ _corn={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  1,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #6 */
u16 _milk_Group_link[]={ 1 };
static NDR_OBJ _milk_Group={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 1, _milk_Group_link
};

/* Object #7 */
static NDR_OBJ _milk={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  2,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #8 */
u16 _Grid_Group_link[]={ 1 };
static NDR_OBJ _Grid_Group={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 1, _Grid_Group_link
};

/* Object #9 */
static NDR_OBJ _Grid={
  NDC_TYPE_3D, 0, 0x500 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  3,
  0x0000, 0x00002001, 0xd6600404, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #10 */
static NDR_OBJ _NULL_OBJECT_1={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #11 */
static NDR_OBJ _NULL_OBJECT_2={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #12 */
static NDR_OBJ _NULL_OBJECT_3={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* ============================================================
          Scene Structure Area
 ============================================================ */
static NDR_SCN_INST_OBJ CornGroup_scene_instlist[]={
 {
  {0,0,0, 0,0,0, 1,1,1},
  10 /* NULL_OBJECT_1 */
 },
 {
  {0,0,0, 0,0,0, 1,1,1},
  12 /* NULL_OBJECT_3 */
 },
 {
  {0,0,0, 0,0,0, 1,1,1},
  11 /* NULL_OBJECT_2 */
 },
 {
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  1 /* CornGroup */
 },
};

static NDR_SCN_LIGHT _CornGroup_scene_light[]={
  { 0, 0xffffff00, 0.57735, 0.57735, 0.57735, 0, 0 }
};

static NDR_SCENE CornGroup_scene={
  {950.000000, 1000.000000, 0x4c, 0x4c, 0x4c, 0xff},
  {1, 45.841393, 1.333330, 1.000000, 0, 0, 0, 0, 1, 10000, 0, 1, 2},
  { 0x202020ff, 1, _CornGroup_scene_light },
  0x0000, 0xfffc,
  CornGroup_scene_instlist, 4,
};

/* ============================================================
          Shape Structure List
 ============================================================ */
static NDR_SHAPE *shapelist_CornGroup[] = {
  &shape_Shape_of___POLYHEDRON_368_,
  &shape_Shape_of___POLYHEDRON_373_,
  &shape_Shape_of___POLYHEDRON_378_,
  &shape_Shape_of___POLYHEDRON_383_,
};

/* ============================================================
          Object Struct List
 ============================================================ */
static NDR_OBJ *objlist_CornGroup[]={
  &_dummy_obj, /* 0 */
  &_CornGroup, /* 1 */
  &_bowlGroup, /* 2 */
  &_bowl, /* 3 */
  &_corn_Group, /* 4 */
  &_corn, /* 5 */
  &_milk_Group, /* 6 */
  &_milk, /* 7 */
  &_Grid_Group, /* 8 */
  &_Grid, /* 9 */
  &_NULL_OBJECT_1, /* 10 */
  &_NULL_OBJECT_2, /* 11 */
  &_NULL_OBJECT_3, /* 12 */
};

/* ############################################################
          Resource Information
 ############################################################ */
NDR_RESINFO resinfo_CornGroup={
  &CornGroup_scene,
  20.000000,
  objlist_CornGroup,
  shapelist_CornGroup,
  NULL,
  NULL,
  NULL,
  NULL,
  13, 4, 0, 0, 0, 0
};

