
/* niff to gfx converter v1.2 */

/* ============================================================
          Header Area
 ============================================================ */

#ifndef __ND_COMMONS__
#define __ND_COMMONS__

/* ------------------ macros */

#define SEGTOP(sno) ((u32)(sno)<<24)
#define SEGADRS(sno,adrs) (SEGTOP(sno)|((u32)(adrs)&0x00ffffff))

/* ------------------ geometric animation */

enum{
  /* NDR_ANIM_CHANNEL.kind */
  NDC_ANIMKIND_TRS_X  = 0x00,
  NDC_ANIMKIND_TRS_Y  = 0x01,
  NDC_ANIMKIND_TRS_Z  = 0x02,
  NDC_ANIMKIND_ROT_X  = 0x03,
  NDC_ANIMKIND_ROT_Y  = 0x04,
  NDC_ANIMKIND_ROT_Z  = 0x05,
  NDC_ANIMKIND_SCL_X  = 0x06,
  NDC_ANIMKIND_SCL_Y  = 0x07,
  NDC_ANIMKIND_SCL_Z  = 0x08
};

typedef struct {
  u16 kind;
  s16 start;
  s16 end;
  s16 nkey;
  s16 *key;
  float *value;
} NDR_ANIM_CHANNEL;

typedef struct {
  NDR_ANIM_CHANNEL *chlist;
  u16 nch;
  u16 total;
} NDR_ANIM;

/* ------------------ shape */

typedef struct{
  s16 *key;
  s16 *tblno;
  u16 nkey;
  u16 nelem;
} NDR_DEFORM;

typedef struct{
  Gfx *gfx;
  Vtx *vtx;
  u16 nvtx;
  u16 vtxsegno;

  /* using texture segment */
  u8 *img;
  u16 *tlut;
  u16 imgsegno, tlutsegno;

  /* shape deform data link */
  s16 *shaperef;
  NDR_DEFORM *vtx_deform;
  NDR_DEFORM *vtxcol_deform;
  NDR_DEFORM *vtxnv_deform;

} NDR_SHAPE;

/* ------------------ object */

enum{
  /* object types */
  NDC_TYPE_NULL = 0x01,
  NDC_TYPE_3D = 0x02,
  NDC_TYPE_BILLBOARD = 0x03,

  /* ColorCombine Mode */
  NDC_CC_COMBINED = 0x00,
  NDC_CC_TEX0 = 0x01,
  NDC_CC_TEX1 = 0x02,
  NDC_CC_PRIMITIVE = 0x03,
  NDC_CC_SHADE = 0x04,
  NDC_CC_ENV = 0x05,
  NDC_CC_KEY_CENTER = 0x10,
  NDC_CC_KEY_SCALE = 0x11,
  NDC_CC_COMBINED_ALPHA = 0x06,
  NDC_CC_TEX0_ALPHA = 0x07,
  NDC_CC_TEX1_ALPHA = 0x08,
  NDC_CC_PRIMITIVE_ALPHA = 0x09,
  NDC_CC_SHADE_ALPHA = 0x0a,
  NDC_CC_ENV_ALPHA = 0x0b,
  NDC_CC_LOD = 0x0c,
  NDC_CC_PRIM_LOD = 0x0d,
  NDC_CC_NOISE = 0x12,
  NDC_CC_K4 = 0x14,
  NDC_CC_K5 = 0x15,
  NDC_CC_1 = 0x0e,
  NDC_CC_0 = 0x0f,

  /* Render Mode(complexed) */
  NDC_RM_AA_EN                     = 0x80000000,
  NDC_RM_Z_CMP                     = 0x40000000,
  NDC_RM_Z_UPD                     = 0x20000000,
  NDC_RM_IM_RD                     = 0x10000000,
  NDC_RM_CVG_DST                   = 0x0c000000,
    NDC_RM_CVG_DST_CLAMP           = 0x00000000,
    NDC_RM_CVG_DST_WRAP            = 0x04000000,
    NDC_RM_CVG_DST_FULL            = 0x08000000,
    NDC_RM_CVG_DST_SAVE            = 0x0c000000,
  NDC_RM_CLR_ON_CVG                = 0x02000000,
  NDC_RM_CVG_X_ALPHA               = 0x01000000,
  NDC_RM_ALPHA_CVG_SEL             = 0x00800000,
  NDC_RM_FORCE_BL                  = 0x00400000,
  NDC_RM_ZMODE                     = 0x00300000,
    NDC_RM_ZMODE_OPA               = 0x00000000,
    NDC_RM_ZMODE_INTER             = 0x00100000,
    NDC_RM_ZMODE_XLU               = 0x00200000,
    NDC_RM_ZMODE_DEC               = 0x00300000,
  NDC_RM_ALPHA_COMPARE             = 0x000c0000,
    NDC_RM_ALPHA_COMPARE_NONE      = 0x00000000,
    NDC_RM_ALPHA_COMPARE_THRESHOLD = 0x00040000,
    NDC_RM_ALPHA_COMPARE_DITHER    = 0x00080000,
  NDC_RM_DITHER_ALPHA              = 0x00030000,
    NDC_RM_DITHER_ALPHA_PATTERN    = 0x00000000,
    NDC_RM_DITHER_ALPHA_NOPATTERN  = 0x00010000,
    NDC_RM_DITHER_ALPHA_NOISE      = 0x00020000,
    NDC_RM_DITHER_ALPHA_DISABLE    = 0x00030000,
  NDC_RM_BLENDER_MUX0              = 0x0000ff00,
  NDC_RM_BLENDER_MUX1              = 0x000000ff,

  /* NDR_OBJ.regflag(bit assign) */
  NDC_REGF_2CYC        = 0x4000
};

typedef struct{
  float tx, ty, tz;
  float rx, ry, rz;
  float sx, sy, sz;
} TRX;

typedef struct ndr_objTag{

  /* object propaties */
  u16 type, gid;
  u32 prio;
  TRX trx;

  /* resourse index */
  s16 shape;

  /* RSP, RDP status register setting */
  u16 regflag;
  u32 geommode;
  u32 rdmode;
  u32 primcol;
  u8 cc1[8], cc2[8];

  /* geometric animation setting */
  s16 geom_anim;
  u16 loop;
  u16 framerate;
  u32 order;

  /* children links */
  s16 bb_obj[2];
  u16 nchild;
  u16 *child;

} NDR_OBJ;

/* ------------------ scene */

typedef struct{
  TRX trx;
  u16 objno;
} NDR_SCN_INST_OBJ;

typedef struct{
  int type;
  u32 color;
  float x, y, z;
  float a1,a2;
} NDR_SCN_LIGHT;

typedef struct{
  struct{
    u16 near, far;
    u8 r,g,b,a;
  }fog;
  struct{
    u32 mode;
    float fovy, aspect, scale;
    u16 top, bottom, left, right, near, far;
    u16 eye_inst, upper_inst, lookat_inst;
  }cam;
  struct{
    u32 amb_color;
    int nlight;
    NDR_SCN_LIGHT *light;
  }light;
  u16 fill_col, fill_depth;
  NDR_SCN_INST_OBJ *entryobj;
  u16 nentobj;
} NDR_SCENE;

typedef struct{
  NDR_SCENE *scene;
  float convert_scale;

  NDR_OBJ **obj;
  NDR_SHAPE **shape;
  NDR_ANIM **anim;
  s16 **rawvtx;
  u32 **rawvtxcol;
  s8 **rawvtxnv;

  u16 nobj;
  u16 nanim;
  u16 nshape;
  u16 nrawvtx;
  u16 nrawvtxcol;
  u16 nrawvtxnv;
} NDR_RESINFO;

#endif    /* #ifndef __ND_COMMONS__ */

#ifdef PREVIEW_TYPE
#undef PREVIEW_TYPE
#endif  /* #ifdef PREVIEW_TYPE */

#ifdef RESINFO_NAME
#undef RESINFO_NAME
#endif  /* #ifdef RESINFO_NAME */

#define PREVIEW_TYPE 28
extern NDR_RESINFO resinfo_frake_kime;
#define RESINFO_NAME resinfo_frake_kime

static Gfx _frake_kime_aligner0[] = { gsSPEndDisplayList() };

/* ============================================================
          Bitmap
 ============================================================ */
static u8 bmp_frake_kime[] = {
/* name:t_shirt3  type:RGBA  pixel/bit: 16 bits
  offset:0x00000000  length:2048 bytes. */
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xa7,0xb4,
0xaf,0x6e,0xaf,0x6e,0xaf,0x6e,0xaf,0x6e,
0xa7,0xb4,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x42,0xcd,0xd0,0xcd,0xd0,0x9f,0xfa,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xa7,0xb6,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xa7,0xb6,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xa7,0xb6,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xa7,0xb6,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xd5,0x88,0xbe,0x9e,0xbe,0x9e,0x9f,0xfc,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xce,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xa7,0x72,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xaf,0x6e,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xaf,0x6e,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xaf,0x6e,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xaf,0x6e,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfa,
0xa7,0xb6,0xa7,0xb6,0xa7,0xb6,0xa7,0xb6,
0xa7,0xb6,0xa7,0xb6,0xa7,0xb6,0xa7,0xb6,
0xa7,0xb6,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x5c,0x1e,0x39,0x88,0x52,0x0a,0x6a,0x8e,
0x6a,0x8e,0x5a,0x4c,0x39,0x88,0x31,0xcc,
0x65,0x6a,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x21,0x8c,0x8b,0x92,
0xf6,0x20,0xfe,0x62,0xfe,0x62,0xfe,0x62,
0xfe,0x62,0xfe,0x62,0xfe,0x62,0xf6,0x20,
0x8b,0x92,0x18,0x82,0x7e,0xb4,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x6d,0xac,0xa4,0x16,0xfe,0x62,
0xfe,0x62,0xfe,0x62,0xfe,0x62,0xfe,0x62,
0xfe,0x62,0xfe,0x62,0xfe,0x62,0xfe,0x62,
0xfe,0x62,0xd5,0x5c,0x10,0xc6,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
/* name:belt2  type:RGBA  pixel/bit: 16 bits
  offset:0x00000800  length:2048 bytes. */
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x24,0x48,0x24,0x48,0x24,0x48,0x26,
0x50,0x66,0x50,0x66,0x48,0x26,0x48,0x24,
0x48,0x24,0x48,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x48,0x24,0x48,0x26,0x48,0x24,0x40,0x24,
0x08,0x02,0x18,0x88,0x49,0xd6,0x73,0x24,
0x8b,0xaa,0x8b,0xaa,0x73,0x24,0x41,0xd6,
0x18,0x88,0x08,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x28,0xcc,0x6a,0xe2,0x10,0x86,0x00,0x02,
0x00,0x00,0x10,0x86,0x4a,0x16,0x7b,0xa4,
0x8c,0x2c,0x8c,0x2c,0x7b,0xa4,0x42,0x14,
0x10,0x84,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x18,0xc8,0x73,0x22,0x18,0xc6,0x00,0x00,
0x08,0x02,0x18,0x88,0x49,0xd8,0x7b,0x66,
0x8b,0xaa,0x8b,0xaa,0x73,0x24,0x41,0xd6,
0x18,0x88,0x08,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x18,0x8a,0x6a,0xe2,0x20,0xca,0x00,0x02,
0x48,0x24,0x48,0x24,0x48,0x24,0x48,0x26,
0x50,0x66,0x50,0x66,0x48,0x26,0x48,0x24,
0x48,0x24,0x48,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x48,0x24,0x48,0x26,0x48,0x24,0x40,0x24,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
/* name:mouth2_32  type:RGBA  pixel/bit: 16 bits
  offset:0x00001000  length:2048 bytes. */
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x5e,0xed,0x5e,0xed,0x5e,0xed,0x5e,
0xe5,0x1c,0xdd,0x1c,0xed,0x5e,0xed,0x5e,
0xf5,0x5e,0xf5,0x5e,0xf5,0x9e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x9e,0xed,0x5e,0xed,0x5e,0xd4,0xdc,
0xb4,0x16,0x9b,0x54,0x8b,0x12,0x72,0x8e,
0x62,0x0c,0x62,0x0c,0x6a,0x8e,0x7a,0xd0,
0x93,0x52,0xa3,0xd4,0xbc,0x18,0xd4,0xda,
0xed,0x5e,0xf5,0x9e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0x9e,0xed,0x5e,
0xcc,0x9a,0x8b,0x52,0x6a,0x4e,0x5a,0x0c,
0x41,0x48,0x31,0x06,0x29,0x06,0x20,0xc4,
0x20,0x84,0x28,0xc4,0x20,0xc4,0x20,0xc4,
0x31,0x06,0x39,0x48,0x41,0x88,0x5a,0x0c,
0x83,0x10,0xc4,0x58,0xed,0x5e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x5e,0xe5,0x1e,0xc4,0x58,0x8b,0x52,
0x51,0xca,0x29,0x06,0x20,0x84,0x20,0xc4,
0x31,0x06,0x39,0x46,0x51,0xca,0x62,0x0c,
0x6a,0x4e,0x7a,0x8e,0x6a,0x4e,0x49,0xca,
0x41,0x88,0x39,0x46,0x28,0xc4,0x28,0xc4,
0x28,0xc4,0x51,0xca,0x9b,0x54,0xdc,0xdc,
0xf5,0x5e,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xed,0x5e,
0xc4,0x58,0x8b,0x10,0x49,0x8a,0x31,0x06,
0x20,0x84,0x39,0x46,0x5a,0x0a,0x7a,0xd0,
0x93,0x52,0xa3,0xd4,0xc4,0x58,0xdc,0xdc,
0xed,0x5e,0xed,0x5e,0xe5,0x1c,0xcc,0x9a,
0xb4,0x16,0xa3,0x94,0x83,0x10,0x6a,0x4c,
0x31,0x06,0x28,0xc4,0x31,0x06,0x6a,0x4c,
0xbc,0x58,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xed,0x5e,0xa3,0xd4,
0x49,0xca,0x29,0x06,0x20,0x84,0x39,0x48,
0x6a,0x4c,0xa3,0x94,0xd4,0xdc,0xed,0x5e,
0xf5,0x5e,0xf5,0x5e,0xf5,0x9e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x9e,0xf5,0x5e,0xed,0x5e,0xd4,0xdc,
0x9b,0x94,0x51,0xca,0x31,0x06,0x20,0xc4,
0x51,0xca,0xbc,0x18,0xed,0x5e,0xf5,0xa0,
0xf5,0x9e,0xe5,0x1c,0xa3,0x94,0x41,0x88,
0x20,0x84,0x39,0x48,0x62,0x4c,0xab,0xd6,
0xdc,0xdc,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xed,0x5e,0xcc,0x9a,0x82,0xd0,0x39,0x46,
0x28,0xc4,0x5a,0x0a,0xc4,0x58,0xed,0x5e,
0xdc,0xdc,0x8b,0x52,0x39,0x48,0x20,0x84,
0x41,0x88,0x9b,0x94,0xdc,0xdc,0xed,0x5e,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0x5e,0xe5,0x1c,0x8b,0x12,
0x31,0x46,0x28,0xc4,0x62,0x4c,0xcc,0x9a,
0x9b,0x94,0x39,0x46,0x20,0xc4,0x51,0xca,
0xab,0xd6,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0x9e,0xdd,0x1c,
0x82,0xd0,0x31,0x06,0x31,0x06,0x8b,0x12,
0x6a,0x8e,0x28,0xc4,0x5a,0x0a,0xbc,0x18,
0xed,0x5e,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0x9e,
0xd4,0xda,0x72,0x8e,0x39,0x48,0x82,0xd0,
0xc4,0x58,0x9b,0x94,0xc4,0x9a,0xed,0x5e,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x5e,0xd4,0xda,0xb4,0x16,0xd4,0x9a,
0xf5,0x9e,0xf5,0x5e,0xf5,0x9e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0x5e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
/* name:eye_32b  type:RGBA  pixel/bit: 16 bits
  offset:0x00001800  length:2048 bytes. */
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xe2,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x9e,0xdc,0xdc,0x8b,0x12,0x72,0x8e,
0x83,0x10,0x6a,0x4c,0x31,0x06,0x39,0x46,
0x7a,0xd0,0x7a,0xd0,0xbc,0x18,0xed,0x5e,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xed,0x5e,0xa3,0x94,
0x5a,0x0c,0x49,0xca,0x6a,0xd4,0x73,0x16,
0xac,0xe4,0xde,0xb2,0xe6,0xf4,0xe6,0xf4,
0xad,0x26,0x6b,0x14,0x6a,0x90,0x39,0x46,
0xab,0xd6,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0x9b,0x54,0x31,0x46,0x31,0x8a,
0x21,0xd0,0x11,0x90,0x00,0x86,0x09,0x0c,
0x22,0x56,0x5b,0xe2,0xef,0xbe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xcd,0xec,
0x31,0x06,0x9b,0x54,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0x8b,0x52,0x31,0x4a,0x21,0x8e,0x01,0x0c,
0x02,0x16,0x03,0x24,0x03,0x64,0x03,0x64,
0x02,0x5a,0x01,0x0c,0x11,0x4c,0xa5,0xf0,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xd6,0x72,0x31,0x48,0x93,0x52,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0x93,0x54,
0x31,0x4a,0x10,0xc8,0x02,0x16,0x03,0xa8,
0x02,0xe0,0x01,0x4e,0x00,0xc8,0x01,0x90,
0x03,0x22,0x03,0xa8,0x02,0x5a,0x00,0x86,
0xa5,0xf0,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xde,0xf4,0x39,0x48,0x83,0x10,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xc4,0x58,0x39,0x8a,
0x21,0x8c,0x02,0x5a,0x03,0xa8,0x03,0x22,
0x00,0x86,0x00,0x00,0x00,0x00,0x00,0x00,
0x01,0x4e,0x03,0xa8,0x03,0xa8,0x02,0x5a,
0x09,0x4c,0xef,0x7c,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xde,0xb2,0x41,0x48,
0xc4,0x58,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x7a,0xd0,0x31,0x8e,
0x01,0x90,0x03,0xa8,0x03,0xa8,0x01,0x92,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x86,0x03,0xa8,0x03,0xa8,0x03,0xa8,
0x01,0x4e,0x53,0x9e,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0x73,0x14,
0x82,0xd0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x7b,0x14,0x21,0x4c,
0x03,0x22,0x03,0xa8,0x03,0x64,0x21,0x8e,
0x21,0x08,0x00,0x42,0x00,0x00,0x00,0x00,
0x00,0x86,0x03,0xa8,0x03,0xa8,0x03,0xa8,
0x02,0x9c,0x22,0x14,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xce,0x30,
0x51,0xca,0xf5,0x9e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x39,0x8a,0x11,0x08,
0x03,0x66,0x03,0x22,0x84,0xa4,0xef,0x7a,
0xef,0x7a,0x84,0x20,0x00,0x00,0x00,0x00,
0x00,0xca,0x03,0xa8,0x03,0xa8,0x03,0xa8,
0x03,0x64,0x01,0x0a,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xf7,0xbc,
0x52,0x0e,0xd4,0x9a,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x29,0x48,0x11,0x0a,
0x03,0xa6,0x33,0x60,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0x18,0xc6,0x00,0x02,
0x02,0xde,0x03,0xa8,0x03,0xa8,0x03,0xa8,
0x03,0x66,0x00,0x88,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0x6a,0xd4,0x82,0xd0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x5a,0x50,0x19,0x4a,
0x03,0x64,0x74,0x64,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0x5b,0x18,0x02,0x5a,
0x03,0xa8,0x03,0xa8,0x03,0xa8,0x03,0xa8,
0x03,0x22,0x09,0x4c,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xbd,0x68,0x72,0x8e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x83,0x54,0x21,0x4a,
0x02,0x16,0x5c,0x24,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0x4b,0x5c,0x03,0xa8,
0x03,0xa8,0x03,0xa8,0x03,0xa8,0x03,0xa8,
0x01,0xd6,0x22,0x56,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0x9c,0xa0,0x7a,0x8e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xdc,0xdc,0x29,0x48,
0x01,0x0a,0x13,0x20,0xe7,0x38,0xff,0xfe,
0xff,0xfe,0xef,0x7a,0x0a,0x9a,0x03,0xa8,
0x03,0xa8,0x03,0xa8,0x03,0xa8,0x03,0x66,
0x00,0xca,0x85,0x2a,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0x62,0x92,0x7a,0xd0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0x8b,0x96,
0x10,0xc6,0x01,0x4e,0x23,0x1e,0xa5,0x6c,
0xa5,0x6a,0x2b,0x1e,0x03,0x66,0x03,0xa8,
0x03,0xa8,0x03,0xa8,0x03,0x20,0x01,0x0a,
0x3b,0x1c,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xef,0x7a,
0x41,0x8a,0xc4,0x98,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xed,0x5e,
0x6a,0xd2,0x08,0x86,0x00,0x84,0x01,0xd4,
0x03,0x22,0x03,0x64,0x03,0x64,0x03,0x20,
0x01,0xd6,0x01,0x4e,0x00,0xc8,0x53,0xe2,
0xf7,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0x62,0xd4,
0x72,0x8e,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xd5,0x1e,0x52,0x94,0x08,0x86,
0x00,0x86,0x00,0x84,0x00,0xca,0x1a,0x56,
0x2a,0x56,0x64,0x66,0xce,0xf8,0xff,0xfe,
0xff,0xfe,0xff,0xfe,0xff,0xfe,0xff,0xfe,
0xff,0xfe,0xe7,0x38,0x62,0xd6,0x5a,0x0c,
0xed,0x5e,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xac,0x5a,0x62,0x92,0x4a,0x10,0x7b,0xde,
0x6b,0x5a,0x73,0x9c,0xad,0x6a,0xe7,0x38,
0xe7,0x38,0xe7,0x38,0xa5,0x28,0x6b,0x5a,
0x73,0x5a,0x31,0x48,0x7a,0xd0,0xf5,0x9e,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0x9e,0xe5,0x1e,0xb4,0x18,
0x83,0x14,0x7b,0x14,0x83,0x98,0x5a,0x92,
0x29,0x48,0x4a,0x0e,0x7b,0x16,0x7b,0x14,
0xcc,0x9a,0xed,0x5e,0xf5,0x9e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x6a,0x4e,0x5a,0x0c,
0x62,0x0c,0x9b,0x94,0xed,0x5e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x51,0xca,0x00,0x00,
0x08,0x40,0x08,0x00,0x49,0xca,0xb4,0x16,
0xd4,0xda,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x8b,0x12,0x18,0x82,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x18,0x82,0x51,0xca,0xb4,0x16,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0x9e,0xbc,0x58,
0x51,0xca,0x08,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x51,0xca,
0xb4,0x16,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x5e,0xb4,0x16,0x5a,0x0a,0x08,0x42,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0x00,0x31,0x46,0x7a,0x8e,0xbc,0x58,
0xe5,0x1e,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xc4,0x58,
0x5a,0x0c,0x10,0x42,0x00,0x00,0x08,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x41,0x88,0xab,0xd6,0xf5,0x5e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xcc,0x9a,0x7a,0xd0,0x9b,0x94,
0x8b,0x52,0x7a,0xd0,0x39,0x48,0x20,0xc4,
0x7a,0xd0,0x7a,0xd0,0x83,0x12,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xe2,
/* name:refmap  type:RGBA  pixel/bit: 16 bits
  offset:0x00002000  length:2048 bytes. */
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x18,0xc9,0x10,0x87,0x08,0x43,0x08,0x01,
0x08,0x43,0x08,0x43,0x08,0x43,0x21,0x09,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x45,0x20,0xc7,
0x10,0x85,0x10,0x85,0x10,0x85,0x10,0x85,
0x10,0x85,0x10,0x85,0x10,0x85,0x10,0x45,
0x10,0x85,0x10,0x43,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0x43,0x18,0xc7,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x10,0x85,0x21,0x09,
0x10,0x85,0x10,0x85,0x10,0x45,0x10,0x43,
0x10,0x45,0x10,0x43,0x10,0x85,0x10,0x43,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x21,0x09,0x18,0xc7,
0x21,0x09,0x21,0x07,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x20,0xc7,0x10,0x85,0x10,0x45,0x10,0x43,
0x18,0x85,0x08,0x01,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x08,0x43,0x18,0xc7,0x21,0x09,
0x10,0x85,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x20,0xc7,0x20,0xc7,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x18,0xc7,0x08,0x03,
0x10,0x85,0x18,0x85,0x08,0x43,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0x43,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x18,0xc7,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x18,0xc7,
0x18,0x87,0x10,0x43,0x10,0x43,0x10,0x85,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc7,
0x08,0x43,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x18,0x87,0x20,0xc7,
0x18,0xc7,0x18,0x85,0x10,0x45,0x20,0xc9,
0x10,0x85,0x10,0x85,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x10,0x85,0x10,0x43,0x10,0x43,
0x20,0xc7,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x43,
0x18,0xc5,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x10,0x85,0x08,0x43,0x08,0x43,
0x10,0x43,0x10,0x43,0x10,0x45,0x10,0x45,
0x10,0x85,0x18,0x87,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x08,0x43,0x10,0x43,
0x10,0x43,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x87,0x10,0x43,
0x20,0xc5,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x10,0x85,0x08,0x43,0x08,0x43,
0x08,0x43,0x08,0x43,0x10,0x45,0x10,0x85,
0x10,0x85,0x21,0x09,0x10,0x85,0x21,0x09,
0x21,0x09,0x21,0x07,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x10,0x85,
0x10,0x43,0x18,0xc7,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x85,0x10,0x43,
0x20,0xc5,0x20,0xc5,0x21,0x09,0x21,0x09,
0x08,0x01,0x10,0x43,0x10,0x43,0x18,0x85,
0x10,0x43,0x08,0x43,0x10,0x45,0x21,0x09,
0x10,0x85,0x10,0x85,0x10,0x85,0x21,0x09,
0x21,0x0b,0x21,0x0b,0x08,0x43,0x21,0x0b,
0x21,0x0b,0x21,0x09,0x21,0x07,0x21,0x09,
0x08,0x43,0x18,0x85,0x00,0x00,0x00,0x00,
0x00,0x00,0x18,0xc7,0x08,0x43,0x10,0x43,
0x20,0xc5,0x20,0xc5,0x21,0x09,0x10,0x43,
0x10,0x43,0x10,0x83,0x18,0x83,0x18,0x83,
0x18,0xc7,0x18,0xc7,0x10,0x85,0x10,0x85,
0x10,0x85,0x10,0x85,0x10,0x85,0x21,0x0b,
0x21,0x0b,0x21,0x0b,0x21,0x0b,0x21,0x09,
0x21,0x09,0x20,0xc5,0x20,0xc5,0x21,0x09,
0x18,0xc7,0x10,0x43,0x08,0x01,0x00,0x00,
0x00,0x00,0x10,0x87,0x08,0x43,0x10,0x85,
0x18,0x85,0x21,0x09,0x21,0x09,0x08,0x41,
0x18,0x85,0x20,0xc7,0x20,0xc7,0x10,0x83,
0x10,0x43,0x10,0x43,0x10,0x85,0x10,0x85,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x21,0x09,
0x21,0x0b,0x21,0x09,0x20,0xc5,0x20,0xc5,
0x20,0xc5,0x20,0xc5,0x18,0x85,0x21,0x07,
0x10,0x85,0x10,0x43,0x08,0x43,0x00,0x00,
0x00,0x00,0x10,0x85,0x08,0x01,0x21,0x09,
0x10,0x83,0x18,0x85,0x10,0x43,0x08,0x03,
0x18,0x85,0x18,0x85,0x18,0xc5,0x18,0xc7,
0x10,0x85,0x10,0x85,0x08,0x43,0x21,0x09,
0x18,0x85,0x10,0x85,0x10,0x85,0x10,0x85,
0x08,0x43,0x08,0x43,0x10,0x83,0x10,0x83,
0x08,0x43,0x08,0x43,0x21,0x09,0x10,0x83,
0x10,0x85,0x08,0x43,0x10,0x43,0x00,0x00,
0x18,0x87,0x08,0x43,0x08,0x01,0x21,0x09,
0x18,0x85,0x08,0x01,0x08,0x43,0x08,0x01,
0x08,0x01,0x08,0x01,0x08,0x01,0x08,0x03,
0x08,0x03,0x10,0x43,0x08,0x01,0x08,0x43,
0x08,0x43,0x08,0x43,0x08,0x43,0x08,0x43,
0x08,0x43,0x08,0x43,0x10,0x43,0x10,0x43,
0x08,0x43,0x08,0x43,0x21,0x09,0x10,0x85,
0x10,0x85,0x08,0x43,0x10,0x85,0x18,0x85,
0x10,0x87,0x08,0x43,0x08,0x43,0x10,0x85,
0x18,0x85,0x08,0x43,0x08,0x43,0x08,0x43,
0x08,0x43,0x10,0x83,0x21,0x09,0x21,0x07,
0x08,0x43,0x08,0x43,0x08,0x03,0x08,0x43,
0x08,0x43,0x10,0x43,0x10,0x85,0x08,0x45,
0x10,0x85,0x10,0x85,0x08,0x43,0x08,0x43,
0x08,0x43,0x08,0x03,0x21,0x09,0x18,0xc7,
0x18,0xc7,0x08,0x43,0x10,0x85,0x21,0x07,
0x10,0x85,0x08,0x43,0x10,0x43,0x08,0x43,
0x10,0x43,0x10,0x43,0x20,0xc7,0x21,0x07,
0x10,0x85,0x10,0x87,0x21,0x09,0x10,0x85,
0x10,0x85,0x08,0x43,0x08,0x03,0x10,0x45,
0x10,0x87,0x10,0x85,0x10,0x87,0x10,0x45,
0x08,0x43,0x10,0x87,0x08,0x43,0x10,0x45,
0x08,0x43,0x08,0x03,0x18,0xc7,0x18,0x85,
0x10,0x85,0x10,0x43,0x10,0x85,0x10,0x85,
0x10,0x85,0x08,0x03,0x08,0x43,0x08,0x43,
0x08,0x01,0x10,0x43,0x10,0x85,0x10,0x85,
0x10,0x85,0x10,0x87,0x10,0x85,0x10,0x43,
0x08,0x43,0x08,0x43,0x08,0x43,0x10,0x45,
0x10,0x87,0x10,0xc7,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x19,0x09,0x10,0x85,0x08,0x45,
0x08,0x45,0x08,0x03,0x08,0x43,0x10,0x85,
0x10,0x85,0x10,0x45,0x10,0x85,0x10,0x85,
0x10,0x85,0x08,0x43,0x10,0x85,0x18,0x87,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0x87,0x10,0x85,0x10,0x43,
0x10,0x85,0x08,0x43,0x08,0x43,0x18,0xc7,
0x18,0xc9,0x10,0xc7,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x10,0x85,0x10,0x85,
0x08,0x43,0x18,0x87,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0xc7,0x18,0x85,0x10,0x43,
0x08,0x43,0x10,0x43,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x20,0xc9,0x20,0xc9,0x21,0x09,
0x21,0x09,0x10,0x87,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x20,0xc9,0x10,0x85,
0x10,0x85,0x10,0x85,0x10,0x43,0x10,0x85,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x20,0xc7,0x18,0xc7,0x18,0xc7,
0x00,0x00,0x10,0x85,0x10,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x19,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x29,0x09,0x29,0x09,
0x21,0x09,0x21,0x09,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x00,0x00,
0x00,0x00,0x10,0x85,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x21,0x09,
0x21,0x09,0x10,0x45,0x21,0x0b,0x21,0x0b,
0x29,0x4b,0x29,0x4b,0x29,0x4d,0x29,0x4b,
0x29,0x4b,0x29,0x0b,0x21,0x09,0x21,0x0b,
0x21,0x09,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc7,0x18,0xc7,0x18,0xc9,0x00,0x00,
0x00,0x00,0x10,0x87,0x18,0xc7,0x18,0xc9,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x21,0x09,0x21,0x09,
0x21,0x09,0x29,0x0b,0x21,0x0b,0x29,0x4b,
0x29,0x4d,0x31,0x8d,0x31,0x8f,0x39,0xcf,
0x31,0x8f,0x31,0x8d,0x29,0x4b,0x21,0x0b,
0x21,0x0b,0x21,0x09,0x18,0xc9,0x18,0xc7,
0x18,0xc7,0x18,0xc9,0x18,0xc9,0x00,0x00,
0x00,0x00,0x00,0x00,0x18,0xc7,0x18,0xc9,
0x18,0xc9,0x18,0xc7,0x18,0xc7,0x18,0xc9,
0x20,0xc9,0x21,0x09,0x19,0x09,0x21,0x09,
0x21,0x0b,0x21,0x0b,0x29,0x4d,0x29,0x4d,
0x29,0x8f,0x39,0xd1,0x42,0x13,0x4a,0x53,
0x42,0x13,0x39,0xd1,0x31,0x8f,0x21,0x4b,
0x21,0x0b,0x21,0x09,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x20,0xc7,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x18,0xc7,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x19,0x09,
0x19,0x0b,0x29,0x4b,0x21,0x4d,0x29,0x8f,
0x39,0xd1,0x52,0x97,0x6b,0x9f,0x73,0x9f,
0x6b,0x5d,0x52,0x95,0x31,0xd1,0x29,0x4d,
0x21,0x0b,0x21,0x09,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x19,0x0b,0x21,0x0b,0x21,0x4d,0x31,0x8f,
0x42,0x55,0x7c,0x23,0xb5,0xf1,0xde,0xf9,
0xb5,0xaf,0x73,0x9f,0x42,0x13,0x31,0x8d,
0x21,0x0b,0x18,0xc9,0x18,0xc9,0x21,0x09,
0x18,0xc9,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x09,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc7,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x19,0x0b,0x21,0x0b,0x29,0x4d,0x31,0xd1,
0x52,0x99,0x9c,0xe9,0xff,0xff,0xff,0xff,
0xe7,0x3b,0x84,0x23,0x4a,0x55,0x31,0x8f,
0x29,0x4b,0x18,0xc9,0x18,0xc9,0x21,0x09,
0x21,0x09,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x21,0x09,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc7,0x10,0xc9,0x18,0xc9,
0x18,0xc9,0x19,0x0b,0x21,0x4d,0x31,0xd1,
0x52,0xd9,0x94,0xe9,0xf7,0xbf,0xff,0xff,
0xc6,0x75,0x6b,0x5d,0x42,0x13,0x29,0x4d,
0x21,0x0b,0x19,0x09,0x18,0xc9,0x21,0x09,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x21,0x09,0x21,0x09,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x10,0xc9,0x10,0xc9,
0x18,0xc9,0x18,0xcb,0x21,0x0d,0x29,0x8f,
0x42,0x13,0x5b,0x1b,0x84,0x23,0x84,0x65,
0x6b,0x5d,0x42,0x13,0x29,0x4d,0x21,0x0b,
0x21,0x0b,0x19,0x0b,0x19,0x0b,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x21,0x09,0x21,0x0b,
0x19,0x09,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x18,0xcb,0x21,0x0b,
0x29,0x8f,0x39,0xd1,0x42,0x13,0x42,0x13,
0x31,0xd1,0x29,0x8f,0x21,0x0d,0x21,0x0b,
0x19,0x0b,0x19,0x0b,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x21,0x0b,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xcb,0x19,0x0b,0x19,0x0b,
0x21,0x0d,0x21,0x4d,0x29,0x4d,0x29,0x4d,
0x21,0x4d,0x21,0x0d,0x21,0x0b,0x19,0x0b,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x21,0x0b,0x19,0x0b,0x18,0xcb,
0x18,0xcb,0x19,0x0b,0x19,0x0b,0x21,0x0b,
0x21,0x0b,0x21,0x0b,0x21,0x0b,0x21,0x0b,
0x21,0x0b,0x19,0x0b,0x19,0x0b,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x19,0x0b,0x19,0x0b,0x19,0x0b,0x19,0x0b,
0x19,0x0b,0x19,0x0b,0x19,0x0b,0x21,0x0b,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
};

static Gfx _frake_kime_aligner1[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_324_[] = {
  {    44,     5,   -40,0, 0x0000,0x0000, 0x1e,0x54,0x54,0xff }, /*     0 */
  {   -44,     5,   -40,0, 0x0000,0x0000, 0x2a,0x75,0x75,0xff }, /*     1 */
  {    40,    31,   -38,0, 0x0000,0x0000, 0x5a,0x97,0x97,0xff }, /*     2 */
  {   -11,   107,    -2,0, 0x0000,0x0000, 0x8b,0xe8,0xe8,0xff }, /*     3 */
  {    11,   107,   -25,0, 0x0000,0x0000, 0x89,0xe4,0xe4,0xff }, /*     4 */
  {   -11,   107,   -25,0, 0x0000,0x0000, 0x80,0xd6,0xd6,0xff }, /*     5 */
  {   -11,   107,    -2,0, 0x0000,0x0000, 0x8b,0xe8,0xe8,0xff }, /*     6 */
  {    11,   107,    -2,0, 0x0000,0x0000, 0x8f,0xef,0xef,0xff }, /*     7 */
  {    11,   107,   -25,0, 0x0000,0x0000, 0x89,0xe4,0xe4,0xff }, /*     8 */
  {    41,    31,    28,0, 0x0000,0x0000, 0x6f,0xb9,0xb9,0xff }, /*     9 */
  {    40,    31,   -38,0, 0x0000,0x0000, 0x5a,0x97,0x97,0xff }, /*    10 */
  {    47,    98,     6,0, 0x0000,0x0000, 0x90,0xf1,0xf1,0xff }, /*    11 */
  {    41,    31,    28,0, 0x0000,0x0000, 0x6f,0xb9,0xb9,0xff }, /*    12 */
  {    44,     5,   -40,0, 0x0000,0x0000, 0x1e,0x54,0x54,0xff }, /*    13 */
  {    40,    31,   -38,0, 0x0000,0x0000, 0x5a,0x97,0x97,0xff }, /*    14 */
  {   -40,    31,   -38,0, 0x0000,0x0000, 0x67,0xac,0xac,0xff }, /*    15 */
  {   -47,    98,     6,0, 0x0000,0x0000, 0x64,0xa8,0xa8,0xff }, /*    16 */
  {   -46,    98,   -33,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*    17 */
  {   -47,    98,     6,0, 0x0000,0x0000, 0x64,0xa8,0xa8,0xff }, /*    18 */
  {   -11,   107,   -25,0, 0x0000,0x0000, 0x80,0xd6,0xd6,0xff }, /*    19 */
  {   -46,    98,   -33,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*    20 */
  {    41,    31,    28,0, 0x0000,0x0000, 0x6f,0xb9,0xb9,0xff }, /*    21 */
  {    44,     5,    31,0, 0x0000,0x0000, 0x2d,0x7f,0x7f,0xff }, /*    22 */
  {    44,     5,   -40,0, 0x0000,0x0000, 0x1e,0x54,0x54,0xff }, /*    23 */
  {   -46,    98,   -33,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*    24 */
  {    11,   107,   -25,0, 0x0000,0x0000, 0x89,0xe4,0xe4,0xff }, /*    25 */
  {    46,    98,   -33,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*    26 */
  {    46,    98,   -33,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*    27 */
  {    11,   107,   -25,0, 0x0000,0x0000, 0x89,0xe4,0xe4,0xff }, /*    28 */
  {    47,    98,     6,0, 0x0000,0x0000, 0x90,0xf1,0xf1,0xff }, /*    29 */
  {   -41,    31,    28,0, 0x0000,0x0000, 0x69,0xb0,0xb0,0xff }, /*    30 */
  {    44,     5,    31,0, 0x0000,0x0000, 0x2d,0x7f,0x7f,0xff }, /*    31 */
  {    41,    31,    28,0, 0x0000,0x0000, 0x6f,0xb9,0xb9,0xff }, /*    32 */
  {   -41,    31,    28,0, 0x0000,0x0000, 0x69,0xb0,0xb0,0xff }, /*    33 */
  {   -44,     5,    31,0, 0x0000,0x0000, 0x2e,0x80,0x80,0xff }, /*    34 */
  {    44,     5,    31,0, 0x0000,0x0000, 0x2d,0x7f,0x7f,0xff }, /*    35 */
  {   -40,    31,   -38,0, 0x0000,0x0000, 0x67,0xac,0xac,0xff }, /*    36 */
  {   -44,     5,   -40,0, 0x0000,0x0000, 0x2a,0x75,0x75,0xff }, /*    37 */
  {   -41,    31,    28,0, 0x0000,0x0000, 0x69,0xb0,0xb0,0xff }, /*    38 */
  {   -40,    31,   -38,0, 0x0000,0x0000, 0x67,0xac,0xac,0xff }, /*    39 */
  {   -46,    98,   -33,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*    40 */
  {    40,    31,   -38,0, 0x0000,0x0000, 0x5a,0x97,0x97,0xff }, /*    41 */
  {   -46,    98,   -33,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*    42 */
  {    46,    98,   -33,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*    43 */
  {    40,    31,   -38,0, 0x0000,0x0000, 0x5a,0x97,0x97,0xff }, /*    44 */
  {   -44,     5,   -40,0, 0x0000,0x0000, 0x2a,0x75,0x75,0xff }, /*    45 */
  {   -44,     5,    31,0, 0x0000,0x0000, 0x2e,0x80,0x80,0xff }, /*    46 */
  {   -41,    31,    28,0, 0x0000,0x0000, 0x69,0xb0,0xb0,0xff }, /*    47 */
  {    11,   107,   -25,0, 0x0000,0x0000, 0x89,0xe4,0xe4,0xff }, /*    48 */
  {    11,   107,    -2,0, 0x0000,0x0000, 0x8f,0xef,0xef,0xff }, /*    49 */
  {    47,    98,     6,0, 0x0000,0x0000, 0x90,0xf1,0xf1,0xff }, /*    50 */
  {   -46,    98,   -33,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*    51 */
  {   -11,   107,   -25,0, 0x0000,0x0000, 0x80,0xd6,0xd6,0xff }, /*    52 */
  {    11,   107,   -25,0, 0x0000,0x0000, 0x89,0xe4,0xe4,0xff }, /*    53 */
  {   -47,    98,     6,0, 0x0000,0x0000, 0x64,0xa8,0xa8,0xff }, /*    54 */
  {   -11,   107,    -2,0, 0x0000,0x0000, 0x8b,0xe8,0xe8,0xff }, /*    55 */
  {   -11,   107,   -25,0, 0x0000,0x0000, 0x80,0xd6,0xd6,0xff }, /*    56 */
  {   -40,    31,   -38,0, 0x0000,0x0000, 0x67,0xac,0xac,0xff }, /*    57 */
  {   -41,    31,    28,0, 0x0000,0x0000, 0x69,0xb0,0xb0,0xff }, /*    58 */
  {   -47,    98,     6,0, 0x0000,0x0000, 0x64,0xa8,0xa8,0xff }, /*    59 */
  {    40,    31,   -38,0, 0x0000,0x0000, 0x5a,0x97,0x97,0xff }, /*    60 */
  {    46,    98,   -33,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*    61 */
  {    47,    98,     6,0, 0x0000,0x0000, 0x90,0xf1,0xf1,0xff }, /*    62 */
  {   -44,     5,   -40,0, 0x0000,0x0000, 0x2a,0x75,0x75,0xff }, /*    63 */
  {   -40,    31,   -38,0, 0x0000,0x0000, 0x67,0xac,0xac,0xff }, /*    64 */
  {    40,    31,   -38,0, 0x0000,0x0000, 0x5a,0x97,0x97,0xff }, /*    65 */
  {    41,    31,    28,0, 0x0779,0x0000, 0xb9,0xb9,0xb9,0xff }, /*    66 */
  {    47,    98,     6,0, 0x07ff,0x070b, 0xf1,0xf1,0xf1,0xff }, /*    67 */
  {   -41,    31,    28,0, 0x0086,0x0000, 0xb0,0xb0,0xb0,0xff }, /*    68 */
  {    47,    98,     6,0, 0x07ff,0x070b, 0xf1,0xf1,0xf1,0xff }, /*    69 */
  {   -11,   107,    -2,0, 0x0302,0x0800, 0xe8,0xe8,0xe8,0xff }, /*    70 */
  {   -47,    98,     6,0, 0x0000,0x070b, 0xa8,0xa8,0xa8,0xff }, /*    71 */
  {    47,    98,     6,0, 0x07ff,0x070b, 0xf1,0xf1,0xf1,0xff }, /*    72 */
  {    11,   107,    -2,0, 0x04fd,0x0800, 0xef,0xef,0xef,0xff }, /*    73 */
  {   -11,   107,    -2,0, 0x0302,0x0800, 0xe8,0xe8,0xe8,0xff }, /*    74 */
  {    47,    98,     6,0, 0x07ff,0x070b, 0xf1,0xf1,0xf1,0xff }, /*    75 */
  {   -47,    98,     6,0, 0x0000,0x070b, 0xa8,0xa8,0xa8,0xff }, /*    76 */
  {   -41,    31,    28,0, 0x0086,0x0000, 0xb0,0xb0,0xb0,0xff }, /*    77 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_324_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP2Triangles(  3,  4,  5,  0,  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 30, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 992), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 1024), 14, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsDPPipeSync(),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0, TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0),
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,0), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    0, 0, 5, 5, 0, 0 ),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_324_ = {
  gfx_Shape_of___POLYHEDRON_324_,
  vtx_Shape_of___POLYHEDRON_324_, 78, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner2[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_338_[] = {
  {   -92,    45,     4,0, 0x0000,0x0000, 0xa1,0x74,0x53,0xff }, /*     0 */
  {   -52,    54,     5,0, 0x0000,0x0000, 0x9c,0x71,0x51,0xff }, /*     1 */
  {   -75,    71,     5,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*     2 */
  {   -92,    45,     4,0, 0x0000,0x0000, 0xa1,0x74,0x53,0xff }, /*     3 */
  {   -71,    30,     4,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*     4 */
  {   -52,    54,     5,0, 0x0000,0x0000, 0x9c,0x71,0x51,0xff }, /*     5 */
  {   -71,    30,   -20,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*     6 */
  {   -92,    45,   -20,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*     7 */
  {   -52,    54,   -22,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*     8 */
  {   -92,    45,   -20,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*     9 */
  {   -75,    71,   -22,0, 0x0000,0x0000, 0xf0,0xad,0x7d,0xff }, /*    10 */
  {   -52,    54,   -22,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    11 */
  {   -71,    30,     4,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    12 */
  {   -71,    30,   -20,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*    13 */
  {   -52,    54,     5,0, 0x0000,0x0000, 0x9c,0x71,0x51,0xff }, /*    14 */
  {   -92,    45,   -20,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    15 */
  {   -75,    71,     5,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*    16 */
  {   -75,    71,   -22,0, 0x0000,0x0000, 0xf0,0xad,0x7d,0xff }, /*    17 */
  {   -52,    54,     5,0, 0x0000,0x0000, 0x9c,0x71,0x51,0xff }, /*    18 */
  {   -56,    73,    -8,0, 0x0000,0x0000, 0xee,0xac,0x7c,0xff }, /*    19 */
  {   -75,    71,     5,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*    20 */
  {   -75,    71,     5,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*    21 */
  {   -56,    73,    -8,0, 0x0000,0x0000, 0xee,0xac,0x7c,0xff }, /*    22 */
  {   -75,    71,   -22,0, 0x0000,0x0000, 0xf0,0xad,0x7d,0xff }, /*    23 */
  {   -75,    71,   -22,0, 0x0000,0x0000, 0xf0,0xad,0x7d,0xff }, /*    24 */
  {   -56,    73,    -8,0, 0x0000,0x0000, 0xee,0xac,0x7c,0xff }, /*    25 */
  {   -52,    54,   -22,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    26 */
  {   -52,    54,   -22,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    27 */
  {   -56,    73,    -8,0, 0x0000,0x0000, 0xee,0xac,0x7c,0xff }, /*    28 */
  {   -52,    54,     5,0, 0x0000,0x0000, 0x9c,0x71,0x51,0xff }, /*    29 */
  {   -92,    45,   -20,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    30 */
  {   -92,    45,     4,0, 0x0000,0x0000, 0xa1,0x74,0x53,0xff }, /*    31 */
  {   -75,    71,     5,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*    32 */
  {   -71,    30,   -20,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*    33 */
  {   -52,    54,   -22,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    34 */
  {   -52,    54,     5,0, 0x0000,0x0000, 0x9c,0x71,0x51,0xff }, /*    35 */
  {   -71,    30,     4,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    36 */
  {   -88,    29,    -8,0, 0x0000,0x0000, 0x8f,0x3e,0x2c,0xff }, /*    37 */
  {   -71,    30,   -20,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*    38 */
  {   -71,    30,   -20,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*    39 */
  {   -88,    29,    -8,0, 0x0000,0x0000, 0x8f,0x3e,0x2c,0xff }, /*    40 */
  {   -92,    45,   -20,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    41 */
  {   -92,    45,   -20,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    42 */
  {   -88,    29,    -8,0, 0x0000,0x0000, 0x8f,0x3e,0x2c,0xff }, /*    43 */
  {   -92,    45,     4,0, 0x0000,0x0000, 0xa1,0x74,0x53,0xff }, /*    44 */
  {   -92,    45,     4,0, 0x0000,0x0000, 0xa1,0x74,0x53,0xff }, /*    45 */
  {   -88,    29,    -8,0, 0x0000,0x0000, 0x8f,0x3e,0x2c,0xff }, /*    46 */
  {   -71,    30,     4,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    47 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_338_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 16, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_338_ = {
  gfx_Shape_of___POLYHEDRON_338_,
  vtx_Shape_of___POLYHEDRON_338_, 48, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner3[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_340_[] = {
  {  -110,    15,    -1,0, 0x0000,0x0000, 0xdb,0x9e,0x71,0xff }, /*     0 */
  {   -74,    29,     3,0, 0x0000,0x0000, 0xe8,0xa8,0x78,0xff }, /*     1 */
  {   -92,    42,     3,0, 0x0000,0x0000, 0xf9,0xb4,0x81,0xff }, /*     2 */
  {  -110,    15,    -1,0, 0x0000,0x0000, 0xdb,0x9e,0x71,0xff }, /*     3 */
  {   -94,     3,    -1,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*     4 */
  {   -74,    29,     3,0, 0x0000,0x0000, 0xe8,0xa8,0x78,0xff }, /*     5 */
  {   -94,     3,   -15,0, 0x0000,0x0000, 0xa5,0x77,0x56,0xff }, /*     6 */
  {  -110,    15,   -15,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*     7 */
  {   -74,    29,   -19,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*     8 */
  {   -94,     3,    -1,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*     9 */
  {   -94,     3,   -15,0, 0x0000,0x0000, 0xa5,0x77,0x56,0xff }, /*    10 */
  {   -74,    29,     3,0, 0x0000,0x0000, 0xe8,0xa8,0x78,0xff }, /*    11 */
  {  -110,    15,   -15,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    12 */
  {   -92,    42,     3,0, 0x0000,0x0000, 0xf9,0xb4,0x81,0xff }, /*    13 */
  {   -92,    42,   -19,0, 0x0000,0x0000, 0xa8,0x79,0x57,0xff }, /*    14 */
  {   -74,    29,     3,0, 0x0000,0x0000, 0xe8,0xa8,0x78,0xff }, /*    15 */
  {   -77,    44,    -8,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    16 */
  {   -92,    42,     3,0, 0x0000,0x0000, 0xf9,0xb4,0x81,0xff }, /*    17 */
  {   -92,    42,     3,0, 0x0000,0x0000, 0xf9,0xb4,0x81,0xff }, /*    18 */
  {   -77,    44,    -8,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    19 */
  {   -92,    42,   -19,0, 0x0000,0x0000, 0xa8,0x79,0x57,0xff }, /*    20 */
  {   -92,    42,   -19,0, 0x0000,0x0000, 0xa8,0x79,0x57,0xff }, /*    21 */
  {   -77,    44,    -8,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    22 */
  {   -74,    29,   -19,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    23 */
  {   -74,    29,   -19,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    24 */
  {   -77,    44,    -8,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    25 */
  {   -74,    29,     3,0, 0x0000,0x0000, 0xe8,0xa8,0x78,0xff }, /*    26 */
  {  -110,    15,   -15,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    27 */
  {  -110,    15,    -1,0, 0x0000,0x0000, 0xdb,0x9e,0x71,0xff }, /*    28 */
  {   -92,    42,     3,0, 0x0000,0x0000, 0xf9,0xb4,0x81,0xff }, /*    29 */
  {   -94,     3,   -15,0, 0x0000,0x0000, 0xa5,0x77,0x56,0xff }, /*    30 */
  {   -74,    29,   -19,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    31 */
  {   -74,    29,     3,0, 0x0000,0x0000, 0xe8,0xa8,0x78,0xff }, /*    32 */
  {  -110,    15,   -15,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    33 */
  {   -92,    42,   -19,0, 0x0000,0x0000, 0xa8,0x79,0x57,0xff }, /*    34 */
  {   -74,    29,   -19,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    35 */
  {   -94,     3,   -15,0, 0x0000,0x0000, 0xa5,0x77,0x56,0xff }, /*    36 */
  {  -107,     2,    -8,0, 0x0000,0x0000, 0xab,0x7c,0x59,0xff }, /*    37 */
  {  -110,    15,   -15,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    38 */
  {  -110,    15,   -15,0, 0x0000,0x0000, 0xac,0x7c,0x59,0xff }, /*    39 */
  {  -107,     2,    -8,0, 0x0000,0x0000, 0xab,0x7c,0x59,0xff }, /*    40 */
  {  -110,    15,    -1,0, 0x0000,0x0000, 0xdb,0x9e,0x71,0xff }, /*    41 */
  {  -110,    15,    -1,0, 0x0000,0x0000, 0xdb,0x9e,0x71,0xff }, /*    42 */
  {  -107,     2,    -8,0, 0x0000,0x0000, 0xab,0x7c,0x59,0xff }, /*    43 */
  {   -94,     3,    -1,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    44 */
  {   -94,     3,    -1,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    45 */
  {  -107,     2,    -8,0, 0x0000,0x0000, 0xab,0x7c,0x59,0xff }, /*    46 */
  {   -94,     3,   -15,0, 0x0000,0x0000, 0xa5,0x77,0x56,0xff }, /*    47 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_340_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 16, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_340_ = {
  gfx_Shape_of___POLYHEDRON_340_,
  vtx_Shape_of___POLYHEDRON_340_, 48, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner4[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_342_[] = {
  {  -127,    -9,     2,0, 0x0000,0x0000, 0xe3,0xa4,0x76,0xff }, /*     0 */
  {  -103,    -5,     3,0, 0x0000,0x0000, 0xc5,0x8e,0x66,0xff }, /*     1 */
  {  -116,     3,     3,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*     2 */
  {  -127,    -9,     2,0, 0x0000,0x0000, 0xe3,0xa4,0x76,0xff }, /*     3 */
  {  -113,   -19,     2,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*     4 */
  {  -103,    -5,     3,0, 0x0000,0x0000, 0xc5,0x8e,0x66,0xff }, /*     5 */
  {  -113,   -19,   -24,0, 0x0000,0x0000, 0xa1,0x74,0x54,0xff }, /*     6 */
  {  -127,    -9,   -24,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*     7 */
  {  -103,    -5,   -19,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*     8 */
  {  -127,    -9,   -24,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*     9 */
  {  -116,     3,   -19,0, 0x0000,0x0000, 0x9f,0x73,0x53,0xff }, /*    10 */
  {  -103,    -5,   -19,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    11 */
  {  -113,   -19,     2,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    12 */
  {  -113,   -19,   -24,0, 0x0000,0x0000, 0xa1,0x74,0x54,0xff }, /*    13 */
  {  -103,    -5,     3,0, 0x0000,0x0000, 0xc5,0x8e,0x66,0xff }, /*    14 */
  {  -116,     3,   -19,0, 0x0000,0x0000, 0x9f,0x73,0x53,0xff }, /*    15 */
  {  -103,     7,    -8,0, 0x0000,0x0000, 0xd9,0x9d,0x71,0xff }, /*    16 */
  {  -103,    -5,   -19,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    17 */
  {  -127,    -9,   -24,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    18 */
  {  -116,     3,     3,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*    19 */
  {  -116,     3,   -19,0, 0x0000,0x0000, 0x9f,0x73,0x53,0xff }, /*    20 */
  {  -103,    -5,     3,0, 0x0000,0x0000, 0xc5,0x8e,0x66,0xff }, /*    21 */
  {  -103,     7,    -8,0, 0x0000,0x0000, 0xd9,0x9d,0x71,0xff }, /*    22 */
  {  -116,     3,     3,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*    23 */
  {  -127,    -9,     2,0, 0x0000,0x0000, 0xe3,0xa4,0x76,0xff }, /*    24 */
  {  -124,   -20,    -8,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*    25 */
  {  -113,   -19,     2,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    26 */
  {  -116,     3,     3,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*    27 */
  {  -103,     7,    -8,0, 0x0000,0x0000, 0xd9,0x9d,0x71,0xff }, /*    28 */
  {  -116,     3,   -19,0, 0x0000,0x0000, 0x9f,0x73,0x53,0xff }, /*    29 */
  {  -103,    -5,   -19,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    30 */
  {  -103,     7,    -8,0, 0x0000,0x0000, 0xd9,0x9d,0x71,0xff }, /*    31 */
  {  -103,    -5,     3,0, 0x0000,0x0000, 0xc5,0x8e,0x66,0xff }, /*    32 */
  {  -127,    -9,   -24,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    33 */
  {  -127,    -9,     2,0, 0x0000,0x0000, 0xe3,0xa4,0x76,0xff }, /*    34 */
  {  -116,     3,     3,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*    35 */
  {  -113,   -19,   -24,0, 0x0000,0x0000, 0xa1,0x74,0x54,0xff }, /*    36 */
  {  -103,    -5,   -19,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    37 */
  {  -103,    -5,     3,0, 0x0000,0x0000, 0xc5,0x8e,0x66,0xff }, /*    38 */
  {  -113,   -19,   -24,0, 0x0000,0x0000, 0xa1,0x74,0x54,0xff }, /*    39 */
  {  -124,   -20,    -8,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*    40 */
  {  -127,    -9,   -24,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    41 */
  {  -127,    -9,   -24,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    42 */
  {  -124,   -20,    -8,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*    43 */
  {  -127,    -9,     2,0, 0x0000,0x0000, 0xe3,0xa4,0x76,0xff }, /*    44 */
  {  -113,   -19,     2,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    45 */
  {  -124,   -20,    -8,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*    46 */
  {  -113,   -19,   -24,0, 0x0000,0x0000, 0xa1,0x74,0x54,0xff }, /*    47 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_342_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 16, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_342_ = {
  gfx_Shape_of___POLYHEDRON_342_,
  vtx_Shape_of___POLYHEDRON_342_, 48, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner5[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_336_[] = {
  {   -81,    69,     9,0, 0x0000,0x0000, 0x67,0xad,0xad,0xff }, /*     0 */
  {   -34,    80,     5,0, 0x0000,0x0000, 0x64,0xa7,0xa7,0xff }, /*     1 */
  {   -57,    97,     5,0, 0x0000,0x0000, 0x85,0xde,0xde,0xff }, /*     2 */
  {   -81,    69,     9,0, 0x0000,0x0000, 0x67,0xad,0xad,0xff }, /*     3 */
  {   -51,    48,     9,0, 0x0000,0x0000, 0x6c,0xb5,0xb5,0xff }, /*     4 */
  {   -34,    80,     5,0, 0x0000,0x0000, 0x64,0xa7,0xa7,0xff }, /*     5 */
  {   -51,    48,   -26,0, 0x0000,0x0000, 0x73,0xc1,0xc1,0xff }, /*     6 */
  {   -81,    69,   -26,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*     7 */
  {   -34,    80,   -22,0, 0x0000,0x0000, 0x80,0xd5,0xd5,0xff }, /*     8 */
  {   -81,    69,   -26,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*     9 */
  {   -57,    97,   -22,0, 0x0000,0x0000, 0x96,0xfb,0xfb,0xff }, /*    10 */
  {   -34,    80,   -22,0, 0x0000,0x0000, 0x80,0xd5,0xd5,0xff }, /*    11 */
  {   -51,    48,     9,0, 0x0000,0x0000, 0x6c,0xb5,0xb5,0xff }, /*    12 */
  {   -51,    48,   -26,0, 0x0000,0x0000, 0x73,0xc1,0xc1,0xff }, /*    13 */
  {   -34,    80,     5,0, 0x0000,0x0000, 0x64,0xa7,0xa7,0xff }, /*    14 */
  {   -81,    69,   -26,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*    15 */
  {   -57,    97,     5,0, 0x0000,0x0000, 0x85,0xde,0xde,0xff }, /*    16 */
  {   -57,    97,   -22,0, 0x0000,0x0000, 0x96,0xfb,0xfb,0xff }, /*    17 */
  {   -34,    80,     5,0, 0x0000,0x0000, 0x64,0xa7,0xa7,0xff }, /*    18 */
  {   -38,    99,    -8,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*    19 */
  {   -57,    97,     5,0, 0x0000,0x0000, 0x85,0xde,0xde,0xff }, /*    20 */
  {   -57,    97,     5,0, 0x0000,0x0000, 0x85,0xde,0xde,0xff }, /*    21 */
  {   -38,    99,    -8,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*    22 */
  {   -57,    97,   -22,0, 0x0000,0x0000, 0x96,0xfb,0xfb,0xff }, /*    23 */
  {   -57,    97,   -22,0, 0x0000,0x0000, 0x96,0xfb,0xfb,0xff }, /*    24 */
  {   -38,    99,    -8,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*    25 */
  {   -34,    80,   -22,0, 0x0000,0x0000, 0x80,0xd5,0xd5,0xff }, /*    26 */
  {   -34,    80,   -22,0, 0x0000,0x0000, 0x80,0xd5,0xd5,0xff }, /*    27 */
  {   -38,    99,    -8,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*    28 */
  {   -34,    80,     5,0, 0x0000,0x0000, 0x64,0xa7,0xa7,0xff }, /*    29 */
  {   -81,    69,   -26,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*    30 */
  {   -81,    69,     9,0, 0x0000,0x0000, 0x67,0xad,0xad,0xff }, /*    31 */
  {   -57,    97,     5,0, 0x0000,0x0000, 0x85,0xde,0xde,0xff }, /*    32 */
  {   -51,    48,   -26,0, 0x0000,0x0000, 0x73,0xc1,0xc1,0xff }, /*    33 */
  {   -34,    80,   -22,0, 0x0000,0x0000, 0x80,0xd5,0xd5,0xff }, /*    34 */
  {   -34,    80,     5,0, 0x0000,0x0000, 0x64,0xa7,0xa7,0xff }, /*    35 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_336_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 4, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_336_ = {
  gfx_Shape_of___POLYHEDRON_336_,
  vtx_Shape_of___POLYHEDRON_336_, 36, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner6[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_330_[] = {
  {    75,    71,     5,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*     0 */
  {    52,    54,     5,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*     1 */
  {    92,    45,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*     2 */
  {    52,    54,     5,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*     3 */
  {    71,    30,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*     4 */
  {    92,    45,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*     5 */
  {    52,    54,   -22,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*     6 */
  {    92,    45,   -20,0, 0x0000,0x0000, 0xc4,0x8e,0x66,0xff }, /*     7 */
  {    71,    30,   -20,0, 0x0000,0x0000, 0x87,0x61,0x46,0xff }, /*     8 */
  {    52,    54,   -22,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*     9 */
  {    75,    71,   -22,0, 0x0000,0x0000, 0xef,0xad,0x7c,0xff }, /*    10 */
  {    92,    45,   -20,0, 0x0000,0x0000, 0xc4,0x8e,0x66,0xff }, /*    11 */
  {    52,    54,     5,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*    12 */
  {    71,    30,   -20,0, 0x0000,0x0000, 0x87,0x61,0x46,0xff }, /*    13 */
  {    71,    30,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*    14 */
  {    75,    71,   -22,0, 0x0000,0x0000, 0xef,0xad,0x7c,0xff }, /*    15 */
  {    75,    71,     5,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*    16 */
  {    92,    45,   -20,0, 0x0000,0x0000, 0xc4,0x8e,0x66,0xff }, /*    17 */
  {    75,    71,     5,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*    18 */
  {    56,    73,    -8,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    19 */
  {    52,    54,     5,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*    20 */
  {    75,    71,   -22,0, 0x0000,0x0000, 0xef,0xad,0x7c,0xff }, /*    21 */
  {    56,    73,    -8,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    22 */
  {    75,    71,     5,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*    23 */
  {    52,    54,   -22,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    24 */
  {    56,    73,    -8,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    25 */
  {    75,    71,   -22,0, 0x0000,0x0000, 0xef,0xad,0x7c,0xff }, /*    26 */
  {    52,    54,     5,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*    27 */
  {    56,    73,    -8,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    28 */
  {    52,    54,   -22,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    29 */
  {    75,    71,     5,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*    30 */
  {    92,    45,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*    31 */
  {    92,    45,   -20,0, 0x0000,0x0000, 0xc4,0x8e,0x66,0xff }, /*    32 */
  {    52,    54,     5,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*    33 */
  {    52,    54,   -22,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    34 */
  {    71,    30,   -20,0, 0x0000,0x0000, 0x87,0x61,0x46,0xff }, /*    35 */
  {    92,    45,   -20,0, 0x0000,0x0000, 0xc4,0x8e,0x66,0xff }, /*    36 */
  {    88,    29,    -8,0, 0x0000,0x0000, 0x9e,0x44,0x31,0xff }, /*    37 */
  {    71,    30,   -20,0, 0x0000,0x0000, 0x87,0x61,0x46,0xff }, /*    38 */
  {    92,    45,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*    39 */
  {    88,    29,    -8,0, 0x0000,0x0000, 0x9e,0x44,0x31,0xff }, /*    40 */
  {    92,    45,   -20,0, 0x0000,0x0000, 0xc4,0x8e,0x66,0xff }, /*    41 */
  {    71,    30,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*    42 */
  {    88,    29,    -8,0, 0x0000,0x0000, 0x9e,0x44,0x31,0xff }, /*    43 */
  {    92,    45,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*    44 */
  {    71,    30,   -20,0, 0x0000,0x0000, 0x87,0x61,0x46,0xff }, /*    45 */
  {    88,    29,    -8,0, 0x0000,0x0000, 0x9e,0x44,0x31,0xff }, /*    46 */
  {    71,    30,     4,0, 0x0000,0x0000, 0xb8,0x85,0x60,0xff }, /*    47 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_330_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 16, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_330_ = {
  gfx_Shape_of___POLYHEDRON_330_,
  vtx_Shape_of___POLYHEDRON_330_, 48, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner7[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_332_[] = {
  {    92,    42,     3,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*     0 */
  {    74,    29,     3,0, 0x0000,0x0000, 0xb2,0x81,0x5d,0xff }, /*     1 */
  {   110,    15,    -1,0, 0x0000,0x0000, 0x9d,0x71,0x51,0xff }, /*     2 */
  {    74,    29,     3,0, 0x0000,0x0000, 0xb2,0x81,0x5d,0xff }, /*     3 */
  {    94,     3,    -1,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*     4 */
  {   110,    15,    -1,0, 0x0000,0x0000, 0x9d,0x71,0x51,0xff }, /*     5 */
  {    74,    29,   -19,0, 0x0000,0x0000, 0x8b,0x64,0x48,0xff }, /*     6 */
  {   110,    15,   -15,0, 0x0000,0x0000, 0x7b,0x59,0x40,0xff }, /*     7 */
  {    94,     3,   -15,0, 0x0000,0x0000, 0x85,0x60,0x45,0xff }, /*     8 */
  {    74,    29,   -19,0, 0x0000,0x0000, 0x8b,0x64,0x48,0xff }, /*     9 */
  {    92,    42,   -19,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    10 */
  {   110,    15,   -15,0, 0x0000,0x0000, 0x7b,0x59,0x40,0xff }, /*    11 */
  {    74,    29,     3,0, 0x0000,0x0000, 0xb2,0x81,0x5d,0xff }, /*    12 */
  {    94,     3,   -15,0, 0x0000,0x0000, 0x85,0x60,0x45,0xff }, /*    13 */
  {    94,     3,    -1,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    14 */
  {    92,    42,   -19,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    15 */
  {    92,    42,     3,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*    16 */
  {   110,    15,   -15,0, 0x0000,0x0000, 0x7b,0x59,0x40,0xff }, /*    17 */
  {    92,    42,     3,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*    18 */
  {    77,    44,    -8,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    19 */
  {    74,    29,     3,0, 0x0000,0x0000, 0xb2,0x81,0x5d,0xff }, /*    20 */
  {    92,    42,   -19,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    21 */
  {    77,    44,    -8,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    22 */
  {    92,    42,     3,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*    23 */
  {    74,    29,   -19,0, 0x0000,0x0000, 0x8b,0x64,0x48,0xff }, /*    24 */
  {    77,    44,    -8,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    25 */
  {    92,    42,   -19,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    26 */
  {    74,    29,     3,0, 0x0000,0x0000, 0xb2,0x81,0x5d,0xff }, /*    27 */
  {    77,    44,    -8,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    28 */
  {    74,    29,   -19,0, 0x0000,0x0000, 0x8b,0x64,0x48,0xff }, /*    29 */
  {    92,    42,     3,0, 0x0000,0x0000, 0xba,0x87,0x61,0xff }, /*    30 */
  {   110,    15,    -1,0, 0x0000,0x0000, 0x9d,0x71,0x51,0xff }, /*    31 */
  {   110,    15,   -15,0, 0x0000,0x0000, 0x7b,0x59,0x40,0xff }, /*    32 */
  {    74,    29,     3,0, 0x0000,0x0000, 0xb2,0x81,0x5d,0xff }, /*    33 */
  {    74,    29,   -19,0, 0x0000,0x0000, 0x8b,0x64,0x48,0xff }, /*    34 */
  {    94,     3,   -15,0, 0x0000,0x0000, 0x85,0x60,0x45,0xff }, /*    35 */
  {   110,    15,   -15,0, 0x0000,0x0000, 0x7b,0x59,0x40,0xff }, /*    36 */
  {   107,     2,    -8,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*    37 */
  {    94,     3,   -15,0, 0x0000,0x0000, 0x85,0x60,0x45,0xff }, /*    38 */
  {   110,    15,    -1,0, 0x0000,0x0000, 0x9d,0x71,0x51,0xff }, /*    39 */
  {   107,     2,    -8,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*    40 */
  {   110,    15,   -15,0, 0x0000,0x0000, 0x7b,0x59,0x40,0xff }, /*    41 */
  {    94,     3,    -1,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    42 */
  {   107,     2,    -8,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*    43 */
  {   110,    15,    -1,0, 0x0000,0x0000, 0x9d,0x71,0x51,0xff }, /*    44 */
  {    94,     3,   -15,0, 0x0000,0x0000, 0x85,0x60,0x45,0xff }, /*    45 */
  {   107,     2,    -8,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*    46 */
  {    94,     3,    -1,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    47 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_332_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 16, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_332_ = {
  gfx_Shape_of___POLYHEDRON_332_,
  vtx_Shape_of___POLYHEDRON_332_, 48, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner8[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_334_[] = {
  {   116,     3,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*     0 */
  {   103,    -5,     3,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*     1 */
  {   127,    -9,     2,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*     2 */
  {   103,    -5,     3,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*     3 */
  {   113,   -19,     2,0, 0x0000,0x0000, 0xc2,0x8c,0x65,0xff }, /*     4 */
  {   127,    -9,     2,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*     5 */
  {   103,    -5,   -19,0, 0x0000,0x0000, 0x6b,0x4d,0x37,0xff }, /*     6 */
  {   127,    -9,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*     7 */
  {   113,   -19,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*     8 */
  {   103,    -5,   -19,0, 0x0000,0x0000, 0x6b,0x4d,0x37,0xff }, /*     9 */
  {   116,     3,   -19,0, 0x0000,0x0000, 0xa3,0x76,0x55,0xff }, /*    10 */
  {   127,    -9,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    11 */
  {   103,    -5,     3,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*    12 */
  {   113,   -19,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    13 */
  {   113,   -19,     2,0, 0x0000,0x0000, 0xc2,0x8c,0x65,0xff }, /*    14 */
  {   116,     3,   -19,0, 0x0000,0x0000, 0xa3,0x76,0x55,0xff }, /*    15 */
  {   116,     3,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*    16 */
  {   127,    -9,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    17 */
  {   127,    -9,     2,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    18 */
  {   124,   -20,    -8,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*    19 */
  {   127,    -9,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    20 */
  {   116,     3,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*    21 */
  {   103,     7,    -8,0, 0x0000,0x0000, 0xd6,0x9b,0x6f,0xff }, /*    22 */
  {   103,    -5,     3,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*    23 */
  {   116,     3,   -19,0, 0x0000,0x0000, 0xa3,0x76,0x55,0xff }, /*    24 */
  {   103,     7,    -8,0, 0x0000,0x0000, 0xd6,0x9b,0x6f,0xff }, /*    25 */
  {   116,     3,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*    26 */
  {   103,    -5,   -19,0, 0x0000,0x0000, 0x6b,0x4d,0x37,0xff }, /*    27 */
  {   103,     7,    -8,0, 0x0000,0x0000, 0xd6,0x9b,0x6f,0xff }, /*    28 */
  {   116,     3,   -19,0, 0x0000,0x0000, 0xa3,0x76,0x55,0xff }, /*    29 */
  {   103,    -5,     3,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*    30 */
  {   103,     7,    -8,0, 0x0000,0x0000, 0xd6,0x9b,0x6f,0xff }, /*    31 */
  {   103,    -5,   -19,0, 0x0000,0x0000, 0x6b,0x4d,0x37,0xff }, /*    32 */
  {   116,     3,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*    33 */
  {   127,    -9,     2,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    34 */
  {   127,    -9,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    35 */
  {   103,    -5,     3,0, 0x0000,0x0000, 0xe5,0xa6,0x77,0xff }, /*    36 */
  {   103,    -5,   -19,0, 0x0000,0x0000, 0x6b,0x4d,0x37,0xff }, /*    37 */
  {   113,   -19,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    38 */
  {   127,    -9,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    39 */
  {   124,   -20,    -8,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*    40 */
  {   113,   -19,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    41 */
  {   113,   -19,     2,0, 0x0000,0x0000, 0xc2,0x8c,0x65,0xff }, /*    42 */
  {   124,   -20,    -8,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*    43 */
  {   127,    -9,     2,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    44 */
  {   113,   -19,   -24,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*    45 */
  {   124,   -20,    -8,0, 0x0000,0x0000, 0xcd,0x94,0x6a,0xff }, /*    46 */
  {   113,   -19,     2,0, 0x0000,0x0000, 0xc2,0x8c,0x65,0xff }, /*    47 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_334_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 16, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_334_ = {
  gfx_Shape_of___POLYHEDRON_334_,
  vtx_Shape_of___POLYHEDRON_334_, 48, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner9[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_328_[] = {
  {    57,    97,     5,0, 0x0000,0x0000, 0x6a,0xb1,0xb1,0xff }, /*     0 */
  {    34,    80,     5,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*     1 */
  {    81,    69,     9,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*     2 */
  {    34,    80,     5,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*     3 */
  {    51,    48,     9,0, 0x0000,0x0000, 0x72,0xbe,0xbe,0xff }, /*     4 */
  {    81,    69,     9,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*     5 */
  {    34,    80,   -22,0, 0x0000,0x0000, 0x88,0xe2,0xe2,0xff }, /*     6 */
  {    81,    69,   -26,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*     7 */
  {    51,    48,   -26,0, 0x0000,0x0000, 0x56,0x8f,0x8f,0xff }, /*     8 */
  {    34,    80,   -22,0, 0x0000,0x0000, 0x88,0xe2,0xe2,0xff }, /*     9 */
  {    57,    97,   -22,0, 0x0000,0x0000, 0x95,0xf9,0xf9,0xff }, /*    10 */
  {    81,    69,   -26,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*    11 */
  {    34,    80,     5,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*    12 */
  {    51,    48,   -26,0, 0x0000,0x0000, 0x56,0x8f,0x8f,0xff }, /*    13 */
  {    51,    48,     9,0, 0x0000,0x0000, 0x72,0xbe,0xbe,0xff }, /*    14 */
  {    57,    97,   -22,0, 0x0000,0x0000, 0x95,0xf9,0xf9,0xff }, /*    15 */
  {    57,    97,     5,0, 0x0000,0x0000, 0x6a,0xb1,0xb1,0xff }, /*    16 */
  {    81,    69,   -26,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*    17 */
  {    57,    97,     5,0, 0x0000,0x0000, 0x6a,0xb1,0xb1,0xff }, /*    18 */
  {    38,    99,    -8,0, 0x0000,0x0000, 0x81,0xd7,0xd7,0xff }, /*    19 */
  {    34,    80,     5,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*    20 */
  {    57,    97,   -22,0, 0x0000,0x0000, 0x95,0xf9,0xf9,0xff }, /*    21 */
  {    38,    99,    -8,0, 0x0000,0x0000, 0x81,0xd7,0xd7,0xff }, /*    22 */
  {    57,    97,     5,0, 0x0000,0x0000, 0x6a,0xb1,0xb1,0xff }, /*    23 */
  {    34,    80,   -22,0, 0x0000,0x0000, 0x88,0xe2,0xe2,0xff }, /*    24 */
  {    38,    99,    -8,0, 0x0000,0x0000, 0x81,0xd7,0xd7,0xff }, /*    25 */
  {    57,    97,   -22,0, 0x0000,0x0000, 0x95,0xf9,0xf9,0xff }, /*    26 */
  {    34,    80,     5,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*    27 */
  {    38,    99,    -8,0, 0x0000,0x0000, 0x81,0xd7,0xd7,0xff }, /*    28 */
  {    34,    80,   -22,0, 0x0000,0x0000, 0x88,0xe2,0xe2,0xff }, /*    29 */
  {    57,    97,     5,0, 0x0000,0x0000, 0x6a,0xb1,0xb1,0xff }, /*    30 */
  {    81,    69,     9,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*    31 */
  {    81,    69,   -26,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*    32 */
  {    34,    80,     5,0, 0x0000,0x0000, 0x7b,0xce,0xce,0xff }, /*    33 */
  {    34,    80,   -22,0, 0x0000,0x0000, 0x88,0xe2,0xe2,0xff }, /*    34 */
  {    51,    48,   -26,0, 0x0000,0x0000, 0x56,0x8f,0x8f,0xff }, /*    35 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_328_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 4, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_328_ = {
  gfx_Shape_of___POLYHEDRON_328_,
  vtx_Shape_of___POLYHEDRON_328_, 36, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner10[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_293_[] = {
  {    57,   188,     0,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*     0 */
  {    36,   132,   -52,0, 0x0000,0x0000, 0x00,0x26,0x4c,0xff }, /*     1 */
  {    51,   178,   -65,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*     2 */
  {    51,   178,   -65,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*     3 */
  {     0,   132,   -74,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*     4 */
  {     0,   168,   -91,0, 0x0000,0x0000, 0x00,0x36,0x6c,0xff }, /*     5 */
  {     0,   168,   -91,0, 0x0000,0x0000, 0x00,0x36,0x6c,0xff }, /*     6 */
  {     0,   132,   -74,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*     7 */
  {   -51,   178,   -65,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*     8 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x00,0x3f,0x7e,0xff }, /*     9 */
  {    73,   158,    -6,0, 0x0000,0x0000, 0x00,0x40,0x80,0xff }, /*    10 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x00,0x27,0x4f,0xff }, /*    11 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*    12 */
  {   -65,   158,    -6,0, 0x0000,0x0000, 0x00,0x3a,0x75,0xff }, /*    13 */
  {   -57,   188,     0,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*    14 */
  {   -73,   158,    -6,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*    15 */
  {   -57,   115,   -36,0, 0x0000,0x0000, 0x00,0x00,0x3f,0xff }, /*    16 */
  {   -65,   158,    -6,0, 0x0000,0x0000, 0x00,0x3a,0x75,0xff }, /*    17 */
  {    -4,   140,  -108,0, 0x0000,0x0000, 0x00,0x2f,0x5f,0xff }, /*    18 */
  {   -56,   148,   -81,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*    19 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x00,0x3b,0x77,0xff }, /*    20 */
  {   -51,   178,   -65,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*    21 */
  {   -36,   132,   -52,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*    22 */
  {   -57,   188,     0,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*    23 */
  {   -57,   188,     0,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*    24 */
  {   -52,   132,     0,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    25 */
  {   -36,   132,    52,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    26 */
  {    57,   188,     0,0, 0x0000,0x0000, 0xab,0x7c,0x59,0xff }, /*    27 */
  {    42,   170,    65,0, 0x0000,0x0000, 0xbf,0x5a,0x3b,0xff }, /*    28 */
  {    36,   132,    52,0, 0x0000,0x0000, 0xa7,0x79,0x57,0xff }, /*    29 */
  {    42,   170,    65,0, 0x0000,0x0000, 0xbf,0x5a,0x3b,0xff }, /*    30 */
  {    57,   188,     0,0, 0x0000,0x0000, 0xab,0x7c,0x59,0xff }, /*    31 */
  {    42,   204,    49,0, 0x0000,0x0000, 0x87,0x61,0x46,0xff }, /*    32 */
  {    52,   132,     0,0, 0x0000,0x0000, 0xb5,0x83,0x5e,0xff }, /*    33 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*    34 */
  {    36,   132,   -52,0, 0x0000,0x0000, 0x7a,0x58,0x3f,0xff }, /*    35 */
  {    11,   114,   -20,0, 0x0000,0x0000, 0x79,0x58,0x3f,0xff }, /*    36 */
  {     0,   114,   -28,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    37 */
  {     0,   132,   -74,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    38 */
  {    36,   132,   -52,0, 0x0000,0x0000, 0x7a,0x58,0x3f,0xff }, /*    39 */
  {    11,   114,   -20,0, 0x0000,0x0000, 0x79,0x58,0x3f,0xff }, /*    40 */
  {     0,   132,   -74,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    41 */
  {     0,   132,   -74,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    42 */
  {   -11,   114,   -20,0, 0x0000,0x0000, 0xc8,0x91,0x68,0xff }, /*    43 */
  {   -36,   132,   -52,0, 0x0000,0x0000, 0xbe,0x89,0x63,0xff }, /*    44 */
  {     0,   132,   -74,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    45 */
  {     0,   114,   -28,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    46 */
  {   -11,   114,   -20,0, 0x0000,0x0000, 0xc8,0x91,0x68,0xff }, /*    47 */
  {   -36,   132,   -52,0, 0x0000,0x0000, 0xbe,0x89,0x63,0xff }, /*    48 */
  {   -15,   114,     0,0, 0x0000,0x0000, 0xbc,0x88,0x62,0xff }, /*    49 */
  {   -52,   132,     0,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    50 */
  {   -52,   132,     0,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    51 */
  {   -15,   114,     0,0, 0x0000,0x0000, 0xbc,0x88,0x62,0xff }, /*    52 */
  {   -36,   132,    52,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    53 */
  {   -36,   132,    52,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    54 */
  {   -18,   114,    20,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*    55 */
  {     0,   114,    28,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*    56 */
  {     0,   114,    28,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*    57 */
  {    18,   114,    20,0, 0x0000,0x0000, 0xa8,0x7a,0x57,0xff }, /*    58 */
  {    36,   132,    52,0, 0x0000,0x0000, 0xa7,0x79,0x57,0xff }, /*    59 */
  {    36,   132,    52,0, 0x0000,0x0000, 0xa7,0x79,0x57,0xff }, /*    60 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*    61 */
  {    52,   132,     0,0, 0x0000,0x0000, 0xb5,0x83,0x5e,0xff }, /*    62 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x27,0x00,0x4f,0xff }, /*    63 */
  {    57,   201,   -84,0, 0x0000,0x0000, 0x28,0x00,0x50,0xff }, /*    64 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x3f,0x00,0x7e,0xff }, /*    65 */
  {    73,   214,     0,0, 0x0000,0x0000, 0x3e,0x00,0x7c,0xff }, /*    66 */
  {    51,   229,    48,0, 0x0000,0x0000, 0x3e,0x00,0x7d,0xff }, /*    67 */
  {    64,   204,    47,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*    68 */
  {    64,   204,    47,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*    69 */
  {    51,   229,    48,0, 0x0000,0x0000, 0x3e,0x00,0x7d,0xff }, /*    70 */
  {     0,   210,    68,0, 0x0000,0x0000, 0x2d,0x00,0x5b,0xff }, /*    71 */
  {   -64,   204,    47,0, 0x0000,0x0000, 0x33,0x00,0x66,0xff }, /*    72 */
  {   -51,   229,    48,0, 0x0000,0x0000, 0x33,0x00,0x66,0xff }, /*    73 */
  {   -73,   214,     0,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*    74 */
  {     0,   210,    68,0, 0x0000,0x0000, 0x2d,0x00,0x5b,0xff }, /*    75 */
  {   -51,   229,    48,0, 0x0000,0x0000, 0x33,0x00,0x66,0xff }, /*    76 */
  {   -64,   204,    47,0, 0x0000,0x0000, 0x33,0x00,0x66,0xff }, /*    77 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x3b,0x00,0x76,0xff }, /*    78 */
  {   -57,   201,   -84,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*    79 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x3b,0x00,0x77,0xff }, /*    80 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x3b,0x00,0x77,0xff }, /*    81 */
  {     0,   193,  -119,0, 0x0000,0x0000, 0x2f,0x00,0x5e,0xff }, /*    82 */
  {     0,   168,  -112,0, 0x0000,0x0000, 0x31,0x00,0x62,0xff }, /*    83 */
  {     0,   168,  -112,0, 0x0000,0x0000, 0x31,0x00,0x62,0xff }, /*    84 */
  {     0,   193,  -119,0, 0x0000,0x0000, 0x2f,0x00,0x5e,0xff }, /*    85 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x27,0x00,0x4f,0xff }, /*    86 */
  {    36,   132,    52,0, 0x0000,0x0000, 0xa7,0x79,0x57,0xff }, /*    87 */
  {    52,   132,     0,0, 0x0000,0x0000, 0xb5,0x83,0x5e,0xff }, /*    88 */
  {    57,   188,     0,0, 0x0000,0x0000, 0xab,0x7c,0x59,0xff }, /*    89 */
  {   -36,   132,    52,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    90 */
  {   -42,   170,    65,0, 0x0000,0x0000, 0x9c,0x4a,0x30,0xff }, /*    91 */
  {   -57,   188,     0,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*    92 */
  {     0,   114,    28,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*    93 */
  {    36,   132,    52,0, 0x0000,0x0000, 0xa7,0x79,0x57,0xff }, /*    94 */
  {   -36,   132,    52,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*    95 */
  {   -57,   188,     0,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*    96 */
  {   -71,   160,    11,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*    97 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*    98 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*    99 */
  {   -64,   174,    43,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   100 */
  {   -64,   204,    47,0, 0x0000,0x0000, 0x00,0x33,0x66,0xff }, /*   101 */
  {   -71,   160,    11,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   102 */
  {   -66,   138,    24,0, 0x0000,0x0000, 0x00,0x00,0x3c,0xff }, /*   103 */
  {   -64,   174,    43,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   104 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   105 */
  {   -71,   160,    11,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   106 */
  {   -64,   174,    43,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   107 */
  {   -64,   204,    47,0, 0x0000,0x0000, 0x00,0x33,0x66,0xff }, /*   108 */
  {   -56,   174,    44,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   109 */
  {   -42,   204,    49,0, 0x0000,0x0000, 0x00,0x36,0x6c,0xff }, /*   110 */
  {    42,   204,    49,0, 0x0000,0x0000, 0x00,0x2a,0x54,0xff }, /*   111 */
  {    56,   174,    44,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   112 */
  {    64,   204,    47,0, 0x0000,0x0000, 0x00,0x3d,0x7b,0xff }, /*   113 */
  {   -65,   160,    12,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   114 */
  {   -66,   138,    24,0, 0x0000,0x0000, 0x00,0x00,0x3c,0xff }, /*   115 */
  {   -71,   160,    11,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   116 */
  {   -64,   174,    43,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   117 */
  {   -66,   138,    24,0, 0x0000,0x0000, 0x00,0x00,0x3c,0xff }, /*   118 */
  {   -56,   174,    44,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   119 */
  {    65,   158,    -6,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   120 */
  {    57,   115,   -36,0, 0x0000,0x0000, 0x00,0x00,0x3c,0xff }, /*   121 */
  {    73,   158,    -6,0, 0x0000,0x0000, 0x00,0x40,0x80,0xff }, /*   122 */
  {    56,   174,    44,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   123 */
  {    64,   174,    43,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   124 */
  {    64,   204,    47,0, 0x0000,0x0000, 0x00,0x3d,0x7b,0xff }, /*   125 */
  {    64,   204,    47,0, 0x0000,0x0000, 0x00,0x3d,0x7b,0xff }, /*   126 */
  {    64,   174,    43,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   127 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x00,0x3f,0x7e,0xff }, /*   128 */
  {    64,   174,    43,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   129 */
  {    66,   138,    24,0, 0x0000,0x0000, 0x00,0x00,0x3f,0xff }, /*   130 */
  {    71,   160,    11,0, 0x0000,0x0000, 0x00,0x26,0x4d,0xff }, /*   131 */
  {    64,   174,    43,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   132 */
  {    71,   160,    11,0, 0x0000,0x0000, 0x00,0x26,0x4d,0xff }, /*   133 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x00,0x3f,0x7e,0xff }, /*   134 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x00,0x3f,0x7e,0xff }, /*   135 */
  {    71,   160,    11,0, 0x0000,0x0000, 0x00,0x26,0x4d,0xff }, /*   136 */
  {    57,   188,     0,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   137 */
  {    56,   174,    44,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   138 */
  {    66,   138,    24,0, 0x0000,0x0000, 0x00,0x00,0x3f,0xff }, /*   139 */
  {    64,   174,    43,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   140 */
  {    51,   178,   -65,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   141 */
  {    36,   132,   -52,0, 0x0000,0x0000, 0x00,0x26,0x4c,0xff }, /*   142 */
  {     0,   132,   -74,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   143 */
  {    71,   160,    11,0, 0x0000,0x0000, 0x00,0x26,0x4d,0xff }, /*   144 */
  {    66,   138,    24,0, 0x0000,0x0000, 0x00,0x00,0x3f,0xff }, /*   145 */
  {    65,   160,    12,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   146 */
  {    57,   188,     0,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   147 */
  {    65,   158,    -6,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   148 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x00,0x3f,0x7e,0xff }, /*   149 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x00,0x27,0x4f,0xff }, /*   150 */
  {    54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   151 */
  {    51,   178,   -65,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   152 */
  {    73,   158,    -6,0, 0x0000,0x0000, 0x00,0x40,0x80,0xff }, /*   153 */
  {    57,   115,   -36,0, 0x0000,0x0000, 0x00,0x00,0x3c,0xff }, /*   154 */
  {    54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   155 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x00,0x3b,0x77,0xff }, /*   156 */
  {   -56,   148,   -81,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   157 */
  {   -47,   148,   -68,0, 0x0000,0x0000, 0x00,0x30,0x61,0xff }, /*   158 */
  {    57,   188,     0,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   159 */
  {    52,   132,     0,0, 0x0000,0x0000, 0x00,0x38,0x70,0xff }, /*   160 */
  {    36,   132,   -52,0, 0x0000,0x0000, 0x00,0x26,0x4c,0xff }, /*   161 */
  {    54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   162 */
  {    57,   115,   -36,0, 0x0000,0x0000, 0x00,0x00,0x3c,0xff }, /*   163 */
  {    54,   149,   -60,0, 0x0000,0x0000, 0x00,0x42,0x85,0xff }, /*   164 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x00,0x3b,0x77,0xff }, /*   165 */
  {   -73,   158,    -6,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   166 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   167 */
  {   -36,   132,   -52,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   168 */
  {   -52,   132,     0,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   169 */
  {   -57,   188,     0,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*   170 */
  {   -51,   178,   -65,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   171 */
  {   -54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   172 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x00,0x3b,0x77,0xff }, /*   173 */
  {   -54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   174 */
  {   -57,   115,   -36,0, 0x0000,0x0000, 0x00,0x00,0x3f,0xff }, /*   175 */
  {   -73,   158,    -6,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   176 */
  {   -57,   188,     0,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*   177 */
  {   -65,   160,    12,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   178 */
  {   -71,   160,    11,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   179 */
  {   -54,   149,   -60,0, 0x0000,0x0000, 0x00,0x47,0x8f,0xff }, /*   180 */
  {   -57,   115,   -36,0, 0x0000,0x0000, 0x00,0x00,0x3f,0xff }, /*   181 */
  {   -54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   182 */
  {    51,   178,   -65,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   183 */
  {    47,   148,   -68,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   184 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x00,0x27,0x4f,0xff }, /*   185 */
  {    47,   148,   -68,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   186 */
  {    28,   113,   -63,0, 0x0000,0x0000, 0x00,0x00,0x45,0xff }, /*   187 */
  {    56,   148,   -81,0, 0x0000,0x0000, 0x00,0x34,0x68,0xff }, /*   188 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x00,0x27,0x4f,0xff }, /*   189 */
  {     4,   140,  -108,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   190 */
  {     0,   168,  -112,0, 0x0000,0x0000, 0x00,0x31,0x62,0xff }, /*   191 */
  {     0,   168,  -112,0, 0x0000,0x0000, 0x00,0x31,0x62,0xff }, /*   192 */
  {     4,   140,  -108,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   193 */
  {     0,   168,   -91,0, 0x0000,0x0000, 0x00,0x36,0x6c,0xff }, /*   194 */
  {     4,   140,  -108,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   195 */
  {    28,   113,   -63,0, 0x0000,0x0000, 0x00,0x00,0x45,0xff }, /*   196 */
  {     4,   140,   -91,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   197 */
  {    56,   148,   -81,0, 0x0000,0x0000, 0x00,0x34,0x68,0xff }, /*   198 */
  {    28,   113,   -63,0, 0x0000,0x0000, 0x00,0x00,0x45,0xff }, /*   199 */
  {     4,   140,  -108,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   200 */
  {     0,   168,   -91,0, 0x0000,0x0000, 0x00,0x36,0x6c,0xff }, /*   201 */
  {    -4,   140,  -108,0, 0x0000,0x0000, 0x00,0x2f,0x5f,0xff }, /*   202 */
  {     0,   168,  -112,0, 0x0000,0x0000, 0x00,0x31,0x62,0xff }, /*   203 */
  {     0,   168,   -91,0, 0x0000,0x0000, 0x00,0x36,0x6c,0xff }, /*   204 */
  {    -4,   140,   -91,0, 0x0000,0x0000, 0x00,0x47,0x8f,0xff }, /*   205 */
  {    -4,   140,  -108,0, 0x0000,0x0000, 0x00,0x2f,0x5f,0xff }, /*   206 */
  {     0,   168,  -112,0, 0x0000,0x0000, 0x00,0x31,0x62,0xff }, /*   207 */
  {    -4,   140,  -108,0, 0x0000,0x0000, 0x00,0x2f,0x5f,0xff }, /*   208 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x00,0x3b,0x77,0xff }, /*   209 */
  {    65,   158,    -6,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   210 */
  {    73,   158,    -6,0, 0x0000,0x0000, 0x00,0x40,0x80,0xff }, /*   211 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x00,0x3f,0x7e,0xff }, /*   212 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x00,0x3b,0x77,0xff }, /*   213 */
  {   -47,   148,   -68,0, 0x0000,0x0000, 0x00,0x30,0x61,0xff }, /*   214 */
  {   -51,   178,   -65,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   215 */
  {    -4,   140,   -91,0, 0x0000,0x0000, 0x00,0x47,0x8f,0xff }, /*   216 */
  {   -28,   113,   -63,0, 0x0000,0x0000, 0x00,0x00,0x40,0xff }, /*   217 */
  {    -4,   140,  -108,0, 0x0000,0x0000, 0x00,0x2f,0x5f,0xff }, /*   218 */
  {    -4,   140,  -108,0, 0x0000,0x0000, 0x00,0x2f,0x5f,0xff }, /*   219 */
  {   -28,   113,   -63,0, 0x0000,0x0000, 0x00,0x00,0x40,0xff }, /*   220 */
  {   -56,   148,   -81,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   221 */
  {   -56,   148,   -81,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   222 */
  {   -28,   113,   -63,0, 0x0000,0x0000, 0x00,0x00,0x40,0xff }, /*   223 */
  {   -47,   148,   -68,0, 0x0000,0x0000, 0x00,0x30,0x61,0xff }, /*   224 */
  {   -42,   170,    65,0, 0x0000,0x0000, 0x9c,0x4a,0x30,0xff }, /*   225 */
  {   -42,   204,    49,0, 0x0000,0x0000, 0xad,0x7d,0x5a,0xff }, /*   226 */
  {   -57,   188,     0,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*   227 */
  {    64,   204,    47,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*   228 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x3f,0x00,0x7e,0xff }, /*   229 */
  {    73,   214,     0,0, 0x0000,0x0000, 0x3e,0x00,0x7c,0xff }, /*   230 */
  {   -73,   214,     0,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*   231 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x3b,0x00,0x76,0xff }, /*   232 */
  {   -64,   204,    47,0, 0x0000,0x0000, 0x33,0x00,0x66,0xff }, /*   233 */
  {     0,   275,    27,0, 0x0000,0x0000, 0xb9,0x8a,0x00,0xff }, /*   234 */
  {    -6,   247,    66,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   235 */
  {     0,   236,    62,0, 0x0000,0x0000, 0xa3,0x79,0x00,0xff }, /*   236 */
  {     0,   236,    62,0, 0x0000,0x0000, 0xa3,0x79,0x00,0xff }, /*   237 */
  {   -50,   241,    55,0, 0x0000,0x0000, 0x9c,0x74,0x00,0xff }, /*   238 */
  {   -51,   229,    48,0, 0x0000,0x0000, 0xaa,0x7e,0x00,0xff }, /*   239 */
  {     0,   236,    62,0, 0x0000,0x0000, 0xa3,0x79,0x00,0xff }, /*   240 */
  {    -6,   247,    66,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   241 */
  {   -50,   241,    55,0, 0x0000,0x0000, 0x9c,0x74,0x00,0xff }, /*   242 */
  {   -51,   229,    48,0, 0x0000,0x0000, 0xaa,0x7e,0x00,0xff }, /*   243 */
  {   -59,   273,    28,0, 0x0000,0x0000, 0x8d,0x69,0x00,0xff }, /*   244 */
  {   -59,   267,    16,0, 0x0000,0x0000, 0xac,0x80,0x00,0xff }, /*   245 */
  {   -59,   267,    16,0, 0x0000,0x0000, 0xac,0x80,0x00,0xff }, /*   246 */
  {    -6,   279,    37,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   247 */
  {     0,   275,    27,0, 0x0000,0x0000, 0xb9,0x8a,0x00,0xff }, /*   248 */
  {    -6,   247,    66,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   249 */
  {    -9,   247,    60,0, 0x0000,0x0000, 0xb4,0x86,0x00,0xff }, /*   250 */
  {   -50,   241,    55,0, 0x0000,0x0000, 0x9c,0x74,0x00,0xff }, /*   251 */
  {    51,   229,    48,0, 0x0000,0x0000, 0xd0,0x9b,0x00,0xff }, /*   252 */
  {    50,   241,    55,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   253 */
  {     0,   236,    62,0, 0x0000,0x0000, 0xa3,0x79,0x00,0xff }, /*   254 */
  {     0,   236,    62,0, 0x0000,0x0000, 0xa3,0x79,0x00,0xff }, /*   255 */
  {     6,   247,    66,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   256 */
  {     0,   275,    27,0, 0x0000,0x0000, 0xb9,0x8a,0x00,0xff }, /*   257 */
  {     0,   275,    27,0, 0x0000,0x0000, 0xb9,0x8a,0x00,0xff }, /*   258 */
  {     6,   279,    37,0, 0x0000,0x0000, 0xc8,0x95,0x00,0xff }, /*   259 */
  {    59,   267,    16,0, 0x0000,0x0000, 0xf1,0xb3,0x00,0xff }, /*   260 */
  {     6,   279,    37,0, 0x0000,0x0000, 0xc8,0x95,0x00,0xff }, /*   261 */
  {    59,   273,    28,0, 0x0000,0x0000, 0xfc,0xbc,0x00,0xff }, /*   262 */
  {    59,   267,    16,0, 0x0000,0x0000, 0xf1,0xb3,0x00,0xff }, /*   263 */
  {    59,   267,    16,0, 0x0000,0x0000, 0xf1,0xb3,0x00,0xff }, /*   264 */
  {    59,   273,    28,0, 0x0000,0x0000, 0xfc,0xbc,0x00,0xff }, /*   265 */
  {    51,   229,    48,0, 0x0000,0x0000, 0xd0,0x9b,0x00,0xff }, /*   266 */
  {    59,   273,    28,0, 0x0000,0x0000, 0xfc,0xbc,0x00,0xff }, /*   267 */
  {    50,   241,    55,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   268 */
  {    51,   229,    48,0, 0x0000,0x0000, 0xd0,0x9b,0x00,0xff }, /*   269 */
  {     6,   247,    66,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   270 */
  {     6,   279,    37,0, 0x0000,0x0000, 0xc8,0x95,0x00,0xff }, /*   271 */
  {     0,   275,    27,0, 0x0000,0x0000, 0xb9,0x8a,0x00,0xff }, /*   272 */
  {    50,   241,    55,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   273 */
  {     6,   247,    66,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   274 */
  {     0,   236,    62,0, 0x0000,0x0000, 0xa3,0x79,0x00,0xff }, /*   275 */
  {   -59,   267,    16,0, 0x0000,0x0000, 0xac,0x80,0x00,0xff }, /*   276 */
  {   -59,   273,    28,0, 0x0000,0x0000, 0x8d,0x69,0x00,0xff }, /*   277 */
  {    -6,   279,    37,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   278 */
  {   -51,   229,    48,0, 0x0000,0x0000, 0xaa,0x7e,0x00,0xff }, /*   279 */
  {   -50,   241,    55,0, 0x0000,0x0000, 0x9c,0x74,0x00,0xff }, /*   280 */
  {   -59,   273,    28,0, 0x0000,0x0000, 0x8d,0x69,0x00,0xff }, /*   281 */
  {     0,   275,    27,0, 0x0000,0x0000, 0xb9,0x8a,0x00,0xff }, /*   282 */
  {    -6,   279,    37,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   283 */
  {    -6,   247,    66,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   284 */
  {     9,   247,    60,0, 0x0000,0x0000, 0xf4,0xb6,0x00,0xff }, /*   285 */
  {     9,   273,    37,0, 0x0000,0x0000, 0xce,0x99,0x00,0xff }, /*   286 */
  {     6,   279,    37,0, 0x0000,0x0000, 0xc8,0x95,0x00,0xff }, /*   287 */
  {     4,   140,  -108,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   288 */
  {     4,   140,   -91,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   289 */
  {     0,   168,   -91,0, 0x0000,0x0000, 0x00,0x36,0x6c,0xff }, /*   290 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x00,0x27,0x4f,0xff }, /*   291 */
  {    56,   148,   -81,0, 0x0000,0x0000, 0x00,0x34,0x68,0xff }, /*   292 */
  {     4,   140,  -108,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   293 */
  {    47,   148,   -68,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   294 */
  {    56,   148,   -81,0, 0x0000,0x0000, 0x00,0x34,0x68,0xff }, /*   295 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x00,0x27,0x4f,0xff }, /*   296 */
  {   -51,   178,   -65,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   297 */
  {   -54,   149,   -60,0, 0x0000,0x0000, 0x00,0x47,0x8f,0xff }, /*   298 */
  {   -54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   299 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   300 */
  {   -73,   158,    -6,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   301 */
  {   -65,   158,    -6,0, 0x0000,0x0000, 0x00,0x3a,0x75,0xff }, /*   302 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x00,0x3b,0x77,0xff }, /*   303 */
  {   -54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   304 */
  {   -73,   158,    -6,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   305 */
  {    54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   306 */
  {    54,   149,   -60,0, 0x0000,0x0000, 0x00,0x42,0x85,0xff }, /*   307 */
  {    51,   178,   -65,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   308 */
  {    73,   158,    -6,0, 0x0000,0x0000, 0x00,0x40,0x80,0xff }, /*   309 */
  {    54,   149,   -72,0, 0x0000,0x0000, 0x00,0x39,0x73,0xff }, /*   310 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x00,0x27,0x4f,0xff }, /*   311 */
  {    71,   160,    11,0, 0x0000,0x0000, 0x00,0x26,0x4d,0xff }, /*   312 */
  {    65,   160,    12,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   313 */
  {    57,   188,     0,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   314 */
  {   -64,   204,    47,0, 0x0000,0x0000, 0x00,0x33,0x66,0xff }, /*   315 */
  {   -64,   174,    43,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   316 */
  {   -56,   174,    44,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   317 */
  {     0,   193,  -119,0, 0x0000,0x0000, 0x2f,0x00,0x5e,0xff }, /*   318 */
  {    57,   201,   -84,0, 0x0000,0x0000, 0x28,0x00,0x50,0xff }, /*   319 */
  {    53,   178,   -80,0, 0x0000,0x0000, 0x27,0x00,0x4f,0xff }, /*   320 */
  {   -53,   178,   -80,0, 0x0000,0x0000, 0x3b,0x00,0x77,0xff }, /*   321 */
  {   -57,   201,   -84,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*   322 */
  {     0,   193,  -119,0, 0x0000,0x0000, 0x2f,0x00,0x5e,0xff }, /*   323 */
  {   -76,   188,     0,0, 0x0000,0x0000, 0x3b,0x00,0x76,0xff }, /*   324 */
  {   -73,   214,     0,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*   325 */
  {   -57,   201,   -84,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*   326 */
  {     0,   210,    68,0, 0x0000,0x0000, 0x2d,0x00,0x5b,0xff }, /*   327 */
  {     0,   236,    62,0, 0x0000,0x0000, 0x31,0x00,0x62,0xff }, /*   328 */
  {   -51,   229,    48,0, 0x0000,0x0000, 0x33,0x00,0x66,0xff }, /*   329 */
  {    51,   229,    48,0, 0x0000,0x0000, 0x3e,0x00,0x7d,0xff }, /*   330 */
  {     0,   236,    62,0, 0x0000,0x0000, 0x31,0x00,0x62,0xff }, /*   331 */
  {     0,   210,    68,0, 0x0000,0x0000, 0x2d,0x00,0x5b,0xff }, /*   332 */
  {    57,   201,   -84,0, 0x0000,0x0000, 0x28,0x00,0x50,0xff }, /*   333 */
  {    73,   214,     0,0, 0x0000,0x0000, 0x3e,0x00,0x7c,0xff }, /*   334 */
  {    76,   188,     0,0, 0x0000,0x0000, 0x3f,0x00,0x7e,0xff }, /*   335 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*   336 */
  {    18,   114,    20,0, 0x0000,0x0000, 0xa8,0x7a,0x57,0xff }, /*   337 */
  {   -18,   114,    20,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   338 */
  {    18,   114,    20,0, 0x0000,0x0000, 0xa8,0x7a,0x57,0xff }, /*   339 */
  {     0,   114,    28,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*   340 */
  {   -18,   114,    20,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   341 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*   342 */
  {   -18,   114,    20,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   343 */
  {   -15,   114,     0,0, 0x0000,0x0000, 0xbc,0x88,0x62,0xff }, /*   344 */
  {    36,   132,    52,0, 0x0000,0x0000, 0xa7,0x79,0x57,0xff }, /*   345 */
  {    18,   114,    20,0, 0x0000,0x0000, 0xa8,0x7a,0x57,0xff }, /*   346 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*   347 */
  {   -15,   114,     0,0, 0x0000,0x0000, 0xbc,0x88,0x62,0xff }, /*   348 */
  {   -18,   114,    20,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   349 */
  {   -36,   132,    52,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*   350 */
  {   -36,   132,   -52,0, 0x0000,0x0000, 0xbe,0x89,0x63,0xff }, /*   351 */
  {   -11,   114,   -20,0, 0x0000,0x0000, 0xc8,0x91,0x68,0xff }, /*   352 */
  {   -15,   114,     0,0, 0x0000,0x0000, 0xbc,0x88,0x62,0xff }, /*   353 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*   354 */
  {    11,   114,   -20,0, 0x0000,0x0000, 0x79,0x58,0x3f,0xff }, /*   355 */
  {    36,   132,   -52,0, 0x0000,0x0000, 0x7a,0x58,0x3f,0xff }, /*   356 */
  {     0,   132,   -74,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   357 */
  {   -36,   132,   -52,0, 0x0000,0x0000, 0x00,0x3b,0x76,0xff }, /*   358 */
  {   -51,   178,   -65,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   359 */
  {     6,   247,    66,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   360 */
  {     9,   247,    60,0, 0x0000,0x0000, 0xf4,0xb6,0x00,0xff }, /*   361 */
  {     6,   279,    37,0, 0x0000,0x0000, 0xc8,0x95,0x00,0xff }, /*   362 */
  {     6,   279,    37,0, 0x0000,0x0000, 0xc8,0x95,0x00,0xff }, /*   363 */
  {    53,   268,    29,0, 0x0000,0x0000, 0xd1,0x9b,0x00,0xff }, /*   364 */
  {    59,   273,    28,0, 0x0000,0x0000, 0xfc,0xbc,0x00,0xff }, /*   365 */
  {    59,   273,    28,0, 0x0000,0x0000, 0xfc,0xbc,0x00,0xff }, /*   366 */
  {    53,   268,    29,0, 0x0000,0x0000, 0xd1,0x9b,0x00,0xff }, /*   367 */
  {    50,   241,    55,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   368 */
  {    50,   241,    55,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   369 */
  {     9,   247,    60,0, 0x0000,0x0000, 0xf4,0xb6,0x00,0xff }, /*   370 */
  {     6,   247,    66,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   371 */
  {    -6,   279,    37,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   372 */
  {    -9,   247,    60,0, 0x0000,0x0000, 0xb4,0x86,0x00,0xff }, /*   373 */
  {    -6,   247,    66,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   374 */
  {   -59,   273,    28,0, 0x0000,0x0000, 0x8d,0x69,0x00,0xff }, /*   375 */
  {   -53,   268,    29,0, 0x0000,0x0000, 0xd9,0xa2,0x00,0xff }, /*   376 */
  {    -6,   279,    37,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   377 */
  {   -50,   241,    55,0, 0x0000,0x0000, 0x9c,0x74,0x00,0xff }, /*   378 */
  {   -53,   268,    29,0, 0x0000,0x0000, 0xd9,0xa2,0x00,0xff }, /*   379 */
  {   -59,   273,    28,0, 0x0000,0x0000, 0x8d,0x69,0x00,0xff }, /*   380 */
  {   -53,   268,    29,0, 0x0000,0x0000, 0xd9,0xa2,0x00,0xff }, /*   381 */
  {    -9,   273,    37,0, 0x0000,0x0000, 0xaa,0x7e,0x00,0xff }, /*   382 */
  {    -6,   279,    37,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   383 */
  {   -50,   241,    55,0, 0x0000,0x0000, 0x9c,0x74,0x00,0xff }, /*   384 */
  {   -46,   242,    50,0, 0x0000,0x0000, 0xdf,0xa6,0x00,0xff }, /*   385 */
  {   -53,   268,    29,0, 0x0000,0x0000, 0xd9,0xa2,0x00,0xff }, /*   386 */
  {    -9,   247,    60,0, 0x0000,0x0000, 0xb4,0x86,0x00,0xff }, /*   387 */
  {   -46,   242,    50,0, 0x0000,0x0000, 0xdf,0xa6,0x00,0xff }, /*   388 */
  {   -50,   241,    55,0, 0x0000,0x0000, 0x9c,0x74,0x00,0xff }, /*   389 */
  {    -6,   279,    37,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   390 */
  {    -9,   273,    37,0, 0x0000,0x0000, 0xaa,0x7e,0x00,0xff }, /*   391 */
  {    -9,   247,    60,0, 0x0000,0x0000, 0xb4,0x86,0x00,0xff }, /*   392 */
  {    50,   241,    55,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   393 */
  {    46,   242,    50,0, 0x0000,0x0000, 0xdb,0xa3,0x00,0xff }, /*   394 */
  {     9,   247,    60,0, 0x0000,0x0000, 0xf4,0xb6,0x00,0xff }, /*   395 */
  {    53,   268,    29,0, 0x0000,0x0000, 0xd1,0x9b,0x00,0xff }, /*   396 */
  {    46,   242,    50,0, 0x0000,0x0000, 0xdb,0xa3,0x00,0xff }, /*   397 */
  {    50,   241,    55,0, 0x0000,0x0000, 0xc1,0x8f,0x00,0xff }, /*   398 */
  {     6,   279,    37,0, 0x0000,0x0000, 0xc8,0x95,0x00,0xff }, /*   399 */
  {     9,   273,    37,0, 0x0000,0x0000, 0xce,0x99,0x00,0xff }, /*   400 */
  {    53,   268,    29,0, 0x0000,0x0000, 0xd1,0x9b,0x00,0xff }, /*   401 */
  {   -15,   114,     0,0, 0x0000,0x0000, 0xbc,0x88,0x62,0xff }, /*   402 */
  {    15,    90,     0,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*   403 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*   404 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*   405 */
  {    11,    90,   -20,0, 0x0000,0x0000, 0x7f,0x5c,0x42,0xff }, /*   406 */
  {    11,   114,   -20,0, 0x0000,0x0000, 0x79,0x58,0x3f,0xff }, /*   407 */
  {    15,   114,     0,0, 0x0000,0x0000, 0x9e,0x73,0x52,0xff }, /*   408 */
  {    15,    90,     0,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*   409 */
  {    11,    90,   -20,0, 0x0000,0x0000, 0x7f,0x5c,0x42,0xff }, /*   410 */
  {    11,   114,   -20,0, 0x0000,0x0000, 0x79,0x58,0x3f,0xff }, /*   411 */
  {     0,    90,   -28,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*   412 */
  {     0,   114,   -28,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*   413 */
  {    11,   114,   -20,0, 0x0000,0x0000, 0x79,0x58,0x3f,0xff }, /*   414 */
  {    11,    90,   -20,0, 0x0000,0x0000, 0x7f,0x5c,0x42,0xff }, /*   415 */
  {     0,    90,   -28,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*   416 */
  {     0,   114,   -28,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*   417 */
  {   -11,    90,   -20,0, 0x0000,0x0000, 0xbf,0x8a,0x63,0xff }, /*   418 */
  {   -11,   114,   -20,0, 0x0000,0x0000, 0xc8,0x91,0x68,0xff }, /*   419 */
  {     0,   114,   -28,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*   420 */
  {     0,    90,   -28,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*   421 */
  {   -11,    90,   -20,0, 0x0000,0x0000, 0xbf,0x8a,0x63,0xff }, /*   422 */
  {   -11,   114,   -20,0, 0x0000,0x0000, 0xc8,0x91,0x68,0xff }, /*   423 */
  {   -15,    90,     0,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   424 */
  {   -15,   114,     0,0, 0x0000,0x0000, 0xbc,0x88,0x62,0xff }, /*   425 */
  {   -11,   114,   -20,0, 0x0000,0x0000, 0xc8,0x91,0x68,0xff }, /*   426 */
  {   -11,    90,   -20,0, 0x0000,0x0000, 0xbf,0x8a,0x63,0xff }, /*   427 */
  {   -15,    90,     0,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   428 */
  {   -15,   114,     0,0, 0x0000,0x0000, 0xbc,0x88,0x62,0xff }, /*   429 */
  {   -15,    90,     0,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   430 */
  {    15,    90,     0,0, 0x0000,0x0000, 0xbb,0x87,0x61,0xff }, /*   431 */
  {   -42,   204,    49,0, 0x01f0,0xfdf1, 0xa1,0xa1,0xa1,0xff }, /*   432 */
  {     0,   210,    49,0, 0x02cf,0xfe41, 0x90,0x90,0x90,0xff }, /*   433 */
  {     0,   210,    68,0, 0x02cf,0xfdb4, 0x89,0x89,0x89,0xff }, /*   434 */
  {     0,   210,    68,0, 0x02cf,0xfdb4, 0x89,0x89,0x89,0xff }, /*   435 */
  {    42,   204,    49,0, 0x0400,0xfdf1, 0x7e,0x7e,0x7e,0xff }, /*   436 */
  {    64,   204,    47,0, 0x045a,0xfdfd, 0xb9,0xb9,0xb9,0xff }, /*   437 */
  {     0,   302,   -81,0, 0x06cf,0x073d, 0x9d,0x9d,0x9d,0xff }, /*   438 */
  {   -23,   300,   -84,0, 0x079f,0x073c, 0x80,0x60,0xa0,0xff }, /*   439 */
  {   -20,   319,   -81,0, 0x07d7,0x082f, 0x77,0x77,0x77,0xff }, /*   440 */
  {    57,   201,   -84,0, 0x0622,0x01a6, 0x78,0x78,0x78,0xff }, /*   441 */
  {    23,   300,   -84,0, 0x062d,0x073c, 0x8f,0x6b,0xb3,0xff }, /*   442 */
  {    73,   214,     0,0, 0x051f,0xfff2, 0xbb,0xbb,0xbb,0xff }, /*   443 */
  {    73,   214,     0,0, 0x051f,0xfff2, 0xbb,0xbb,0xbb,0xff }, /*   444 */
  {    23,   300,   -84,0, 0x062d,0x073c, 0x8f,0x6b,0xb3,0xff }, /*   445 */
  {    59,   267,    16,0, 0x0445,0x0269, 0xd9,0xd9,0xd9,0xff }, /*   446 */
  {     0,   302,   -81,0, 0x06cf,0x073d, 0x9d,0x9d,0x9d,0xff }, /*   447 */
  {     0,   292,  -111,0, 0x06cf,0x0784, 0x6a,0x4f,0x84,0xff }, /*   448 */
  {   -23,   302,  -104,0, 0x0764,0x07ec, 0x5c,0x45,0x73,0xff }, /*   449 */
  {   -59,   267,    16,0, 0x01c4,0x0269, 0x9b,0x9b,0x9b,0xff }, /*   450 */
  {   -23,   300,   -84,0, 0xffa0,0x073c, 0x80,0x60,0xa0,0xff }, /*   451 */
  {   -73,   214,     0,0, 0x011b,0xfff2, 0xb9,0xb9,0xb9,0xff }, /*   452 */
  {   -73,   214,     0,0, 0x011b,0xfff2, 0xb9,0xb9,0xb9,0xff }, /*   453 */
  {   -23,   300,   -84,0, 0xffa0,0x073c, 0x80,0x60,0xa0,0xff }, /*   454 */
  {   -57,   201,   -84,0, 0xffb1,0x01a6, 0xb9,0xb9,0xb9,0xff }, /*   455 */
  {   -57,   201,   -84,0, 0x07b0,0x01a6, 0xb9,0xb9,0xb9,0xff }, /*   456 */
  {     0,   292,  -111,0, 0x06cf,0x0784, 0x6a,0x4f,0x84,0xff }, /*   457 */
  {     0,   193,  -119,0, 0x06cf,0x0230, 0x8d,0x8d,0x8d,0xff }, /*   458 */
  {   -73,   214,     0,0, 0x011b,0xfff2, 0xb9,0xb9,0xb9,0xff }, /*   459 */
  {   -51,   229,    48,0, 0x01f4,0xff5b, 0x99,0x99,0x99,0xff }, /*   460 */
  {   -59,   267,    16,0, 0x01c4,0x0269, 0x9b,0x9b,0x9b,0xff }, /*   461 */
  {     0,   193,  -119,0, 0x06cf,0x0230, 0x8d,0x8d,0x8d,0xff }, /*   462 */
  {     0,   292,  -111,0, 0x06cf,0x0784, 0x6a,0x4f,0x84,0xff }, /*   463 */
  {    57,   201,   -84,0, 0x0622,0x01a6, 0x78,0x78,0x78,0xff }, /*   464 */
  {    23,   302,  -104,0, 0x0654,0x07ec, 0x8d,0x69,0xb0,0xff }, /*   465 */
  {     0,   292,  -111,0, 0x06cf,0x0784, 0x6a,0x4f,0x84,0xff }, /*   466 */
  {     0,   302,   -81,0, 0x06cf,0x073d, 0x9d,0x9d,0x9d,0xff }, /*   467 */
  {     0,   275,    27,0, 0x02cf,0x0289, 0xa6,0xa6,0xa6,0xff }, /*   468 */
  {     0,   313,   -51,0, 0xfed0,0x06f6, 0x85,0x64,0xa6,0xff }, /*   469 */
  {   -59,   267,    16,0, 0x01c4,0x0269, 0x9b,0x9b,0x9b,0xff }, /*   470 */
  {    59,   267,    16,0, 0x0c45,0x0269, 0xd9,0xd9,0xd9,0xff }, /*   471 */
  {     0,   313,   -51,0, 0x06cf,0x06f6, 0x85,0x64,0xa6,0xff }, /*   472 */
  {     0,   275,    27,0, 0x0acf,0x0289, 0xa6,0xa6,0xa6,0xff }, /*   473 */
  {    59,   267,    16,0, 0x0445,0x0269, 0xd9,0xd9,0xd9,0xff }, /*   474 */
  {    51,   229,    48,0, 0x03f8,0xff5b, 0xbb,0xbb,0xbb,0xff }, /*   475 */
  {    73,   214,     0,0, 0x051f,0xfff2, 0xbb,0xbb,0xbb,0xff }, /*   476 */
  {     0,   302,   -81,0, 0x06cf,0x073d, 0x9d,0x9d,0x9d,0xff }, /*   477 */
  {     0,   313,   -51,0, 0x06cf,0x06f6, 0x85,0x64,0xa6,0xff }, /*   478 */
  {    20,   319,   -81,0, 0x0609,0x082f, 0x8a,0x67,0xac,0xff }, /*   479 */
  {     0,   302,   -81,0, 0x06cf,0x073d, 0x9d,0x9d,0x9d,0xff }, /*   480 */
  {    20,   319,   -81,0, 0x0609,0x082f, 0x8a,0x67,0xac,0xff }, /*   481 */
  {    23,   300,   -84,0, 0x062d,0x073c, 0x8f,0x6b,0xb3,0xff }, /*   482 */
  {     0,   302,   -81,0, 0x06cf,0x073d, 0x9d,0x9d,0x9d,0xff }, /*   483 */
  {    23,   300,   -84,0, 0x062d,0x073c, 0x8f,0x6b,0xb3,0xff }, /*   484 */
  {    23,   302,  -104,0, 0x0654,0x07ec, 0x8d,0x69,0xb0,0xff }, /*   485 */
  {   -20,   319,   -81,0, 0x07d7,0x082f, 0x77,0x77,0x77,0xff }, /*   486 */
  {     0,   313,   -51,0, 0x06cf,0x06f6, 0x85,0x64,0xa6,0xff }, /*   487 */
  {     0,   302,   -81,0, 0x06cf,0x073d, 0x9d,0x9d,0x9d,0xff }, /*   488 */
  {     0,   302,   -81,0, 0x06cf,0x073d, 0x9d,0x9d,0x9d,0xff }, /*   489 */
  {   -23,   302,  -104,0, 0x0764,0x07ec, 0x5c,0x45,0x73,0xff }, /*   490 */
  {   -23,   300,   -84,0, 0x079f,0x073c, 0x80,0x60,0xa0,0xff }, /*   491 */
  {    59,   267,    16,0, 0x0445,0x0269, 0xd9,0xd9,0xd9,0xff }, /*   492 */
  {    20,   319,   -81,0, 0x0609,0x082f, 0x8a,0x67,0xac,0xff }, /*   493 */
  {     0,   313,   -51,0, 0x06cf,0x06f6, 0x85,0x64,0xa6,0xff }, /*   494 */
  {     0,   313,   -51,0, 0x06cf,0x06f6, 0x85,0x64,0xa6,0xff }, /*   495 */
  {   -20,   319,   -81,0, 0x07d7,0x082f, 0x77,0x77,0x77,0xff }, /*   496 */
  {   -59,   267,    16,0, 0x09c4,0x0269, 0x9b,0x9b,0x9b,0xff }, /*   497 */
  {     0,   292,  -111,0, 0x06cf,0x0784, 0x6a,0x4f,0x84,0xff }, /*   498 */
  {    23,   302,  -104,0, 0x0654,0x07ec, 0x8d,0x69,0xb0,0xff }, /*   499 */
  {    57,   201,   -84,0, 0x0622,0x01a6, 0x78,0x78,0x78,0xff }, /*   500 */
  {   -57,   201,   -84,0, 0x07b0,0x01a6, 0xb9,0xb9,0xb9,0xff }, /*   501 */
  {   -23,   302,  -104,0, 0x0764,0x07ec, 0x5c,0x45,0x73,0xff }, /*   502 */
  {     0,   292,  -111,0, 0x06cf,0x0784, 0x6a,0x4f,0x84,0xff }, /*   503 */
  {   -23,   300,   -84,0, 0x079f,0x073c, 0x80,0x60,0xa0,0xff }, /*   504 */
  {   -23,   302,  -104,0, 0x0764,0x07ec, 0x5c,0x45,0x73,0xff }, /*   505 */
  {   -57,   201,   -84,0, 0x07b0,0x01a6, 0xb9,0xb9,0xb9,0xff }, /*   506 */
  {   -59,   267,    16,0, 0x01c4,0x0269, 0x9b,0x9b,0x9b,0xff }, /*   507 */
  {   -20,   319,   -81,0, 0xffd8,0x082f, 0x77,0x77,0x77,0xff }, /*   508 */
  {   -23,   300,   -84,0, 0xffa0,0x073c, 0x80,0x60,0xa0,0xff }, /*   509 */
  {    23,   300,   -84,0, 0x062d,0x073c, 0x8f,0x6b,0xb3,0xff }, /*   510 */
  {    20,   319,   -81,0, 0x0609,0x082f, 0x8a,0x67,0xac,0xff }, /*   511 */
  {    59,   267,    16,0, 0x0445,0x0269, 0xd9,0xd9,0xd9,0xff }, /*   512 */
  {    57,   201,   -84,0, 0x0622,0x01a6, 0x78,0x78,0x78,0xff }, /*   513 */
  {    23,   302,  -104,0, 0x0654,0x07ec, 0x8d,0x69,0xb0,0xff }, /*   514 */
  {    23,   300,   -84,0, 0x062d,0x073c, 0x8f,0x6b,0xb3,0xff }, /*   515 */
  {     0,   210,    68,0, 0x02cf,0xfdb4, 0x89,0x89,0x89,0xff }, /*   516 */
  {     0,   210,    49,0, 0x02cf,0xfe41, 0x90,0x90,0x90,0xff }, /*   517 */
  {    42,   204,    49,0, 0x0400,0xfdf1, 0x7e,0x7e,0x7e,0xff }, /*   518 */
  {     0,   210,    68,0, 0x02cf,0xfdb4, 0x89,0x89,0x89,0xff }, /*   519 */
  {   -64,   204,    47,0, 0x01b7,0xfdfd, 0x99,0x99,0x99,0xff }, /*   520 */
  {   -42,   204,    49,0, 0x01f0,0xfdf1, 0xa1,0xa1,0xa1,0xff }, /*   521 */
  {    36,   132,    52,0, 0x077e,0x0000, 0xad,0xad,0xad,0xff }, /*   522 */
  {     0,   170,    73,0, 0x0400,0x07ff, 0xa1,0x81,0x61,0xff }, /*   523 */
  {   -36,   132,    52,0, 0x0081,0x0000, 0xc3,0xc3,0xc3,0xff }, /*   524 */
  {     0,   170,    73,0, 0x0400,0x07ff, 0xa1,0x81,0x61,0xff }, /*   525 */
  {   -42,   170,    65,0, 0x0000,0x0755, 0xa2,0x6a,0x61,0xff }, /*   526 */
  {   -36,   132,    52,0, 0x0081,0x0000, 0xc3,0xc3,0xc3,0xff }, /*   527 */
  {    36,   132,    52,0, 0x077e,0x0000, 0xad,0xad,0xad,0xff }, /*   528 */
  {    42,   170,    65,0, 0x0800,0x0755, 0xc6,0x82,0x77,0xff }, /*   529 */
  {     0,   170,    73,0, 0x0400,0x07ff, 0xa1,0x81,0x61,0xff }, /*   530 */
  {   -42,   170,    65,0, 0xf800,0x0000, 0xa2,0x6a,0x61,0xff }, /*   531 */
  {     0,   210,    49,0, 0x0000,0x0800, 0xa0,0xa0,0xa0,0xff }, /*   532 */
  {   -42,   204,    49,0, 0xf800,0x06e5, 0xb3,0xb3,0xb3,0xff }, /*   533 */
  {    42,   170,    65,0, 0x0800,0x0000, 0xc6,0x82,0x77,0xff }, /*   534 */
  {    42,   204,    49,0, 0x0800,0x06e5, 0x8c,0x8c,0x8c,0xff }, /*   535 */
  {     0,   210,    49,0, 0x0000,0x0800, 0xa0,0xa0,0xa0,0xff }, /*   536 */
  {   -42,   170,    65,0, 0xf800,0x0000, 0xa2,0x6a,0x61,0xff }, /*   537 */
  {     0,   170,    73,0, 0x0000,0x0000, 0xa1,0x81,0x61,0xff }, /*   538 */
  {     0,   210,    49,0, 0x0000,0x0800, 0xa0,0xa0,0xa0,0xff }, /*   539 */
  {     0,   170,    73,0, 0x0000,0x0000, 0xa1,0x81,0x61,0xff }, /*   540 */
  {    42,   170,    65,0, 0x0800,0x0000, 0xc6,0x82,0x77,0xff }, /*   541 */
  {     0,   210,    49,0, 0x0000,0x0800, 0xa0,0xa0,0xa0,0xff }, /*   542 */
  {    -9,   247,    60,0, 0x0000,0x0000, 0xc2,0x5e,0x39,0xff }, /*   543 */
  {    -9,   273,    37,0, 0x0000,0x0000, 0xc2,0x29,0x66,0xff }, /*   544 */
  {   -46,   242,    50,0, 0x0000,0x0000, 0x02,0x69,0x46,0xff }, /*   545 */
  {     9,   273,    37,0, 0x0000,0x0000, 0x3e,0x29,0x66,0xff }, /*   546 */
  {    46,   242,    50,0, 0x0000,0x0000, 0xfe,0x69,0x46,0xff }, /*   547 */
  {    53,   268,    29,0, 0x0000,0x0000, 0xfa,0x36,0x72,0xff }, /*   548 */
  {     9,   273,    37,0, 0x0000,0x0000, 0x3e,0x29,0x66,0xff }, /*   549 */
  {     9,   247,    60,0, 0x0000,0x0000, 0x3e,0x5e,0x39,0xff }, /*   550 */
  {    46,   242,    50,0, 0x0000,0x0000, 0xfe,0x69,0x46,0xff }, /*   551 */
  {    -9,   273,    37,0, 0x0000,0x0000, 0xc2,0x29,0x66,0xff }, /*   552 */
  {   -53,   268,    29,0, 0x0000,0x0000, 0x06,0x36,0x72,0xff }, /*   553 */
  {   -46,   242,    50,0, 0x0000,0x0000, 0x02,0x69,0x46,0xff }, /*   554 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_293_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP2Triangles( 10, 11, 12,  0, 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 992), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 1024), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP2Triangles(  5,  6,  7,  0,  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 1520), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 1536), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP2Triangles(  3,  4,  5,  0,  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 2000), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 2048), 30, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP2Triangles( 10, 11, 12,  0, 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 2528), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 2560), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP2Triangles(  5,  6,  7,  0,  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP2Triangles( 14, 15, 16,  0, 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP2Triangles( 23, 24, 25,  0, 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 3056), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 3072), 29, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 3536), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 3584), 10, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSPClearGeometryMode( G_SHADING_SMOOTH ),
  gsSPVertex( SEGADRS(5, 3744), 22, 10 ),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP2Triangles( 13, 14, 15,  0, 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP2Triangles( 22, 23, 24,  0, 25, 26, 27,  0),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 4096), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP2Triangles(  2,  3,  4,  0,  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP2Triangles( 20, 21, 22,  0, 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 4592), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPSetGeometryMode( G_SHADING_SMOOTH ),
  gsSPVertex( SEGADRS(5, 4608), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 5072), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 5120), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP2Triangles( 16, 17, 18,  0, 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 5600), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 5632), 8, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSPClearGeometryMode( G_SHADING_SMOOTH ),
  gsSPVertex( SEGADRS(5, 5760), 24, 8 ),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP2Triangles( 20, 21, 22,  0, 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 6144), 18, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSPSetGeometryMode( G_SHADING_SMOOTH ),
  gsSPVertex( SEGADRS(5, 6432), 14, 18 ),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 6656), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsDPPipeSync(),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0, TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0),
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,2048), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    0, 0, 5, 5, 0, 0 ),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 7136), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 7168), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP2Triangles(  2,  3,  4,  0,  5,  6,  7,  0),
  gsSP2Triangles(  8,  9, 10,  0, 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 7664), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 7680), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 8144), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 8192), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsDPPipeSync(),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,4096), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    1, 1, 5, 5, 0, 0 ),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsDPPipeSync(),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,6144), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    1, 1, 5, 5, 0, 0 ),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 8672), 1, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPSetGeometryMode( G_LIGHTING|G_TEXTURE_GEN ),
  gsDPPipeSync(),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, 0, 0, 0, TEXEL0, TEXEL0, 0, SHADE, 0, 0, 0, 0, TEXEL0),
  gsSPTexture(0x0800, 0x0800, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,8192), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    0, 0, 5, 5, 0, 0 ),
  gsSPVertex( SEGADRS(5, 8688), 12, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_293_ = {
  gfx_Shape_of___POLYHEDRON_293_,
  vtx_Shape_of___POLYHEDRON_293_, 555, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner11[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_352_[] = {
  {    38,   -53,     3,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*     0 */
  {    38,   -75,     3,0, 0x0000,0x0000, 0xe0,0xa2,0x75,0xff }, /*     1 */
  {    38,   -53,   -22,0, 0x0000,0x0000, 0x88,0x62,0x46,0xff }, /*     2 */
  {    38,   -75,     3,0, 0x0000,0x0000, 0xe0,0xa2,0x75,0xff }, /*     3 */
  {    38,   -75,   -22,0, 0x0000,0x0000, 0x96,0x6c,0x4e,0xff }, /*     4 */
  {    38,   -53,   -22,0, 0x0000,0x0000, 0x88,0x62,0x46,0xff }, /*     5 */
  {    38,   -53,   -22,0, 0x0000,0x0000, 0x88,0x62,0x46,0xff }, /*     6 */
  {    38,   -75,   -22,0, 0x0000,0x0000, 0x96,0x6c,0x4e,0xff }, /*     7 */
  {    13,   -53,   -22,0, 0x0000,0x0000, 0xf0,0xad,0x7d,0xff }, /*     8 */
  {    38,   -75,   -22,0, 0x0000,0x0000, 0x96,0x6c,0x4e,0xff }, /*     9 */
  {    13,   -75,   -22,0, 0x0000,0x0000, 0x8f,0x67,0x4a,0xff }, /*    10 */
  {    13,   -53,   -22,0, 0x0000,0x0000, 0xf0,0xad,0x7d,0xff }, /*    11 */
  {    13,   -53,   -22,0, 0x0000,0x0000, 0xf0,0xad,0x7d,0xff }, /*    12 */
  {    13,   -75,     3,0, 0x0000,0x0000, 0xb7,0x85,0x5f,0xff }, /*    13 */
  {    13,   -53,     3,0, 0x0000,0x0000, 0xff,0xbf,0x89,0xff }, /*    14 */
  {    13,   -53,   -22,0, 0x0000,0x0000, 0xf0,0xad,0x7d,0xff }, /*    15 */
  {    13,   -75,   -22,0, 0x0000,0x0000, 0x8f,0x67,0x4a,0xff }, /*    16 */
  {    13,   -75,     3,0, 0x0000,0x0000, 0xb7,0x85,0x5f,0xff }, /*    17 */
  {    13,   -53,     3,0, 0x0000,0x0000, 0xff,0xbf,0x89,0xff }, /*    18 */
  {    13,   -75,     3,0, 0x0000,0x0000, 0xb7,0x85,0x5f,0xff }, /*    19 */
  {    38,   -53,     3,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*    20 */
  {    13,   -75,     3,0, 0x0000,0x0000, 0xb7,0x85,0x5f,0xff }, /*    21 */
  {    38,   -75,     3,0, 0x0000,0x0000, 0xe0,0xa2,0x75,0xff }, /*    22 */
  {    38,   -53,     3,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*    23 */
  {    38,   -75,   -22,0, 0x0000,0x0000, 0x96,0x6c,0x4e,0xff }, /*    24 */
  {    26,   -86,    -9,0, 0x0000,0x0000, 0x84,0x39,0x29,0xff }, /*    25 */
  {    13,   -75,   -22,0, 0x0000,0x0000, 0x8f,0x67,0x4a,0xff }, /*    26 */
  {    38,   -75,     3,0, 0x0000,0x0000, 0xe0,0xa2,0x75,0xff }, /*    27 */
  {    26,   -86,    -9,0, 0x0000,0x0000, 0x84,0x39,0x29,0xff }, /*    28 */
  {    38,   -75,   -22,0, 0x0000,0x0000, 0x96,0x6c,0x4e,0xff }, /*    29 */
  {    13,   -75,     3,0, 0x0000,0x0000, 0xb7,0x85,0x5f,0xff }, /*    30 */
  {    26,   -86,    -9,0, 0x0000,0x0000, 0x84,0x39,0x29,0xff }, /*    31 */
  {    38,   -75,     3,0, 0x0000,0x0000, 0xe0,0xa2,0x75,0xff }, /*    32 */
  {    13,   -75,   -22,0, 0x0000,0x0000, 0x8f,0x67,0x4a,0xff }, /*    33 */
  {    26,   -86,    -9,0, 0x0000,0x0000, 0x84,0x39,0x29,0xff }, /*    34 */
  {    13,   -75,     3,0, 0x0000,0x0000, 0xb7,0x85,0x5f,0xff }, /*    35 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_352_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 4, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_352_ = {
  gfx_Shape_of___POLYHEDRON_352_,
  vtx_Shape_of___POLYHEDRON_352_, 36, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner12[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_356_[] = {
  {    38,  -104,     3,0, 0x0000,0x0000, 0xe5,0xa5,0x77,0xff }, /*     0 */
  {    38,   -80,     3,0, 0x0000,0x0000, 0xd7,0x9c,0x70,0xff }, /*     1 */
  {    13,  -104,     3,0, 0x0000,0x0000, 0xd0,0x96,0x6c,0xff }, /*     2 */
  {    38,   -80,     3,0, 0x0000,0x0000, 0xd7,0x9c,0x70,0xff }, /*     3 */
  {    13,   -80,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*     4 */
  {    13,  -104,     3,0, 0x0000,0x0000, 0xd0,0x96,0x6c,0xff }, /*     5 */
  {    13,  -104,   -22,0, 0x0000,0x0000, 0xe0,0xa2,0x74,0xff }, /*     6 */
  {    13,   -80,   -22,0, 0x0000,0x0000, 0xf7,0xb3,0x80,0xff }, /*     7 */
  {    38,  -104,   -22,0, 0x0000,0x0000, 0x9f,0x73,0x52,0xff }, /*     8 */
  {    13,   -80,   -22,0, 0x0000,0x0000, 0xf7,0xb3,0x80,0xff }, /*     9 */
  {    38,   -80,   -22,0, 0x0000,0x0000, 0x7e,0x5b,0x42,0xff }, /*    10 */
  {    38,  -104,   -22,0, 0x0000,0x0000, 0x9f,0x73,0x52,0xff }, /*    11 */
  {    13,   -80,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*    12 */
  {    13,   -80,   -22,0, 0x0000,0x0000, 0xf7,0xb3,0x80,0xff }, /*    13 */
  {    13,  -104,     3,0, 0x0000,0x0000, 0xd0,0x96,0x6c,0xff }, /*    14 */
  {    38,   -80,   -22,0, 0x0000,0x0000, 0x7e,0x5b,0x42,0xff }, /*    15 */
  {    38,   -80,     3,0, 0x0000,0x0000, 0xd7,0x9c,0x70,0xff }, /*    16 */
  {    38,  -104,   -22,0, 0x0000,0x0000, 0x9f,0x73,0x52,0xff }, /*    17 */
  {    38,   -80,     3,0, 0x0000,0x0000, 0xd7,0x9c,0x70,0xff }, /*    18 */
  {    26,   -67,    -9,0, 0x0000,0x0000, 0xfa,0x6c,0x4e,0xff }, /*    19 */
  {    13,   -80,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*    20 */
  {    38,   -80,   -22,0, 0x0000,0x0000, 0x7e,0x5b,0x42,0xff }, /*    21 */
  {    26,   -67,    -9,0, 0x0000,0x0000, 0xfa,0x6c,0x4e,0xff }, /*    22 */
  {    38,   -80,     3,0, 0x0000,0x0000, 0xd7,0x9c,0x70,0xff }, /*    23 */
  {    13,   -80,   -22,0, 0x0000,0x0000, 0xf7,0xb3,0x80,0xff }, /*    24 */
  {    26,   -67,    -9,0, 0x0000,0x0000, 0xfa,0x6c,0x4e,0xff }, /*    25 */
  {    38,   -80,   -22,0, 0x0000,0x0000, 0x7e,0x5b,0x42,0xff }, /*    26 */
  {    13,   -80,     3,0, 0x0000,0x0000, 0xfd,0xb7,0x84,0xff }, /*    27 */
  {    26,   -67,    -9,0, 0x0000,0x0000, 0xfa,0x6c,0x4e,0xff }, /*    28 */
  {    13,   -80,   -22,0, 0x0000,0x0000, 0xf7,0xb3,0x80,0xff }, /*    29 */
  {    38,  -104,     3,0, 0x0000,0x0000, 0x8e,0x47,0x00,0xff }, /*    30 */
  {    38,  -138,     3,0, 0x0000,0x0000, 0x70,0x38,0x00,0xff }, /*    31 */
  {    38,  -104,   -22,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*    32 */
  {    38,  -138,     3,0, 0x0000,0x0000, 0x70,0x38,0x00,0xff }, /*    33 */
  {    38,  -138,   -22,0, 0x0000,0x0000, 0x5e,0x2f,0x00,0xff }, /*    34 */
  {    38,  -104,   -22,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*    35 */
  {    38,  -104,   -22,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*    36 */
  {    38,  -138,   -22,0, 0x0000,0x0000, 0x5e,0x2f,0x00,0xff }, /*    37 */
  {    13,  -104,   -22,0, 0x0000,0x0000, 0x8b,0x45,0x00,0xff }, /*    38 */
  {    38,  -138,   -22,0, 0x0000,0x0000, 0x5e,0x2f,0x00,0xff }, /*    39 */
  {    13,  -138,   -22,0, 0x0000,0x0000, 0x55,0x2a,0x00,0xff }, /*    40 */
  {    13,  -104,   -22,0, 0x0000,0x0000, 0x8b,0x45,0x00,0xff }, /*    41 */
  {    13,  -104,   -22,0, 0x0000,0x0000, 0x8b,0x45,0x00,0xff }, /*    42 */
  {    13,  -138,     3,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    43 */
  {    13,  -104,     3,0, 0x0000,0x0000, 0x81,0x40,0x00,0xff }, /*    44 */
  {    13,  -104,     3,0, 0x0000,0x0000, 0x81,0x40,0x00,0xff }, /*    45 */
  {    13,  -138,     3,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    46 */
  {    38,  -104,     3,0, 0x0000,0x0000, 0x8e,0x47,0x00,0xff }, /*    47 */
  {    13,  -138,     3,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    48 */
  {    38,  -138,     3,0, 0x0000,0x0000, 0x70,0x38,0x00,0xff }, /*    49 */
  {    38,  -104,     3,0, 0x0000,0x0000, 0x8e,0x47,0x00,0xff }, /*    50 */
  {    13,  -104,   -22,0, 0x0000,0x0000, 0x8b,0x45,0x00,0xff }, /*    51 */
  {    13,  -138,   -22,0, 0x0000,0x0000, 0x55,0x2a,0x00,0xff }, /*    52 */
  {    13,  -138,     3,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    53 */
  {    38,   -80,     3,0, 0x0000,0x0000, 0xd7,0x9c,0x70,0xff }, /*    54 */
  {    38,  -104,     3,0, 0x0000,0x0000, 0xe5,0xa5,0x77,0xff }, /*    55 */
  {    38,  -104,   -22,0, 0x0000,0x0000, 0x9f,0x73,0x52,0xff }, /*    56 */
  {    13,   -80,   -22,0, 0x0000,0x0000, 0xf7,0xb3,0x80,0xff }, /*    57 */
  {    13,  -104,   -22,0, 0x0000,0x0000, 0xe0,0xa2,0x74,0xff }, /*    58 */
  {    13,  -104,     3,0, 0x0000,0x0000, 0xd0,0x96,0x6c,0xff }, /*    59 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_356_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 28, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP2Triangles(  4,  5,  6,  0,  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP2Triangles( 13, 14, 15,  0, 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_356_ = {
  gfx_Shape_of___POLYHEDRON_356_,
  vtx_Shape_of___POLYHEDRON_356_, 60, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner13[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_360_[] = {
  {    10,  -129,   -24,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*     0 */
  {    44,  -151,   -30,0, 0x0000,0x0000, 0x55,0x2a,0x00,0xff }, /*     1 */
  {     5,  -151,   -23,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*     2 */
  {    55,  -119,     8,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*     3 */
  {    10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*     4 */
  {    52,  -109,    39,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*     5 */
  {    13,  -151,    46,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*     6 */
  {    39,  -138,    62,0, 0x0000,0x0000, 0x88,0x44,0x00,0xff }, /*     7 */
  {    18,  -109,    45,0, 0x0000,0x0000, 0xad,0x56,0x00,0xff }, /*     8 */
  {    10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*     9 */
  {    18,  -109,    45,0, 0x0000,0x0000, 0xad,0x56,0x00,0xff }, /*    10 */
  {    52,  -109,    39,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*    11 */
  {    59,  -151,     7,0, 0x0000,0x0000, 0x61,0x30,0x00,0xff }, /*    12 */
  {    13,  -151,    46,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*    13 */
  {     5,  -151,    17,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    14 */
  {     5,  -151,    17,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    15 */
  {    44,  -151,   -30,0, 0x0000,0x0000, 0x55,0x2a,0x00,0xff }, /*    16 */
  {    59,  -151,     7,0, 0x0000,0x0000, 0x61,0x30,0x00,0xff }, /*    17 */
  {     5,  -151,    17,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    18 */
  {     5,  -151,   -23,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    19 */
  {    44,  -151,   -30,0, 0x0000,0x0000, 0x55,0x2a,0x00,0xff }, /*    20 */
  {    18,  -109,    45,0, 0x0000,0x0000, 0xad,0x56,0x00,0xff }, /*    21 */
  {    10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    22 */
  {    13,  -151,    46,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*    23 */
  {    55,  -119,     8,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*    24 */
  {    65,  -151,    37,0, 0x0000,0x0000, 0x54,0x2a,0x00,0xff }, /*    25 */
  {    59,  -151,     7,0, 0x0000,0x0000, 0x61,0x30,0x00,0xff }, /*    26 */
  {    65,  -151,    37,0, 0x0000,0x0000, 0x54,0x2a,0x00,0xff }, /*    27 */
  {    39,  -138,    62,0, 0x0000,0x0000, 0x88,0x44,0x00,0xff }, /*    28 */
  {    13,  -151,    46,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*    29 */
  {    52,  -109,    39,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*    30 */
  {    39,  -138,    62,0, 0x0000,0x0000, 0x88,0x44,0x00,0xff }, /*    31 */
  {    65,  -151,    37,0, 0x0000,0x0000, 0x54,0x2a,0x00,0xff }, /*    32 */
  {    18,  -109,    45,0, 0x0000,0x0000, 0xad,0x56,0x00,0xff }, /*    33 */
  {    39,  -138,    62,0, 0x0000,0x0000, 0x88,0x44,0x00,0xff }, /*    34 */
  {    52,  -109,    39,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*    35 */
  {    55,  -119,     8,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*    36 */
  {    10,  -129,   -24,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*    37 */
  {    10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    38 */
  {    10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    39 */
  {     5,  -151,   -23,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    40 */
  {     5,  -151,    17,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    41 */
  {    59,  -151,     7,0, 0x0000,0x0000, 0x61,0x30,0x00,0xff }, /*    42 */
  {    41,  -129,   -29,0, 0x0000,0x0000, 0x6f,0x37,0x00,0xff }, /*    43 */
  {    55,  -119,     8,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*    44 */
  {    59,  -151,     7,0, 0x0000,0x0000, 0x61,0x30,0x00,0xff }, /*    45 */
  {    44,  -151,   -30,0, 0x0000,0x0000, 0x55,0x2a,0x00,0xff }, /*    46 */
  {    41,  -129,   -29,0, 0x0000,0x0000, 0x6f,0x37,0x00,0xff }, /*    47 */
  {    10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    48 */
  {    10,  -129,   -24,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*    49 */
  {     5,  -151,   -23,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    50 */
  {    55,  -119,     8,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*    51 */
  {    41,  -129,   -29,0, 0x0000,0x0000, 0x6f,0x37,0x00,0xff }, /*    52 */
  {    10,  -129,   -24,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*    53 */
  {    55,  -119,     8,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*    54 */
  {    52,  -109,    39,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*    55 */
  {    65,  -151,    37,0, 0x0000,0x0000, 0x54,0x2a,0x00,0xff }, /*    56 */
  {    10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    57 */
  {     5,  -151,    17,0, 0x0000,0x0000, 0x42,0x21,0x00,0xff }, /*    58 */
  {    13,  -151,    46,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*    59 */
  {    59,  -151,     7,0, 0x0000,0x0000, 0x61,0x30,0x00,0xff }, /*    60 */
  {    65,  -151,    37,0, 0x0000,0x0000, 0x54,0x2a,0x00,0xff }, /*    61 */
  {    13,  -151,    46,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*    62 */
  {    10,  -129,   -24,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*    63 */
  {    41,  -129,   -29,0, 0x0000,0x0000, 0x6f,0x37,0x00,0xff }, /*    64 */
  {    44,  -151,   -30,0, 0x0000,0x0000, 0x55,0x2a,0x00,0xff }, /*    65 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_360_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP2Triangles(  3,  4,  5,  0,  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 992), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 1024), 2, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_360_ = {
  gfx_Shape_of___POLYHEDRON_360_,
  vtx_Shape_of___POLYHEDRON_360_, 66, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner14[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_348_[] = {
  {    46,   -16,    12,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*     0 */
  {     0,   -70,    15,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*     1 */
  {    53,   -70,    15,0, 0x0000,0x0000, 0x00,0x48,0x00,0xff }, /*     2 */
  {    46,   -16,    12,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*     3 */
  {    24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*     4 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x53,0x00,0xff }, /*     5 */
  {    46,   -16,    12,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*     6 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x53,0x00,0xff }, /*     7 */
  {     0,   -70,    15,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*     8 */
  {     0,    -9,   -35,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*     9 */
  {    45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    10 */
  {     0,   -70,   -37,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    11 */
  {    45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    12 */
  {    53,   -70,   -37,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    13 */
  {     0,   -70,   -37,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    14 */
  {    24,     7,   -24,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    15 */
  {     8,     7,   -24,0, 0x0000,0x0000, 0x00,0x49,0x00,0xff }, /*    16 */
  {    24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    17 */
  {     8,     7,   -24,0, 0x0000,0x0000, 0x00,0x49,0x00,0xff }, /*    18 */
  {     8,     7,    -3,0, 0x0000,0x0000, 0x00,0x57,0x00,0xff }, /*    19 */
  {    24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    20 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x53,0x00,0xff }, /*    21 */
  {     0,   -70,   -37,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    22 */
  {     0,   -70,    15,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*    23 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x53,0x00,0xff }, /*    24 */
  {     0,    -9,   -35,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    25 */
  {     0,   -70,   -37,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    26 */
  {    45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    27 */
  {    46,   -16,    12,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*    28 */
  {    53,   -70,   -37,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    29 */
  {    45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    30 */
  {    24,     7,   -24,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    31 */
  {    46,   -16,    12,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*    32 */
  {     0,    -9,   -35,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    33 */
  {    24,     7,   -24,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    34 */
  {    45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*    35 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x53,0x00,0xff }, /*    36 */
  {     8,     7,   -24,0, 0x0000,0x0000, 0x00,0x49,0x00,0xff }, /*    37 */
  {     0,    -9,   -35,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    38 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x53,0x00,0xff }, /*    39 */
  {     8,     7,    -3,0, 0x0000,0x0000, 0x00,0x57,0x00,0xff }, /*    40 */
  {     8,     7,   -24,0, 0x0000,0x0000, 0x00,0x49,0x00,0xff }, /*    41 */
  {     0,    -9,   -35,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    42 */
  {     8,     7,   -24,0, 0x0000,0x0000, 0x00,0x49,0x00,0xff }, /*    43 */
  {    24,     7,   -24,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    44 */
  {    24,     7,   -24,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    45 */
  {    24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    46 */
  {    46,   -16,    12,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*    47 */
  {    24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    48 */
  {     8,     7,    -3,0, 0x0000,0x0000, 0x00,0x57,0x00,0xff }, /*    49 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x53,0x00,0xff }, /*    50 */
  {    46,   -16,    12,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*    51 */
  {    53,   -70,    15,0, 0x0000,0x0000, 0x00,0x48,0x00,0xff }, /*    52 */
  {    53,   -70,   -37,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    53 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_348_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 22, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP2Triangles(  4,  5,  6,  0,  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_348_ = {
  gfx_Shape_of___POLYHEDRON_348_,
  vtx_Shape_of___POLYHEDRON_348_, 54, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner15[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_346_[] = {
  {     5,    -7,    -4,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*     0 */
  {   -30,    11,    22,0, 0x0000,0x0000, 0x00,0x3c,0x00,0xff }, /*     1 */
  {    -5,    -7,    -4,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*     2 */
  {     5,    -7,    -4,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*     3 */
  {    30,    11,    22,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*     4 */
  {   -30,    11,    22,0, 0x0000,0x0000, 0x00,0x3c,0x00,0xff }, /*     5 */
  {    -6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x30,0x00,0xff }, /*     6 */
  {    30,    11,   -37,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*     7 */
  {     6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*     8 */
  {     6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*     9 */
  {    30,    11,    22,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*    10 */
  {     5,    -7,    -4,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*    11 */
  {     6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    12 */
  {    30,    11,   -37,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*    13 */
  {    30,    11,    22,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*    14 */
  {    -6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x30,0x00,0xff }, /*    15 */
  {   -30,    11,   -37,0, 0x0000,0x0000, 0x00,0x39,0x00,0xff }, /*    16 */
  {    30,    11,   -37,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*    17 */
  {   -30,    11,    22,0, 0x0000,0x0000, 0x00,0x3c,0x00,0xff }, /*    18 */
  {    30,    11,   -37,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*    19 */
  {   -30,    11,   -37,0, 0x0000,0x0000, 0x00,0x39,0x00,0xff }, /*    20 */
  {   -30,    11,    22,0, 0x0000,0x0000, 0x00,0x3c,0x00,0xff }, /*    21 */
  {    30,    11,    22,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*    22 */
  {    30,    11,   -37,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*    23 */
  {    -5,    -7,    -4,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*    24 */
  {   -30,    11,    22,0, 0x0000,0x0000, 0x00,0x3c,0x00,0xff }, /*    25 */
  {    -6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x30,0x00,0xff }, /*    26 */
  {     6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    27 */
  {    -5,    -7,    -4,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*    28 */
  {    -6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x30,0x00,0xff }, /*    29 */
  {     6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x35,0x00,0xff }, /*    30 */
  {     5,    -7,    -4,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*    31 */
  {    -5,    -7,    -4,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*    32 */
  {   -30,    11,    22,0, 0x0000,0x0000, 0x00,0x3c,0x00,0xff }, /*    33 */
  {   -30,    11,   -37,0, 0x0000,0x0000, 0x00,0x39,0x00,0xff }, /*    34 */
  {    -6,    -7,   -15,0, 0x0000,0x0000, 0x00,0x30,0x00,0xff }, /*    35 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_346_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 4, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_346_ = {
  gfx_Shape_of___POLYHEDRON_346_,
  vtx_Shape_of___POLYHEDRON_346_, 36, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner16[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_344_[] = {
  {   -53,   -70,    15,0, 0x0000,0x0000, 0x00,0x3f,0x00,0xff }, /*     0 */
  {     0,   -70,    15,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*     1 */
  {   -46,   -16,    12,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*     2 */
  {     0,   -70,   -37,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*     3 */
  {   -45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*     4 */
  {     1,    -9,   -35,0, 0x0000,0x0000, 0x00,0x46,0x00,0xff }, /*     5 */
  {     0,   -70,   -37,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*     6 */
  {   -53,   -70,   -37,0, 0x0000,0x0000, 0x00,0x30,0x00,0xff }, /*     7 */
  {   -45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*     8 */
  {   -24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*     9 */
  {    -8,     7,   -24,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*    10 */
  {   -24,     7,   -24,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    11 */
  {   -24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    12 */
  {    -8,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    13 */
  {    -8,     7,   -24,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*    14 */
  {     0,   -70,    15,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*    15 */
  {     0,   -70,   -37,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*    16 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x4d,0x00,0xff }, /*    17 */
  {   -53,   -70,   -37,0, 0x0000,0x0000, 0x00,0x30,0x00,0xff }, /*    18 */
  {   -46,   -16,    12,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*    19 */
  {   -45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*    20 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x4d,0x00,0xff }, /*    21 */
  {   -24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    22 */
  {   -46,   -16,    12,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*    23 */
  {   -46,   -16,    12,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*    24 */
  {   -24,     7,   -24,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    25 */
  {   -45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*    26 */
  {     0,   -70,   -37,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*    27 */
  {     1,    -9,   -35,0, 0x0000,0x0000, 0x00,0x46,0x00,0xff }, /*    28 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x4d,0x00,0xff }, /*    29 */
  {   -45,   -16,   -35,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*    30 */
  {   -24,     7,   -24,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    31 */
  {     1,    -9,   -35,0, 0x0000,0x0000, 0x00,0x46,0x00,0xff }, /*    32 */
  {     1,    -9,   -35,0, 0x0000,0x0000, 0x00,0x46,0x00,0xff }, /*    33 */
  {    -8,     7,   -24,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*    34 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x4d,0x00,0xff }, /*    35 */
  {    -8,     7,   -24,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*    36 */
  {    -8,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    37 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x4d,0x00,0xff }, /*    38 */
  {   -24,     7,   -24,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    39 */
  {    -8,     7,   -24,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*    40 */
  {     1,    -9,   -35,0, 0x0000,0x0000, 0x00,0x46,0x00,0xff }, /*    41 */
  {   -46,   -16,    12,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*    42 */
  {   -24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    43 */
  {   -24,     7,   -24,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*    44 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x4d,0x00,0xff }, /*    45 */
  {    -8,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    46 */
  {   -24,     7,    -3,0, 0x0000,0x0000, 0x00,0x52,0x00,0xff }, /*    47 */
  {   -53,   -70,   -37,0, 0x0000,0x0000, 0x00,0x30,0x00,0xff }, /*    48 */
  {   -53,   -70,    15,0, 0x0000,0x0000, 0x00,0x3f,0x00,0xff }, /*    49 */
  {   -46,   -16,    12,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*    50 */
  {     0,   -70,    15,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*    51 */
  {     0,    -9,    12,0, 0x0000,0x0000, 0x00,0x4d,0x00,0xff }, /*    52 */
  {   -46,   -16,    12,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*    53 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_344_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP2Triangles(  3,  4,  5,  0,  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP2Triangles( 24, 25, 26,  0, 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 22, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_344_ = {
  gfx_Shape_of___POLYHEDRON_344_,
  vtx_Shape_of___POLYHEDRON_344_, 54, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner17[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_354_[] = {
  {   -13,  -104,     3,0, 0x0000,0x0000, 0x95,0x6c,0x4d,0xff }, /*     0 */
  {   -38,   -80,     3,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*     1 */
  {   -38,  -104,     3,0, 0x0000,0x0000, 0xd4,0x99,0x6e,0xff }, /*     2 */
  {   -38,  -104,   -22,0, 0x0000,0x0000, 0x9b,0x70,0x51,0xff }, /*     3 */
  {   -13,   -80,   -22,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*     4 */
  {   -13,  -104,   -22,0, 0x0000,0x0000, 0xde,0xa0,0x73,0xff }, /*     5 */
  {   -13,  -104,     3,0, 0x0000,0x0000, 0x95,0x6c,0x4d,0xff }, /*     6 */
  {   -13,   -80,   -22,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*     7 */
  {   -13,   -80,     3,0, 0x0000,0x0000, 0xcb,0x93,0x69,0xff }, /*     8 */
  {   -38,  -104,   -22,0, 0x0000,0x0000, 0x9b,0x70,0x51,0xff }, /*     9 */
  {   -38,   -80,     3,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    10 */
  {   -38,   -80,   -22,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*    11 */
  {   -13,   -80,     3,0, 0x0000,0x0000, 0xcb,0x93,0x69,0xff }, /*    12 */
  {   -26,   -67,    -9,0, 0x0000,0x0000, 0xfe,0x6e,0x4f,0xff }, /*    13 */
  {   -38,   -80,     3,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    14 */
  {   -38,   -80,     3,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    15 */
  {   -26,   -67,    -9,0, 0x0000,0x0000, 0xfe,0x6e,0x4f,0xff }, /*    16 */
  {   -38,   -80,   -22,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*    17 */
  {   -38,   -80,   -22,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*    18 */
  {   -26,   -67,    -9,0, 0x0000,0x0000, 0xfe,0x6e,0x4f,0xff }, /*    19 */
  {   -13,   -80,   -22,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*    20 */
  {   -13,   -80,   -22,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*    21 */
  {   -26,   -67,    -9,0, 0x0000,0x0000, 0xfe,0x6e,0x4f,0xff }, /*    22 */
  {   -13,   -80,     3,0, 0x0000,0x0000, 0xcb,0x93,0x69,0xff }, /*    23 */
  {   -38,  -104,   -22,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*    24 */
  {   -38,  -138,     3,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*    25 */
  {   -38,  -104,     3,0, 0x0000,0x0000, 0x84,0x42,0x00,0xff }, /*    26 */
  {   -38,  -104,   -22,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*    27 */
  {   -38,  -138,   -22,0, 0x0000,0x0000, 0x5b,0x2d,0x00,0xff }, /*    28 */
  {   -38,  -138,     3,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*    29 */
  {   -13,  -104,   -22,0, 0x0000,0x0000, 0x8a,0x45,0x00,0xff }, /*    30 */
  {   -38,  -138,   -22,0, 0x0000,0x0000, 0x5b,0x2d,0x00,0xff }, /*    31 */
  {   -38,  -104,   -22,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*    32 */
  {   -13,  -104,   -22,0, 0x0000,0x0000, 0x8a,0x45,0x00,0xff }, /*    33 */
  {   -13,  -138,   -22,0, 0x0000,0x0000, 0x65,0x32,0x00,0xff }, /*    34 */
  {   -38,  -138,   -22,0, 0x0000,0x0000, 0x5b,0x2d,0x00,0xff }, /*    35 */
  {   -13,  -104,     3,0, 0x0000,0x0000, 0x5d,0x2e,0x00,0xff }, /*    36 */
  {   -13,  -138,     3,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*    37 */
  {   -13,  -104,   -22,0, 0x0000,0x0000, 0x8a,0x45,0x00,0xff }, /*    38 */
  {   -38,  -104,     3,0, 0x0000,0x0000, 0x84,0x42,0x00,0xff }, /*    39 */
  {   -13,  -138,     3,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*    40 */
  {   -13,  -104,     3,0, 0x0000,0x0000, 0x5d,0x2e,0x00,0xff }, /*    41 */
  {   -38,  -104,     3,0, 0x0000,0x0000, 0x84,0x42,0x00,0xff }, /*    42 */
  {   -38,  -138,     3,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*    43 */
  {   -13,  -138,     3,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*    44 */
  {   -13,  -138,     3,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*    45 */
  {   -13,  -138,   -22,0, 0x0000,0x0000, 0x65,0x32,0x00,0xff }, /*    46 */
  {   -13,  -104,   -22,0, 0x0000,0x0000, 0x8a,0x45,0x00,0xff }, /*    47 */
  {   -38,  -104,   -22,0, 0x0000,0x0000, 0x9b,0x70,0x51,0xff }, /*    48 */
  {   -38,  -104,     3,0, 0x0000,0x0000, 0xd4,0x99,0x6e,0xff }, /*    49 */
  {   -38,   -80,     3,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    50 */
  {   -13,  -104,     3,0, 0x0000,0x0000, 0x95,0x6c,0x4d,0xff }, /*    51 */
  {   -13,  -104,   -22,0, 0x0000,0x0000, 0xde,0xa0,0x73,0xff }, /*    52 */
  {   -13,   -80,   -22,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*    53 */
  {   -38,  -104,   -22,0, 0x0000,0x0000, 0x9b,0x70,0x51,0xff }, /*    54 */
  {   -38,   -80,   -22,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*    55 */
  {   -13,   -80,   -22,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*    56 */
  {   -13,  -104,     3,0, 0x0000,0x0000, 0x95,0x6c,0x4d,0xff }, /*    57 */
  {   -13,   -80,     3,0, 0x0000,0x0000, 0xcb,0x93,0x69,0xff }, /*    58 */
  {   -38,   -80,     3,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    59 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_354_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP2Triangles( 24, 25, 26,  0, 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 28, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_354_ = {
  gfx_Shape_of___POLYHEDRON_354_,
  vtx_Shape_of___POLYHEDRON_354_, 60, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner18[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_358_[] = {
  {    -5,  -151,   -23,0, 0x0000,0x0000, 0x6b,0x35,0x00,0xff }, /*     0 */
  {   -44,  -151,   -30,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*     1 */
  {   -10,  -129,   -24,0, 0x0000,0x0000, 0x90,0x48,0x00,0xff }, /*     2 */
  {   -52,  -109,    39,0, 0x0000,0x0000, 0xac,0x56,0x00,0xff }, /*     3 */
  {   -10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*     4 */
  {   -55,  -119,     8,0, 0x0000,0x0000, 0x93,0x49,0x00,0xff }, /*     5 */
  {   -52,  -109,    39,0, 0x0000,0x0000, 0xac,0x56,0x00,0xff }, /*     6 */
  {   -39,  -138,    62,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*     7 */
  {   -18,  -109,    45,0, 0x0000,0x0000, 0x9d,0x4e,0x00,0xff }, /*     8 */
  {   -52,  -109,    39,0, 0x0000,0x0000, 0xac,0x56,0x00,0xff }, /*     9 */
  {   -18,  -109,    45,0, 0x0000,0x0000, 0x9d,0x4e,0x00,0xff }, /*    10 */
  {   -10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    11 */
  {    -5,  -151,    17,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*    12 */
  {   -13,  -151,    46,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    13 */
  {   -59,  -151,     7,0, 0x0000,0x0000, 0x41,0x20,0x00,0xff }, /*    14 */
  {   -59,  -151,     7,0, 0x0000,0x0000, 0x41,0x20,0x00,0xff }, /*    15 */
  {   -44,  -151,   -30,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*    16 */
  {    -5,  -151,    17,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*    17 */
  {   -13,  -151,    46,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    18 */
  {   -10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    19 */
  {   -18,  -109,    45,0, 0x0000,0x0000, 0x9d,0x4e,0x00,0xff }, /*    20 */
  {   -18,  -109,    45,0, 0x0000,0x0000, 0x9d,0x4e,0x00,0xff }, /*    21 */
  {   -39,  -138,    62,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*    22 */
  {   -13,  -151,    46,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    23 */
  {   -13,  -151,    46,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    24 */
  {    -5,  -151,    17,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*    25 */
  {   -10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    26 */
  {   -59,  -151,     7,0, 0x0000,0x0000, 0x41,0x20,0x00,0xff }, /*    27 */
  {   -65,  -151,    37,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*    28 */
  {   -55,  -119,     8,0, 0x0000,0x0000, 0x93,0x49,0x00,0xff }, /*    29 */
  {   -55,  -119,     8,0, 0x0000,0x0000, 0x93,0x49,0x00,0xff }, /*    30 */
  {   -41,  -129,   -29,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*    31 */
  {   -59,  -151,     7,0, 0x0000,0x0000, 0x41,0x20,0x00,0xff }, /*    32 */
  {   -13,  -151,    46,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    33 */
  {   -39,  -138,    62,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*    34 */
  {   -65,  -151,    37,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*    35 */
  {   -65,  -151,    37,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*    36 */
  {   -39,  -138,    62,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*    37 */
  {   -52,  -109,    39,0, 0x0000,0x0000, 0xac,0x56,0x00,0xff }, /*    38 */
  {   -10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    39 */
  {   -10,  -129,   -24,0, 0x0000,0x0000, 0x90,0x48,0x00,0xff }, /*    40 */
  {   -55,  -119,     8,0, 0x0000,0x0000, 0x93,0x49,0x00,0xff }, /*    41 */
  {   -10,  -129,   -24,0, 0x0000,0x0000, 0x90,0x48,0x00,0xff }, /*    42 */
  {   -41,  -129,   -29,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*    43 */
  {   -55,  -119,     8,0, 0x0000,0x0000, 0x93,0x49,0x00,0xff }, /*    44 */
  {    -5,  -151,    17,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*    45 */
  {    -5,  -151,   -23,0, 0x0000,0x0000, 0x6b,0x35,0x00,0xff }, /*    46 */
  {   -10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    47 */
  {   -41,  -129,   -29,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*    48 */
  {   -44,  -151,   -30,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*    49 */
  {   -59,  -151,     7,0, 0x0000,0x0000, 0x41,0x20,0x00,0xff }, /*    50 */
  {   -44,  -151,   -30,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*    51 */
  {    -5,  -151,   -23,0, 0x0000,0x0000, 0x6b,0x35,0x00,0xff }, /*    52 */
  {    -5,  -151,    17,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*    53 */
  {    -5,  -151,   -23,0, 0x0000,0x0000, 0x6b,0x35,0x00,0xff }, /*    54 */
  {   -10,  -129,   -24,0, 0x0000,0x0000, 0x90,0x48,0x00,0xff }, /*    55 */
  {   -10,  -119,    16,0, 0x0000,0x0000, 0x95,0x4a,0x00,0xff }, /*    56 */
  {   -65,  -151,    37,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*    57 */
  {   -52,  -109,    39,0, 0x0000,0x0000, 0xac,0x56,0x00,0xff }, /*    58 */
  {   -55,  -119,     8,0, 0x0000,0x0000, 0x93,0x49,0x00,0xff }, /*    59 */
  {   -13,  -151,    46,0, 0x0000,0x0000, 0x52,0x29,0x00,0xff }, /*    60 */
  {   -65,  -151,    37,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*    61 */
  {   -59,  -151,     7,0, 0x0000,0x0000, 0x41,0x20,0x00,0xff }, /*    62 */
  {   -44,  -151,   -30,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*    63 */
  {   -41,  -129,   -29,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*    64 */
  {   -10,  -129,   -24,0, 0x0000,0x0000, 0x90,0x48,0x00,0xff }, /*    65 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_358_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP2Triangles(  3,  4,  5,  0,  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 992), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 1024), 2, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_358_ = {
  gfx_Shape_of___POLYHEDRON_358_,
  vtx_Shape_of___POLYHEDRON_358_, 66, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

static Gfx _frake_kime_aligner19[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_350_[] = {
  {   -38,   -53,   -22,0, 0x0000,0x0000, 0xb4,0x82,0x5d,0xff }, /*     0 */
  {   -38,   -75,     3,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*     1 */
  {   -38,   -53,     3,0, 0x0000,0x0000, 0xff,0xbc,0x87,0xff }, /*     2 */
  {   -38,   -53,   -22,0, 0x0000,0x0000, 0xb4,0x82,0x5d,0xff }, /*     3 */
  {   -38,   -75,   -22,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*     4 */
  {   -38,   -75,     3,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*     5 */
  {   -13,   -53,   -22,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*     6 */
  {   -38,   -75,   -22,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*     7 */
  {   -38,   -53,   -22,0, 0x0000,0x0000, 0xb4,0x82,0x5d,0xff }, /*     8 */
  {   -13,   -53,   -22,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*     9 */
  {   -13,   -75,   -22,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    10 */
  {   -38,   -75,   -22,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*    11 */
  {   -13,   -53,     3,0, 0x0000,0x0000, 0xf6,0xb2,0x80,0xff }, /*    12 */
  {   -13,   -75,     3,0, 0x0000,0x0000, 0x83,0x5f,0x44,0xff }, /*    13 */
  {   -13,   -53,   -22,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    14 */
  {   -38,   -53,     3,0, 0x0000,0x0000, 0xff,0xbc,0x87,0xff }, /*    15 */
  {   -13,   -75,     3,0, 0x0000,0x0000, 0x83,0x5f,0x44,0xff }, /*    16 */
  {   -13,   -53,     3,0, 0x0000,0x0000, 0xf6,0xb2,0x80,0xff }, /*    17 */
  {   -38,   -53,     3,0, 0x0000,0x0000, 0xff,0xbc,0x87,0xff }, /*    18 */
  {   -38,   -75,     3,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*    19 */
  {   -13,   -75,     3,0, 0x0000,0x0000, 0x83,0x5f,0x44,0xff }, /*    20 */
  {   -13,   -75,     3,0, 0x0000,0x0000, 0x83,0x5f,0x44,0xff }, /*    21 */
  {   -13,   -75,   -22,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    22 */
  {   -13,   -53,   -22,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    23 */
  {   -13,   -75,   -22,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    24 */
  {   -26,   -86,    -9,0, 0x0000,0x0000, 0x87,0x3a,0x2a,0xff }, /*    25 */
  {   -38,   -75,   -22,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*    26 */
  {   -38,   -75,   -22,0, 0x0000,0x0000, 0x97,0x6d,0x4e,0xff }, /*    27 */
  {   -26,   -86,    -9,0, 0x0000,0x0000, 0x87,0x3a,0x2a,0xff }, /*    28 */
  {   -38,   -75,     3,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*    29 */
  {   -38,   -75,     3,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*    30 */
  {   -26,   -86,    -9,0, 0x0000,0x0000, 0x87,0x3a,0x2a,0xff }, /*    31 */
  {   -13,   -75,     3,0, 0x0000,0x0000, 0x83,0x5f,0x44,0xff }, /*    32 */
  {   -13,   -75,     3,0, 0x0000,0x0000, 0x83,0x5f,0x44,0xff }, /*    33 */
  {   -26,   -86,    -9,0, 0x0000,0x0000, 0x87,0x3a,0x2a,0xff }, /*    34 */
  {   -13,   -75,   -22,0, 0x0000,0x0000, 0xaa,0x7b,0x58,0xff }, /*    35 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_350_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 4, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_350_ = {
  gfx_Shape_of___POLYHEDRON_350_,
  vtx_Shape_of___POLYHEDRON_350_, 36, 5,
  bmp_frake_kime,
  NULL,
  6, 7,
  NULL,
  NULL,
  NULL,
  NULL
};

/* ============================================================
          Geometric Animation Data Area
 ============================================================ */
static s16 Animation_for_body_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch0_val[]={
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, -0.5559, -1.1026, -1.6371, -2.1570,
  -2.6595, -3.1423, -3.6029, -4.0392, -4.0392, -4.0392, -4.0392, -4.0392,
  -4.0392, -4.0392, -4.0392, -4.0392, -4.0392, -4.0392,
};

static s16 Animation_for_body_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch1_val[]={
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, -0.1219, -0.2781, -0.4677, -0.6895,
  -0.9425, -1.2251, -1.5357, -1.8725, -1.8725, -1.8725, -1.8725, -1.8725,
  -1.8725, -1.8725, -1.8725, -1.8725, -1.8725, -1.8725,
};

static s16 Animation_for_body_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch2_val[]={
  -12.3406, -11.3122, -10.2838, -9.2554, -8.2271, -7.1987, -6.1703,
  -5.1419, -4.1135, -3.0851, -2.0568, -1.0284, 0.0000, -0.0131, -0.0525,
  -0.1180, -0.2095, -0.3269, -0.4698, -0.6380, -0.8311, -0.8311, -0.8311,
  -0.8311, -0.8311, -0.8311, -0.8311, -0.8311, -0.8311, -0.8311, -0.8311,
 };

static s16 Animation_for_body_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch3_val[]={
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000,
};

static s16 Animation_for_body_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch4_val[]={
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, -0.0461, -0.0923, -0.1384, -0.1845,
  -0.2307, -0.2768, -0.3230, -0.3691, -0.3691, -0.3691, -0.3691, -0.3691,
  -0.3691, -0.3691, -0.3691, -0.3691, -0.3691, -0.3691,
};

static s16 Animation_for_body_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch5_val[]={
  0.0000, 0.0154, 0.0308, 0.0462, 0.0616, 0.0770, 0.0924, 0.1078, 0.1232,
  0.1386, 0.1539, 0.1693, 0.1847, 0.2159, 0.2471, 0.2782, 0.3094, 0.3406,
  0.3717, 0.4029, 0.4341, 0.4341, 0.4341, 0.4341, 0.4341, 0.4341, 0.4341,
  0.4341, 0.4341, 0.4341, 0.4341,
};

static s16 Animation_for_body_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_body_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_body_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_body_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_body_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_body_motion_ch0_key, Animation_for_body_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_body_motion_ch1_key, Animation_for_body_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_body_motion_ch2_key, Animation_for_body_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_body_motion_ch3_key, Animation_for_body_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_body_motion_ch4_key, Animation_for_body_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_body_motion_ch5_key, Animation_for_body_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_body_motion_ch6_key, Animation_for_body_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_body_motion_ch7_key, Animation_for_body_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_body_motion_ch8_key, Animation_for_body_motion_ch8_val},
};

static NDR_ANIM Animation_for_body_motion={
  Animation_for_body_motion_chlist, 9, 30
};

static s16 Animation_for_R_uparm_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch0_val[]={
  0.0000, 1.9370, 1.5347, -1.3960, -6.8895, -14.8230, -24.9257, -36.7993,
  -49.9466, -63.8091, -77.8058, -91.3753, -104.0130, -103.0527, -101.6016,
  -99.6788, -97.3083, -94.5169, -91.3350, -87.7971, -83.9400, -83.9400,
  -83.9400, -83.9400, -83.9400, -83.9400, -83.9400, -83.9400, -83.9400,
  -83.9400, -83.9400,
};

static s16 Animation_for_R_uparm_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch1_val[]={
  0.0000, 1.0458, 4.7507, 10.7307, 18.5152, 27.5824, 37.3987, 47.4550,
  57.2996, 66.5630, 74.9748, 82.3704, 88.6875, 83.1972, 77.9010, 72.8423,
  68.0635, 63.6042, 59.5014, 55.7898, 52.5003, 52.5003, 52.5003, 52.5003,
  52.5003, 52.5003, 52.5003, 52.5003, 52.5003, 52.5003, 52.5003,
};

static s16 Animation_for_R_uparm_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch2_val[]={
  0.0000, -19.1408, -37.7941, -55.2848, -70.9912, -84.3760, -95.0133,
  -102.6073, -107.0048, -108.1998, -106.3277, -101.6537, -94.5539, -94.3663,
  -94.2203, -94.1270, -94.0975, -94.1409, -94.2650, -94.4758, -94.7778,
  -94.7778, -94.7778, -94.7778, -94.7778, -94.7778, -94.7778, -94.7778,
  -94.7778, -94.7778, -94.7778,
};

static s16 Animation_for_R_uparm_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch3_val[]={
  0.0000, 0.1780, 0.3521, 0.5204, 0.6812, 0.8326, 0.9732, 1.1015, 1.2157,
  1.3137, 1.3921, 1.4444, 1.4579, 1.4630, 1.4708, 1.4809, 1.4934, 1.5081,
  1.5244, 1.5422, 1.5608, 1.5608, 1.5608, 1.5608, 1.5608, 1.5608, 1.5608,
  1.5608, 1.5608, 1.5608, 1.5608,
};

static s16 Animation_for_R_uparm_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch4_val[]={
  0.0000, 0.0326, 0.0717, 0.1194, 0.1775, 0.2467, 0.3274, 0.4195, 0.5220,
  0.6340, 0.7540, 0.8800, 1.0092, 1.0131, 1.0166, 1.0196, 1.0218, 1.0229,
  1.0228, 1.0213, 1.0181, 1.0181, 1.0181, 1.0181, 1.0181, 1.0181, 1.0181,
  1.0181, 1.0181, 1.0181, 1.0181,
};

static s16 Animation_for_R_uparm_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch5_val[]={
  0.0000, 0.0228, 0.0370, 0.0439, 0.0452, 0.0424, 0.0364, 0.0279, 0.0163,
  0.0002, -0.0240, -0.0628, -0.1297, -0.0348, 0.0622, 0.1613, 0.2623,
  0.3651, 0.4693, 0.5745, 0.6804, 0.6804, 0.6804, 0.6804, 0.6804, 0.6804,
  0.6804, 0.6804, 0.6804, 0.6804, 0.6804,
};

static s16 Animation_for_R_uparm_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_uparm_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_uparm_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_uparm_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_R_uparm_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_R_uparm_motion_ch0_key, Animation_for_R_uparm_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_R_uparm_motion_ch1_key, Animation_for_R_uparm_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_R_uparm_motion_ch2_key, Animation_for_R_uparm_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_R_uparm_motion_ch3_key, Animation_for_R_uparm_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_R_uparm_motion_ch4_key, Animation_for_R_uparm_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_R_uparm_motion_ch5_key, Animation_for_R_uparm_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_R_uparm_motion_ch6_key, Animation_for_R_uparm_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_R_uparm_motion_ch7_key, Animation_for_R_uparm_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_R_uparm_motion_ch8_key, Animation_for_R_uparm_motion_ch8_val},
};

static NDR_ANIM Animation_for_R_uparm_motion={
  Animation_for_R_uparm_motion_chlist, 9, 30
};

static s16 Animation_for_R_lowarm_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch0_val[]={
  -0.0000, 0.5187, 0.9067, 1.1581, 1.2695, 1.2392, 1.0678, 0.7577, 0.3133,
  -0.2593, -0.9515, -1.7538, -2.6546, -2.5748, -2.4955, -2.4171, -2.3392,
  -2.2618, -2.1852, -2.1092, -2.0338, -2.0338, -2.0338, -2.0338, -2.0338,
  -2.0338, -2.0338, -2.0338, -2.0338, -2.0338, -2.0338,
};

static s16 Animation_for_R_lowarm_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch1_val[]={
  0.0000, 0.7126, 1.2454, 1.5910, 1.7439, 1.7023, 1.4669, 1.0410, 0.4302,
  -0.3561, -1.3072, -2.4094, -3.6469, -3.5374, -3.4284, -3.3207, -3.2137,
  -3.1073, -3.0021, -2.8978, -2.7944, -2.7944, -2.7944, -2.7944, -2.7944,
  -2.7944, -2.7944, -2.7944, -2.7944, -2.7944, -2.7944,
};

static s16 Animation_for_R_lowarm_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch2_val[]={
  0.0000, -1.8149, -3.7218, -5.6937, -7.7024, -9.7194, -11.7159, -13.6635,
  -15.5344, -17.3021, -18.9412, -20.4287, -21.7432, -21.6390, -21.5332,
  -21.4265, -21.3183, -21.2087, -21.0977, -20.9857, -20.8722, -20.8722,
  -20.8722, -20.8722, -20.8722, -20.8722, -20.8722, -20.8722, -20.8722,
  -20.8722, -20.8722,
};

static s16 Animation_for_R_lowarm_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch3_val[]={
  0.0000, -0.0967, -0.1943, -0.2939, -0.3963, -0.5025, -0.6134, -0.7297,
  -0.8521, -0.9808, -1.1157, -1.2561, -1.4007, -1.3883, -1.3760, -1.3636,
  -1.3513, -1.3390, -1.3268, -1.3145, -1.3023, -1.3023, -1.3023, -1.3023,
  -1.3023, -1.3023, -1.3023, -1.3023, -1.3023, -1.3023, -1.3023,
};

static s16 Animation_for_R_lowarm_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch4_val[]={
  0.0000, 0.0702, 0.1397, 0.2078, 0.2739, 0.3372, 0.3968, 0.4518, 0.5012,
  0.5440, 0.5790, 0.6054, 0.6223, 0.6213, 0.6201, 0.6190, 0.6177, 0.6164,
  0.6150, 0.6135, 0.6119, 0.6119, 0.6119, 0.6119, 0.6119, 0.6119, 0.6119,
  0.6119, 0.6119, 0.6119, 0.6119,
};

static s16 Animation_for_R_lowarm_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch5_val[]={
  -0.0000, -0.0034, -0.0136, -0.0309, -0.0553, -0.0873, -0.1272, -0.1751,
  -0.2313, -0.2956, -0.3675, -0.4460, -0.5294, -0.5222, -0.5150, -0.5079,
  -0.5007, -0.4936, -0.4865, -0.4795, -0.4725, -0.4725, -0.4725, -0.4725,
  -0.4725, -0.4725, -0.4725, -0.4725, -0.4725, -0.4725, -0.4725,
};

static s16 Animation_for_R_lowarm_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_lowarm_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_lowarm_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowarm_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_R_lowarm_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch0_key, Animation_for_R_lowarm_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch1_key, Animation_for_R_lowarm_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch2_key, Animation_for_R_lowarm_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch3_key, Animation_for_R_lowarm_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch4_key, Animation_for_R_lowarm_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch5_key, Animation_for_R_lowarm_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch6_key, Animation_for_R_lowarm_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch7_key, Animation_for_R_lowarm_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_R_lowarm_motion_ch8_key, Animation_for_R_lowarm_motion_ch8_val},
};

static NDR_ANIM Animation_for_R_lowarm_motion={
  Animation_for_R_lowarm_motion_chlist, 9, 30
};

static s16 Animation_for_R_hand_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch0_val[]={
  -0.0000, 0.3453, 0.0875, -0.7694, -2.2110, -4.2128, -6.7413, -9.7538,
  -13.1991, -17.0192, -21.1496, -25.5202, -30.0573, -26.6929, -23.4084,
  -20.2336, -17.1982, -14.3302, -11.6562, -9.2010, -6.9874, -6.9874,
  -6.9874, -6.9874, -6.9874, -6.9874, -6.9874, -6.9874, -6.9874, -6.9874,
  -6.9874,
};

static s16 Animation_for_R_hand_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch1_val[]={
  0.0000, 0.4684, 0.1292, -1.0118, -2.9356, -5.6095, -8.9885, -13.0154,
  -17.6218, -22.7302, -28.2534, -34.0986, -40.1661, -35.6604, -31.2611,
  -27.0088, -22.9430, -19.1014, -15.5195, -12.2308, -9.2654, -9.2654,
  -9.2654, -9.2654, -9.2654, -9.2654, -9.2654, -9.2654, -9.2654, -9.2654,
  -9.2654,
};

static s16 Animation_for_R_hand_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch2_val[]={
  0.0000, -7.7218, -15.4545, -23.0671, -30.4303, -37.4197, -43.9165,
  -49.8108, -55.0019, -59.4026, -62.9379, -65.5473, -67.1872, -66.0755,
  -64.4289, -62.2616, -59.5942, -56.4516, -52.8624, -48.8599, -44.4813,
  -44.4813, -44.4813, -44.4813, -44.4813, -44.4813, -44.4813, -44.4813,
  -44.4813, -44.4813, -44.4813,
};

static s16 Animation_for_R_hand_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch3_val[]={
  0.0000, -0.1053, -0.2120, -0.3211, -0.4341, -0.5521, -0.6764, -0.8079,
  -0.9471, -1.0941, -1.2483, -1.4080, -1.5708, -1.4511, -1.3327, -1.2167,
  -1.1039, -0.9950, -0.8904, -0.7901, -0.6939, -0.6939, -0.6939, -0.6939,
  -0.6939, -0.6939, -0.6939, -0.6939, -0.6939, -0.6939, -0.6939,
};

static s16 Animation_for_R_hand_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch4_val[]={
  0.0000, 0.0778, 0.1548, 0.2301, 0.3026, 0.3714, 0.4353, 0.4930, 0.5432,
  0.5844, 0.6152, 0.6345, 0.6415, 0.6376, 0.6268, 0.6095, 0.5860, 0.5568,
  0.5225, 0.4836, 0.4408, 0.4408, 0.4408, 0.4408, 0.4408, 0.4408, 0.4408,
  0.4408, 0.4408, 0.4408, 0.4408,
};

static s16 Animation_for_R_hand_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch5_val[]={
  0.0000, -0.0041, -0.0164, -0.0372, -0.0668, -0.1056, -0.1542, -0.2128,
  -0.2815, -0.3598, -0.4465, -0.5397, -0.6363, -0.5647, -0.4945, -0.4271,
  -0.3635, -0.3045, -0.2505, -0.2020, -0.1590, -0.1590, -0.1590, -0.1590,
  -0.1590, -0.1590, -0.1590, -0.1590, -0.1590, -0.1590, -0.1590,
};

static s16 Animation_for_R_hand_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_hand_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_hand_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_hand_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_R_hand_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_R_hand_motion_ch0_key, Animation_for_R_hand_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_R_hand_motion_ch1_key, Animation_for_R_hand_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_R_hand_motion_ch2_key, Animation_for_R_hand_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_R_hand_motion_ch3_key, Animation_for_R_hand_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_R_hand_motion_ch4_key, Animation_for_R_hand_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_R_hand_motion_ch5_key, Animation_for_R_hand_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_R_hand_motion_ch6_key, Animation_for_R_hand_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_R_hand_motion_ch7_key, Animation_for_R_hand_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_R_hand_motion_ch8_key, Animation_for_R_hand_motion_ch8_val},
};

static NDR_ANIM Animation_for_R_hand_motion={
  Animation_for_R_hand_motion_chlist, 9, 30
};

static s16 Animation_for_R_sode_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch0_val[]={
  0.0000, 1.9370, 1.5347, -1.3960, -6.8895, -14.8230, -24.9257, -36.7993,
  -49.9466, -63.8091, -77.8058, -91.3753, -104.0130, -103.0527, -101.6016,
  -99.6788, -97.3083, -94.5169, -91.3350, -87.7971, -83.9400, -83.9400,
  -83.9400, -83.9400, -83.9400, -83.9400, -83.9400, -83.9400, -83.9400,
  -83.9400, -83.9400,
};

static s16 Animation_for_R_sode_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch1_val[]={
  0.0000, 1.0458, 4.7507, 10.7307, 18.5152, 27.5824, 37.3987, 47.4550,
  57.2996, 66.5630, 74.9748, 82.3704, 88.6875, 83.1972, 77.9010, 72.8423,
  68.0635, 63.6042, 59.5014, 55.7898, 52.5003, 52.5003, 52.5003, 52.5003,
  52.5003, 52.5003, 52.5003, 52.5003, 52.5003, 52.5003, 52.5003,
};

static s16 Animation_for_R_sode_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch2_val[]={
  0.0000, -19.1408, -37.7941, -55.2848, -70.9912, -84.3760, -95.0133,
  -102.6073, -107.0048, -108.1998, -106.3277, -101.6537, -94.5539, -94.3663,
  -94.2203, -94.1270, -94.0975, -94.1409, -94.2650, -94.4758, -94.7778,
  -94.7778, -94.7778, -94.7778, -94.7778, -94.7778, -94.7778, -94.7778,
  -94.7778, -94.7778, -94.7778,
};

static s16 Animation_for_R_sode_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch3_val[]={
  0.0000, 0.1780, 0.3521, 0.5204, 0.6812, 0.8326, 0.9732, 1.1015, 1.2157,
  1.3137, 1.3921, 1.4444, 1.4579, 1.4630, 1.4708, 1.4809, 1.4934, 1.5081,
  1.5244, 1.5422, 1.5608, 1.5608, 1.5608, 1.5608, 1.5608, 1.5608, 1.5608,
  1.5608, 1.5608, 1.5608, 1.5608,
};

static s16 Animation_for_R_sode_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch4_val[]={
  0.0000, 0.0326, 0.0717, 0.1194, 0.1775, 0.2467, 0.3274, 0.4195, 0.5220,
  0.6340, 0.7540, 0.8800, 1.0092, 1.0131, 1.0166, 1.0196, 1.0218, 1.0229,
  1.0228, 1.0213, 1.0181, 1.0181, 1.0181, 1.0181, 1.0181, 1.0181, 1.0181,
  1.0181, 1.0181, 1.0181, 1.0181,
};

static s16 Animation_for_R_sode_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch5_val[]={
  0.0000, 0.0228, 0.0370, 0.0439, 0.0452, 0.0424, 0.0364, 0.0279, 0.0163,
  0.0002, -0.0240, -0.0628, -0.1297, -0.0348, 0.0622, 0.1613, 0.2623,
  0.3651, 0.4693, 0.5745, 0.6804, 0.6804, 0.6804, 0.6804, 0.6804, 0.6804,
  0.6804, 0.6804, 0.6804, 0.6804, 0.6804,
};

static s16 Animation_for_R_sode_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_sode_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_sode_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_sode_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_R_sode_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_R_sode_motion_ch0_key, Animation_for_R_sode_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_R_sode_motion_ch1_key, Animation_for_R_sode_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_R_sode_motion_ch2_key, Animation_for_R_sode_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_R_sode_motion_ch3_key, Animation_for_R_sode_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_R_sode_motion_ch4_key, Animation_for_R_sode_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_R_sode_motion_ch5_key, Animation_for_R_sode_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_R_sode_motion_ch6_key, Animation_for_R_sode_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_R_sode_motion_ch7_key, Animation_for_R_sode_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_R_sode_motion_ch8_key, Animation_for_R_sode_motion_ch8_val},
};

static NDR_ANIM Animation_for_R_sode_motion={
  Animation_for_R_sode_motion_chlist, 9, 30
};

static s16 Animation_for_L_uparm_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch0_val[]={
  0.0000, -5.2006, -7.8028, -7.3780, -3.7385, 3.0518, 12.6895, 24.6665,
  38.3208, 52.9012, 67.6360, 81.8000, 94.7730, 91.9784, 88.8981, 85.5520,
  81.9634, 78.1555, 74.1539, 69.9855, 65.6776, 65.6776, 65.6776, 65.6776,
  65.6776, 65.6776, 65.6776, 65.6776, 65.6776, 65.6776, 65.6776,
};

static s16 Animation_for_L_uparm_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch1_val[]={
  0.0000, 2.5457, 8.0203, 15.7382, 24.8984, 34.6598, 44.2144, 52.8562,
  60.0333, 65.3838, 68.7487, 70.1650, 69.8366, 65.6384, 61.7206, 58.1061,
  54.8171, 51.8728, 49.2908, 47.0860, 45.2718, 45.2718, 45.2718, 45.2718,
  45.2718, 45.2718, 45.2718, 45.2718, 45.2718, 45.2718, 45.2718,
};

static s16 Animation_for_L_uparm_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch2_val[]={
  0.0000, -19.6026, -38.6660, -56.4877, -72.4319, -85.9606, -96.6595,
  -104.2551, -108.6230, -109.7895, -107.9218, -103.3142, -96.3648, -96.5204,
  -96.6684, -96.8168, -96.9729, -97.1439, -97.3358, -97.5539, -97.8027,
  -97.8027, -97.8027, -97.8027, -97.8027, -97.8027, -97.8027, -97.8027,
  -97.8027, -97.8027, -97.8027,
};

static s16 Animation_for_L_uparm_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch3_val[]={
  0.0000, 0.1840, 0.3637, 0.5374, 0.7033, 0.8596, 1.0048, 1.1375, 1.2561,
  1.3589, 1.4428, 1.5023, 1.5263, 1.5245, 1.5234, 1.5233, 1.5239, 1.5254,
  1.5276, 1.5304, 1.5337, 1.5337, 1.5337, 1.5337, 1.5337, 1.5337, 1.5337,
  1.5337, 1.5337, 1.5337, 1.5337,
};

static s16 Animation_for_L_uparm_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch4_val[]={
  0.0000, -0.0294, -0.0653, -0.1101, -0.1656, -0.2327, -0.3117, -0.4024,
  -0.5038, -0.6150, -0.7343, -0.8600, -0.9895, -0.9868, -0.9842, -0.9817,
  -0.9792, -0.9766, -0.9736, -0.9703, -0.9665, -0.9665, -0.9665, -0.9665,
  -0.9665, -0.9665, -0.9665, -0.9665, -0.9665, -0.9665, -0.9665,
};

static s16 Animation_for_L_uparm_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch5_val[]={
  0.0000, -0.0559, -0.1029, -0.1427, -0.1770, -0.2074, -0.2354, -0.2614,
  -0.2854, -0.3058, -0.3198, -0.3213, -0.2985, -0.3755, -0.4532, -0.5316,
  -0.6106, -0.6903, -0.7706, -0.8514, -0.9325, -0.9325, -0.9325, -0.9325,
  -0.9325, -0.9325, -0.9325, -0.9325, -0.9325, -0.9325, -0.9325,
};

static s16 Animation_for_L_uparm_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_uparm_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_uparm_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_uparm_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_L_uparm_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_L_uparm_motion_ch0_key, Animation_for_L_uparm_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_L_uparm_motion_ch1_key, Animation_for_L_uparm_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_L_uparm_motion_ch2_key, Animation_for_L_uparm_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_L_uparm_motion_ch3_key, Animation_for_L_uparm_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_L_uparm_motion_ch4_key, Animation_for_L_uparm_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_L_uparm_motion_ch5_key, Animation_for_L_uparm_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_L_uparm_motion_ch6_key, Animation_for_L_uparm_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_L_uparm_motion_ch7_key, Animation_for_L_uparm_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_L_uparm_motion_ch8_key, Animation_for_L_uparm_motion_ch8_val},
};

static NDR_ANIM Animation_for_L_uparm_motion={
  Animation_for_L_uparm_motion_chlist, 9, 30
};

static s16 Animation_for_L_lowarm_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch0_val[]={
  0.0000, -0.3306, -0.6137, -0.8481, -1.0321, -1.1653, -1.2463, -1.2753,
  -1.2518, -1.1760, -1.0484, -0.8695, -0.6402, -0.5846, -0.5268, -0.4667,
  -0.4043, -0.3399, -0.2730, -0.2042, -0.1332, -0.1332, -0.1332, -0.1332,
  -0.1332, -0.1332, -0.1332, -0.1332, -0.1332, -0.1332, -0.1332,
};

static s16 Animation_for_L_lowarm_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch1_val[]={
  0.0000, 0.4542, 0.8433, 1.1650, 1.4181, 1.6006, 1.7122, 1.7519, 1.7196,
  1.6156, 1.4402, 1.1945, 0.8796, 0.8032, 0.7239, 0.6412, 0.5555, 0.4670,
  0.3752, 0.2805, 0.1830, 0.1830, 0.1830, 0.1830, 0.1830, 0.1830, 0.1830,
  0.1830, 0.1830, 0.1830, 0.1830,
};

static s16 Animation_for_L_lowarm_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch2_val[]={
  0.0000, -1.0909, -2.2196, -3.3803, -4.5667, -5.7727, -6.9921, -8.2181,
  -9.4445, -10.6647, -11.8724, -13.0612, -14.2248, -14.4707, -14.7151,
  -14.9579, -15.1991, -15.4386, -15.6764, -15.9124, -16.1465, -16.1465,
  -16.1465, -16.1465, -16.1465, -16.1465, -16.1465, -16.1465, -16.1465,
  -16.1465, -16.1465,
};

static s16 Animation_for_L_lowarm_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch3_val[]={
  0.0000, -0.0587, -0.1177, -0.1770, -0.2370, -0.2979, -0.3598, -0.4231,
  -0.4878, -0.5542, -0.6224, -0.6927, -0.7652, -0.7810, -0.7970, -0.8131,
  -0.8292, -0.8455, -0.8619, -0.8784, -0.8950, -0.8950, -0.8950, -0.8950,
  -0.8950, -0.8950, -0.8950, -0.8950, -0.8950, -0.8950, -0.8950,
};

static s16 Animation_for_L_lowarm_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch4_val[]={
  0.0000, -0.0427, -0.0852, -0.1275, -0.1693, -0.2105, -0.2509, -0.2904,
  -0.3288, -0.3658, -0.4013, -0.4351, -0.4670, -0.4736, -0.4800, -0.4864,
  -0.4926, -0.4988, -0.5048, -0.5107, -0.5165, -0.5165, -0.5165, -0.5165,
  -0.5165, -0.5165, -0.5165, -0.5165, -0.5165, -0.5165, -0.5165,
};

static s16 Animation_for_L_lowarm_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch5_val[]={
  -0.0000, 0.0013, 0.0050, 0.0113, 0.0202, 0.0317, 0.0459, 0.0628, 0.0825,
  0.1051, 0.1307, 0.1592, 0.1908, 0.1980, 0.2053, 0.2128, 0.2204, 0.2282,
  0.2360, 0.2441, 0.2522, 0.2522, 0.2522, 0.2522, 0.2522, 0.2522, 0.2522,
  0.2522, 0.2522, 0.2522, 0.2522,
};

static s16 Animation_for_L_lowarm_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_lowarm_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_lowarm_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowarm_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_L_lowarm_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch0_key, Animation_for_L_lowarm_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch1_key, Animation_for_L_lowarm_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch2_key, Animation_for_L_lowarm_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch3_key, Animation_for_L_lowarm_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch4_key, Animation_for_L_lowarm_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch5_key, Animation_for_L_lowarm_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch6_key, Animation_for_L_lowarm_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch7_key, Animation_for_L_lowarm_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_L_lowarm_motion_ch8_key, Animation_for_L_lowarm_motion_ch8_val},
};

static NDR_ANIM Animation_for_L_lowarm_motion={
  Animation_for_L_lowarm_motion_chlist, 9, 30
};

static s16 Animation_for_L_hand_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch0_val[]={
  0.0000, -0.3455, -0.1127, 0.6953, 2.0660, 3.9782, 6.4013, 9.2976,
  12.6197, 16.3153, 20.3248, 24.5837, 29.0235, 26.4201, 23.8668, 21.3774,
  18.9661, 16.6465, 14.4308, 12.3316, 10.3608, 10.3608, 10.3608, 10.3608,
  10.3608, 10.3608, 10.3608, 10.3608, 10.3608, 10.3608, 10.3608,
};

static s16 Animation_for_L_hand_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch1_val[]={
  -0.0000, 0.4914, 0.2094, -0.8419, -2.6463, -5.1747, -8.3869, -12.2314,
  -16.6459, -21.5597, -26.8928, -32.5597, -38.4679, -34.9833, -31.5655,
  -28.2338, -25.0062, -21.9014, -18.9360, -16.1264, -13.4888, -13.4888,
  -13.4888, -13.4888, -13.4888, -13.4888, -13.4888, -13.4888, -13.4888,
  -13.4888, -13.4888,
};

static s16 Animation_for_L_hand_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch2_val[]={
  0.0000, -7.5576, -15.1337, -22.6055, -29.8516, -36.7543, -43.2012,
  -49.0874, -54.3166, -58.8031, -62.4741, -65.2679, -67.1393, -66.1780,
  -64.8956, -63.2993, -61.3979, -59.2022, -56.7241, -53.9774, -50.9772,
  -50.9772, -50.9772, -50.9772, -50.9772, -50.9772, -50.9772, -50.9772,
  -50.9772, -50.9772, -50.9772,
};

static s16 Animation_for_L_hand_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch3_val[]={
  -0.0000, -0.1060, -0.2132, -0.3229, -0.4361, -0.5540, -0.6779, -0.8085,
  -0.9466, -1.0923, -1.2450, -1.4034, -1.5653, -1.4725, -1.3806, -1.2900,
  -1.2012, -1.1146, -1.0303, -0.9486, -0.8694, -0.8694, -0.8694, -0.8694,
  -0.8694, -0.8694, -0.8694, -0.8694, -0.8694, -0.8694, -0.8694,
};

static s16 Animation_for_L_hand_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch4_val[]={
  -0.0000, -0.0763, -0.1518, -0.2257, -0.2970, -0.3649, -0.4281, -0.4856,
  -0.5360, -0.5780, -0.6103, -0.6317, -0.6414, -0.6372, -0.6290, -0.6168,
  -0.6008, -0.5813, -0.5584, -0.5324, -0.5035, -0.5035, -0.5035, -0.5035,
  -0.5035, -0.5035, -0.5035, -0.5035, -0.5035, -0.5035, -0.5035,
};

static s16 Animation_for_L_hand_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch5_val[]={
  0.0000, 0.0039, 0.0157, 0.0357, 0.0641, 0.1013, 0.1478, 0.2040, 0.2699,
  0.3451, 0.4288, 0.5190, 0.6133, 0.5580, 0.5037, 0.4508, 0.4001, 0.3518,
  0.3064, 0.2640, 0.2248, 0.2248, 0.2248, 0.2248, 0.2248, 0.2248, 0.2248,
  0.2248, 0.2248, 0.2248, 0.2248,
};

static s16 Animation_for_L_hand_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_hand_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_hand_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_hand_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_L_hand_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_L_hand_motion_ch0_key, Animation_for_L_hand_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_L_hand_motion_ch1_key, Animation_for_L_hand_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_L_hand_motion_ch2_key, Animation_for_L_hand_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_L_hand_motion_ch3_key, Animation_for_L_hand_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_L_hand_motion_ch4_key, Animation_for_L_hand_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_L_hand_motion_ch5_key, Animation_for_L_hand_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_L_hand_motion_ch6_key, Animation_for_L_hand_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_L_hand_motion_ch7_key, Animation_for_L_hand_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_L_hand_motion_ch8_key, Animation_for_L_hand_motion_ch8_val},
};

static NDR_ANIM Animation_for_L_hand_motion={
  Animation_for_L_hand_motion_chlist, 9, 30
};

static s16 Animation_for_L_sode_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch0_val[]={
  0.0000, -5.2006, -7.8028, -7.3780, -3.7385, 3.0518, 12.6895, 24.6665,
  38.3208, 52.9012, 67.6360, 81.8000, 94.7730, 91.9784, 88.8981, 85.5520,
  81.9634, 78.1555, 74.1539, 69.9855, 65.6776, 65.6776, 65.6776, 65.6776,
  65.6776, 65.6776, 65.6776, 65.6776, 65.6776, 65.6776, 65.6776,
};

static s16 Animation_for_L_sode_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch1_val[]={
  0.0000, 2.5457, 8.0203, 15.7382, 24.8984, 34.6598, 44.2144, 52.8562,
  60.0333, 65.3838, 68.7487, 70.1650, 69.8366, 65.6384, 61.7206, 58.1061,
  54.8171, 51.8728, 49.2908, 47.0860, 45.2718, 45.2718, 45.2718, 45.2718,
  45.2718, 45.2718, 45.2718, 45.2718, 45.2718, 45.2718, 45.2718,
};

static s16 Animation_for_L_sode_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch2_val[]={
  0.0000, -19.6026, -38.6660, -56.4877, -72.4319, -85.9606, -96.6595,
  -104.2551, -108.6230, -109.7895, -107.9218, -103.3142, -96.3648, -96.5204,
  -96.6684, -96.8168, -96.9729, -97.1439, -97.3358, -97.5539, -97.8027,
  -97.8027, -97.8027, -97.8027, -97.8027, -97.8027, -97.8027, -97.8027,
  -97.8027, -97.8027, -97.8027,
};

static s16 Animation_for_L_sode_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch3_val[]={
  0.0000, 0.1840, 0.3637, 0.5374, 0.7033, 0.8596, 1.0048, 1.1375, 1.2561,
  1.3589, 1.4428, 1.5023, 1.5263, 1.5245, 1.5234, 1.5233, 1.5239, 1.5254,
  1.5276, 1.5304, 1.5337, 1.5337, 1.5337, 1.5337, 1.5337, 1.5337, 1.5337,
  1.5337, 1.5337, 1.5337, 1.5337,
};

static s16 Animation_for_L_sode_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch4_val[]={
  0.0000, -0.0294, -0.0653, -0.1101, -0.1656, -0.2327, -0.3117, -0.4024,
  -0.5038, -0.6150, -0.7343, -0.8600, -0.9895, -0.9868, -0.9842, -0.9817,
  -0.9792, -0.9766, -0.9736, -0.9703, -0.9665, -0.9665, -0.9665, -0.9665,
  -0.9665, -0.9665, -0.9665, -0.9665, -0.9665, -0.9665, -0.9665,
};

static s16 Animation_for_L_sode_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch5_val[]={
  0.0000, -0.0559, -0.1029, -0.1427, -0.1770, -0.2074, -0.2354, -0.2614,
  -0.2854, -0.3058, -0.3198, -0.3213, -0.2985, -0.3755, -0.4532, -0.5316,
  -0.6106, -0.6903, -0.7706, -0.8514, -0.9325, -0.9325, -0.9325, -0.9325,
  -0.9325, -0.9325, -0.9325, -0.9325, -0.9325, -0.9325, -0.9325,
};

static s16 Animation_for_L_sode_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_sode_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_sode_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_sode_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_L_sode_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_L_sode_motion_ch0_key, Animation_for_L_sode_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_L_sode_motion_ch1_key, Animation_for_L_sode_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_L_sode_motion_ch2_key, Animation_for_L_sode_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_L_sode_motion_ch3_key, Animation_for_L_sode_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_L_sode_motion_ch4_key, Animation_for_L_sode_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_L_sode_motion_ch5_key, Animation_for_L_sode_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_L_sode_motion_ch6_key, Animation_for_L_sode_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_L_sode_motion_ch7_key, Animation_for_L_sode_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_L_sode_motion_ch8_key, Animation_for_L_sode_motion_ch8_val},
};

static NDR_ANIM Animation_for_L_sode_motion={
  Animation_for_L_sode_motion_chlist, 9, 30
};

static s16 Animation_for_head_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch0_val[]={
  0.0000, -0.2011, -0.4022, -0.6033, -0.8044, -1.0056, -1.2069, -1.4081,
  -1.6094, -1.8107, -2.0120, -2.2133, -2.4147, -1.7139, -1.0134, -0.3133,
  0.3861, 1.0848, 1.7825, 2.4791, 3.1743, 3.1743, 3.1743, 3.1743, 3.1743,
  3.1743, 3.1743, 3.1743, 3.1743, 3.1743, 3.1743,
};

static s16 Animation_for_head_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch1_val[]={
  0.0000, -0.0081, -0.0157, -0.0229, -0.0296, -0.0359, -0.0417, -0.0470,
  -0.0520, -0.0564, -0.0605, -0.0640, -0.0672, -0.0634, -0.0552, -0.0428,
  -0.0262, -0.0052, 0.0199, 0.0491, 0.0825, 0.0825, 0.0825, 0.0825,
  0.0825, 0.0825, 0.0825, 0.0825, 0.0825, 0.0825, 0.0825,
};

static s16 Animation_for_head_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch2_val[]={
  0.0000, -0.0672, -0.1344, -0.2017, -0.2689, -0.3361, -0.4034, -0.4706,
  -0.5379, -0.6051, -0.6724, -0.7396, -0.8069, -0.6498, -0.4996, -0.3563,
  -0.2199, -0.0903, 0.0324, 0.1483, 0.2574, 0.2574, 0.2574, 0.2574,
  0.2574, 0.2574, 0.2574, 0.2574, 0.2574, 0.2574, 0.2574,
};

static s16 Animation_for_head_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch3_val[]={
  0.0000, 0.0007, 0.0013, 0.0020, 0.0027, 0.0034, 0.0040, 0.0047, 0.0054,
  0.0060, 0.0067, 0.0074, 0.0081, 0.0065, 0.0049, 0.0033, 0.0017, 0.0000,
  -0.0016, -0.0032, -0.0049, -0.0049, -0.0049, -0.0049, -0.0049, -0.0049,
  -0.0049, -0.0049, -0.0049, -0.0049, -0.0049,
};

static s16 Animation_for_head_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch4_val[]={
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0001, 0.0001, 0.0001, 0.0001, 0.0237, 0.0473, 0.0709, 0.0945, 0.1181,
  0.1416, 0.1652, 0.1888, 0.1888, 0.1888, 0.1888, 0.1888, 0.1888, 0.1888,
  0.1888, 0.1888, 0.1888, 0.1888,
};

static s16 Animation_for_head_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch5_val[]={
  0.0000, -0.0020, -0.0040, -0.0060, -0.0080, -0.0101, -0.0121, -0.0141,
  -0.0161, -0.0181, -0.0201, -0.0221, -0.0241, -0.0199, -0.0157, -0.0116,
  -0.0076, -0.0037, 0.0002, 0.0040, 0.0077, 0.0077, 0.0077, 0.0077,
  0.0077, 0.0077, 0.0077, 0.0077, 0.0077, 0.0077, 0.0077,
};

static s16 Animation_for_head_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_head_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_head_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_head_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_head_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_head_motion_ch0_key, Animation_for_head_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_head_motion_ch1_key, Animation_for_head_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_head_motion_ch2_key, Animation_for_head_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_head_motion_ch3_key, Animation_for_head_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_head_motion_ch4_key, Animation_for_head_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_head_motion_ch5_key, Animation_for_head_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_head_motion_ch6_key, Animation_for_head_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_head_motion_ch7_key, Animation_for_head_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_head_motion_ch8_key, Animation_for_head_motion_ch8_val},
};

static NDR_ANIM Animation_for_head_motion={
  Animation_for_head_motion_chlist, 9, 30
};

static s16 Animation_for_L_upleg_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch0_val[]={
  0.0000, -0.0074, -0.0294, -0.0648, -0.1120, -0.1686, -0.2315, -0.2973,
  -0.3619, -0.4207, -0.4687, -0.5008, -0.5112, -0.4362, -0.3070, -0.1209,
  0.1243, 0.4307, 0.7999, 1.2328, 1.7303, 1.7303, 1.7303, 1.7303, 1.7303,
  1.7303, 1.7303, 1.7303, 1.7303, 1.7303, 1.7303,
};

static s16 Animation_for_L_upleg_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch1_val[]={
  0.0000, 0.2207, 0.4346, 0.6350, 0.8156, 0.9702, 1.0928, 1.1782, 1.2215,
  1.2185, 1.1655, 1.0597, 0.8990, 0.7548, 0.5518, 0.2890, -0.0337, -0.4161,
  -0.8571, -1.3551, -1.9080, -1.9080, -1.9080, -1.9080, -1.9080, -1.9080,
  -1.9080, -1.9080, -1.9080, -1.9080, -1.9080,
};

static s16 Animation_for_L_upleg_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch2_val[]={
  -12.3406, -11.3459, -10.4179, -9.5558, -8.7583, -8.0237, -7.3496,
  -6.7333, -6.1716, -5.6609, -5.1972, -4.7762, -4.3932, -3.1954, -1.9522,
  -0.6717, 0.6376, 1.9671, 3.3081, 4.6515, 5.9885, 5.9885, 5.9885, 5.9885,
  5.9885, 5.9885, 5.9885, 5.9885, 5.9885, 5.9885, 5.9885,
};

static s16 Animation_for_L_upleg_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch3_val[]={
  -0.0000, -0.0793, -0.1587, -0.2379, -0.3171, -0.3961, -0.4750, -0.5538,
  -0.6324, -0.7109, -0.7892, -0.8674, -0.9454, -0.9084, -0.8734, -0.8405,
  -0.8094, -0.7802, -0.7526, -0.7267, -0.7022, -0.7022, -0.7022, -0.7022,
  -0.7022, -0.7022, -0.7022, -0.7022, -0.7022, -0.7022, -0.7022,
};

static s16 Animation_for_L_upleg_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch4_val[]={
  0.0000, -0.0007, -0.0028, -0.0063, -0.0111, -0.0172, -0.0246, -0.0332,
  -0.0428, -0.0536, -0.0652, -0.0777, -0.0910, -0.0515, -0.0095, 0.0347,
  0.0811, 0.1294, 0.1794, 0.2309, 0.2839, 0.2839, 0.2839, 0.2839, 0.2839,
  0.2839, 0.2839, 0.2839, 0.2839, 0.2839, 0.2839,
};

static s16 Animation_for_L_upleg_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch5_val[]={
  0.0000, 0.0174, 0.0349, 0.0528, 0.0710, 0.0898, 0.1093, 0.1296, 0.1508,
  0.1730, 0.1964, 0.2210, 0.2470, 0.2184, 0.1924, 0.1689, 0.1479, 0.1293,
  0.1131, 0.0992, 0.0875, 0.0875, 0.0875, 0.0875, 0.0875, 0.0875, 0.0875,
  0.0875, 0.0875, 0.0875, 0.0875,
};

static s16 Animation_for_L_upleg_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_upleg_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_upleg_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_upleg_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_L_upleg_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_L_upleg_motion_ch0_key, Animation_for_L_upleg_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_L_upleg_motion_ch1_key, Animation_for_L_upleg_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_L_upleg_motion_ch2_key, Animation_for_L_upleg_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_L_upleg_motion_ch3_key, Animation_for_L_upleg_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_L_upleg_motion_ch4_key, Animation_for_L_upleg_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_L_upleg_motion_ch5_key, Animation_for_L_upleg_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_L_upleg_motion_ch6_key, Animation_for_L_upleg_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_L_upleg_motion_ch7_key, Animation_for_L_upleg_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_L_upleg_motion_ch8_key, Animation_for_L_upleg_motion_ch8_val},
};

static NDR_ANIM Animation_for_L_upleg_motion={
  Animation_for_L_upleg_motion_chlist, 9, 30
};

static s16 Animation_for_L_lowleg_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch0_val[]={
  0.0000, -0.0000, 0.0000, -0.0000, 0.0000, -0.0000, 0.0000, -0.0000,
  -0.0000, -0.0000, 0.0000, 0.0000, 0.0001, 0.0000, 0.0000, -0.0000,
  -0.0000, 0.0000, -0.0001, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
  -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
};

static s16 Animation_for_L_lowleg_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch1_val[]={
  0.0000, -0.8133, -2.3313, -4.5396, -7.4173, -10.9373, -15.0661, -19.7647,
  -24.9887, -30.6887, -36.8107, -43.2969, -50.0858, -43.1383, -36.5097,
  -30.2658, -24.4685, -19.1753, -14.4387, -10.3057, -6.8171, -6.8171,
  -6.8171, -6.8171, -6.8171, -6.8171, -6.8171, -6.8171, -6.8171, -6.8171,
  -6.8171,
};

static s16 Animation_for_L_lowleg_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch2_val[]={
  0.0000, 7.2930, 14.4725, 21.4706, 28.2211, 34.6600, 40.7265, 46.3632,
  51.5168, 56.1384, 60.1845, 63.6166, 66.4024, 63.5421, 60.0050, 55.8261,
  51.0468, 45.7148, 39.8826, 33.6082, 26.9539, 26.9539, 26.9539, 26.9539,
  26.9539, 26.9539, 26.9539, 26.9539, 26.9539, 26.9539, 26.9539,
};

static s16 Animation_for_L_lowleg_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch3_val[]={
  0.0000, 0.0973, 0.1946, 0.2919, 0.3892, 0.4865, 0.5838, 0.6811, 0.7784,
  0.8757, 0.9730, 1.0703, 1.1676, 1.0680, 0.9684, 0.8688, 0.7691, 0.6695,
  0.5699, 0.4703, 0.3706, 0.3706, 0.3706, 0.3706, 0.3706, 0.3706, 0.3706,
  0.3706, 0.3706, 0.3706, 0.3706,
};

static s16 Animation_for_L_lowleg_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch4_val[]={
  -0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000,
};

static s16 Animation_for_L_lowleg_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch5_val[]={
  -0.0000, -0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
  -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
};

static s16 Animation_for_L_lowleg_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_lowleg_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_lowleg_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_lowleg_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_L_lowleg_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch0_key, Animation_for_L_lowleg_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch1_key, Animation_for_L_lowleg_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch2_key, Animation_for_L_lowleg_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch3_key, Animation_for_L_lowleg_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch4_key, Animation_for_L_lowleg_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch5_key, Animation_for_L_lowleg_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch6_key, Animation_for_L_lowleg_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch7_key, Animation_for_L_lowleg_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_L_lowleg_motion_ch8_key, Animation_for_L_lowleg_motion_ch8_val},
};

static NDR_ANIM Animation_for_L_lowleg_motion={
  Animation_for_L_lowleg_motion_chlist, 9, 30
};

static s16 Animation_for_L_shoe_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch0_val[]={
  0.0000, 2.0474, 4.0793, 6.0799, 8.0340, 9.9269, 11.7441, 13.4716,
  15.0967, 16.6062, 17.9899, 19.2362, 20.3356, 24.5315, 25.5965, 23.1018,
  16.9017, 7.1494, -5.7076, -20.9553, -37.6550, -37.6551, -37.6551,
  -37.6551, -37.6551, -37.6551, -37.6551, -37.6551, -37.6551, -37.6551,
  -37.6551,
};

static s16 Animation_for_L_shoe_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch1_val[]={
  -0.0000, -0.5252, -2.0755, -4.6402, -8.1990, -12.7252, -18.1846, -24.5349,
  -31.7279, -39.7099, -48.4189, -57.7890, -67.7491, -46.1771, -28.0292,
  -14.0041, -4.6404, -0.2973, -1.1424, -7.1431, -18.0686, -18.0689,
  -18.0689, -18.0689, -18.0689, -18.0689, -18.0689, -18.0689, -18.0689,
  -18.0689, -18.0689,
};

static s16 Animation_for_L_shoe_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch2_val[]={
  0.0000, 11.6124, 23.1357, 34.4820, 45.5649, 56.3001, 66.6063, 76.4045,
  85.6207, 94.1837, 102.0294, 109.0979, 115.3350, 100.4612, 81.8859,
  60.7473, 38.3078, 15.8726, -5.2955, -24.0537, -39.4539, -39.4541,
  -39.4541, -39.4541, -39.4541, -39.4541, -39.4541, -39.4541, -39.4541,
  -39.4541, -39.4541,
};

static s16 Animation_for_L_shoe_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch3_val[]={
  -0.0000, 0.0859, 0.1719, 0.2577, 0.3436, 0.4293, 0.5150, 0.6006, 0.6861,
  0.7715, 0.8569, 0.9422, 1.0275, 0.8270, 0.6294, 0.4354, 0.2457, 0.0606,
  -0.1195, -0.2945, -0.4642, -0.4642, -0.4642, -0.4642, -0.4642, -0.4642,
  -0.4642, -0.4642, -0.4642, -0.4642, -0.4642,
};

static s16 Animation_for_L_shoe_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch4_val[]={
  0.0000, 0.0007, 0.0026, 0.0058, 0.0103, 0.0160, 0.0229, 0.0309, 0.0400,
  0.0501, 0.0611, 0.0730, 0.0856, 0.1232, 0.1655, 0.2134, 0.2674, 0.3276,
  0.3941, 0.4665, 0.5443, 0.5443, 0.5443, 0.5443, 0.5443, 0.5443, 0.5443,
  0.5443, 0.5443, 0.5443, 0.5443,
};

static s16 Animation_for_L_shoe_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch5_val[]={
  0.0000, -0.0151, -0.0302, -0.0450, -0.0594, -0.0735, -0.0870, -0.0998,
  -0.1119, -0.1233, -0.1337, -0.1431, -0.1515, -0.1319, -0.1074, -0.0787,
  -0.0466, -0.0120, 0.0245, 0.0625, 0.1017, 0.1017, 0.1017, 0.1017,
  0.1017, 0.1017, 0.1017, 0.1017, 0.1017, 0.1017, 0.1017,
};

static s16 Animation_for_L_shoe_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_shoe_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_shoe_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_shoe_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_L_shoe_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_L_shoe_motion_ch0_key, Animation_for_L_shoe_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_L_shoe_motion_ch1_key, Animation_for_L_shoe_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_L_shoe_motion_ch2_key, Animation_for_L_shoe_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_L_shoe_motion_ch3_key, Animation_for_L_shoe_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_L_shoe_motion_ch4_key, Animation_for_L_shoe_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_L_shoe_motion_ch5_key, Animation_for_L_shoe_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_L_shoe_motion_ch6_key, Animation_for_L_shoe_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_L_shoe_motion_ch7_key, Animation_for_L_shoe_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_L_shoe_motion_ch8_key, Animation_for_L_shoe_motion_ch8_val},
};

static NDR_ANIM Animation_for_L_shoe_motion={
  Animation_for_L_shoe_motion_chlist, 9, 30
};

static s16 Animation_for_L_leg_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch0_val[]={
  0.0000, -0.0074, -0.0294, -0.0648, -0.1120, -0.1686, -0.2315, -0.2973,
  -0.3619, -0.4207, -0.4687, -0.5008, -0.5112, -0.4362, -0.3070, -0.1209,
  0.1243, 0.4307, 0.7999, 1.2328, 1.7303, 1.7303, 1.7303, 1.7303, 1.7303,
  1.7303, 1.7303, 1.7303, 1.7303, 1.7303, 1.7303,
};

static s16 Animation_for_L_leg_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch1_val[]={
  0.0000, 0.2207, 0.4346, 0.6350, 0.8156, 0.9702, 1.0928, 1.1782, 1.2215,
  1.2185, 1.1655, 1.0597, 0.8990, 0.7548, 0.5518, 0.2890, -0.0337, -0.4161,
  -0.8571, -1.3551, -1.9080, -1.9080, -1.9080, -1.9080, -1.9080, -1.9080,
  -1.9080, -1.9080, -1.9080, -1.9080, -1.9080,
};

static s16 Animation_for_L_leg_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch2_val[]={
  -12.3406, -11.3459, -10.4179, -9.5558, -8.7583, -8.0237, -7.3496,
  -6.7333, -6.1716, -5.6609, -5.1972, -4.7762, -4.3932, -3.1954, -1.9522,
  -0.6717, 0.6376, 1.9671, 3.3081, 4.6515, 5.9885, 5.9885, 5.9885, 5.9885,
  5.9885, 5.9885, 5.9885, 5.9885, 5.9885, 5.9885, 5.9885,
};

static s16 Animation_for_L_leg_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch3_val[]={
  -0.0000, -0.0793, -0.1587, -0.2379, -0.3171, -0.3961, -0.4750, -0.5538,
  -0.6324, -0.7109, -0.7892, -0.8674, -0.9454, -0.9084, -0.8734, -0.8405,
  -0.8094, -0.7802, -0.7526, -0.7267, -0.7022, -0.7022, -0.7022, -0.7022,
  -0.7022, -0.7022, -0.7022, -0.7022, -0.7022, -0.7022, -0.7022,
};

static s16 Animation_for_L_leg_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch4_val[]={
  0.0000, -0.0007, -0.0028, -0.0063, -0.0111, -0.0172, -0.0246, -0.0332,
  -0.0428, -0.0536, -0.0652, -0.0777, -0.0910, -0.0515, -0.0095, 0.0347,
  0.0811, 0.1294, 0.1794, 0.2309, 0.2839, 0.2839, 0.2839, 0.2839, 0.2839,
  0.2839, 0.2839, 0.2839, 0.2839, 0.2839, 0.2839,
};

static s16 Animation_for_L_leg_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch5_val[]={
  0.0000, 0.0174, 0.0349, 0.0528, 0.0710, 0.0898, 0.1093, 0.1296, 0.1508,
  0.1730, 0.1964, 0.2210, 0.2470, 0.2184, 0.1924, 0.1689, 0.1479, 0.1293,
  0.1131, 0.0992, 0.0875, 0.0875, 0.0875, 0.0875, 0.0875, 0.0875, 0.0875,
  0.0875, 0.0875, 0.0875, 0.0875,
};

static s16 Animation_for_L_leg_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_leg_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_L_leg_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_L_leg_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_L_leg_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_L_leg_motion_ch0_key, Animation_for_L_leg_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_L_leg_motion_ch1_key, Animation_for_L_leg_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_L_leg_motion_ch2_key, Animation_for_L_leg_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_L_leg_motion_ch3_key, Animation_for_L_leg_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_L_leg_motion_ch4_key, Animation_for_L_leg_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_L_leg_motion_ch5_key, Animation_for_L_leg_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_L_leg_motion_ch6_key, Animation_for_L_leg_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_L_leg_motion_ch7_key, Animation_for_L_leg_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_L_leg_motion_ch8_key, Animation_for_L_leg_motion_ch8_val},
};

static NDR_ANIM Animation_for_L_leg_motion={
  Animation_for_L_leg_motion_chlist, 9, 30
};

static s16 Animation_for_hip_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch0_val[]={
  0.0000, 0.0000, 0.0002, 0.0004, 0.0007, 0.0010, 0.0015, 0.0020, 0.0026,
  0.0033, 0.0041, 0.0050, 0.0060, -0.9360, -1.8723, -2.7973, -3.7053,
  -4.5910, -5.4490, -6.2742, -7.0616, -7.0616, -7.0616, -7.0616, -7.0616,
  -7.0616, -7.0616, -7.0616, -7.0616, -7.0616, -7.0616,
};

static s16 Animation_for_hip_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch1_val[]={
  0.0000, -0.0173, -0.0346, -0.0519, -0.0692, -0.0865, -0.1038, -0.1211,
  -0.1384, -0.1557, -0.1730, -0.1903, -0.2075, -0.1774, -0.1329, -0.0742,
  -0.0020, 0.0831, 0.1802, 0.2884, 0.4065, 0.4065, 0.4065, 0.4065, 0.4065,
  0.4065, 0.4065, 0.4065, 0.4065, 0.4065, 0.4065,
};

static s16 Animation_for_hip_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch2_val[]={
  -12.3406, -11.3122, -10.2839, -9.2555, -8.2273, -7.1990, -6.1707,
  -5.1425, -4.1143, -3.0861, -2.0580, -1.0299, -0.0017, -0.0368, -0.1436,
  -0.3214, -0.5694, -0.8861, -1.2697, -1.7179, -2.2283, -2.2283, -2.2283,
  -2.2283, -2.2283, -2.2283, -2.2283, -2.2283, -2.2283, -2.2283, -2.2283,
 };

static s16 Animation_for_hip_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch3_val[]={
  0.0000, 0.0014, 0.0028, 0.0042, 0.0056, 0.0070, 0.0084, 0.0098, 0.0112,
  0.0126, 0.0140, 0.0154, 0.0168, 0.0106, 0.0042, -0.0024, -0.0092,
  -0.0162, -0.0236, -0.0314, -0.0397, -0.0397, -0.0397, -0.0397, -0.0397,
  -0.0397, -0.0397, -0.0397, -0.0397, -0.0397, -0.0397,
};

static s16 Animation_for_hip_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch4_val[]={
  0.0000, -0.0000, -0.0000, -0.0000, -0.0001, -0.0001, -0.0001, -0.0002,
  -0.0002, -0.0003, -0.0003, -0.0004, -0.0005, -0.0766, -0.1526, -0.2287,
  -0.3048, -0.3809, -0.4570, -0.5331, -0.6092, -0.6092, -0.6092, -0.6092,
  -0.6092, -0.6092, -0.6092, -0.6092, -0.6092, -0.6092, -0.6092,
};

static s16 Animation_for_hip_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch5_val[]={
  0.0000, 0.0048, 0.0096, 0.0143, 0.0191, 0.0239, 0.0287, 0.0335, 0.0382,
  0.0430, 0.0478, 0.0526, 0.0573, 0.0503, 0.0435, 0.0371, 0.0311, 0.0255,
  0.0203, 0.0157, 0.0118, 0.0118, 0.0118, 0.0118, 0.0118, 0.0118, 0.0118,
  0.0118, 0.0118, 0.0118, 0.0118,
};

static s16 Animation_for_hip_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_hip_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_hip_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_hip_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_hip_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_hip_motion_ch0_key, Animation_for_hip_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_hip_motion_ch1_key, Animation_for_hip_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_hip_motion_ch2_key, Animation_for_hip_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_hip_motion_ch3_key, Animation_for_hip_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_hip_motion_ch4_key, Animation_for_hip_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_hip_motion_ch5_key, Animation_for_hip_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_hip_motion_ch6_key, Animation_for_hip_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_hip_motion_ch7_key, Animation_for_hip_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_hip_motion_ch8_key, Animation_for_hip_motion_ch8_val},
};

static NDR_ANIM Animation_for_hip_motion={
  Animation_for_hip_motion_chlist, 9, 30
};

static s16 Animation_for_R_leg_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch0_val[]={
  0.0000, -0.1406, -0.3042, -0.4902, -0.6981, -0.9272, -1.1768, -1.4465,
  -1.7353, -2.0427, -2.3679, -2.7102, -3.0687, -3.0623, -3.0559, -3.0495,
  -3.0432, -3.0368, -3.0305, -3.0242, -3.0180, -3.0180, -3.0180, -3.0180,
  -3.0180, -3.0180, -3.0180, -3.0180, -3.0180, -3.0180, -3.0180,
};

static s16 Animation_for_R_leg_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch1_val[]={
  0.0000, -0.3052, -0.5953, -0.8695, -1.1273, -1.3679, -1.5908, -1.7955,
  -1.9813, -2.1478, -2.2946, -2.4213, -2.5275, -2.4878, -2.4481, -2.4084,
  -2.3687, -2.3290, -2.2894, -2.2497, -2.2100, -2.2100, -2.2100, -2.2100,
  -2.2100, -2.2100, -2.2100, -2.2100, -2.2100, -2.2100, -2.2100,
};

static s16 Animation_for_R_leg_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch2_val[]={
  0.0000, 0.7119, 1.4205, 2.1252, 2.8254, 3.5203, 4.2092, 4.8915, 5.5665,
  6.2336, 6.8920, 7.5411, 8.1802, 8.1765, 8.1726, 8.1687, 8.1648, 8.1607,
  8.1565, 8.1523, 8.1480, 8.1480, 8.1480, 8.1480, 8.1480, 8.1480, 8.1480,
  8.1480, 8.1480, 8.1480, 8.1480,
};

static s16 Animation_for_R_leg_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch3_val[]={
  0.0000, -0.0077, -0.0153, -0.0231, -0.0308, -0.0386, -0.0466, -0.0546,
  -0.0627, -0.0710, -0.0795, -0.0881, -0.0970, -0.0992, -0.1013, -0.1035,
  -0.1057, -0.1079, -0.1100, -0.1122, -0.1144, -0.1144, -0.1144, -0.1144,
  -0.1144, -0.1144, -0.1144, -0.1144, -0.1144, -0.1144, -0.1144,
};

static s16 Animation_for_R_leg_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch4_val[]={
  0.0000, -0.0274, -0.0549, -0.0824, -0.1100, -0.1376, -0.1652, -0.1928,
  -0.2204, -0.2481, -0.2757, -0.3034, -0.3310, -0.3309, -0.3308, -0.3306,
  -0.3305, -0.3304, -0.3302, -0.3301, -0.3300, -0.3300, -0.3300, -0.3300,
  -0.3300, -0.3300, -0.3300, -0.3300, -0.3300, -0.3300, -0.3300,
};

static s16 Animation_for_R_leg_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch5_val[]={
  0.0000, -0.0132, -0.0259, -0.0383, -0.0502, -0.0617, -0.0727, -0.0834,
  -0.0935, -0.1032, -0.1124, -0.1212, -0.1294, -0.1281, -0.1268, -0.1255,
  -0.1242, -0.1229, -0.1216, -0.1203, -0.1190, -0.1190, -0.1190, -0.1190,
  -0.1190, -0.1190, -0.1190, -0.1190, -0.1190, -0.1190, -0.1190,
};

static s16 Animation_for_R_leg_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_leg_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_leg_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_leg_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_R_leg_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_R_leg_motion_ch0_key, Animation_for_R_leg_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_R_leg_motion_ch1_key, Animation_for_R_leg_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_R_leg_motion_ch2_key, Animation_for_R_leg_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_R_leg_motion_ch3_key, Animation_for_R_leg_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_R_leg_motion_ch4_key, Animation_for_R_leg_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_R_leg_motion_ch5_key, Animation_for_R_leg_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_R_leg_motion_ch6_key, Animation_for_R_leg_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_R_leg_motion_ch7_key, Animation_for_R_leg_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_R_leg_motion_ch8_key, Animation_for_R_leg_motion_ch8_val},
};

static NDR_ANIM Animation_for_R_leg_motion={
  Animation_for_R_leg_motion_chlist, 9, 30
};

static s16 Animation_for_R_lowleg_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch0_val[]={
  0.0000, -0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, 0.0001, 0.0001, 0.0000, 0.0001, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000, 0.0000,
  0.0000, 0.0000, 0.0000, 0.0000,
};

static s16 Animation_for_R_lowleg_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch1_val[]={
  0.0000, -0.2325, -0.5728, -1.0205, -1.5749, -2.2353, -3.0007, -3.8699,
  -4.8419, -5.9150, -7.0879, -8.3588, -9.7259, -9.7259, -9.7258, -9.7258,
  -9.7259, -9.7259, -9.7259, -9.7259, -9.7259, -9.7259, -9.7259, -9.7259,
  -9.7259, -9.7259, -9.7259, -9.7259, -9.7259, -9.7259, -9.7259,
};

static s16 Animation_for_R_lowleg_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch2_val[]={
  0.0000, 2.8505, 5.6902, 8.5149, 11.3207, 14.1034, 16.8590, 19.5837,
  22.2735, 24.9245, 27.5330, 30.0951, 32.6072, 32.6072, 32.6072, 32.6071,
  32.6072, 32.6072, 32.6072, 32.6072, 32.6072, 32.6072, 32.6072, 32.6072,
  32.6072, 32.6072, 32.6072, 32.6072, 32.6072, 32.6072, 32.6072,
};

static s16 Animation_for_R_lowleg_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch3_val[]={
  -0.0000, 0.0379, 0.0758, 0.1137, 0.1516, 0.1896, 0.2275, 0.2654, 0.3033,
  0.3412, 0.3791, 0.4170, 0.4549, 0.4549, 0.4549, 0.4549, 0.4549, 0.4549,
  0.4549, 0.4549, 0.4549, 0.4549, 0.4549, 0.4549, 0.4549, 0.4549, 0.4549,
  0.4549, 0.4549, 0.4549, 0.4549,
};

static s16 Animation_for_R_lowleg_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch4_val[]={
  0.0000, 0.0000, -0.0000, -0.0000, 0.0000, 0.0000, -0.0000, -0.0000,
  -0.0000, -0.0000, 0.0000, 0.0000, -0.0000, 0.0000, 0.0000, -0.0000,
  0.0000, -0.0000, -0.0000, 0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
  -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
};

static s16 Animation_for_R_lowleg_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch5_val[]={
  0.0000, 0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
  -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
  -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
  -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000, -0.0000,
};

static s16 Animation_for_R_lowleg_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_lowleg_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_lowleg_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_lowleg_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_R_lowleg_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch0_key, Animation_for_R_lowleg_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch1_key, Animation_for_R_lowleg_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch2_key, Animation_for_R_lowleg_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch3_key, Animation_for_R_lowleg_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch4_key, Animation_for_R_lowleg_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch5_key, Animation_for_R_lowleg_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch6_key, Animation_for_R_lowleg_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch7_key, Animation_for_R_lowleg_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_R_lowleg_motion_ch8_key, Animation_for_R_lowleg_motion_ch8_val},
};

static NDR_ANIM Animation_for_R_lowleg_motion={
  Animation_for_R_lowleg_motion_chlist, 9, 30
};

static s16 Animation_for_R_shoe_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch0_val[]={
  0.0000, 0.5789, 1.1711, 1.7764, 2.3943, 3.0243, 3.6661, 4.3191, 4.9830,
  5.6572, 6.3412, 7.0345, 7.7366, 7.8294, 7.9222, 8.0148, 8.1074, 8.1999,
  8.2922, 8.3843, 8.4765, 8.4765, 8.4765, 8.4765, 8.4765, 8.4765, 8.4765,
  8.4765, 8.4765, 8.4765, 8.4765,
};

static s16 Animation_for_R_shoe_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch1_val[]={
  0.0000, -0.0386, -0.1603, -0.3647, -0.6521, -1.0220, -1.4742, -2.0086,
  -2.6245, -3.3225, -4.1009, -4.9598, -5.8988, -6.0429, -6.1881, -6.3353,
  -6.4843, -6.6344, -6.7871, -6.9409, -7.0967, -7.0967, -7.0967, -7.0967,
  -7.0967, -7.0967, -7.0967, -7.0967, -7.0967, -7.0967, -7.0967,
};

static s16 Animation_for_R_shoe_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch2_val[]={
  0.0000, -3.2441, -6.4838, -9.7170, -12.9417, -16.1558, -19.3573, -22.5440,
  -25.7143, -28.8656, -31.9964, -35.1044, -38.1879, -38.6464, -39.1047,
  -39.5622, -40.0193, -40.4761, -40.9319, -41.3875, -41.8424, -41.8424,
  -41.8424, -41.8424, -41.8424, -41.8424, -41.8424, -41.8424, -41.8424,
  -41.8424, -41.8424,
};

static s16 Animation_for_R_shoe_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch3_val[]={
  0.0000, -0.0244, -0.0487, -0.0731, -0.0974, -0.1217, -0.1460, -0.1703,
  -0.1945, -0.2188, -0.2430, -0.2671, -0.2913, -0.2948, -0.2984, -0.3019,
  -0.3055, -0.3090, -0.3126, -0.3161, -0.3197, -0.3197, -0.3197, -0.3197,
  -0.3197, -0.3197, -0.3197, -0.3197, -0.3197, -0.3197, -0.3197,
};

static s16 Animation_for_R_shoe_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch4_val[]={
  -0.0000, -0.0022, -0.0044, -0.0068, -0.0092, -0.0118, -0.0145, -0.0173,
  -0.0201, -0.0231, -0.0262, -0.0294, -0.0327, -0.0329, -0.0330, -0.0332,
  -0.0334, -0.0336, -0.0338, -0.0340, -0.0342, -0.0342, -0.0342, -0.0342,
  -0.0342, -0.0342, -0.0342, -0.0342, -0.0342, -0.0342, -0.0342,
};

static s16 Animation_for_R_shoe_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch5_val[]={
  0.0000, -0.0043, -0.0086, -0.0129, -0.0172, -0.0215, -0.0257, -0.0300,
  -0.0342, -0.0384, -0.0426, -0.0468, -0.0509, -0.0515, -0.0521, -0.0527,
  -0.0533, -0.0539, -0.0545, -0.0551, -0.0557, -0.0557, -0.0557, -0.0557,
  -0.0557, -0.0557, -0.0557, -0.0557, -0.0557, -0.0557, -0.0557,
};

static s16 Animation_for_R_shoe_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_shoe_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_shoe_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_shoe_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_R_shoe_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_R_shoe_motion_ch0_key, Animation_for_R_shoe_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_R_shoe_motion_ch1_key, Animation_for_R_shoe_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_R_shoe_motion_ch2_key, Animation_for_R_shoe_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_R_shoe_motion_ch3_key, Animation_for_R_shoe_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_R_shoe_motion_ch4_key, Animation_for_R_shoe_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_R_shoe_motion_ch5_key, Animation_for_R_shoe_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_R_shoe_motion_ch6_key, Animation_for_R_shoe_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_R_shoe_motion_ch7_key, Animation_for_R_shoe_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_R_shoe_motion_ch8_key, Animation_for_R_shoe_motion_ch8_val},
};

static NDR_ANIM Animation_for_R_shoe_motion={
  Animation_for_R_shoe_motion_chlist, 9, 30
};

static s16 Animation_for_R_upleg_motion_ch0_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch0_val[]={
  0.0000, -0.1406, -0.3042, -0.4902, -0.6981, -0.9272, -1.1768, -1.4465,
  -1.7353, -2.0427, -2.3679, -2.7102, -3.0687, -3.0623, -3.0559, -3.0495,
  -3.0432, -3.0368, -3.0305, -3.0242, -3.0180, -3.0180, -3.0180, -3.0180,
  -3.0180, -3.0180, -3.0180, -3.0180, -3.0180, -3.0180, -3.0180,
};

static s16 Animation_for_R_upleg_motion_ch1_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch1_val[]={
  0.0000, -0.3052, -0.5953, -0.8695, -1.1273, -1.3679, -1.5908, -1.7955,
  -1.9813, -2.1478, -2.2946, -2.4213, -2.5275, -2.4878, -2.4481, -2.4084,
  -2.3687, -2.3290, -2.2894, -2.2497, -2.2100, -2.2100, -2.2100, -2.2100,
  -2.2100, -2.2100, -2.2100, -2.2100, -2.2100, -2.2100, -2.2100,
};

static s16 Animation_for_R_upleg_motion_ch2_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch2_val[]={
  0.0000, 0.7119, 1.4205, 2.1252, 2.8254, 3.5203, 4.2092, 4.8915, 5.5665,
  6.2336, 6.8920, 7.5411, 8.1802, 8.1765, 8.1726, 8.1687, 8.1648, 8.1607,
  8.1565, 8.1523, 8.1480, 8.1480, 8.1480, 8.1480, 8.1480, 8.1480, 8.1480,
  8.1480, 8.1480, 8.1480, 8.1480,
};

static s16 Animation_for_R_upleg_motion_ch3_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch3_val[]={
  0.0000, -0.0077, -0.0153, -0.0231, -0.0308, -0.0386, -0.0466, -0.0546,
  -0.0627, -0.0710, -0.0795, -0.0881, -0.0970, -0.0992, -0.1013, -0.1035,
  -0.1057, -0.1079, -0.1100, -0.1122, -0.1144, -0.1144, -0.1144, -0.1144,
  -0.1144, -0.1144, -0.1144, -0.1144, -0.1144, -0.1144, -0.1144,
};

static s16 Animation_for_R_upleg_motion_ch4_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch4_val[]={
  0.0000, -0.0274, -0.0549, -0.0824, -0.1100, -0.1376, -0.1652, -0.1928,
  -0.2204, -0.2481, -0.2757, -0.3034, -0.3310, -0.3309, -0.3308, -0.3306,
  -0.3305, -0.3304, -0.3302, -0.3301, -0.3300, -0.3300, -0.3300, -0.3300,
  -0.3300, -0.3300, -0.3300, -0.3300, -0.3300, -0.3300, -0.3300,
};

static s16 Animation_for_R_upleg_motion_ch5_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch5_val[]={
  0.0000, -0.0132, -0.0259, -0.0383, -0.0502, -0.0617, -0.0727, -0.0834,
  -0.0935, -0.1032, -0.1124, -0.1212, -0.1294, -0.1281, -0.1268, -0.1255,
  -0.1242, -0.1229, -0.1216, -0.1203, -0.1190, -0.1190, -0.1190, -0.1190,
  -0.1190, -0.1190, -0.1190, -0.1190, -0.1190, -0.1190, -0.1190,
};

static s16 Animation_for_R_upleg_motion_ch6_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch6_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_upleg_motion_ch7_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch7_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static s16 Animation_for_R_upleg_motion_ch8_key[]={
  0, 1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20,
  21, 22, 23, 24, 25, 26, 27, 28, 29, 30,
};
static float Animation_for_R_upleg_motion_ch8_val[]={
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000, 1.0000,
  1.0000, 1.0000, 1.0000, 1.0000,
};

static NDR_ANIM_CHANNEL Animation_for_R_upleg_motion_chlist[]={
  {NDC_ANIMKIND_TRS_X, 0, 30, 31,
   Animation_for_R_upleg_motion_ch0_key, Animation_for_R_upleg_motion_ch0_val},
  {NDC_ANIMKIND_TRS_Y, 0, 30, 31,
   Animation_for_R_upleg_motion_ch1_key, Animation_for_R_upleg_motion_ch1_val},
  {NDC_ANIMKIND_TRS_Z, 0, 30, 31,
   Animation_for_R_upleg_motion_ch2_key, Animation_for_R_upleg_motion_ch2_val},
  {NDC_ANIMKIND_ROT_X, 0, 30, 31,
   Animation_for_R_upleg_motion_ch3_key, Animation_for_R_upleg_motion_ch3_val},
  {NDC_ANIMKIND_ROT_Y, 0, 30, 31,
   Animation_for_R_upleg_motion_ch4_key, Animation_for_R_upleg_motion_ch4_val},
  {NDC_ANIMKIND_ROT_Z, 0, 30, 31,
   Animation_for_R_upleg_motion_ch5_key, Animation_for_R_upleg_motion_ch5_val},
  {NDC_ANIMKIND_SCL_X, 0, 30, 31,
   Animation_for_R_upleg_motion_ch6_key, Animation_for_R_upleg_motion_ch6_val},
  {NDC_ANIMKIND_SCL_Y, 0, 30, 31,
   Animation_for_R_upleg_motion_ch7_key, Animation_for_R_upleg_motion_ch7_val},
  {NDC_ANIMKIND_SCL_Z, 0, 30, 31,
   Animation_for_R_upleg_motion_ch8_key, Animation_for_R_upleg_motion_ch8_val},
};

static NDR_ANIM Animation_for_R_upleg_motion={
  Animation_for_R_upleg_motion_chlist, 9, 30
};

/* ============================================================
          Object Structure Area
 ============================================================ */
/* Object #0 */
static NDR_OBJ _dummy_obj={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #1 */
static u16 _body_link[]={ 1, 4, 5, 8, 9, 10, 13, 14 };
static NDR_OBJ _body={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,-12.340581,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  0,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  0, 0, 2, 0x010203,
  {-1, -1}, 8, _body_link
};

/* Object #2 */
static u16 _R_uparm_link[]={ 1 };
static NDR_OBJ _R_uparm={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  1,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  1, 0, 2, 0x010203,
  {-1, -1}, 1, _R_uparm_link
};

/* Object #3 */
static u16 _R_lowarm_link[]={ 1 };
static NDR_OBJ _R_lowarm={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {-0.000005,0.000000,0.000000,
   0.000000,0.000000,-0.000000,
   1.000000,1.000000,1.000000},
  2,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  2, 0, 2, 0x010203,
  {-1, -1}, 1, _R_lowarm_link
};

/* Object #4 */
static NDR_OBJ _R_hand={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {-0.000005,0.000004,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  3,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  3, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #5 */
static NDR_OBJ _R_sode={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  4,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  4, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #6 */
static u16 _L_uparm_link[]={ 1 };
static NDR_OBJ _L_uparm={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  5,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  5, 0, 2, 0x010203,
  {-1, -1}, 1, _L_uparm_link
};

/* Object #7 */
static u16 _L_lowarm_link[]={ 1 };
static NDR_OBJ _L_lowarm={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000005,0.000000,
   0.000000,0.000000,-0.000000,
   1.000000,1.000000,1.000000},
  6,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  6, 0, 2, 0x010203,
  {-1, -1}, 1, _L_lowarm_link
};

/* Object #8 */
static NDR_OBJ _L_hand={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,-0.000010,0.000000,
   -0.000000,-0.000000,0.000000,
   1.000000,1.000000,1.000000},
  7,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  7, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #9 */
static NDR_OBJ _L_sode={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  8,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  8, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #10 */
static NDR_OBJ _head={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  9,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  9, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #11 */
static u16 _L_upleg_link[]={ 1 };
static NDR_OBJ _L_upleg={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,-12.340581,
   -0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  10,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  10, 0, 2, 0x010203,
  {-1, -1}, 1, _L_upleg_link
};

/* Object #12 */
static u16 _L_lowleg_link[]={ 1 };
static NDR_OBJ _L_lowleg={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000005,0.000000,
   0.000000,-0.000000,-0.000000,
   1.000000,1.000000,1.000000},
  11,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  11, 0, 2, 0x010203,
  {-1, -1}, 1, _L_lowleg_link
};

/* Object #13 */
static NDR_OBJ _L_shoe={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,-0.000005,0.000000,
   -0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  12,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  12, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #14 */
static NDR_OBJ _L_leg={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,-12.340581,
   -0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  13,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  13, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #15 */
static u16 _hip_link[]={ 1, 4 };
static NDR_OBJ _hip={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,-12.340586,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  14,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  14, 0, 2, 0x010203,
  {-1, -1}, 2, _hip_link
};

/* Object #16 */
static u16 _R_leg_link[]={ 1 };
static NDR_OBJ _R_leg={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000005,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  15,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  15, 0, 2, 0x010203,
  {-1, -1}, 1, _R_leg_link
};

/* Object #17 */
static u16 _R_lowleg_link[]={ 1 };
static NDR_OBJ _R_lowleg={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   -0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  16,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  16, 0, 2, 0x010203,
  {-1, -1}, 1, _R_lowleg_link
};

/* Object #18 */
static NDR_OBJ _R_shoe={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,-0.000000,0.000000,
   1.000000,1.000000,1.000000},
  17,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  17, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #19 */
static NDR_OBJ _R_upleg={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000005,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  18,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  18, 0, 2, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #20 */
static NDR_OBJ _NULL_OBJECT_1={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #21 */
static NDR_OBJ _NULL_OBJECT_2={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #22 */
static NDR_OBJ _NULL_OBJECT_3={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* ============================================================
          Scene Structure Area
 ============================================================ */
static NDR_SCN_INST_OBJ kime_scene_instlist[]={
 {
  {0,0,0, 0,0,0, 1,1,1},
  20 /* NULL_OBJECT_1 */
 },
 {
  {0,0,0, 0,0,0, 1,1,1},
  22 /* NULL_OBJECT_3 */
 },
 {
  {0,0,0, 0,0,0, 1,1,1},
  21 /* NULL_OBJECT_2 */
 },
 {
  {0.000000,0.000000,-12.340581,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  1 /* body */
 },
};

static NDR_SCN_LIGHT _kime_scene_light[]={
  { 0, 0xffffff00, 0.57735, 0.57735, 0.57735, 0, 0 }
};

static NDR_SCENE kime_scene={
  {950.000000, 1000.000000, 0x4c, 0x4c, 0x4c, 0xff},
  {1, 45.841393, 1.333330, 1.000000, 0, 0, 0, 0, 1, 10000, 0, 1, 2},
  { 0x000000ff, 1, _kime_scene_light },
  0x0000, 0xfffc,
  kime_scene_instlist, 4,
};

/* ============================================================
          Shape Structure List
 ============================================================ */
static NDR_SHAPE *shapelist_frake_kime[] = {
  &shape_Shape_of___POLYHEDRON_324_,
  &shape_Shape_of___POLYHEDRON_338_,
  &shape_Shape_of___POLYHEDRON_340_,
  &shape_Shape_of___POLYHEDRON_342_,
  &shape_Shape_of___POLYHEDRON_336_,
  &shape_Shape_of___POLYHEDRON_330_,
  &shape_Shape_of___POLYHEDRON_332_,
  &shape_Shape_of___POLYHEDRON_334_,
  &shape_Shape_of___POLYHEDRON_328_,
  &shape_Shape_of___POLYHEDRON_293_,
  &shape_Shape_of___POLYHEDRON_352_,
  &shape_Shape_of___POLYHEDRON_356_,
  &shape_Shape_of___POLYHEDRON_360_,
  &shape_Shape_of___POLYHEDRON_348_,
  &shape_Shape_of___POLYHEDRON_346_,
  &shape_Shape_of___POLYHEDRON_344_,
  &shape_Shape_of___POLYHEDRON_354_,
  &shape_Shape_of___POLYHEDRON_358_,
  &shape_Shape_of___POLYHEDRON_350_,
};

/* ============================================================
          Geometric Animation List
 ============================================================ */
static NDR_ANIM *animlist_frake_kime[]={
  &Animation_for_body_motion,
  &Animation_for_R_uparm_motion,
  &Animation_for_R_lowarm_motion,
  &Animation_for_R_hand_motion,
  &Animation_for_R_sode_motion,
  &Animation_for_L_uparm_motion,
  &Animation_for_L_lowarm_motion,
  &Animation_for_L_hand_motion,
  &Animation_for_L_sode_motion,
  &Animation_for_head_motion,
  &Animation_for_L_upleg_motion,
  &Animation_for_L_lowleg_motion,
  &Animation_for_L_shoe_motion,
  &Animation_for_L_leg_motion,
  &Animation_for_hip_motion,
  &Animation_for_R_leg_motion,
  &Animation_for_R_lowleg_motion,
  &Animation_for_R_shoe_motion,
  &Animation_for_R_upleg_motion,
};

/* ============================================================
          Object Struct List
 ============================================================ */
static NDR_OBJ *objlist_frake_kime[]={
  &_dummy_obj, /* 0 */
  &_body, /* 1 */
  &_R_uparm, /* 2 */
  &_R_lowarm, /* 3 */
  &_R_hand, /* 4 */
  &_R_sode, /* 5 */
  &_L_uparm, /* 6 */
  &_L_lowarm, /* 7 */
  &_L_hand, /* 8 */
  &_L_sode, /* 9 */
  &_head, /* 10 */
  &_L_upleg, /* 11 */
  &_L_lowleg, /* 12 */
  &_L_shoe, /* 13 */
  &_L_leg, /* 14 */
  &_hip, /* 15 */
  &_R_leg, /* 16 */
  &_R_lowleg, /* 17 */
  &_R_shoe, /* 18 */
  &_R_upleg, /* 19 */
  &_NULL_OBJECT_1, /* 20 */
  &_NULL_OBJECT_2, /* 21 */
  &_NULL_OBJECT_3, /* 22 */
};

/* ############################################################
          Resource Information
 ############################################################ */
NDR_RESINFO resinfo_frake_kime={
  &kime_scene,
  20.000000,
  objlist_frake_kime,
  shapelist_frake_kime,
  animlist_frake_kime,
  NULL,
  NULL,
  NULL,
  23, 19, 19, 0, 0, 0
};

