
/* niff to gfx converter v1.2 */

/* ============================================================
          Header Area
 ============================================================ */

#ifndef __ND_COMMONS__
#define __ND_COMMONS__

/* ------------------ macros */

#define SEGTOP(sno) ((u32)(sno)<<24)
#define SEGADRS(sno,adrs) (SEGTOP(sno)|((u32)(adrs)&0x00ffffff))

/* ------------------ geometric animation */

enum{
  /* NDR_ANIM_CHANNEL.kind */
  NDC_ANIMKIND_TRS_X  = 0x00,
  NDC_ANIMKIND_TRS_Y  = 0x01,
  NDC_ANIMKIND_TRS_Z  = 0x02,
  NDC_ANIMKIND_ROT_X  = 0x03,
  NDC_ANIMKIND_ROT_Y  = 0x04,
  NDC_ANIMKIND_ROT_Z  = 0x05,
  NDC_ANIMKIND_SCL_X  = 0x06,
  NDC_ANIMKIND_SCL_Y  = 0x07,
  NDC_ANIMKIND_SCL_Z  = 0x08
};

typedef struct {
  u16 kind;
  s16 start;
  s16 end;
  s16 nkey;
  s16 *key;
  float *value;
} NDR_ANIM_CHANNEL;

typedef struct {
  NDR_ANIM_CHANNEL *chlist;
  u16 nch;
  u16 total;
} NDR_ANIM;

/* ------------------ shape */

typedef struct{
  s16 *key;
  s16 *tblno;
  u16 nkey;
  u16 nelem;
} NDR_DEFORM;

typedef struct{
  Gfx *gfx;
  Vtx *vtx;
  u16 nvtx;
  u16 vtxsegno;

  /* using texture segment */
  u8 *img;
  u16 *tlut;
  u16 imgsegno, tlutsegno;

  /* shape deform data link */
  s16 *shaperef;
  NDR_DEFORM *vtx_deform;
  NDR_DEFORM *vtxcol_deform;
  NDR_DEFORM *vtxnv_deform;

} NDR_SHAPE;

/* ------------------ object */

enum{
  /* object types */
  NDC_TYPE_NULL = 0x01,
  NDC_TYPE_3D = 0x02,
  NDC_TYPE_BILLBOARD = 0x03,

  /* ColorCombine Mode */
  NDC_CC_COMBINED = 0x00,
  NDC_CC_TEX0 = 0x01,
  NDC_CC_TEX1 = 0x02,
  NDC_CC_PRIMITIVE = 0x03,
  NDC_CC_SHADE = 0x04,
  NDC_CC_ENV = 0x05,
  NDC_CC_KEY_CENTER = 0x10,
  NDC_CC_KEY_SCALE = 0x11,
  NDC_CC_COMBINED_ALPHA = 0x06,
  NDC_CC_TEX0_ALPHA = 0x07,
  NDC_CC_TEX1_ALPHA = 0x08,
  NDC_CC_PRIMITIVE_ALPHA = 0x09,
  NDC_CC_SHADE_ALPHA = 0x0a,
  NDC_CC_ENV_ALPHA = 0x0b,
  NDC_CC_LOD = 0x0c,
  NDC_CC_PRIM_LOD = 0x0d,
  NDC_CC_NOISE = 0x12,
  NDC_CC_K4 = 0x14,
  NDC_CC_K5 = 0x15,
  NDC_CC_1 = 0x0e,
  NDC_CC_0 = 0x0f,

  /* Render Mode(complexed) */
  NDC_RM_AA_EN                     = 0x80000000,
  NDC_RM_Z_CMP                     = 0x40000000,
  NDC_RM_Z_UPD                     = 0x20000000,
  NDC_RM_IM_RD                     = 0x10000000,
  NDC_RM_CVG_DST                   = 0x0c000000,
    NDC_RM_CVG_DST_CLAMP           = 0x00000000,
    NDC_RM_CVG_DST_WRAP            = 0x04000000,
    NDC_RM_CVG_DST_FULL            = 0x08000000,
    NDC_RM_CVG_DST_SAVE            = 0x0c000000,
  NDC_RM_CLR_ON_CVG                = 0x02000000,
  NDC_RM_CVG_X_ALPHA               = 0x01000000,
  NDC_RM_ALPHA_CVG_SEL             = 0x00800000,
  NDC_RM_FORCE_BL                  = 0x00400000,
  NDC_RM_ZMODE                     = 0x00300000,
    NDC_RM_ZMODE_OPA               = 0x00000000,
    NDC_RM_ZMODE_INTER             = 0x00100000,
    NDC_RM_ZMODE_XLU               = 0x00200000,
    NDC_RM_ZMODE_DEC               = 0x00300000,
  NDC_RM_ALPHA_COMPARE             = 0x000c0000,
    NDC_RM_ALPHA_COMPARE_NONE      = 0x00000000,
    NDC_RM_ALPHA_COMPARE_THRESHOLD = 0x00040000,
    NDC_RM_ALPHA_COMPARE_DITHER    = 0x00080000,
  NDC_RM_DITHER_ALPHA              = 0x00030000,
    NDC_RM_DITHER_ALPHA_PATTERN    = 0x00000000,
    NDC_RM_DITHER_ALPHA_NOPATTERN  = 0x00010000,
    NDC_RM_DITHER_ALPHA_NOISE      = 0x00020000,
    NDC_RM_DITHER_ALPHA_DISABLE    = 0x00030000,
  NDC_RM_BLENDER_MUX0              = 0x0000ff00,
  NDC_RM_BLENDER_MUX1              = 0x000000ff,

  /* NDR_OBJ.regflag(bit assign) */
  NDC_REGF_2CYC        = 0x4000
};

typedef struct{
  float tx, ty, tz;
  float rx, ry, rz;
  float sx, sy, sz;
} TRX;

typedef struct ndr_objTag{

  /* object propaties */
  u16 type, gid;
  u32 prio;
  TRX trx;

  /* resourse index */
  s16 shape;

  /* RSP, RDP status register setting */
  u16 regflag;
  u32 geommode;
  u32 rdmode;
  u32 primcol;
  u8 cc1[8], cc2[8];

  /* geometric animation setting */
  s16 geom_anim;
  u16 loop;
  u16 framerate;
  u32 order;

  /* children links */
  s16 bb_obj[2];
  u16 nchild;
  u16 *child;

} NDR_OBJ;

/* ------------------ scene */

typedef struct{
  TRX trx;
  u16 objno;
} NDR_SCN_INST_OBJ;

typedef struct{
  int type;
  u32 color;
  float x, y, z;
  float a1,a2;
} NDR_SCN_LIGHT;

typedef struct{
  struct{
    u16 near, far;
    u8 r,g,b,a;
  }fog;
  struct{
    u32 mode;
    float fovy, aspect, scale;
    u16 top, bottom, left, right, near, far;
    u16 eye_inst, upper_inst, lookat_inst;
  }cam;
  struct{
    u32 amb_color;
    int nlight;
    NDR_SCN_LIGHT *light;
  }light;
  u16 fill_col, fill_depth;
  NDR_SCN_INST_OBJ *entryobj;
  u16 nentobj;
} NDR_SCENE;

typedef struct{
  NDR_SCENE *scene;
  float convert_scale;

  NDR_OBJ **obj;
  NDR_SHAPE **shape;
  NDR_ANIM **anim;
  s16 **rawvtx;
  u32 **rawvtxcol;
  s8 **rawvtxnv;

  u16 nobj;
  u16 nanim;
  u16 nshape;
  u16 nrawvtx;
  u16 nrawvtxcol;
  u16 nrawvtxnv;
} NDR_RESINFO;

#endif    /* #ifndef __ND_COMMONS__ */

#ifdef PREVIEW_TYPE
#undef PREVIEW_TYPE
#endif  /* #ifdef PREVIEW_TYPE */

#ifdef RESINFO_NAME
#undef RESINFO_NAME
#endif  /* #ifdef RESINFO_NAME */

#define PREVIEW_TYPE 28
extern NDR_RESINFO resinfo_frake_select;
#define RESINFO_NAME resinfo_frake_select

static Gfx _frake_select_aligner0[] = { gsSPEndDisplayList() };

/* ============================================================
          Bitmap
 ============================================================ */
static u8 bmp_frake_select[] = {
/* name:belt2  type:RGBA  pixel/bit: 16 bits
  offset:0x00000000  length:2048 bytes. */
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x24,0x48,0x24,0x48,0x24,0x48,0x26,
0x50,0x66,0x50,0x66,0x48,0x26,0x48,0x24,
0x48,0x24,0x48,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x48,0x24,0x48,0x26,0x48,0x24,0x40,0x24,
0x08,0x02,0x18,0x88,0x49,0xd6,0x73,0x24,
0x8b,0xaa,0x8b,0xaa,0x73,0x24,0x41,0xd6,
0x18,0x88,0x08,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x28,0xcc,0x6a,0xe2,0x10,0x86,0x00,0x02,
0x00,0x00,0x10,0x86,0x4a,0x16,0x7b,0xa4,
0x8c,0x2c,0x8c,0x2c,0x7b,0xa4,0x42,0x14,
0x10,0x84,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x18,0xc8,0x73,0x22,0x18,0xc6,0x00,0x00,
0x08,0x02,0x18,0x88,0x49,0xd8,0x7b,0x66,
0x8b,0xaa,0x8b,0xaa,0x73,0x24,0x41,0xd6,
0x18,0x88,0x08,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x00,0x02,0x00,0x02,0x00,0x02,0x00,0x02,
0x18,0x8a,0x6a,0xe2,0x20,0xca,0x00,0x02,
0x48,0x24,0x48,0x24,0x48,0x24,0x48,0x26,
0x50,0x66,0x50,0x66,0x48,0x26,0x48,0x24,
0x48,0x24,0x48,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x40,0x24,0x40,0x24,0x40,0x24,0x40,0x24,
0x48,0x24,0x48,0x26,0x48,0x24,0x40,0x24,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
0x48,0x26,0x48,0x26,0x48,0x26,0x48,0x26,
/* name:mouth2_32  type:RGBA  pixel/bit: 16 bits
  offset:0x00000800  length:2048 bytes. */
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x5e,0xed,0x5e,0xed,0x5e,0xed,0x5e,
0xe5,0x1c,0xdd,0x1c,0xed,0x5e,0xed,0x5e,
0xf5,0x5e,0xf5,0x5e,0xf5,0x9e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x9e,0xed,0x5e,0xed,0x5e,0xd4,0xdc,
0xb4,0x16,0x9b,0x54,0x8b,0x12,0x72,0x8e,
0x62,0x0c,0x62,0x0c,0x6a,0x8e,0x7a,0xd0,
0x93,0x52,0xa3,0xd4,0xbc,0x18,0xd4,0xda,
0xed,0x5e,0xf5,0x9e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0x9e,0xed,0x5e,
0xcc,0x9a,0x8b,0x52,0x6a,0x4e,0x5a,0x0c,
0x41,0x48,0x31,0x06,0x29,0x06,0x20,0xc4,
0x20,0x84,0x28,0xc4,0x20,0xc4,0x20,0xc4,
0x31,0x06,0x39,0x48,0x41,0x88,0x5a,0x0c,
0x83,0x10,0xc4,0x58,0xed,0x5e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x5e,0xe5,0x1e,0xc4,0x58,0x8b,0x52,
0x51,0xca,0x29,0x06,0x20,0x84,0x20,0xc4,
0x31,0x06,0x39,0x46,0x51,0xca,0x62,0x0c,
0x6a,0x4e,0x7a,0x8e,0x6a,0x4e,0x49,0xca,
0x41,0x88,0x39,0x46,0x28,0xc4,0x28,0xc4,
0x28,0xc4,0x51,0xca,0x9b,0x54,0xdc,0xdc,
0xf5,0x5e,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xed,0x5e,
0xc4,0x58,0x8b,0x10,0x49,0x8a,0x31,0x06,
0x20,0x84,0x39,0x46,0x5a,0x0a,0x7a,0xd0,
0x93,0x52,0xa3,0xd4,0xc4,0x58,0xdc,0xdc,
0xed,0x5e,0xed,0x5e,0xe5,0x1c,0xcc,0x9a,
0xb4,0x16,0xa3,0x94,0x83,0x10,0x6a,0x4c,
0x31,0x06,0x28,0xc4,0x31,0x06,0x6a,0x4c,
0xbc,0x58,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xed,0x5e,0xa3,0xd4,
0x49,0xca,0x29,0x06,0x20,0x84,0x39,0x48,
0x6a,0x4c,0xa3,0x94,0xd4,0xdc,0xed,0x5e,
0xf5,0x5e,0xf5,0x5e,0xf5,0x9e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x9e,0xf5,0x5e,0xed,0x5e,0xd4,0xdc,
0x9b,0x94,0x51,0xca,0x31,0x06,0x20,0xc4,
0x51,0xca,0xbc,0x18,0xed,0x5e,0xf5,0xa0,
0xf5,0x9e,0xe5,0x1c,0xa3,0x94,0x41,0x88,
0x20,0x84,0x39,0x48,0x62,0x4c,0xab,0xd6,
0xdc,0xdc,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xed,0x5e,0xcc,0x9a,0x82,0xd0,0x39,0x46,
0x28,0xc4,0x5a,0x0a,0xc4,0x58,0xed,0x5e,
0xdc,0xdc,0x8b,0x52,0x39,0x48,0x20,0x84,
0x41,0x88,0x9b,0x94,0xdc,0xdc,0xed,0x5e,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0x5e,0xe5,0x1c,0x8b,0x12,
0x31,0x46,0x28,0xc4,0x62,0x4c,0xcc,0x9a,
0x9b,0x94,0x39,0x46,0x20,0xc4,0x51,0xca,
0xab,0xd6,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0x9e,0xdd,0x1c,
0x82,0xd0,0x31,0x06,0x31,0x06,0x8b,0x12,
0x6a,0x8e,0x28,0xc4,0x5a,0x0a,0xbc,0x18,
0xed,0x5e,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0x9e,
0xd4,0xda,0x72,0x8e,0x39,0x48,0x82,0xd0,
0xc4,0x58,0x9b,0x94,0xc4,0x9a,0xed,0x5e,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x5e,0xd4,0xda,0xb4,0x16,0xd4,0x9a,
0xf5,0x9e,0xf5,0x5e,0xf5,0x9e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0x5e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
/* name:defeye2  type:RGBA  pixel/bit: 16 bits
  offset:0x00001000  length:2048 bytes. */
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xe2,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xcc,0x9a,0x62,0x4c,0x10,0x42,0x62,0x4c,
0xcc,0x9a,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xed,0x5e,
0x5a,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
0x5a,0x0c,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0x9b,0x94,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x9b,0x94,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0x49,0xca,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x49,0xca,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xc4,0x58,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xc4,0x58,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x93,0x52,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x93,0x52,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x6a,0x4e,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x6a,0x4e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x41,0x88,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x41,0x88,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x28,0xc4,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x28,0xc4,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x10,0x42,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x42,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x10,0x42,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x42,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x28,0xc4,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x28,0xc4,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x41,0x88,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x41,0x88,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x6a,0x4e,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x6a,0x4e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x93,0x52,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x93,0x52,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xc4,0x58,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xc4,0x58,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0x49,0xca,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x49,0xca,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0x9b,0x94,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x9b,0x94,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xed,0x5e,
0x5a,0x0c,0x00,0x00,0x00,0x00,0x00,0x00,
0x5a,0x0c,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xcc,0x9a,0x62,0x4c,0x10,0x42,0x62,0x4c,
0xcc,0x9a,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x6a,0x4e,0x5a,0x0c,
0x62,0x0c,0x9b,0x94,0xed,0x5e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x51,0xca,0x00,0x00,
0x08,0x40,0x08,0x00,0x49,0xca,0xb4,0x16,
0xd4,0xda,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0x8b,0x12,0x18,0x82,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x18,0x82,0x51,0xca,0xb4,0x16,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0x9e,0xbc,0x58,
0x51,0xca,0x08,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x51,0xca,
0xb4,0x16,0xed,0x5e,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0x5e,0xb4,0x16,0x5a,0x0a,0x08,0x42,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0x00,0x31,0x46,0x7a,0x8e,0xbc,0x58,
0xe5,0x1e,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xc4,0x58,
0x5a,0x0c,0x10,0x42,0x00,0x00,0x08,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x41,0x88,0xab,0xd6,0xf5,0x5e,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xcc,0x9a,0x7a,0xd0,0x9b,0x94,
0x8b,0x52,0x7a,0xd0,0x39,0x48,0x20,0xc4,
0x7a,0xd0,0x7a,0xd0,0x83,0x12,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,
0xf5,0xa0,0xf5,0xa0,0xf5,0xa0,0xf5,0xe2,
/* name:refmap  type:RGBA  pixel/bit: 16 bits
  offset:0x00001800  length:2048 bytes. */
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x18,0xc9,0x10,0x87,0x08,0x43,0x08,0x01,
0x08,0x43,0x08,0x43,0x08,0x43,0x21,0x09,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x45,0x20,0xc7,
0x10,0x85,0x10,0x85,0x10,0x85,0x10,0x85,
0x10,0x85,0x10,0x85,0x10,0x85,0x10,0x45,
0x10,0x85,0x10,0x43,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0x43,0x18,0xc7,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x10,0x85,0x21,0x09,
0x10,0x85,0x10,0x85,0x10,0x45,0x10,0x43,
0x10,0x45,0x10,0x43,0x10,0x85,0x10,0x43,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x21,0x09,0x18,0xc7,
0x21,0x09,0x21,0x07,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x20,0xc7,0x10,0x85,0x10,0x45,0x10,0x43,
0x18,0x85,0x08,0x01,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x08,0x43,0x18,0xc7,0x21,0x09,
0x10,0x85,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x20,0xc7,0x20,0xc7,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x18,0xc7,0x08,0x03,
0x10,0x85,0x18,0x85,0x08,0x43,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x08,0x43,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x18,0xc7,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x18,0xc7,
0x18,0x87,0x10,0x43,0x10,0x43,0x10,0x85,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x20,0xc7,
0x08,0x43,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x18,0x87,0x20,0xc7,
0x18,0xc7,0x18,0x85,0x10,0x45,0x20,0xc9,
0x10,0x85,0x10,0x85,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x10,0x85,0x10,0x43,0x10,0x43,
0x20,0xc7,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x10,0x43,
0x18,0xc5,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x10,0x85,0x08,0x43,0x08,0x43,
0x10,0x43,0x10,0x43,0x10,0x45,0x10,0x45,
0x10,0x85,0x18,0x87,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x08,0x43,0x10,0x43,
0x10,0x43,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x87,0x10,0x43,
0x20,0xc5,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x10,0x85,0x08,0x43,0x08,0x43,
0x08,0x43,0x08,0x43,0x10,0x45,0x10,0x85,
0x10,0x85,0x21,0x09,0x10,0x85,0x21,0x09,
0x21,0x09,0x21,0x07,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x10,0x85,
0x10,0x43,0x18,0xc7,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x10,0x85,0x10,0x43,
0x20,0xc5,0x20,0xc5,0x21,0x09,0x21,0x09,
0x08,0x01,0x10,0x43,0x10,0x43,0x18,0x85,
0x10,0x43,0x08,0x43,0x10,0x45,0x21,0x09,
0x10,0x85,0x10,0x85,0x10,0x85,0x21,0x09,
0x21,0x0b,0x21,0x0b,0x08,0x43,0x21,0x0b,
0x21,0x0b,0x21,0x09,0x21,0x07,0x21,0x09,
0x08,0x43,0x18,0x85,0x00,0x00,0x00,0x00,
0x00,0x00,0x18,0xc7,0x08,0x43,0x10,0x43,
0x20,0xc5,0x20,0xc5,0x21,0x09,0x10,0x43,
0x10,0x43,0x10,0x83,0x18,0x83,0x18,0x83,
0x18,0xc7,0x18,0xc7,0x10,0x85,0x10,0x85,
0x10,0x85,0x10,0x85,0x10,0x85,0x21,0x0b,
0x21,0x0b,0x21,0x0b,0x21,0x0b,0x21,0x09,
0x21,0x09,0x20,0xc5,0x20,0xc5,0x21,0x09,
0x18,0xc7,0x10,0x43,0x08,0x01,0x00,0x00,
0x00,0x00,0x10,0x87,0x08,0x43,0x10,0x85,
0x18,0x85,0x21,0x09,0x21,0x09,0x08,0x41,
0x18,0x85,0x20,0xc7,0x20,0xc7,0x10,0x83,
0x10,0x43,0x10,0x43,0x10,0x85,0x10,0x85,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x21,0x09,
0x21,0x0b,0x21,0x09,0x20,0xc5,0x20,0xc5,
0x20,0xc5,0x20,0xc5,0x18,0x85,0x21,0x07,
0x10,0x85,0x10,0x43,0x08,0x43,0x00,0x00,
0x00,0x00,0x10,0x85,0x08,0x01,0x21,0x09,
0x10,0x83,0x18,0x85,0x10,0x43,0x08,0x03,
0x18,0x85,0x18,0x85,0x18,0xc5,0x18,0xc7,
0x10,0x85,0x10,0x85,0x08,0x43,0x21,0x09,
0x18,0x85,0x10,0x85,0x10,0x85,0x10,0x85,
0x08,0x43,0x08,0x43,0x10,0x83,0x10,0x83,
0x08,0x43,0x08,0x43,0x21,0x09,0x10,0x83,
0x10,0x85,0x08,0x43,0x10,0x43,0x00,0x00,
0x18,0x87,0x08,0x43,0x08,0x01,0x21,0x09,
0x18,0x85,0x08,0x01,0x08,0x43,0x08,0x01,
0x08,0x01,0x08,0x01,0x08,0x01,0x08,0x03,
0x08,0x03,0x10,0x43,0x08,0x01,0x08,0x43,
0x08,0x43,0x08,0x43,0x08,0x43,0x08,0x43,
0x08,0x43,0x08,0x43,0x10,0x43,0x10,0x43,
0x08,0x43,0x08,0x43,0x21,0x09,0x10,0x85,
0x10,0x85,0x08,0x43,0x10,0x85,0x18,0x85,
0x10,0x87,0x08,0x43,0x08,0x43,0x10,0x85,
0x18,0x85,0x08,0x43,0x08,0x43,0x08,0x43,
0x08,0x43,0x10,0x83,0x21,0x09,0x21,0x07,
0x08,0x43,0x08,0x43,0x08,0x03,0x08,0x43,
0x08,0x43,0x10,0x43,0x10,0x85,0x08,0x45,
0x10,0x85,0x10,0x85,0x08,0x43,0x08,0x43,
0x08,0x43,0x08,0x03,0x21,0x09,0x18,0xc7,
0x18,0xc7,0x08,0x43,0x10,0x85,0x21,0x07,
0x10,0x85,0x08,0x43,0x10,0x43,0x08,0x43,
0x10,0x43,0x10,0x43,0x20,0xc7,0x21,0x07,
0x10,0x85,0x10,0x87,0x21,0x09,0x10,0x85,
0x10,0x85,0x08,0x43,0x08,0x03,0x10,0x45,
0x10,0x87,0x10,0x85,0x10,0x87,0x10,0x45,
0x08,0x43,0x10,0x87,0x08,0x43,0x10,0x45,
0x08,0x43,0x08,0x03,0x18,0xc7,0x18,0x85,
0x10,0x85,0x10,0x43,0x10,0x85,0x10,0x85,
0x10,0x85,0x08,0x03,0x08,0x43,0x08,0x43,
0x08,0x01,0x10,0x43,0x10,0x85,0x10,0x85,
0x10,0x85,0x10,0x87,0x10,0x85,0x10,0x43,
0x08,0x43,0x08,0x43,0x08,0x43,0x10,0x45,
0x10,0x87,0x10,0xc7,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x19,0x09,0x10,0x85,0x08,0x45,
0x08,0x45,0x08,0x03,0x08,0x43,0x10,0x85,
0x10,0x85,0x10,0x45,0x10,0x85,0x10,0x85,
0x10,0x85,0x08,0x43,0x10,0x85,0x18,0x87,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0x87,0x10,0x85,0x10,0x43,
0x10,0x85,0x08,0x43,0x08,0x43,0x18,0xc7,
0x18,0xc9,0x10,0xc7,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x10,0x85,0x10,0x85,
0x08,0x43,0x18,0x87,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0xc7,0x18,0x85,0x10,0x43,
0x08,0x43,0x10,0x43,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x20,0xc9,0x20,0xc9,0x21,0x09,
0x21,0x09,0x10,0x87,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x20,0xc9,0x10,0x85,
0x10,0x85,0x10,0x85,0x10,0x43,0x10,0x85,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x20,0xc7,0x18,0xc7,0x18,0xc7,
0x00,0x00,0x10,0x85,0x10,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x19,0x09,
0x21,0x09,0x21,0x09,0x21,0x09,0x21,0x09,
0x21,0x09,0x21,0x09,0x29,0x09,0x29,0x09,
0x21,0x09,0x21,0x09,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x00,0x00,
0x00,0x00,0x10,0x85,0x18,0xc7,0x18,0xc7,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x21,0x09,
0x21,0x09,0x10,0x45,0x21,0x0b,0x21,0x0b,
0x29,0x4b,0x29,0x4b,0x29,0x4d,0x29,0x4b,
0x29,0x4b,0x29,0x0b,0x21,0x09,0x21,0x0b,
0x21,0x09,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc7,0x18,0xc7,0x18,0xc9,0x00,0x00,
0x00,0x00,0x10,0x87,0x18,0xc7,0x18,0xc9,
0x18,0xc7,0x18,0xc7,0x18,0xc7,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x21,0x09,0x21,0x09,
0x21,0x09,0x29,0x0b,0x21,0x0b,0x29,0x4b,
0x29,0x4d,0x31,0x8d,0x31,0x8f,0x39,0xcf,
0x31,0x8f,0x31,0x8d,0x29,0x4b,0x21,0x0b,
0x21,0x0b,0x21,0x09,0x18,0xc9,0x18,0xc7,
0x18,0xc7,0x18,0xc9,0x18,0xc9,0x00,0x00,
0x00,0x00,0x00,0x00,0x18,0xc7,0x18,0xc9,
0x18,0xc9,0x18,0xc7,0x18,0xc7,0x18,0xc9,
0x20,0xc9,0x21,0x09,0x19,0x09,0x21,0x09,
0x21,0x0b,0x21,0x0b,0x29,0x4d,0x29,0x4d,
0x29,0x8f,0x39,0xd1,0x42,0x13,0x4a,0x53,
0x42,0x13,0x39,0xd1,0x31,0x8f,0x21,0x4b,
0x21,0x0b,0x21,0x09,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x20,0xc7,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x18,0xc7,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x19,0x09,
0x19,0x0b,0x29,0x4b,0x21,0x4d,0x29,0x8f,
0x39,0xd1,0x52,0x97,0x6b,0x9f,0x73,0x9f,
0x6b,0x5d,0x52,0x95,0x31,0xd1,0x29,0x4d,
0x21,0x0b,0x21,0x09,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x18,0xc7,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x19,0x0b,0x21,0x0b,0x21,0x4d,0x31,0x8f,
0x42,0x55,0x7c,0x23,0xb5,0xf1,0xde,0xf9,
0xb5,0xaf,0x73,0x9f,0x42,0x13,0x31,0x8d,
0x21,0x0b,0x18,0xc9,0x18,0xc9,0x21,0x09,
0x18,0xc9,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x21,0x09,
0x18,0xc9,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc7,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x19,0x0b,0x21,0x0b,0x29,0x4d,0x31,0xd1,
0x52,0x99,0x9c,0xe9,0xff,0xff,0xff,0xff,
0xe7,0x3b,0x84,0x23,0x4a,0x55,0x31,0x8f,
0x29,0x4b,0x18,0xc9,0x18,0xc9,0x21,0x09,
0x21,0x09,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x21,0x09,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc7,0x10,0xc9,0x18,0xc9,
0x18,0xc9,0x19,0x0b,0x21,0x4d,0x31,0xd1,
0x52,0xd9,0x94,0xe9,0xf7,0xbf,0xff,0xff,
0xc6,0x75,0x6b,0x5d,0x42,0x13,0x29,0x4d,
0x21,0x0b,0x19,0x09,0x18,0xc9,0x21,0x09,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x21,0x09,0x21,0x09,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x10,0xc9,0x10,0xc9,
0x18,0xc9,0x18,0xcb,0x21,0x0d,0x29,0x8f,
0x42,0x13,0x5b,0x1b,0x84,0x23,0x84,0x65,
0x6b,0x5d,0x42,0x13,0x29,0x4d,0x21,0x0b,
0x21,0x0b,0x19,0x0b,0x19,0x0b,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x21,0x09,0x21,0x0b,
0x19,0x09,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xc9,0x18,0xcb,0x21,0x0b,
0x29,0x8f,0x39,0xd1,0x42,0x13,0x42,0x13,
0x31,0xd1,0x29,0x8f,0x21,0x0d,0x21,0x0b,
0x19,0x0b,0x19,0x0b,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x21,0x0b,0x18,0xc9,0x18,0xc9,0x18,0xc9,
0x18,0xc9,0x18,0xcb,0x19,0x0b,0x19,0x0b,
0x21,0x0d,0x21,0x4d,0x29,0x4d,0x29,0x4d,
0x21,0x4d,0x21,0x0d,0x21,0x0b,0x19,0x0b,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x21,0x0b,0x19,0x0b,0x18,0xcb,
0x18,0xcb,0x19,0x0b,0x19,0x0b,0x21,0x0b,
0x21,0x0b,0x21,0x0b,0x21,0x0b,0x21,0x0b,
0x21,0x0b,0x19,0x0b,0x19,0x0b,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x19,0x0b,0x19,0x0b,0x19,0x0b,0x19,0x0b,
0x19,0x0b,0x19,0x0b,0x19,0x0b,0x21,0x0b,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
/* name:t_shirt3  type:RGBA  pixel/bit: 16 bits
  offset:0x00002000  length:2048 bytes. */
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xa7,0xb4,
0xaf,0x6e,0xaf,0x6e,0xaf,0x6e,0xaf,0x6e,
0xa7,0xb4,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xd0,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x42,0xcd,0xd0,0xcd,0xd0,0x9f,0xfa,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xa7,0xb6,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xa7,0xb6,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xa7,0xb6,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xa7,0xb6,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xd5,0x88,0xbe,0x9e,0xbe,0x9e,0x9f,0xfc,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xcd,0xce,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xa7,0x72,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xaf,0x6e,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xaf,0x6e,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xaf,0x6e,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0xcd,0xd0,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xdd,0x40,0xdd,0x40,0xdd,0x40,
0xdd,0x40,0xaf,0x6e,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfa,
0xa7,0xb6,0xa7,0xb6,0xa7,0xb6,0xa7,0xb6,
0xa7,0xb6,0xa7,0xb6,0xa7,0xb6,0xa7,0xb6,
0xa7,0xb6,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x5c,0x1e,0x39,0x88,0x52,0x0a,0x6a,0x8e,
0x6a,0x8e,0x5a,0x4c,0x39,0x88,0x31,0xcc,
0x65,0x6a,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x21,0x8c,0x8b,0x92,
0xf6,0x20,0xfe,0x62,0xfe,0x62,0xfe,0x62,
0xfe,0x62,0xfe,0x62,0xfe,0x62,0xf6,0x20,
0x8b,0x92,0x18,0x82,0x7e,0xb4,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x6d,0xac,0xa4,0x16,0xfe,0x62,
0xfe,0x62,0xfe,0x62,0xfe,0x62,0xfe,0x62,
0xfe,0x62,0xfe,0x62,0xfe,0x62,0xfe,0x62,
0xfe,0x62,0xd5,0x5c,0x10,0xc6,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,0x9f,0xfe,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:1 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_1[]={
76, -150, 346,
53, -150, 335,
0, -150, 326,
-53, -150, 335,
-76, -150, 346,
-64, -150, 362,
0, -150, 368,
64, -150, 362,
-42, -150, 362,
0, -150, 368,
42, -150, 362,
57, -150, 346,
51, -150, 335,
0, -150, 326,
-51, -150, 335,
-57, -150, 346,
52, -150, 290,
36, -150, 290,
0, -150, 290,
-36, -150, 290,
-52, -150, 290,
-36, -150, 290,
36, -150, 290,
15, -150, 271,
11, -150, 271,
0, -150, 271,
-11, -150, 271,
-15, -150, 271,
-18, -150, 271,
0, -150, 271,
18, -150, 271,
57, -150, 359,
73, -150, 372,
51, -150, 387,
0, -150, 394,
-51, -150, 387,
-73, -150, 372,
-57, -150, 359,
0, -150, 350,
23, -150, 460,
23, -150, 458,
20, -150, 477,
0, -150, 471,
-20, -150, 477,
-23, -150, 458,
-23, -150, 460,
0, -150, 450,
-42, -150, 327,
42, -150, 327,
-56, -150, 331,
-65, -150, 318,
-71, -150, 318,
-64, -150, 331,
65, -150, 318,
56, -150, 331,
64, -150, 331,
71, -150, 318,
-66, -150, 296,
66, -150, 296,
54, -150, 307,
65, -150, 316,
73, -150, 316,
54, -150, 307,
-54, -150, 307,
-73, -150, 316,
-65, -150, 316,
-54, -150, 307,
57, -150, 273,
-57, -150, 273,
4, -150, 297,
47, -150, 305,
56, -150, 305,
4, -150, 297,
-47, -150, 305,
-4, -150, 297,
-4, -150, 297,
-56, -150, 305,
-28, -150, 271,
28, -150, 271,
-59, -150, 425,
0, -150, 433,
59, -150, 425,
0, -150, 460,
-6, -150, 437,
-6, -150, 405,
-50, -150, 399,
-59, -150, 430,
50, -150, 399,
6, -150, 405,
6, -150, 437,
59, -150, 430,
0, -150, 327,
9, -150, 405,
9, -150, 431,
53, -150, 426,
46, -150, 400,
-9, -150, 431,
-9, -150, 405,
-46, -150, 400,
-53, -150, 426,
-44, -150, 162,
-47, -150, 256,
47, -150, 256,
44, -150, 162,
44, -150, 162,
46, -150, 256,
-46, -150, 256,
-44, -150, 162,
11, -150, 265,
-11, -150, 265,
-11, -150, 265,
11, -150, 265,
41, -150, 189,
-41, -150, 189,
40, -150, 189,
-40, -150, 189,
45, -150, 233,
44, -150, 233,
-45, -150, 233,
-44, -150, 233,
-81, -150, 227,
-57, -150, 255,
-49, -150, 222,
-51, -150, 206,
-51, -150, 206,
-49, -150, 222,
-57, -150, 255,
-81, -150, 227,
81, -150, 227,
57, -150, 255,
49, -150, 222,
51, -150, 206,
51, -150, 206,
49, -150, 222,
57, -150, 255,
81, -150, 227,
-30, -150, 156,
30, -150, 156,
29, -150, 156,
-30, -150, 156,
-5, -150, 149,
5, -150, 149,
6, -150, 150,
-5, -150, 150,
-53, -150, 87,
-46, -150, 141,
0, -150, 148,
0, -150, 87,
0, -150, 87,
-1, -150, 148,
-45, -150, 141,
-53, -150, 87,
53, -150, 87,
46, -150, 141,
0, -150, 148,
0, -150, 87,
0, -150, 87,
1, -150, 148,
45, -150, 141,
53, -150, 87,
55, -150, 208,
55, -150, 208,
78, -150, 225,
78, -150, 225,
-55, -150, 208,
-55, -150, 208,
-78, -150, 225,
-78, -150, 225,
-110, -150, 172,
-94, -150, 161,
-94, -150, 161,
-110, -150, 172,
-127, -150, 147,
-116, -150, 161,
-103, -150, 152,
-113, -150, 137,
-113, -150, 137,
-103, -150, 152,
-116, -150, 161,
-127, -150, 147,
-124, -150, 137,
-11, -150, 87,
-41, -150, 87,
-41, -150, 87,
-11, -150, 87,
11, -150, 87,
41, -150, 87,
41, -150, 87,
11, -150, 87,
38, -150, 42,
38, -150, 77,
13, -150, 77,
13, -150, 42,
13, -150, 42,
13, -150, 77,
38, -150, 77,
38, -150, 42,
13, -150, 53,
38, -150, 53,
38, -150, 53,
13, -150, 53,
-38, -150, 42,
-38, -150, 77,
-13, -150, 77,
-13, -150, 42,
-13, -150, 42,
-13, -150, 77,
-38, -150, 77,
-38, -150, 42,
-13, -150, 53,
-38, -150, 53,
-38, -150, 53,
-13, -150, 53,
-65, -150, 6,
-52, -150, 48,
-18, -150, 48,
-13, -150, 6,
-5, -150, 6,
-10, -150, 28,
-41, -150, 28,
-44, -150, 6,
-39, -150, 19,
-10, -150, 38,
-5, -150, 6,
-55, -150, 38,
-59, -150, 6,
65, -150, 6,
52, -150, 48,
18, -150, 48,
13, -150, 6,
5, -150, 6,
10, -150, 28,
41, -150, 28,
44, -150, 6,
39, -150, 19,
10, -150, 38,
5, -150, 6,
55, -150, 38,
59, -150, 6,
110, -150, 172,
94, -150, 161,
94, -150, 161,
110, -150, 172,
127, -150, 147,
116, -150, 161,
103, -150, 152,
113, -150, 137,
113, -150, 137,
103, -150, 152,
116, -150, 161,
127, -150, 147,
124, -150, 137,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:2 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_2[]={
76, -80, 286,
53, -66, 267,
0, -61, 255,
-53, -66, 267,
-76, -80, 286,
-64, -87, 306,
0, -90, 313,
64, -87, 306,
-42, -88, 306,
0, -87, 311,
42, -88, 306,
57, -80, 286,
51, -69, 269,
0, -65, 257,
-51, -69, 269,
-57, -80, 286,
52, -86, 233,
36, -77, 228,
0, -72, 225,
-36, -77, 228,
-52, -86, 233,
-36, -96, 239,
36, -96, 239,
15, -88, 216,
11, -85, 214,
0, -83, 213,
-11, -85, 214,
-15, -88, 216,
-18, -92, 218,
0, -94, 219,
18, -92, 218,
57, -63, 289,
73, -77, 310,
51, -85, 329,
0, -87, 337,
-51, -85, 329,
-73, -77, 310,
-57, -63, 289,
0, -57, 277,
23, -48, 381,
23, -52, 382,
20, -51, 399,
0, -57, 397,
-20, -51, 399,
-23, -52, 382,
-23, -48, 381,
0, -48, 371,
-42, -94, 275,
42, -94, 275,
-56, -90, 277,
-65, -85, 261,
-71, -85, 261,
-64, -90, 277,
65, -85, 261,
56, -90, 277,
64, -90, 277,
71, -85, 261,
-66, -90, 241,
66, -90, 241,
54, -73, 243,
65, -82, 257,
73, -82, 257,
54, -71, 241,
-54, -71, 241,
-73, -82, 257,
-65, -82, 257,
-54, -73, 243,
57, -81, 213,
-57, -81, 213,
4, -69, 230,
47, -72, 240,
56, -69, 239,
4, -65, 229,
-47, -72, 240,
-4, -69, 230,
-4, -65, 229,
-56, -69, 239,
-28, -76, 209,
28, -76, 209,
-59, -75, 361,
0, -76, 370,
59, -75, 361,
0, -53, 384,
-6, -77, 375,
-6, -86, 347,
-50, -85, 340,
-59, -76, 367,
50, -85, 340,
6, -86, 347,
6, -77, 375,
59, -76, 367,
0, -96, 276,
9, -85, 347,
9, -78, 369,
53, -77, 363,
46, -84, 341,
-9, -78, 369,
-9, -85, 347,
-46, -84, 341,
-53, -77, 363,
-44, -113, 130,
-47, -90, 206,
47, -90, 206,
44, -113, 130,
44, -104, 115,
46, -85, 197,
-46, -85, 197,
-44, -104, 115,
11, -87, 212,
-11, -87, 212,
-11, -84, 207,
11, -84, 207,
41, -107, 152,
-41, -107, 152,
40, -99, 138,
-40, -99, 138,
45, -96, 188,
44, -90, 178,
-45, -96, 188,
-44, -90, 178,
-81, -96, 182,
-57, -90, 204,
-49, -97, 176,
-51, -101, 163,
-51, -97, 156,
-49, -94, 171,
-57, -87, 199,
-81, -92, 174,
81, -96, 182,
57, -90, 204,
49, -97, 176,
51, -101, 163,
51, -97, 156,
49, -94, 171,
57, -87, 199,
81, -92, 174,
-30, -113, 122,
30, -113, 122,
29, -113, 108,
-30, -113, 108,
-5, -118, 114,
5, -118, 114,
6, -120, 113,
-5, -120, 113,
-53, -126, 80,
-46, -117, 112,
0, -116, 116,
0, -126, 80,
0, -134, 71,
-1, -123, 108,
-45, -124, 104,
-53, -134, 71,
53, -126, 80,
46, -117, 112,
0, -115, 113,
0, -126, 80,
0, -134, 71,
1, -123, 108,
45, -124, 104,
53, -134, 71,
55, -97, 159,
55, -100, 164,
78, -96, 179,
78, -93, 173,
-55, -100, 164,
-55, -97, 159,
-78, -93, 173,
-78, -96, 179,
-110, -107, 132,
-94, -109, 122,
-94, -107, 119,
-110, -105, 129,
-127, -112, 111,
-116, -110, 123,
-103, -111, 115,
-113, -114, 102,
-113, -111, 97,
-103, -109, 110,
-116, -107, 118,
-127, -109, 105,
-124, -113, 99,
-11, -132, 73,
-41, -132, 73,
-41, -128, 78,
-11, -128, 78,
11, -128, 78,
41, -128, 78,
41, -132, 73,
11, -132, 73,
38, -138, 47,
38, -129, 72,
13, -129, 72,
13, -138, 47,
13, -138, 41,
13, -133, 68,
38, -133, 68,
38, -138, 41,
13, -135, 55,
38, -135, 55,
38, -136, 49,
13, -136, 49,
-38, -138, 47,
-38, -129, 72,
-13, -129, 72,
-13, -138, 47,
-13, -138, 41,
-13, -133, 68,
-38, -133, 68,
-38, -138, 41,
-13, -135, 55,
-38, -135, 55,
-38, -136, 49,
-13, -136, 49,
-65, -146, 29,
-52, -135, 60,
-18, -135, 61,
-13, -145, 31,
-5, -147, 14,
-10, -142, 30,
-41, -142, 29,
-44, -147, 13,
-39, -142, 44,
-10, -138, 47,
-5, -146, 24,
-55, -139, 45,
-59, -146, 22,
65, -146, 29,
52, -135, 60,
18, -135, 61,
13, -145, 31,
5, -147, 14,
10, -142, 30,
41, -142, 29,
44, -147, 13,
39, -142, 44,
10, -138, 47,
5, -146, 24,
55, -139, 45,
59, -146, 22,
110, -107, 132,
94, -109, 122,
94, -107, 119,
110, -105, 129,
127, -112, 111,
116, -110, 123,
103, -111, 115,
113, -114, 102,
113, -111, 97,
103, -109, 110,
116, -107, 118,
127, -109, 105,
124, -113, 99,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:3 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_3[]={
76, -57, 265,
53, -38, 244,
0, -32, 231,
-53, -38, 244,
-76, -57, 265,
-64, -66, 287,
0, -70, 295,
64, -66, 287,
-42, -67, 287,
0, -66, 292,
42, -67, 287,
57, -57, 266,
51, -42, 247,
0, -37, 234,
-51, -42, 247,
-57, -57, 266,
52, -65, 214,
36, -52, 207,
0, -47, 204,
-36, -52, 207,
-52, -65, 214,
-36, -78, 222,
36, -78, 222,
15, -68, 197,
11, -63, 194,
0, -61, 193,
-11, -63, 194,
-15, -68, 197,
-18, -73, 200,
0, -75, 201,
18, -73, 200,
57, -34, 265,
73, -53, 289,
51, -63, 310,
0, -65, 318,
-51, -63, 310,
-73, -53, 289,
-57, -34, 265,
0, -26, 252,
23, -14, 355,
23, -19, 356,
20, -17, 373,
0, -26, 372,
-20, -17, 373,
-23, -19, 356,
-23, -14, 355,
0, -14, 344,
-42, -76, 258,
42, -76, 258,
-56, -70, 258,
-65, -64, 242,
-71, -64, 242,
-64, -70, 258,
65, -64, 242,
56, -70, 258,
64, -70, 258,
71, -64, 242,
-66, -70, 223,
66, -70, 223,
54, -48, 221,
65, -60, 237,
73, -60, 237,
54, -44, 220,
-54, -44, 220,
-73, -60, 237,
-65, -60, 237,
-54, -48, 221,
57, -58, 193,
-57, -58, 193,
4, -41, 208,
47, -46, 219,
56, -43, 217,
4, -37, 206,
-47, -46, 219,
-4, -41, 208,
-4, -37, 206,
-56, -43, 217,
-28, -52, 188,
28, -52, 188,
-59, -49, 340,
0, -51, 349,
59, -49, 340,
0, -20, 358,
-6, -53, 354,
-6, -65, 328,
-50, -63, 321,
-59, -51, 346,
50, -63, 321,
6, -65, 328,
6, -53, 354,
59, -51, 346,
0, -78, 259,
9, -63, 328,
9, -53, 348,
53, -52, 342,
46, -61, 322,
-9, -53, 348,
-9, -63, 328,
-46, -61, 322,
-53, -52, 342,
-44, -100, 119,
-47, -70, 189,
47, -70, 189,
44, -100, 119,
44, -89, 99,
46, -64, 178,
-46, -64, 178,
-44, -89, 99,
11, -66, 194,
-11, -66, 194,
-11, -62, 188,
11, -62, 188,
41, -92, 140,
-41, -92, 140,
40, -82, 121,
-40, -82, 121,
45, -77, 173,
44, -70, 159,
-45, -77, 173,
-44, -70, 159,
-81, -78, 166,
-57, -70, 188,
-49, -79, 161,
-51, -84, 149,
-51, -79, 139,
-49, -75, 153,
-57, -66, 180,
-81, -73, 156,
81, -78, 166,
57, -70, 188,
49, -79, 161,
51, -84, 149,
51, -79, 139,
49, -75, 153,
57, -66, 180,
81, -73, 156,
-30, -100, 111,
30, -100, 111,
29, -100, 92,
-30, -100, 92,
-5, -108, 102,
5, -108, 102,
6, -110, 100,
-5, -110, 100,
-53, -118, 78,
-46, -106, 102,
0, -105, 105,
0, -118, 78,
0, -129, 66,
-1, -114, 95,
-45, -116, 92,
-53, -129, 66,
53, -118, 78,
46, -106, 102,
0, -103, 102,
0, -118, 78,
0, -129, 66,
1, -114, 95,
45, -116, 92,
53, -129, 66,
55, -79, 142,
55, -83, 150,
78, -78, 163,
78, -74, 156,
-55, -83, 150,
-55, -79, 142,
-78, -74, 156,
-78, -78, 163,
-110, -92, 118,
-94, -95, 109,
-94, -93, 105,
-110, -90, 114,
-127, -100, 98,
-116, -96, 110,
-103, -99, 102,
-113, -102, 90,
-113, -98, 83,
-103, -95, 96,
-116, -92, 104,
-127, -96, 91,
-124, -101, 87,
-11, -126, 69,
-41, -126, 69,
-41, -120, 75,
-11, -120, 75,
11, -120, 75,
41, -120, 75,
41, -126, 69,
11, -126, 69,
38, -133, 49,
38, -122, 71,
13, -122, 71,
13, -133, 49,
13, -134, 40,
13, -128, 65,
38, -128, 65,
38, -134, 40,
13, -130, 55,
38, -130, 55,
38, -131, 47,
13, -131, 47,
-38, -133, 49,
-38, -122, 71,
-13, -122, 71,
-13, -133, 49,
-13, -134, 40,
-13, -128, 65,
-38, -128, 65,
-38, -134, 40,
-13, -130, 55,
-38, -130, 55,
-38, -131, 47,
-13, -131, 47,
-65, -144, 36,
-52, -131, 64,
-18, -130, 65,
-13, -144, 39,
-5, -146, 17,
-10, -139, 31,
-41, -139, 29,
-44, -146, 15,
-39, -139, 52,
-10, -134, 50,
-5, -145, 30,
-55, -135, 47,
-59, -145, 27,
65, -144, 36,
52, -131, 64,
18, -130, 65,
13, -144, 39,
5, -146, 17,
10, -139, 31,
41, -139, 29,
44, -146, 15,
39, -139, 52,
10, -134, 50,
5, -145, 30,
55, -135, 47,
59, -145, 27,
110, -92, 118,
94, -95, 109,
94, -93, 105,
110, -90, 114,
127, -100, 98,
116, -96, 110,
103, -99, 102,
113, -102, 90,
113, -98, 83,
103, -95, 96,
116, -92, 104,
127, -96, 91,
124, -101, 87,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:4 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_4[]={
76, -33, 245,
53, -11, 222,
0, -2, 207,
-53, -11, 222,
-76, -33, 245,
-64, -45, 268,
0, -51, 276,
64, -45, 268,
-42, -46, 268,
0, -45, 273,
42, -46, 268,
57, -33, 245,
51, -15, 224,
0, -9, 211,
-51, -15, 224,
-57, -33, 245,
52, -44, 195,
36, -27, 186,
0, -21, 182,
-36, -27, 186,
-52, -44, 195,
-36, -60, 204,
36, -60, 204,
15, -47, 179,
11, -41, 175,
0, -38, 174,
-11, -41, 175,
-15, -47, 179,
-18, -53, 182,
0, -56, 184,
18, -53, 182,
57, -5, 242,
73, -28, 268,
51, -41, 290,
0, -44, 299,
-51, -41, 290,
-73, -28, 268,
-57, -5, 242,
0, 3, 228,
23, 19, 329,
23, 12, 330,
20, 15, 348,
0, 4, 347,
-20, 15, 348,
-23, 12, 330,
-23, 19, 329,
0, 19, 318,
-42, -57, 240,
42, -57, 240,
-56, -50, 240,
-65, -42, 223,
-71, -42, 222,
-64, -50, 240,
65, -42, 223,
56, -50, 240,
64, -50, 240,
71, -42, 222,
-66, -50, 204,
66, -50, 204,
54, -22, 200,
65, -37, 217,
73, -37, 217,
54, -18, 198,
-54, -18, 198,
-73, -37, 217,
-65, -37, 217,
-54, -22, 200,
57, -36, 174,
-57, -36, 174,
4, -14, 186,
47, -20, 197,
56, -16, 195,
4, -9, 183,
-47, -20, 197,
-4, -14, 186,
-4, -9, 183,
-56, -16, 195,
-28, -27, 167,
28, -27, 167,
-59, -24, 319,
0, -26, 328,
59, -24, 319,
0, 12, 333,
-6, -28, 333,
-6, -43, 309,
-50, -41, 302,
-59, -27, 325,
50, -41, 302,
6, -43, 309,
6, -28, 333,
59, -27, 325,
0, -59, 241,
9, -41, 309,
9, -29, 328,
53, -28, 322,
46, -39, 302,
-9, -29, 328,
-9, -41, 309,
-46, -39, 302,
-53, -28, 322,
-44, -88, 108,
-47, -50, 172,
47, -50, 172,
44, -88, 108,
44, -73, 83,
46, -42, 158,
-46, -42, 158,
-44, -73, 83,
11, -45, 176,
-11, -45, 176,
-11, -40, 168,
11, -40, 168,
41, -78, 128,
-41, -78, 128,
40, -64, 104,
-40, -64, 104,
45, -59, 157,
44, -49, 140,
-45, -59, 157,
-44, -49, 140,
-81, -61, 151,
-57, -50, 171,
-49, -61, 146,
-51, -68, 135,
-51, -61, 122,
-49, -56, 136,
-57, -45, 161,
-81, -53, 139,
81, -61, 151,
57, -50, 171,
49, -61, 146,
51, -68, 135,
51, -61, 122,
49, -56, 136,
57, -45, 161,
81, -53, 139,
-30, -88, 100,
30, -88, 100,
29, -88, 75,
-30, -88, 75,
-5, -97, 91,
5, -97, 91,
6, -100, 88,
-5, -100, 88,
-53, -110, 76,
-46, -95, 92,
0, -93, 94,
0, -110, 76,
0, -123, 61,
-1, -105, 81,
-45, -107, 79,
-53, -123, 61,
53, -110, 76,
46, -95, 92,
0, -91, 91,
0, -110, 76,
0, -123, 61,
1, -105, 81,
45, -107, 79,
53, -123, 61,
55, -61, 125,
55, -66, 135,
78, -61, 148,
78, -55, 138,
-55, -66, 135,
-55, -61, 125,
-78, -55, 138,
-78, -61, 148,
-110, -78, 104,
-94, -82, 95,
-94, -79, 91,
-110, -75, 100,
-127, -87, 86,
-116, -82, 97,
-103, -86, 90,
-113, -91, 78,
-113, -85, 69,
-103, -81, 82,
-116, -78, 89,
-127, -82, 77,
-124, -88, 74,
-11, -120, 64,
-41, -120, 64,
-41, -113, 72,
-11, -113, 72,
11, -113, 72,
41, -113, 72,
41, -120, 64,
11, -120, 64,
38, -129, 50,
38, -115, 69,
13, -115, 69,
13, -129, 50,
13, -130, 40,
13, -122, 62,
38, -122, 62,
38, -130, 40,
13, -125, 56,
38, -125, 56,
38, -126, 46,
13, -126, 46,
-38, -129, 50,
-38, -115, 69,
-13, -115, 69,
-13, -129, 50,
-13, -130, 40,
-13, -122, 62,
-38, -122, 62,
-38, -130, 40,
-13, -125, 56,
-38, -125, 56,
-38, -126, 46,
-13, -126, 46,
-65, -142, 44,
-52, -126, 67,
-18, -125, 70,
-13, -142, 47,
-5, -145, 20,
-10, -136, 31,
-41, -136, 29,
-44, -145, 17,
-39, -137, 61,
-10, -131, 53,
-5, -143, 36,
-55, -131, 50,
-59, -144, 32,
65, -142, 44,
52, -126, 67,
18, -125, 70,
13, -142, 47,
5, -145, 20,
10, -136, 31,
41, -136, 29,
44, -145, 17,
39, -137, 61,
10, -131, 53,
5, -143, 36,
55, -131, 50,
59, -144, 32,
110, -78, 104,
94, -82, 95,
94, -79, 91,
110, -75, 100,
127, -87, 86,
116, -82, 97,
103, -86, 90,
113, -91, 78,
113, -85, 69,
103, -81, 82,
116, -78, 89,
127, -82, 77,
124, -88, 74,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:5 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_5[]={
76, -10, 225,
53, 16, 199,
0, 26, 184,
-53, 16, 199,
-76, -10, 225,
-64, -24, 249,
0, -31, 258,
64, -24, 249,
-42, -25, 249,
0, -24, 254,
42, -25, 249,
57, -10, 225,
51, 11, 202,
0, 19, 188,
-51, 11, 202,
-57, -10, 225,
52, -22, 176,
36, -3, 165,
0, 4, 161,
-36, -3, 165,
-52, -22, 176,
-36, -42, 187,
36, -42, 187,
15, -26, 160,
11, -19, 156,
0, -16, 154,
-11, -19, 156,
-15, -26, 160,
-18, -34, 164,
0, -37, 166,
18, -34, 164,
57, 23, 218,
73, -4, 247,
51, -19, 271,
0, -23, 280,
-51, -19, 271,
-73, -4, 247,
-57, 23, 218,
0, 34, 204,
23, 53, 302,
23, 45, 305,
20, 48, 322,
0, 36, 323,
-20, 48, 322,
-23, 45, 305,
-23, 53, 302,
0, 53, 292,
-42, -39, 223,
42, -39, 223,
-56, -30, 222,
-65, -21, 203,
-71, -21, 203,
-64, -29, 222,
65, -21, 203,
56, -30, 222,
64, -29, 222,
71, -21, 203,
-66, -30, 186,
66, -30, 186,
54, 3, 178,
65, -14, 198,
73, -14, 198,
54, 7, 176,
-54, 7, 176,
-73, -14, 198,
-65, -14, 198,
-54, 3, 178,
57, -13, 154,
-57, -13, 154,
4, 12, 163,
47, 6, 175,
56, 10, 173,
4, 19, 160,
-47, 6, 175,
-4, 12, 163,
-4, 19, 160,
-56, 10, 173,
-28, -3, 146,
28, -3, 146,
-59, 0, 297,
0, -1, 307,
59, 0, 297,
0, 44, 307,
-6, -4, 312,
-6, -22, 290,
-50, -19, 282,
-59, -2, 304,
50, -19, 282,
6, -22, 290,
6, -4, 312,
59, -2, 304,
0, -41, 224,
9, -20, 289,
9, -5, 307,
53, -3, 301,
46, -17, 283,
-9, -5, 307,
-9, -20, 289,
-46, -17, 283,
-53, -3, 301,
-44, -75, 97,
-47, -30, 155,
47, -30, 155,
44, -75, 97,
44, -58, 67,
46, -20, 139,
-46, -20, 139,
-44, -58, 67,
11, -24, 159,
-11, -24, 159,
-11, -18, 149,
11, -18, 149,
41, -63, 115,
-41, -63, 115,
40, -47, 88,
-40, -47, 88,
45, -41, 142,
44, -29, 122,
-45, -41, 142,
-44, -29, 122,
-81, -43, 136,
-57, -30, 154,
-49, -44, 131,
-51, -51, 120,
-51, -43, 105,
-49, -37, 119,
-57, -23, 143,
-81, -34, 121,
81, -43, 136,
57, -30, 154,
49, -44, 131,
51, -51, 120,
51, -43, 105,
49, -37, 119,
57, -23, 143,
81, -34, 121,
-30, -75, 89,
30, -75, 89,
29, -75, 59,
-30, -75, 59,
-5, -86, 79,
5, -86, 79,
6, -90, 75,
-5, -90, 75,
-53, -101, 73,
-46, -84, 83,
0, -82, 84,
0, -101, 73,
0, -118, 56,
-1, -96, 68,
-45, -99, 67,
-53, -118, 56,
53, -101, 73,
46, -84, 83,
0, -80, 79,
0, -101, 73,
0, -118, 56,
1, -96, 68,
45, -99, 67,
53, -118, 56,
55, -43, 109,
55, -50, 120,
78, -43, 133,
78, -36, 121,
-55, -50, 120,
-55, -43, 109,
-78, -36, 121,
-78, -43, 133,
-110, -63, 91,
-94, -68, 82,
-94, -65, 77,
-110, -60, 85,
-127, -74, 74,
-116, -69, 84,
-103, -73, 78,
-113, -79, 67,
-113, -72, 56,
-103, -67, 68,
-116, -63, 75,
-127, -68, 63,
-124, -76, 62,
-11, -114, 60,
-41, -114, 60,
-41, -105, 70,
-11, -105, 70,
11, -105, 70,
41, -105, 70,
41, -114, 60,
11, -114, 60,
38, -125, 52,
38, -108, 68,
13, -108, 68,
13, -125, 52,
13, -126, 39,
13, -117, 59,
38, -117, 59,
38, -126, 39,
13, -120, 57,
38, -120, 57,
38, -121, 44,
13, -121, 44,
-38, -125, 52,
-38, -108, 68,
-13, -108, 68,
-13, -125, 52,
-13, -126, 39,
-13, -117, 59,
-38, -117, 59,
-38, -126, 39,
-13, -120, 57,
-38, -120, 57,
-38, -121, 44,
-13, -121, 44,
-65, -141, 51,
-52, -121, 71,
-18, -120, 74,
-13, -141, 55,
-5, -143, 23,
-10, -133, 32,
-41, -133, 30,
-44, -144, 19,
-39, -134, 69,
-10, -127, 56,
-5, -142, 42,
-55, -127, 52,
-59, -142, 37,
65, -141, 51,
52, -121, 71,
18, -120, 74,
13, -141, 55,
5, -143, 23,
10, -133, 32,
41, -133, 30,
44, -144, 19,
39, -134, 69,
10, -127, 56,
5, -142, 42,
55, -127, 52,
59, -142, 37,
110, -63, 91,
94, -68, 82,
94, -65, 77,
110, -60, 85,
127, -74, 74,
116, -69, 84,
103, -73, 78,
113, -79, 67,
113, -72, 56,
103, -67, 68,
116, -63, 75,
127, -68, 63,
124, -76, 62,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:6 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_6[]={
76, 12, 207,
53, 44, 179,
0, 57, 162,
-53, 44, 179,
-76, 12, 207,
-64, -5, 232,
0, -13, 241,
64, -5, 232,
-42, -5, 232,
0, -4, 237,
42, -5, 232,
57, 11, 207,
51, 38, 182,
0, 47, 167,
-51, 38, 182,
-57, 11, 207,
52, -1, 158,
36, 21, 146,
0, 31, 141,
-36, 21, 146,
-52, -1, 158,
-36, -25, 171,
36, -25, 171,
15, -6, 142,
11, 2, 138,
0, 6, 136,
-11, 2, 138,
-15, -6, 142,
-18, -15, 147,
0, -19, 149,
18, -15, 147,
57, 52, 198,
73, 18, 229,
51, 0, 253,
0, -3, 263,
-51, 0, 253,
-73, 18, 229,
-57, 52, 198,
0, 66, 182,
23, 86, 280,
23, 77, 283,
20, 80, 300,
0, 65, 302,
-20, 80, 300,
-23, 77, 283,
-23, 86, 280,
0, 87, 269,
-42, -21, 206,
42, -21, 206,
-56, -11, 205,
-65, 0, 185,
-71, 0, 185,
-64, -11, 204,
65, 0, 185,
56, -11, 205,
64, -11, 204,
71, 0, 185,
-66, -11, 169,
66, -11, 169,
54, 29, 159,
65, 7, 179,
73, 7, 179,
54, 34, 156,
-54, 34, 156,
-73, 7, 179,
-65, 7, 179,
-54, 29, 159,
57, 10, 135,
-57, 10, 135,
4, 40, 143,
47, 32, 155,
56, 38, 152,
4, 48, 139,
-47, 32, 155,
-4, 40, 143,
-4, 48, 139,
-56, 38, 152,
-28, 21, 127,
28, 21, 127,
-59, 24, 278,
0, 21, 288,
59, 24, 278,
0, 76, 286,
-6, 17, 294,
-6, -3, 273,
-50, 0, 265,
-59, 20, 286,
50, 0, 265,
6, -3, 273,
6, 17, 294,
59, 20, 286,
0, -25, 208,
9, 0, 272,
9, 16, 289,
53, 18, 282,
46, 2, 265,
-9, 16, 289,
-9, 0, 272,
-46, 2, 265,
-53, 18, 282,
-44, -63, 86,
-47, -10, 139,
47, -10, 139,
44, -63, 86,
44, -42, 52,
46, 1, 120,
-46, 1, 120,
-44, -42, 52,
11, -3, 142,
-11, -3, 142,
-11, 3, 131,
11, 3, 131,
41, -49, 103,
-41, -49, 103,
40, -30, 71,
-40, -30, 71,
45, -23, 127,
44, -9, 104,
-45, -23, 127,
-44, -9, 104,
-81, -25, 121,
-57, -10, 138,
-49, -26, 116,
-51, -35, 107,
-51, -25, 89,
-49, -18, 102,
-57, -2, 125,
-81, -14, 104,
81, -25, 121,
57, -10, 138,
49, -26, 116,
51, -35, 107,
51, -25, 89,
49, -18, 102,
57, -2, 125,
81, -14, 104,
-30, -63, 78,
30, -63, 78,
29, -63, 43,
-30, -63, 43,
-5, -76, 67,
5, -76, 67,
6, -80, 63,
-5, -80, 63,
-53, -93, 72,
-46, -73, 73,
0, -70, 73,
0, -93, 72,
0, -113, 52,
-1, -88, 55,
-45, -90, 55,
-53, -113, 52,
53, -93, 72,
46, -73, 73,
0, -68, 68,
0, -93, 72,
0, -113, 52,
1, -88, 55,
45, -90, 55,
53, -113, 52,
55, -25, 93,
55, -33, 106,
78, -25, 118,
78, -17, 104,
-55, -33, 106,
-55, -25, 93,
-78, -17, 104,
-78, -25, 118,
-110, -48, 78,
-94, -54, 69,
-94, -50, 63,
-110, -44, 71,
-127, -62, 62,
-116, -55, 72,
-103, -60, 65,
-113, -66, 55,
-113, -59, 42,
-103, -53, 55,
-116, -49, 61,
-127, -54, 49,
-124, -64, 49,
-11, -108, 56,
-41, -108, 56,
-41, -97, 68,
-11, -97, 68,
11, -97, 68,
41, -97, 68,
41, -108, 56,
11, -108, 56,
38, -120, 55,
38, -101, 67,
13, -101, 67,
13, -120, 55,
13, -122, 40,
13, -111, 57,
38, -111, 57,
38, -122, 40,
13, -114, 58,
38, -114, 58,
38, -116, 44,
13, -116, 44,
-38, -120, 55,
-38, -101, 67,
-13, -101, 67,
-13, -120, 55,
-13, -122, 40,
-13, -111, 57,
-38, -111, 57,
-38, -122, 40,
-13, -114, 58,
-38, -114, 58,
-38, -116, 44,
-13, -116, 44,
-65, -139, 60,
-52, -115, 76,
-18, -115, 79,
-13, -138, 65,
-5, -142, 27,
-10, -130, 34,
-41, -130, 31,
-44, -142, 23,
-39, -131, 78,
-10, -122, 60,
-5, -140, 49,
-55, -123, 55,
-59, -140, 43,
65, -139, 60,
52, -115, 76,
18, -115, 79,
13, -138, 65,
5, -142, 27,
10, -130, 34,
41, -130, 31,
44, -142, 23,
39, -131, 78,
10, -122, 60,
5, -140, 49,
55, -123, 55,
59, -140, 43,
110, -48, 78,
94, -54, 69,
94, -50, 63,
110, -44, 71,
127, -62, 62,
116, -55, 72,
103, -60, 65,
113, -66, 55,
113, -59, 42,
103, -53, 55,
116, -49, 61,
127, -54, 49,
124, -64, 49,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:7 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_7[]={
76, 34, 188,
53, 73, 158,
0, 87, 141,
-53, 73, 158,
-76, 34, 188,
-64, 14, 214,
0, 5, 224,
64, 14, 214,
-42, 13, 215,
0, 14, 219,
42, 13, 215,
57, 34, 188,
51, 65, 162,
0, 76, 147,
-51, 65, 162,
-57, 34, 188,
52, 18, 140,
36, 46, 127,
0, 57, 121,
-36, 46, 127,
-52, 18, 140,
-36, -8, 154,
36, -8, 154,
15, 13, 125,
11, 24, 119,
0, 28, 117,
-11, 24, 119,
-15, 13, 125,
-18, 3, 130,
0, 0, 132,
18, 3, 130,
57, 81, 177,
73, 41, 210,
51, 20, 236,
0, 15, 245,
-51, 20, 236,
-73, 41, 210,
-57, 81, 177,
0, 97, 160,
23, 120, 258,
23, 109, 261,
20, 112, 278,
0, 95, 281,
-20, 112, 278,
-23, 109, 261,
-23, 120, 258,
0, 120, 247,
-42, -4, 189,
42, -4, 189,
-56, 7, 187,
-65, 20, 168,
-71, 20, 167,
-64, 7, 187,
65, 20, 168,
56, 7, 187,
64, 7, 187,
71, 20, 167,
-66, 8, 151,
66, 8, 151,
54, 54, 139,
65, 29, 161,
73, 29, 161,
54, 61, 136,
-54, 61, 136,
-73, 29, 161,
-65, 29, 161,
-54, 54, 139,
57, 33, 116,
-57, 33, 116,
4, 68, 123,
47, 58, 135,
56, 65, 132,
4, 77, 118,
-47, 58, 135,
-4, 68, 123,
-4, 77, 118,
-56, 65, 132,
-28, 46, 108,
28, 46, 108,
-59, 47, 260,
0, 43, 269,
59, 47, 260,
0, 108, 264,
-6, 39, 275,
-6, 15, 255,
-50, 20, 247,
-59, 42, 267,
50, 20, 247,
6, 15, 255,
6, 39, 275,
59, 42, 267,
0, -8, 191,
9, 19, 254,
9, 38, 270,
53, 41, 264,
46, 22, 247,
-9, 38, 270,
-9, 19, 254,
-46, 22, 247,
-53, 41, 264,
-44, -50, 76,
-47, 9, 123,
47, 9, 123,
44, -50, 76,
44, -26, 36,
46, 22, 102,
-46, 22, 102,
-44, -26, 36,
11, 17, 125,
-11, 17, 125,
-11, 25, 112,
11, 25, 112,
41, -34, 91,
-41, -34, 91,
40, -12, 55,
-40, -12, 55,
45, -5, 113,
44, 11, 86,
-45, -5, 113,
-44, 11, 86,
-81, -7, 107,
-57, 9, 123,
-49, -8, 101,
-51, -19, 93,
-51, -7, 73,
-49, 0, 86,
-57, 18, 107,
-81, 4, 87,
81, -7, 107,
57, 9, 123,
49, -8, 101,
51, -19, 93,
51, -7, 73,
49, 0, 86,
57, 18, 107,
81, 4, 87,
-30, -51, 66,
30, -51, 66,
29, -51, 27,
-30, -51, 27,
-5, -65, 56,
5, -65, 56,
6, -70, 51,
-5, -70, 51,
-53, -85, 70,
-46, -62, 63,
0, -59, 63,
0, -85, 70,
0, -107, 48,
-1, -80, 43,
-45, -82, 43,
-53, -107, 48,
53, -85, 70,
46, -62, 63,
0, -56, 57,
0, -85, 70,
0, -107, 48,
1, -80, 43,
45, -82, 43,
53, -107, 48,
55, -7, 77,
55, -16, 92,
78, -7, 103,
78, 2, 88,
-55, -16, 92,
-55, -7, 77,
-78, 2, 88,
-78, -7, 103,
-110, -34, 64,
-94, -40, 57,
-94, -36, 49,
-110, -29, 57,
-127, -49, 50,
-116, -41, 59,
-103, -46, 53,
-113, -54, 43,
-113, -46, 29,
-103, -39, 41,
-116, -34, 47,
-127, -40, 35,
-124, -51, 37,
-11, -103, 53,
-41, -103, 53,
-41, -90, 66,
-11, -90, 66,
11, -90, 66,
41, -90, 66,
41, -103, 53,
11, -103, 53,
38, -116, 57,
38, -94, 67,
13, -94, 67,
13, -116, 57,
13, -118, 41,
13, -105, 55,
38, -105, 55,
38, -118, 41,
13, -109, 60,
38, -109, 60,
38, -111, 43,
13, -111, 43,
-38, -116, 57,
-38, -94, 67,
-13, -94, 67,
-13, -116, 57,
-13, -118, 41,
-13, -105, 55,
-38, -105, 55,
-38, -118, 41,
-13, -109, 60,
-38, -109, 60,
-38, -111, 43,
-13, -111, 43,
-65, -137, 68,
-52, -110, 81,
-18, -110, 85,
-13, -136, 74,
-5, -141, 30,
-10, -127, 36,
-41, -127, 32,
-44, -141, 26,
-39, -127, 88,
-10, -118, 64,
-5, -138, 56,
-55, -119, 59,
-59, -139, 50,
65, -137, 68,
52, -110, 81,
18, -110, 85,
13, -136, 74,
5, -141, 30,
10, -127, 36,
41, -127, 32,
44, -141, 26,
39, -127, 88,
10, -118, 64,
5, -138, 56,
55, -119, 59,
59, -139, 50,
110, -34, 64,
94, -40, 57,
94, -36, 49,
110, -29, 57,
127, -49, 50,
116, -41, 59,
103, -46, 53,
113, -54, 43,
113, -46, 29,
103, -39, 41,
116, -34, 47,
127, -40, 35,
124, -51, 37,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:8 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_8[]={
76, 57, 170,
53, 101, 138,
0, 117, 120,
-53, 101, 138,
-76, 57, 170,
-64, 33, 197,
0, 23, 207,
64, 33, 197,
-42, 32, 197,
0, 34, 202,
42, 32, 197,
57, 56, 170,
51, 92, 142,
0, 105, 126,
-51, 92, 142,
-57, 56, 170,
52, 39, 122,
36, 70, 107,
0, 83, 101,
-36, 70, 107,
-52, 39, 122,
-36, 8, 138,
36, 8, 138,
15, 34, 107,
11, 46, 101,
0, 51, 99,
-11, 46, 101,
-15, 34, 107,
-18, 22, 113,
0, 17, 115,
18, 22, 113,
57, 110, 156,
73, 65, 191,
51, 40, 218,
0, 34, 228,
-51, 40, 218,
-73, 65, 191,
-57, 110, 156,
0, 129, 139,
23, 153, 235,
23, 141, 240,
20, 144, 256,
0, 125, 259,
-20, 144, 256,
-23, 141, 240,
-23, 153, 235,
0, 154, 225,
-42, 12, 173,
42, 12, 173,
-56, 25, 170,
-65, 41, 150,
-71, 41, 150,
-64, 26, 170,
65, 41, 150,
56, 25, 170,
64, 26, 170,
71, 41, 150,
-66, 27, 134,
66, 27, 134,
54, 80, 119,
65, 51, 143,
73, 51, 142,
54, 88, 116,
-54, 88, 116,
-73, 51, 142,
-65, 51, 143,
-54, 80, 119,
57, 56, 98,
-57, 56, 98,
4, 96, 102,
47, 85, 116,
56, 92, 112,
4, 106, 97,
-47, 85, 116,
-4, 96, 102,
-4, 106, 97,
-56, 92, 112,
-28, 71, 88,
28, 71, 88,
-59, 70, 241,
0, 66, 251,
59, 70, 241,
0, 139, 242,
-6, 62, 257,
-6, 35, 238,
-50, 40, 230,
-59, 65, 249,
50, 40, 230,
6, 35, 238,
6, 62, 257,
59, 65, 249,
0, 7, 175,
9, 38, 237,
9, 60, 252,
53, 63, 245,
46, 43, 229,
-9, 60, 252,
-9, 38, 237,
-46, 43, 229,
-53, 63, 245,
-44, -38, 65,
-47, 29, 108,
47, 29, 108,
44, -38, 65,
44, -10, 21,
46, 44, 83,
-46, 44, 83,
-44, -10, 21,
11, 38, 108,
-11, 38, 108,
-11, 47, 94,
11, 47, 94,
41, -20, 79,
-41, -20, 79,
40, 4, 38,
-40, 4, 38,
45, 13, 98,
44, 31, 68,
-45, 13, 98,
-44, 31, 68,
-81, 10, 92,
-57, 29, 107,
-49, 8, 86,
-51, -2, 79,
-51, 10, 57,
-49, 19, 69,
-57, 39, 89,
-81, 24, 70,
81, 10, 92,
57, 29, 107,
49, 8, 86,
51, -2, 79,
51, 10, 57,
49, 19, 69,
57, 39, 89,
81, 24, 70,
-30, -38, 55,
30, -38, 55,
29, -38, 11,
-30, -38, 11,
-5, -55, 44,
5, -55, 44,
6, -60, 38,
-5, -60, 38,
-53, -76, 69,
-46, -51, 54,
0, -48, 52,
0, -76, 69,
0, -102, 44,
-1, -71, 30,
-45, -74, 31,
-53, -102, 44,
53, -76, 69,
46, -51, 54,
0, -44, 45,
0, -76, 69,
0, -102, 44,
1, -71, 30,
45, -74, 31,
53, -102, 44,
55, 10, 61,
55, 0, 78,
78, 10, 88,
78, 21, 71,
-55, 0, 78,
-55, 10, 61,
-78, 21, 71,
-78, 10, 88,
-110, -19, 51,
-94, -26, 44,
-94, -21, 35,
-110, -14, 42,
-127, -36, 37,
-116, -28, 46,
-103, -33, 41,
-113, -42, 31,
-113, -32, 15,
-103, -25, 27,
-116, -19, 33,
-127, -26, 21,
-124, -38, 24,
-11, -97, 49,
-41, -97, 49,
-41, -82, 64,
-11, -82, 64,
11, -82, 64,
41, -82, 64,
41, -97, 49,
11, -97, 49,
38, -112, 60,
38, -86, 66,
13, -86, 66,
13, -112, 60,
13, -113, 41,
13, -100, 53,
38, -100, 53,
38, -113, 41,
13, -104, 62,
38, -104, 62,
38, -106, 43,
13, -106, 43,
-38, -112, 60,
-38, -86, 66,
-13, -86, 66,
-13, -112, 60,
-13, -113, 41,
-13, -100, 53,
-38, -100, 53,
-38, -113, 41,
-13, -104, 62,
-38, -104, 62,
-38, -106, 43,
-13, -106, 43,
-65, -135, 77,
-52, -105, 86,
-18, -104, 90,
-13, -134, 83,
-5, -139, 34,
-10, -124, 38,
-41, -124, 34,
-44, -140, 30,
-39, -124, 97,
-10, -114, 68,
-5, -136, 63,
-55, -114, 62,
-59, -137, 56,
65, -135, 77,
52, -105, 86,
18, -104, 90,
13, -134, 83,
5, -139, 34,
10, -124, 38,
41, -124, 34,
44, -140, 30,
39, -124, 97,
10, -114, 68,
5, -136, 63,
55, -114, 62,
59, -137, 56,
110, -19, 51,
94, -26, 44,
94, -21, 35,
110, -14, 42,
127, -36, 37,
116, -28, 46,
103, -33, 41,
113, -42, 31,
113, -32, 15,
103, -25, 27,
116, -19, 33,
127, -26, 21,
124, -38, 24,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:9 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_9[]={
76, 79, 151,
53, 129, 117,
0, 147, 99,
-53, 129, 117,
-76, 79, 151,
-64, 52, 179,
0, 41, 190,
64, 52, 179,
-42, 51, 180,
0, 53, 184,
42, 51, 180,
57, 79, 151,
51, 119, 122,
0, 133, 105,
-51, 119, 122,
-57, 79, 151,
52, 60, 104,
36, 95, 88,
0, 110, 81,
-36, 95, 88,
-52, 60, 104,
-36, 25, 121,
36, 25, 121,
15, 54, 89,
11, 67, 83,
0, 73, 80,
-11, 67, 83,
-15, 54, 89,
-18, 41, 95,
0, 35, 98,
18, 41, 95,
57, 139, 135,
73, 88, 172,
51, 60, 200,
0, 53, 211,
-51, 60, 200,
-73, 88, 172,
-57, 139, 135,
0, 160, 117,
23, 186, 213,
23, 172, 218,
20, 176, 234,
0, 154, 238,
-20, 176, 234,
-23, 172, 218,
-23, 186, 213,
0, 187, 202,
-42, 29, 156,
42, 29, 156,
-56, 44, 153,
-65, 61, 132,
-71, 62, 132,
-64, 45, 153,
65, 61, 132,
56, 44, 153,
64, 45, 153,
71, 62, 132,
-66, 46, 117,
66, 46, 117,
54, 106, 100,
65, 73, 124,
73, 73, 124,
54, 114, 96,
-54, 114, 96,
-73, 73, 124,
-65, 73, 124,
-54, 106, 100,
57, 79, 79,
-57, 79, 79,
4, 123, 82,
47, 111, 96,
56, 119, 92,
4, 135, 77,
-47, 111, 96,
-4, 123, 82,
-4, 135, 77,
-56, 119, 92,
-28, 96, 69,
28, 96, 69,
-59, 94, 222,
0, 89, 232,
59, 94, 222,
0, 171, 220,
-6, 84, 238,
-6, 54, 221,
-50, 59, 212,
-59, 88, 230,
50, 59, 212,
6, 54, 221,
6, 84, 238,
59, 88, 230,
0, 24, 158,
9, 58, 219,
9, 82, 233,
53, 86, 227,
46, 63, 212,
-9, 82, 233,
-9, 58, 219,
-46, 63, 212,
-53, 86, 227,
-44, -25, 54,
-47, 49, 92,
47, 49, 92,
44, -25, 54,
44, 4, 5,
46, 66, 65,
-46, 66, 65,
-44, 4, 5,
11, 59, 91,
-11, 59, 91,
-11, 69, 76,
11, 69, 76,
41, -6, 67,
-41, -6, 67,
40, 22, 22,
-40, 22, 22,
45, 31, 84,
44, 51, 50,
-45, 31, 84,
-44, 51, 50,
-81, 28, 77,
-57, 48, 91,
-49, 26, 72,
-51, 13, 65,
-51, 29, 40,
-49, 38, 53,
-57, 60, 72,
-81, 43, 53,
81, 28, 77,
57, 48, 91,
49, 26, 72,
51, 13, 65,
51, 29, 40,
49, 38, 53,
57, 60, 72,
81, 43, 53,
-30, -26, 44,
30, -26, 44,
29, -26, -4,
-30, -26, -4,
-5, -44, 32,
5, -44, 32,
6, -50, 26,
-5, -50, 26,
-53, -68, 67,
-46, -40, 44,
0, -36, 42,
0, -68, 67,
0, -97, 40,
-1, -63, 17,
-45, -66, 20,
-53, -97, 40,
53, -68, 67,
46, -40, 44,
0, -33, 34,
0, -68, 67,
0, -97, 40,
1, -63, 17,
45, -66, 20,
53, -97, 40,
55, 29, 44,
55, 17, 64,
78, 28, 73,
78, 40, 54,
-55, 17, 64,
-55, 29, 44,
-78, 40, 54,
-78, 28, 73,
-110, -4, 37,
-94, -12, 31,
-94, -6, 21,
-110, 1, 28,
-127, -23, 25,
-116, -14, 34,
-103, -20, 28,
-113, -30, 19,
-113, -19, 2,
-103, -11, 13,
-116, -4, 18,
-127, -12, 8,
-124, -26, 12,
-11, -91, 46,
-41, -91, 46,
-41, -74, 61,
-11, -74, 61,
11, -74, 61,
41, -74, 61,
41, -91, 46,
11, -91, 46,
38, -107, 62,
38, -79, 65,
13, -79, 65,
13, -107, 62,
13, -109, 42,
13, -94, 51,
38, -94, 51,
38, -109, 42,
13, -99, 63,
38, -99, 63,
38, -101, 43,
13, -101, 43,
-38, -107, 62,
-38, -79, 65,
-13, -79, 65,
-13, -107, 62,
-13, -109, 42,
-13, -94, 51,
-38, -94, 51,
-38, -109, 42,
-13, -99, 63,
-38, -99, 63,
-38, -101, 43,
-13, -101, 43,
-65, -133, 85,
-52, -99, 90,
-18, -99, 95,
-13, -132, 92,
-5, -138, 38,
-10, -121, 39,
-41, -121, 35,
-44, -139, 33,
-39, -121, 106,
-10, -109, 72,
-5, -135, 70,
-55, -110, 66,
-59, -135, 62,
65, -133, 85,
52, -99, 90,
18, -99, 95,
13, -132, 92,
5, -138, 38,
10, -121, 39,
41, -121, 35,
44, -139, 33,
39, -121, 106,
10, -109, 72,
5, -135, 70,
55, -110, 66,
59, -135, 62,
110, -4, 37,
94, -12, 31,
94, -6, 21,
110, 1, 28,
127, -23, 25,
116, -14, 34,
103, -20, 28,
113, -30, 19,
113, -19, 2,
103, -11, 13,
116, -4, 18,
127, -12, 8,
124, -26, 12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:10 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_10[]={
76, 102, 132,
53, 157, 97,
0, 177, 78,
-53, 157, 97,
-76, 102, 132,
-64, 72, 162,
0, 59, 173,
64, 72, 162,
-42, 71, 162,
0, 73, 167,
42, 71, 162,
57, 101, 133,
51, 145, 102,
0, 162, 85,
-51, 145, 102,
-57, 101, 133,
52, 81, 86,
36, 120, 69,
0, 136, 61,
-36, 120, 69,
-52, 81, 86,
-36, 42, 104,
36, 42, 104,
15, 74, 71,
11, 89, 64,
0, 95, 62,
-11, 89, 64,
-15, 74, 71,
-18, 60, 78,
0, 53, 81,
18, 60, 78,
57, 168, 114,
73, 111, 153,
51, 80, 183,
0, 72, 193,
-51, 80, 183,
-73, 111, 153,
-57, 168, 114,
0, 191, 96,
23, 220, 191,
23, 204, 196,
20, 209, 212,
0, 184, 217,
-20, 209, 212,
-23, 204, 196,
-23, 220, 191,
0, 221, 180,
-42, 46, 139,
42, 46, 139,
-56, 63, 136,
-65, 82, 114,
-71, 83, 114,
-64, 64, 135,
65, 82, 114,
56, 63, 136,
64, 64, 135,
71, 83, 114,
-66, 65, 99,
66, 65, 99,
54, 132, 80,
65, 95, 106,
73, 95, 106,
54, 141, 76,
-54, 141, 76,
-73, 95, 106,
-65, 95, 106,
-54, 132, 80,
57, 102, 60,
-57, 102, 60,
4, 151, 62,
47, 137, 76,
56, 147, 72,
4, 164, 56,
-47, 137, 76,
-4, 151, 62,
-4, 164, 56,
-56, 147, 72,
-28, 122, 49,
28, 122, 49,
-59, 117, 203,
0, 112, 213,
59, 117, 203,
0, 202, 199,
-6, 106, 220,
-6, 73, 203,
-50, 79, 194,
-59, 111, 211,
50, 79, 194,
6, 73, 203,
6, 106, 220,
59, 111, 211,
0, 41, 142,
9, 78, 202,
9, 105, 215,
53, 108, 208,
46, 83, 194,
-9, 105, 215,
-9, 78, 202,
-46, 83, 194,
-53, 108, 208,
-44, -13, 43,
-47, 69, 76,
47, 69, 76,
44, -13, 43,
44, 20, -9,
46, 88, 46,
-46, 88, 46,
-44, 20, -9,
11, 80, 74,
-11, 80, 74,
-11, 91, 57,
11, 91, 57,
41, 8, 55,
-41, 8, 55,
40, 39, 6,
-40, 39, 6,
45, 49, 69,
44, 72, 33,
-45, 49, 69,
-44, 72, 33,
-81, 46, 63,
-57, 68, 75,
-49, 44, 57,
-51, 30, 51,
-51, 47, 24,
-49, 57, 36,
-57, 82, 54,
-81, 63, 36,
81, 46, 63,
57, 68, 75,
49, 44, 57,
51, 30, 51,
51, 47, 24,
49, 57, 36,
57, 82, 54,
81, 63, 36,
-30, -13, 33,
30, -13, 33,
29, -13, -20,
-30, -13, -20,
-5, -34, 21,
5, -34, 21,
6, -41, 14,
-5, -41, 14,
-53, -59, 66,
-46, -29, 35,
0, -25, 31,
0, -59, 66,
0, -92, 36,
-1, -54, 4,
-45, -58, 8,
-53, -92, 36,
53, -59, 66,
46, -29, 35,
0, -21, 23,
0, -59, 66,
0, -92, 36,
1, -54, 4,
45, -58, 8,
53, -92, 36,
55, 47, 28,
55, 33, 49,
78, 46, 58,
78, 59, 37,
-55, 33, 49,
-55, 47, 28,
-78, 59, 37,
-78, 46, 58,
-110, 9, 24,
-94, 1, 18,
-94, 7, 7,
-110, 16, 14,
-127, -10, 13,
-116, 0, 21,
-103, -7, 16,
-113, -18, 7,
-113, -6, -11,
-103, 2, 0,
-116, 9, 4,
-127, 1, -5,
-124, -13, 0,
-11, -85, 42,
-41, -85, 42,
-41, -66, 59,
-11, -66, 59,
11, -66, 59,
41, -66, 59,
41, -85, 42,
11, -85, 42,
38, -103, 65,
38, -72, 65,
13, -72, 65,
13, -103, 65,
13, -105, 42,
13, -89, 49,
38, -89, 49,
38, -105, 42,
13, -93, 65,
38, -93, 65,
38, -96, 42,
13, -96, 42,
-38, -103, 65,
-38, -72, 65,
-13, -72, 65,
-13, -103, 65,
-13, -105, 42,
-13, -89, 49,
-38, -89, 49,
-38, -105, 42,
-13, -93, 65,
-38, -93, 65,
-38, -96, 42,
-13, -96, 42,
-65, -131, 94,
-52, -94, 95,
-18, -94, 100,
-13, -130, 101,
-5, -137, 42,
-10, -118, 41,
-41, -118, 37,
-44, -137, 36,
-39, -118, 116,
-10, -105, 76,
-5, -133, 77,
-55, -106, 69,
-59, -134, 69,
65, -131, 94,
52, -94, 95,
18, -94, 100,
13, -130, 101,
5, -137, 42,
10, -118, 41,
41, -118, 37,
44, -137, 36,
39, -118, 116,
10, -105, 76,
5, -133, 77,
55, -106, 69,
59, -134, 69,
110, 9, 24,
94, 1, 18,
94, 7, 7,
110, 16, 14,
127, -10, 13,
116, 0, 21,
103, -7, 16,
113, -18, 7,
113, -6, -11,
103, 2, 0,
116, 9, 4,
127, 1, -5,
124, -13, 0,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:11 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_11[]={
76, 124, 114,
53, 185, 76,
0, 207, 56,
-53, 185, 76,
-76, 124, 114,
-64, 91, 144,
0, 77, 156,
64, 91, 144,
-42, 90, 145,
0, 92, 149,
42, 90, 145,
57, 124, 114,
51, 172, 82,
0, 191, 64,
-51, 172, 82,
-57, 124, 114,
52, 102, 69,
36, 145, 49,
0, 162, 42,
-36, 145, 49,
-52, 102, 69,
-36, 59, 88,
36, 59, 88,
15, 95, 53,
11, 111, 46,
0, 118, 43,
-11, 111, 46,
-15, 95, 53,
-18, 78, 61,
0, 72, 64,
18, 78, 61,
57, 197, 94,
73, 134, 135,
51, 100, 165,
0, 92, 176,
-51, 100, 165,
-73, 134, 135,
-57, 197, 94,
0, 223, 74,
23, 253, 169,
23, 236, 174,
20, 241, 190,
0, 214, 196,
-20, 241, 190,
-23, 236, 174,
-23, 253, 169,
0, 254, 158,
-42, 63, 123,
42, 63, 123,
-56, 82, 119,
-65, 103, 96,
-71, 103, 96,
-64, 83, 118,
65, 103, 96,
56, 82, 119,
64, 83, 118,
71, 103, 96,
-66, 85, 82,
66, 85, 82,
54, 158, 60,
65, 117, 87,
73, 117, 87,
54, 168, 56,
-54, 168, 56,
-73, 117, 87,
-65, 117, 87,
-54, 158, 60,
57, 125, 41,
-57, 125, 41,
4, 179, 41,
47, 164, 56,
56, 174, 51,
4, 193, 35,
-47, 164, 56,
-4, 179, 41,
-4, 193, 35,
-56, 174, 51,
-28, 147, 30,
28, 147, 30,
-59, 141, 184,
0, 135, 195,
59, 141, 184,
0, 234, 177,
-6, 128, 202,
-6, 92, 186,
-50, 99, 177,
-59, 133, 193,
50, 99, 177,
6, 92, 186,
6, 128, 202,
59, 133, 193,
0, 57, 125,
9, 97, 184,
9, 127, 197,
53, 131, 190,
46, 103, 176,
-9, 127, 197,
-9, 97, 184,
-46, 103, 176,
-53, 131, 190,
-44, 0, 32,
-47, 89, 60,
47, 89, 60,
44, 0, 32,
44, 36, -25,
46, 110, 28,
-46, 110, 28,
-44, 36, -25,
11, 101, 58,
-11, 101, 58,
-11, 113, 39,
11, 113, 39,
41, 22, 43,
-41, 22, 43,
40, 57, -10,
-40, 57, -10,
45, 67, 54,
44, 92, 15,
-45, 67, 54,
-44, 92, 15,
-81, 64, 48,
-57, 88, 59,
-49, 62, 42,
-51, 46, 37,
-51, 65, 8,
-49, 76, 19,
-57, 103, 36,
-81, 82, 19,
81, 64, 48,
57, 88, 59,
49, 62, 42,
51, 46, 37,
51, 65, 8,
49, 76, 19,
57, 103, 36,
81, 82, 19,
-30, -1, 22,
30, -1, 22,
29, -1, -36,
-30, -1, -36,
-5, -23, 9,
5, -23, 9,
6, -31, 2,
-5, -31, 2,
-53, -51, 64,
-46, -18, 25,
0, -13, 21,
0, -51, 64,
0, -87, 32,
-1, -46, -8,
-45, -50, -3,
-53, -87, 32,
53, -51, 64,
46, -18, 25,
0, -9, 11,
0, -51, 64,
0, -87, 32,
1, -46, -8,
45, -50, -3,
53, -87, 32,
55, 65, 12,
55, 50, 35,
78, 64, 44,
78, 78, 21,
-55, 50, 35,
-55, 65, 12,
-78, 78, 21,
-78, 64, 44,
-110, 24, 11,
-94, 14, 5,
-94, 22, -5,
-110, 31, 0,
-127, 2, 1,
-116, 12, 8,
-103, 5, 4,
-113, -6, -3,
-113, 7, -24,
-103, 17, -14,
-116, 24, -9,
-127, 15, -19,
-124, 0, -12,
-11, -79, 39,
-41, -79, 39,
-41, -59, 57,
-11, -59, 57,
11, -59, 57,
41, -59, 57,
41, -79, 39,
11, -79, 39,
38, -98, 68,
38, -65, 64,
13, -65, 64,
13, -98, 68,
13, -101, 43,
13, -83, 47,
38, -83, 47,
38, -101, 43,
13, -88, 67,
38, -88, 67,
38, -91, 42,
13, -91, 42,
-38, -98, 68,
-38, -65, 64,
-13, -65, 64,
-13, -98, 68,
-13, -101, 43,
-13, -83, 47,
-38, -83, 47,
-38, -101, 43,
-13, -88, 67,
-38, -88, 67,
-38, -91, 42,
-13, -91, 42,
-65, -129, 102,
-52, -89, 100,
-18, -88, 105,
-13, -128, 111,
-5, -135, 46,
-10, -114, 43,
-41, -115, 38,
-44, -136, 40,
-39, -114, 125,
-10, -101, 80,
-5, -131, 84,
-55, -102, 72,
-59, -132, 75,
65, -129, 102,
52, -89, 100,
18, -88, 105,
13, -128, 111,
5, -135, 46,
10, -114, 43,
41, -115, 38,
44, -136, 40,
39, -114, 125,
10, -101, 80,
5, -131, 84,
55, -102, 72,
59, -132, 75,
110, 24, 11,
94, 14, 5,
94, 22, -5,
110, 31, 0,
127, 2, 1,
116, 12, 8,
103, 5, 4,
113, -6, -3,
113, 7, -24,
103, 17, -14,
116, 24, -9,
127, 15, -19,
124, 0, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:12 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_12[]={
78, 125, 108,
55, 184, 70,
2, 207, 52,
-50, 185, 74,
-71, 127, 114,
-59, 95, 144,
4, 80, 154,
67, 93, 139,
-37, 93, 144,
4, 95, 147,
45, 92, 141,
59, 125, 109,
53, 172, 76,
2, 190, 60,
-48, 173, 80,
-53, 126, 113,
52, 102, 65,
37, 144, 46,
0, 162, 39,
-35, 145, 49,
-50, 103, 69,
-35, 62, 89,
37, 61, 86,
15, 95, 52,
11, 111, 45,
0, 118, 42,
-11, 111, 45,
-15, 95, 52,
-18, 79, 60,
0, 73, 64,
18, 79, 60,
60, 197, 86,
76, 135, 128,
56, 102, 160,
5, 95, 172,
-46, 104, 163,
-68, 137, 133,
-53, 198, 91,
3, 222, 68,
30, 254, 159,
30, 237, 165,
28, 242, 181,
8, 216, 188,
-12, 243, 182,
-15, 238, 167,
-15, 254, 161,
7, 255, 149,
-38, 66, 123,
44, 65, 120,
-52, 84, 119,
-62, 105, 96,
-67, 106, 97,
-61, 86, 119,
66, 104, 92,
58, 83, 115,
66, 84, 114,
72, 104, 91,
-64, 87, 83,
66, 85, 78,
54, 157, 56,
66, 117, 83,
74, 117, 82,
55, 167, 51,
-52, 168, 55,
-70, 119, 88,
-62, 119, 88,
-51, 158, 60,
56, 124, 38,
-56, 126, 42,
5, 178, 38,
48, 163, 51,
57, 173, 46,
5, 192, 31,
-45, 164, 55,
-3, 178, 38,
-3, 192, 32,
-54, 174, 50,
-27, 146, 29,
28, 146, 27,
-52, 144, 181,
6, 138, 189,
65, 143, 177,
7, 236, 169,
0, 132, 197,
-1, 96, 182,
-44, 103, 175,
-51, 137, 190,
55, 102, 171,
12, 96, 182,
13, 132, 196,
64, 136, 185,
2, 60, 124,
15, 101, 180,
16, 130, 191,
59, 133, 182,
51, 106, 171,
-3, 130, 192,
-4, 101, 181,
-40, 107, 174,
-46, 135, 186,
-44, 0, 32,
-47, 89, 58,
47, 89, 58,
44, 0, 32,
44, 35, -25,
46, 110, 26,
-46, 110, 26,
-44, 35, -25,
11, 101, 56,
-11, 101, 56,
-11, 113, 37,
11, 113, 37,
41, 22, 43,
-41, 22, 43,
40, 56, -11,
-40, 56, -11,
45, 67, 53,
44, 92, 14,
-45, 67, 53,
-44, 92, 14,
-81, 64, 47,
-57, 88, 58,
-49, 62, 41,
-51, 46, 37,
-51, 65, 7,
-49, 76, 19,
-57, 103, 35,
-81, 82, 18,
81, 64, 47,
57, 88, 58,
49, 62, 41,
51, 46, 37,
51, 65, 7,
49, 76, 19,
57, 103, 35,
81, 82, 18,
-30, -1, 22,
30, -1, 22,
29, -1, -36,
-30, -1, -36,
-5, -23, 9,
5, -23, 9,
6, -30, 1,
-5, -30, 1,
-53, -51, 63,
-46, -18, 25,
0, -13, 21,
0, -51, 63,
0, -86, 30,
-1, -45, -8,
-45, -49, -4,
-53, -86, 30,
53, -51, 63,
46, -18, 25,
0, -9, 11,
0, -51, 63,
0, -86, 30,
1, -45, -8,
45, -49, -4,
53, -86, 30,
55, 64, 12,
55, 50, 35,
78, 64, 43,
78, 78, 20,
-55, 50, 35,
-55, 64, 12,
-78, 78, 20,
-78, 64, 43,
-110, 24, 10,
-94, 14, 5,
-94, 21, -6,
-110, 31, 0,
-127, 1, 1,
-116, 12, 8,
-103, 5, 4,
-113, -6, -3,
-113, 6, -25,
-103, 16, -14,
-116, 24, -9,
-127, 15, -19,
-124, -1, -12,
-11, -79, 38,
-41, -79, 38,
-41, -59, 56,
-11, -59, 56,
11, -59, 56,
41, -59, 56,
41, -79, 38,
11, -79, 38,
38, -98, 68,
38, -65, 63,
13, -65, 63,
13, -98, 68,
13, -101, 43,
13, -83, 46,
38, -83, 46,
38, -101, 43,
13, -88, 66,
38, -88, 66,
38, -91, 42,
13, -91, 42,
-38, -98, 68,
-38, -65, 63,
-13, -65, 63,
-13, -98, 68,
-13, -101, 43,
-13, -83, 46,
-38, -83, 46,
-38, -101, 43,
-13, -88, 66,
-38, -88, 66,
-38, -91, 42,
-13, -91, 42,
-65, -127, 103,
-52, -87, 99,
-18, -86, 105,
-13, -125, 111,
-5, -135, 48,
-10, -115, 44,
-41, -116, 39,
-44, -136, 42,
-39, -111, 125,
-10, -100, 80,
-5, -129, 85,
-55, -101, 73,
-59, -131, 76,
65, -127, 103,
52, -87, 99,
18, -86, 105,
13, -125, 111,
5, -135, 48,
10, -115, 44,
41, -116, 39,
44, -136, 42,
39, -111, 125,
10, -100, 80,
5, -129, 85,
55, -101, 73,
59, -131, 76,
110, 24, 10,
94, 14, 5,
94, 21, -6,
110, 31, 0,
127, 1, 1,
116, 12, 8,
103, 5, 4,
113, -6, -3,
113, 6, -25,
103, 16, -14,
116, 24, -9,
127, 15, -19,
124, -1, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:13 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_13[]={
80, 125, 102,
57, 183, 64,
4, 206, 47,
-46, 186, 72,
-67, 129, 114,
-54, 98, 144,
8, 83, 151,
70, 95, 134,
-33, 96, 143,
8, 98, 144,
48, 94, 137,
61, 125, 104,
55, 172, 70,
4, 190, 56,
-44, 174, 78,
-49, 128, 112,
52, 102, 62,
37, 144, 42,
1, 161, 36,
-33, 145, 48,
-48, 105, 70,
-33, 64, 90,
37, 62, 85,
15, 96, 51,
11, 111, 43,
0, 118, 40,
-11, 111, 43,
-15, 96, 51,
-18, 80, 59,
0, 74, 64,
18, 80, 59,
63, 196, 79,
80, 136, 121,
60, 105, 154,
10, 98, 169,
-40, 107, 162,
-63, 140, 132,
-49, 199, 88,
6, 221, 63,
38, 255, 149,
37, 238, 156,
36, 244, 171,
16, 218, 180,
-3, 245, 174,
-7, 240, 159,
-8, 256, 153,
14, 256, 140,
-35, 69, 124,
46, 67, 117,
-49, 87, 119,
-58, 108, 97,
-64, 108, 97,
-57, 89, 120,
67, 104, 87,
60, 85, 111,
68, 85, 110,
73, 104, 87,
-61, 89, 85,
66, 86, 75,
55, 156, 51,
67, 117, 78,
74, 118, 78,
55, 166, 46,
-49, 169, 54,
-66, 121, 89,
-59, 121, 88,
-49, 159, 59,
56, 123, 35,
-55, 126, 43,
6, 177, 35,
49, 162, 46,
57, 172, 41,
6, 191, 28,
-43, 165, 54,
-2, 178, 35,
-2, 191, 28,
-52, 175, 49,
-27, 146, 29,
27, 145, 24,
-45, 148, 178,
13, 141, 184,
70, 145, 169,
15, 237, 160,
7, 135, 192,
4, 99, 179,
-38, 107, 173,
-44, 141, 187,
59, 104, 166,
17, 99, 178,
20, 135, 191,
70, 138, 178,
5, 62, 123,
20, 104, 176,
22, 133, 186,
64, 136, 175,
55, 109, 165,
3, 134, 187,
1, 104, 177,
-34, 111, 172,
-39, 138, 183,
-44, 0, 32,
-47, 90, 57,
47, 90, 57,
44, 0, 32,
44, 35, -26,
46, 109, 25,
-46, 109, 25,
-44, 35, -26,
11, 101, 55,
-11, 101, 55,
-11, 113, 36,
11, 113, 36,
41, 22, 43,
-41, 22, 43,
40, 56, -11,
-40, 56, -11,
45, 67, 53,
44, 91, 13,
-45, 67, 53,
-44, 91, 13,
-81, 64, 46,
-57, 89, 57,
-49, 62, 41,
-51, 46, 36,
-51, 64, 6,
-49, 76, 18,
-57, 103, 34,
-81, 82, 17,
81, 64, 46,
57, 89, 57,
49, 62, 41,
51, 46, 36,
51, 64, 6,
49, 76, 18,
57, 103, 34,
81, 82, 17,
-30, -1, 22,
30, -1, 22,
29, -1, -36,
-30, -1, -36,
-5, -23, 9,
5, -23, 9,
6, -30, 1,
-5, -30, 1,
-53, -52, 62,
-46, -18, 25,
0, -13, 20,
0, -52, 62,
0, -86, 29,
-1, -44, -9,
-45, -48, -5,
-53, -86, 29,
53, -52, 62,
46, -18, 25,
0, -9, 11,
0, -52, 62,
0, -86, 29,
1, -44, -9,
45, -48, -5,
53, -86, 29,
55, 64, 11,
55, 50, 34,
78, 64, 42,
78, 78, 19,
-55, 50, 34,
-55, 64, 11,
-78, 78, 19,
-78, 64, 42,
-110, 24, 10,
-94, 14, 5,
-94, 21, -6,
-110, 30, 0,
-127, 1, 1,
-116, 12, 8,
-103, 4, 4,
-113, -6, -3,
-113, 6, -25,
-103, 16, -14,
-116, 23, -9,
-127, 14, -20,
-124, -1, -12,
-11, -79, 36,
-41, -79, 36,
-41, -59, 55,
-11, -59, 55,
11, -59, 55,
41, -59, 55,
41, -79, 36,
11, -79, 36,
38, -97, 68,
38, -65, 61,
13, -65, 61,
13, -97, 68,
13, -102, 44,
13, -83, 44,
38, -83, 44,
38, -102, 44,
13, -88, 66,
38, -88, 66,
38, -92, 42,
13, -92, 42,
-38, -97, 68,
-38, -65, 61,
-13, -65, 61,
-13, -97, 68,
-13, -102, 44,
-13, -83, 44,
-38, -83, 44,
-38, -102, 44,
-13, -88, 66,
-38, -88, 66,
-38, -92, 42,
-13, -92, 42,
-65, -124, 104,
-52, -85, 98,
-18, -84, 104,
-13, -123, 112,
-5, -135, 50,
-10, -115, 45,
-41, -116, 40,
-44, -136, 44,
-39, -108, 125,
-10, -99, 80,
-5, -128, 86,
-55, -100, 73,
-59, -129, 78,
65, -124, 104,
52, -85, 98,
18, -84, 104,
13, -123, 112,
5, -135, 50,
10, -115, 45,
41, -116, 40,
44, -136, 44,
39, -108, 125,
10, -99, 80,
5, -128, 86,
55, -100, 73,
59, -129, 78,
110, 24, 10,
94, 14, 5,
94, 21, -6,
110, 30, 0,
127, 1, 1,
116, 12, 8,
103, 4, 4,
113, -6, -3,
113, 6, -25,
103, 16, -14,
116, 23, -9,
127, 14, -20,
124, -1, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:14 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_14[]={
82, 126, 96,
59, 182, 58,
6, 205, 43,
-43, 187, 70,
-63, 132, 113,
-49, 102, 144,
12, 86, 149,
73, 97, 129,
-28, 100, 142,
12, 100, 141,
51, 96, 132,
64, 126, 99,
57, 171, 64,
6, 189, 52,
-41, 175, 76,
-45, 131, 112,
52, 103, 59,
37, 143, 39,
2, 161, 34,
-32, 146, 47,
-46, 106, 71,
-31, 66, 91,
38, 63, 83,
15, 96, 50,
11, 111, 42,
0, 118, 38,
-11, 111, 42,
-15, 96, 50,
-18, 81, 58,
0, 75, 64,
18, 81, 58,
65, 196, 72,
83, 137, 115,
64, 107, 149,
15, 102, 166,
-34, 111, 161,
-57, 143, 131,
-44, 200, 85,
9, 221, 57,
45, 255, 139,
44, 240, 147,
44, 245, 161,
24, 221, 172,
4, 247, 166,
0, 241, 152,
0, 257, 145,
21, 257, 132,
-32, 72, 124,
47, 69, 115,
-45, 90, 120,
-55, 110, 98,
-61, 110, 98,
-53, 92, 120,
68, 105, 83,
61, 86, 107,
69, 87, 106,
74, 105, 82,
-59, 91, 87,
67, 86, 72,
56, 155, 46,
68, 118, 74,
75, 118, 73,
56, 165, 40,
-47, 169, 53,
-63, 123, 89,
-56, 123, 88,
-47, 159, 58,
55, 123, 31,
-54, 127, 44,
7, 176, 31,
50, 161, 42,
58, 170, 35,
7, 190, 24,
-41, 165, 52,
-1, 177, 32,
-1, 190, 25,
-49, 175, 48,
-26, 146, 28,
27, 144, 22,
-38, 152, 175,
20, 144, 179,
76, 147, 162,
22, 239, 152,
13, 139, 187,
10, 103, 176,
-32, 111, 171,
-36, 145, 184,
64, 107, 160,
23, 103, 174,
27, 138, 185,
76, 141, 170,
7, 65, 123,
26, 107, 172,
29, 136, 180,
70, 138, 168,
60, 111, 160,
10, 137, 182,
7, 108, 174,
-28, 115, 170,
-31, 142, 180,
-44, 0, 32,
-47, 90, 56,
47, 90, 56,
44, 0, 32,
44, 34, -26,
46, 109, 24,
-46, 109, 24,
-44, 34, -26,
11, 101, 54,
-11, 101, 54,
-11, 113, 35,
11, 113, 35,
41, 23, 43,
-41, 23, 43,
40, 55, -12,
-40, 55, -12,
45, 67, 52,
44, 91, 11,
-45, 67, 52,
-44, 91, 11,
-81, 64, 46,
-57, 89, 55,
-49, 62, 40,
-51, 46, 35,
-51, 64, 6,
-49, 75, 17,
-57, 103, 32,
-81, 82, 16,
81, 64, 46,
57, 89, 55,
49, 62, 40,
51, 46, 35,
51, 64, 6,
49, 75, 17,
57, 103, 32,
81, 82, 16,
-30, -1, 22,
30, -1, 22,
29, -1, -36,
-30, -1, -36,
-5, -22, 8,
5, -22, 8,
6, -29, 1,
-5, -29, 1,
-53, -52, 61,
-46, -17, 24,
0, -13, 20,
0, -52, 61,
0, -86, 27,
-1, -43, -10,
-45, -48, -5,
-53, -86, 27,
53, -52, 61,
46, -17, 24,
0, -9, 11,
0, -52, 61,
0, -86, 27,
1, -43, -10,
45, -48, -5,
53, -86, 27,
55, 64, 10,
55, 50, 33,
78, 64, 41,
78, 78, 18,
-55, 50, 33,
-55, 64, 10,
-78, 78, 18,
-78, 64, 41,
-110, 23, 10,
-94, 14, 4,
-94, 20, -6,
-110, 30, 0,
-127, 1, 1,
-116, 12, 8,
-103, 4, 4,
-113, -7, -3,
-113, 5, -25,
-103, 15, -14,
-116, 23, -10,
-127, 13, -20,
-124, -2, -12,
-11, -78, 35,
-41, -78, 35,
-41, -59, 54,
-11, -59, 54,
11, -59, 54,
41, -59, 54,
41, -78, 35,
11, -78, 35,
38, -97, 68,
38, -66, 60,
13, -66, 60,
13, -97, 68,
13, -103, 45,
13, -83, 43,
38, -83, 43,
38, -103, 45,
13, -87, 66,
38, -87, 66,
38, -93, 42,
13, -93, 42,
-38, -97, 68,
-38, -66, 60,
-13, -66, 60,
-13, -97, 68,
-13, -103, 45,
-13, -83, 43,
-38, -83, 43,
-38, -103, 45,
-13, -87, 66,
-38, -87, 66,
-38, -93, 42,
-13, -93, 42,
-65, -122, 105,
-52, -84, 98,
-18, -83, 103,
-13, -120, 113,
-5, -135, 52,
-10, -116, 46,
-41, -117, 42,
-44, -136, 46,
-39, -105, 125,
-10, -98, 80,
-5, -126, 87,
-55, -100, 73,
-59, -128, 79,
65, -122, 105,
52, -84, 98,
18, -83, 103,
13, -120, 113,
5, -135, 52,
10, -116, 46,
41, -117, 42,
44, -136, 46,
39, -105, 125,
10, -98, 80,
5, -126, 87,
55, -100, 73,
59, -128, 79,
110, 23, 10,
94, 14, 4,
94, 20, -6,
110, 30, 0,
127, 1, 1,
116, 12, 8,
103, 4, 4,
113, -7, -3,
113, 5, -25,
103, 15, -14,
116, 23, -10,
127, 13, -20,
124, -2, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:15 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_15[]={
84, 126, 90,
60, 182, 51,
8, 204, 38,
-39, 187, 67,
-58, 134, 113,
-44, 105, 144,
16, 89, 147,
76, 99, 124,
-23, 103, 141,
16, 103, 138,
55, 99, 128,
66, 127, 93,
59, 171, 58,
8, 189, 48,
-37, 176, 74,
-40, 133, 111,
52, 103, 56,
38, 142, 35,
3, 160, 31,
-31, 146, 46,
-45, 108, 72,
-30, 68, 93,
38, 65, 82,
15, 96, 49,
11, 111, 40,
0, 118, 37,
-11, 111, 40,
-15, 96, 49,
-18, 81, 57,
1, 76, 64,
18, 81, 57,
68, 195, 65,
86, 138, 108,
68, 109, 143,
20, 105, 162,
-29, 115, 159,
-52, 146, 130,
-40, 201, 82,
12, 220, 52,
52, 256, 130,
51, 241, 137,
52, 247, 152,
32, 223, 164,
13, 249, 158,
8, 243, 144,
7, 259, 137,
28, 258, 123,
-29, 75, 125,
49, 71, 112,
-42, 93, 120,
-52, 112, 98,
-58, 113, 99,
-50, 95, 121,
69, 105, 79,
63, 88, 103,
71, 88, 102,
75, 105, 78,
-57, 93, 88,
67, 87, 68,
57, 155, 41,
69, 118, 69,
76, 118, 68,
57, 164, 35,
-44, 169, 52,
-60, 125, 90,
-53, 125, 89,
-44, 160, 57,
55, 122, 28,
-53, 128, 45,
8, 176, 28,
50, 160, 37,
59, 169, 30,
8, 188, 20,
-39, 165, 51,
0, 176, 29,
0, 189, 22,
-47, 175, 47,
-26, 146, 27,
27, 143, 19,
-30, 155, 172,
26, 148, 173,
81, 149, 154,
30, 240, 144,
20, 142, 181,
16, 107, 172,
-25, 115, 170,
-29, 149, 181,
68, 110, 154,
28, 106, 170,
33, 142, 179,
81, 143, 163,
10, 68, 122,
31, 111, 167,
35, 140, 175,
75, 141, 161,
65, 114, 154,
17, 141, 178,
13, 112, 170,
-21, 118, 168,
-24, 146, 177,
-44, 0, 32,
-47, 90, 55,
47, 90, 55,
44, 0, 32,
44, 33, -27,
46, 109, 22,
-46, 109, 22,
-44, 33, -27,
11, 102, 53,
-11, 102, 53,
-11, 113, 33,
11, 113, 33,
41, 23, 42,
-41, 23, 42,
40, 55, -12,
-40, 55, -12,
45, 68, 51,
44, 91, 10,
-45, 68, 51,
-44, 91, 10,
-81, 64, 45,
-57, 89, 54,
-49, 62, 39,
-51, 46, 35,
-51, 63, 5,
-49, 75, 16,
-57, 102, 31,
-81, 81, 15,
81, 64, 45,
57, 89, 54,
49, 62, 39,
51, 46, 35,
51, 63, 5,
49, 75, 16,
57, 102, 31,
81, 81, 15,
-30, -1, 22,
30, -1, 22,
29, -1, -36,
-30, -1, -36,
-5, -22, 8,
5, -22, 8,
6, -29, 0,
-5, -29, 0,
-53, -53, 60,
-46, -17, 24,
0, -13, 20,
0, -53, 60,
0, -85, 26,
-1, -43, -10,
-45, -47, -6,
-53, -85, 26,
53, -53, 60,
46, -17, 24,
0, -9, 11,
0, -53, 60,
0, -85, 26,
1, -43, -10,
45, -47, -6,
53, -85, 26,
55, 64, 9,
55, 50, 33,
78, 64, 40,
78, 77, 17,
-55, 50, 33,
-55, 64, 9,
-78, 77, 17,
-78, 64, 40,
-110, 23, 10,
-94, 13, 4,
-94, 20, -6,
-110, 30, -1,
-127, 1, 1,
-116, 12, 8,
-103, 4, 4,
-113, -7, -3,
-113, 4, -25,
-103, 15, -14,
-116, 22, -10,
-127, 13, -20,
-124, -2, -12,
-11, -78, 33,
-41, -78, 33,
-41, -60, 53,
-11, -60, 53,
11, -60, 53,
41, -60, 53,
41, -78, 33,
11, -78, 33,
38, -97, 68,
38, -66, 59,
13, -66, 59,
13, -97, 68,
13, -103, 45,
13, -83, 41,
38, -83, 41,
38, -103, 45,
13, -87, 65,
38, -87, 65,
38, -94, 42,
13, -94, 42,
-38, -97, 68,
-38, -66, 59,
-13, -66, 59,
-13, -97, 68,
-13, -103, 45,
-13, -83, 41,
-38, -83, 41,
-38, -103, 45,
-13, -87, 65,
-38, -87, 65,
-38, -94, 42,
-13, -94, 42,
-65, -119, 106,
-52, -82, 97,
-18, -81, 102,
-13, -117, 113,
-5, -135, 54,
-10, -116, 48,
-41, -117, 43,
-44, -137, 48,
-39, -102, 125,
-10, -97, 80,
-5, -124, 89,
-55, -99, 73,
-59, -127, 81,
65, -119, 106,
52, -82, 97,
18, -81, 102,
13, -117, 113,
5, -135, 54,
10, -116, 48,
41, -117, 43,
44, -137, 48,
39, -102, 125,
10, -97, 80,
5, -124, 89,
55, -99, 73,
59, -127, 81,
110, 23, 10,
94, 13, 4,
94, 20, -6,
110, 30, -1,
127, 1, 1,
116, 12, 8,
103, 4, 4,
113, -7, -3,
113, 4, -25,
103, 15, -14,
116, 22, -10,
127, 13, -20,
124, -2, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:16 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_16[]={
86, 127, 85,
62, 181, 45,
10, 204, 34,
-36, 188, 65,
-54, 137, 113,
-39, 109, 143,
20, 92, 144,
79, 101, 119,
-19, 106, 140,
20, 106, 136,
58, 101, 124,
68, 128, 88,
61, 170, 52,
11, 189, 43,
-34, 177, 72,
-36, 135, 110,
53, 103, 53,
38, 142, 32,
4, 160, 29,
-29, 146, 45,
-43, 109, 73,
-28, 71, 94,
39, 66, 80,
15, 97, 48,
11, 111, 39,
0, 117, 35,
-11, 111, 39,
-15, 97, 48,
-18, 82, 57,
1, 77, 64,
18, 82, 57,
71, 195, 57,
89, 139, 101,
72, 112, 138,
26, 108, 159,
-23, 118, 158,
-47, 149, 129,
-35, 202, 79,
15, 220, 47,
59, 257, 120,
58, 242, 128,
60, 248, 142,
40, 225, 156,
21, 251, 150,
16, 245, 137,
15, 260, 129,
35, 258, 115,
-26, 78, 125,
51, 73, 109,
-38, 96, 121,
-49, 114, 99,
-55, 115, 100,
-46, 98, 122,
70, 106, 74,
65, 89, 100,
73, 89, 97,
76, 106, 73,
-55, 96, 90,
67, 87, 65,
57, 154, 36,
70, 118, 65,
77, 118, 63,
57, 163, 30,
-42, 170, 50,
-57, 127, 90,
-50, 126, 89,
-42, 161, 56,
54, 121, 24,
-52, 128, 46,
9, 175, 25,
51, 160, 32,
59, 168, 25,
9, 187, 17,
-36, 166, 50,
1, 175, 26,
0, 188, 18,
-45, 175, 46,
-25, 145, 27,
26, 142, 16,
-23, 159, 169,
33, 151, 168,
86, 151, 146,
37, 242, 135,
27, 146, 176,
21, 110, 169,
-19, 119, 168,
-21, 153, 178,
73, 112, 149,
34, 109, 166,
40, 145, 174,
87, 145, 155,
12, 71, 121,
37, 114, 163,
42, 143, 169,
81, 143, 154,
69, 116, 148,
24, 144, 173,
18, 115, 167,
-15, 122, 166,
-17, 150, 174,
-44, 0, 32,
-47, 90, 54,
47, 90, 54,
44, 0, 32,
44, 33, -27,
46, 109, 21,
-46, 109, 21,
-44, 33, -27,
11, 102, 51,
-11, 102, 51,
-11, 112, 32,
11, 112, 32,
41, 23, 42,
-41, 23, 42,
40, 54, -13,
-40, 54, -13,
45, 68, 50,
44, 90, 9,
-45, 68, 50,
-44, 90, 9,
-81, 64, 44,
-57, 89, 53,
-49, 62, 38,
-51, 46, 34,
-51, 63, 4,
-49, 75, 15,
-57, 102, 30,
-81, 81, 14,
81, 64, 44,
57, 89, 53,
49, 62, 38,
51, 46, 34,
51, 63, 4,
49, 75, 15,
57, 102, 30,
81, 81, 14,
-30, -1, 22,
30, -1, 22,
29, -1, -36,
-30, -1, -36,
-5, -22, 8,
5, -22, 8,
6, -28, 0,
-5, -28, 0,
-53, -53, 59,
-46, -17, 24,
0, -13, 20,
0, -53, 59,
0, -85, 24,
-1, -42, -11,
-45, -46, -7,
-53, -85, 24,
53, -53, 59,
46, -17, 24,
0, -9, 11,
0, -53, 59,
0, -85, 24,
1, -42, -11,
45, -46, -7,
53, -85, 24,
55, 63, 8,
55, 50, 32,
78, 64, 40,
78, 77, 16,
-55, 50, 32,
-55, 63, 8,
-78, 77, 16,
-78, 64, 40,
-110, 23, 9,
-94, 13, 4,
-94, 20, -6,
-110, 29, -1,
-127, 0, 1,
-116, 11, 8,
-103, 4, 4,
-113, -7, -3,
-113, 4, -25,
-103, 14, -14,
-116, 22, -10,
-127, 12, -20,
-124, -2, -12,
-11, -78, 32,
-41, -78, 32,
-41, -60, 52,
-11, -60, 52,
11, -60, 52,
41, -60, 52,
41, -78, 32,
11, -78, 32,
38, -96, 68,
38, -66, 58,
13, -66, 58,
13, -96, 68,
13, -104, 46,
13, -83, 40,
38, -83, 40,
38, -104, 46,
13, -87, 65,
38, -87, 65,
38, -95, 43,
13, -95, 43,
-38, -96, 68,
-38, -66, 58,
-13, -66, 58,
-13, -96, 68,
-13, -104, 46,
-13, -83, 40,
-38, -83, 40,
-38, -104, 46,
-13, -87, 65,
-38, -87, 65,
-38, -95, 43,
-13, -95, 43,
-65, -117, 107,
-52, -81, 96,
-18, -79, 101,
-13, -114, 114,
-5, -135, 56,
-10, -116, 49,
-41, -118, 44,
-44, -137, 50,
-39, -99, 124,
-10, -96, 80,
-5, -123, 90,
-55, -98, 73,
-59, -126, 82,
65, -117, 107,
52, -81, 96,
18, -79, 101,
13, -114, 114,
5, -135, 56,
10, -116, 49,
41, -118, 44,
44, -137, 50,
39, -99, 124,
10, -96, 80,
5, -123, 90,
55, -98, 73,
59, -126, 82,
110, 23, 9,
94, 13, 4,
94, 20, -6,
110, 29, -1,
127, 0, 1,
116, 11, 8,
103, 4, 4,
113, -7, -3,
113, 4, -25,
103, 14, -14,
116, 22, -10,
127, 12, -20,
124, -2, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:17 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_17[]={
88, 128, 79,
64, 180, 39,
13, 203, 29,
-33, 188, 63,
-50, 139, 113,
-35, 112, 143,
24, 95, 142,
82, 102, 114,
-14, 109, 139,
24, 109, 133,
61, 103, 120,
71, 129, 83,
62, 170, 47,
13, 188, 39,
-31, 178, 70,
-32, 137, 109,
53, 103, 50,
38, 141, 28,
5, 159, 26,
-28, 147, 45,
-41, 111, 73,
-27, 73, 95,
39, 67, 79,
15, 97, 47,
11, 111, 38,
0, 117, 34,
-11, 111, 38,
-15, 97, 47,
-18, 83, 56,
1, 78, 64,
18, 83, 56,
73, 194, 50,
92, 140, 95,
76, 114, 133,
31, 112, 156,
-17, 122, 156,
-41, 151, 128,
-31, 203, 76,
18, 219, 41,
66, 258, 110,
65, 243, 119,
68, 250, 132,
48, 227, 148,
30, 253, 142,
23, 247, 129,
23, 261, 121,
42, 259, 106,
-22, 82, 126,
53, 75, 107,
-35, 99, 121,
-46, 117, 99,
-51, 117, 101,
-42, 101, 123,
71, 107, 70,
67, 91, 96,
75, 91, 93,
77, 107, 69,
-52, 98, 92,
67, 88, 62,
58, 153, 31,
71, 118, 60,
78, 118, 58,
58, 162, 25,
-40, 170, 49,
-54, 129, 91,
-47, 128, 89,
-40, 161, 55,
53, 120, 21,
-50, 129, 47,
10, 174, 21,
52, 159, 27,
60, 167, 19,
10, 186, 13,
-34, 166, 49,
2, 175, 23,
2, 187, 15,
-42, 176, 45,
-25, 145, 26,
26, 141, 13,
-16, 163, 166,
40, 154, 163,
92, 154, 139,
45, 243, 127,
34, 149, 171,
27, 114, 166,
-13, 123, 166,
-14, 157, 175,
77, 115, 143,
40, 113, 162,
47, 148, 168,
93, 148, 148,
15, 73, 120,
42, 117, 159,
48, 146, 164,
87, 146, 147,
74, 119, 143,
30, 148, 168,
24, 119, 164,
-9, 126, 164,
-10, 154, 171,
-44, 0, 32,
-47, 90, 53,
47, 90, 53,
44, 0, 32,
44, 32, -27,
46, 108, 19,
-46, 108, 19,
-44, 32, -27,
11, 102, 50,
-11, 102, 50,
-11, 112, 30,
11, 112, 30,
41, 23, 42,
-41, 23, 42,
40, 54, -14,
-40, 54, -14,
45, 68, 49,
44, 90, 8,
-45, 68, 49,
-44, 90, 8,
-81, 64, 43,
-57, 89, 52,
-49, 62, 38,
-51, 46, 34,
-51, 63, 3,
-49, 75, 14,
-57, 102, 28,
-81, 81, 13,
81, 64, 43,
57, 89, 52,
49, 62, 38,
51, 46, 34,
51, 63, 3,
49, 75, 14,
57, 102, 28,
81, 81, 13,
-30, -1, 22,
30, -1, 22,
29, -1, -36,
-30, -1, -36,
-5, -21, 7,
5, -21, 7,
6, -28, 0,
-5, -28, 0,
-53, -53, 58,
-46, -17, 24,
0, -13, 20,
0, -53, 58,
0, -85, 23,
-1, -41, -11,
-45, -46, -8,
-53, -85, 23,
53, -53, 58,
46, -17, 24,
0, -9, 11,
0, -53, 58,
0, -85, 23,
1, -41, -11,
45, -46, -8,
53, -85, 23,
55, 63, 8,
55, 50, 31,
78, 64, 39,
78, 77, 15,
-55, 50, 31,
-55, 63, 8,
-78, 77, 15,
-78, 64, 39,
-110, 23, 9,
-94, 13, 4,
-94, 19, -7,
-110, 29, -2,
-127, 0, 1,
-116, 11, 8,
-103, 4, 4,
-113, -7, -3,
-113, 3, -25,
-103, 14, -14,
-116, 21, -10,
-127, 12, -20,
-124, -3, -12,
-11, -78, 30,
-41, -78, 30,
-41, -60, 51,
-11, -60, 51,
11, -60, 51,
41, -60, 51,
41, -78, 30,
11, -78, 30,
38, -96, 68,
38, -67, 56,
13, -67, 56,
13, -96, 68,
13, -105, 46,
13, -83, 38,
38, -83, 38,
38, -105, 46,
13, -87, 65,
38, -87, 65,
38, -96, 43,
13, -96, 43,
-38, -96, 68,
-38, -67, 56,
-13, -67, 56,
-13, -96, 68,
-13, -105, 46,
-13, -83, 38,
-38, -83, 38,
-38, -105, 46,
-13, -87, 65,
-38, -87, 65,
-38, -96, 43,
-13, -96, 43,
-65, -115, 107,
-52, -79, 95,
-18, -77, 100,
-13, -111, 115,
-5, -135, 58,
-10, -117, 50,
-41, -119, 45,
-44, -137, 52,
-39, -96, 124,
-10, -95, 80,
-5, -121, 91,
-55, -98, 73,
-59, -124, 83,
65, -115, 107,
52, -79, 95,
18, -77, 100,
13, -111, 115,
5, -135, 58,
10, -117, 50,
41, -119, 45,
44, -137, 52,
39, -96, 124,
10, -95, 80,
5, -121, 91,
55, -98, 73,
59, -124, 83,
110, 23, 9,
94, 13, 4,
94, 19, -7,
110, 29, -2,
127, 0, 1,
116, 11, 8,
103, 4, 4,
113, -7, -3,
113, 3, -25,
103, 14, -14,
116, 21, -10,
127, 12, -20,
124, -3, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:18 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_18[]={
90, 128, 73,
66, 180, 33,
15, 202, 25,
-29, 189, 61,
-45, 142, 113,
-30, 116, 143,
29, 99, 139,
84, 104, 109,
-10, 112, 138,
28, 111, 130,
65, 105, 116,
73, 130, 78,
64, 169, 41,
15, 188, 35,
-27, 179, 68,
-28, 140, 108,
53, 103, 47,
39, 141, 25,
5, 159, 23,
-26, 147, 44,
-39, 112, 74,
-25, 75, 96,
40, 69, 77,
15, 98, 46,
11, 112, 36,
0, 117, 32,
-11, 112, 36,
-15, 98, 46,
-18, 84, 55,
2, 80, 64,
18, 84, 55,
76, 193, 43,
95, 141, 88,
80, 116, 127,
36, 115, 152,
-12, 126, 155,
-36, 154, 127,
-26, 204, 73,
22, 218, 36,
73, 259, 101,
72, 244, 110,
76, 251, 122,
56, 229, 139,
38, 255, 133,
31, 248, 122,
31, 263, 113,
49, 260, 97,
-19, 85, 126,
55, 77, 104,
-31, 102, 122,
-43, 119, 100,
-48, 120, 101,
-39, 104, 123,
73, 107, 66,
69, 92, 92,
76, 92, 89,
78, 107, 64,
-50, 100, 93,
68, 88, 58,
59, 152, 26,
72, 119, 55,
79, 118, 53,
59, 161, 20,
-37, 171, 48,
-51, 131, 92,
-44, 130, 90,
-37, 162, 55,
53, 119, 17,
-49, 130, 48,
11, 173, 18,
52, 158, 22,
60, 166, 14,
11, 185, 9,
-32, 166, 48,
3, 174, 20,
3, 186, 12,
-40, 176, 44,
-24, 145, 25,
26, 140, 10,
-9, 166, 163,
46, 157, 157,
97, 156, 131,
52, 245, 118,
41, 153, 166,
33, 118, 162,
-7, 127, 164,
-6, 161, 172,
82, 118, 138,
45, 116, 159,
54, 152, 163,
98, 150, 141,
18, 76, 119,
48, 121, 155,
55, 149, 158,
92, 148, 140,
79, 122, 137,
37, 151, 163,
30, 122, 160,
-3, 130, 162,
-2, 157, 168,
-44, 0, 32,
-47, 91, 52,
47, 91, 52,
44, 0, 32,
44, 32, -28,
46, 108, 18,
-46, 108, 18,
-44, 32, -28,
11, 102, 49,
-11, 102, 49,
-11, 112, 29,
11, 112, 29,
41, 23, 42,
-41, 23, 42,
40, 53, -14,
-40, 53, -14,
45, 68, 48,
44, 90, 7,
-45, 68, 48,
-44, 90, 7,
-81, 64, 42,
-57, 90, 51,
-49, 62, 37,
-51, 46, 33,
-51, 62, 2,
-49, 74, 13,
-57, 102, 27,
-81, 80, 12,
81, 64, 42,
57, 90, 51,
49, 62, 37,
51, 46, 33,
51, 62, 2,
49, 74, 13,
57, 102, 27,
81, 80, 12,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -21, 7,
5, -21, 7,
6, -27, 0,
-5, -27, 0,
-53, -54, 57,
-46, -17, 23,
0, -13, 20,
0, -54, 57,
0, -84, 21,
-1, -40, -12,
-45, -45, -8,
-53, -84, 21,
53, -54, 57,
46, -17, 23,
0, -9, 11,
0, -54, 57,
0, -84, 21,
1, -40, -12,
45, -45, -8,
53, -84, 21,
55, 63, 7,
55, 50, 31,
78, 64, 38,
78, 77, 14,
-55, 50, 31,
-55, 63, 7,
-78, 77, 14,
-78, 64, 38,
-110, 23, 9,
-94, 13, 4,
-94, 19, -7,
-110, 29, -2,
-127, 0, 1,
-116, 11, 8,
-103, 3, 4,
-113, -8, -3,
-113, 3, -25,
-103, 13, -15,
-116, 21, -11,
-127, 11, -20,
-124, -3, -12,
-11, -78, 29,
-41, -78, 29,
-41, -60, 49,
-11, -60, 49,
11, -60, 49,
41, -60, 49,
41, -78, 29,
11, -78, 29,
38, -95, 68,
38, -67, 55,
13, -67, 55,
13, -95, 68,
13, -105, 47,
13, -83, 37,
38, -83, 37,
38, -105, 47,
13, -87, 64,
38, -87, 64,
38, -97, 43,
13, -97, 43,
-38, -95, 68,
-38, -67, 55,
-13, -67, 55,
-13, -95, 68,
-13, -105, 47,
-13, -83, 37,
-38, -83, 37,
-38, -105, 47,
-13, -87, 64,
-38, -87, 64,
-38, -97, 43,
-13, -97, 43,
-65, -112, 108,
-52, -77, 94,
-18, -75, 99,
-13, -109, 116,
-5, -135, 60,
-10, -117, 51,
-41, -119, 47,
-44, -137, 54,
-39, -92, 124,
-10, -94, 80,
-5, -120, 92,
-55, -97, 74,
-59, -123, 85,
65, -112, 108,
52, -77, 94,
18, -75, 99,
13, -109, 116,
5, -135, 60,
10, -117, 51,
41, -119, 47,
44, -137, 54,
39, -92, 124,
10, -94, 80,
5, -120, 92,
55, -97, 74,
59, -123, 85,
110, 23, 9,
94, 13, 4,
94, 19, -7,
110, 29, -2,
127, 0, 1,
116, 11, 8,
103, 3, 4,
113, -8, -3,
113, 3, -25,
103, 13, -15,
116, 21, -11,
127, 11, -20,
124, -3, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:19 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_19[]={
92, 129, 67,
68, 179, 26,
17, 201, 20,
-26, 190, 59,
-41, 144, 113,
-25, 119, 143,
33, 102, 137,
87, 106, 104,
-5, 116, 137,
33, 114, 127,
68, 107, 112,
75, 131, 73,
66, 169, 35,
17, 187, 31,
-24, 179, 66,
-24, 142, 107,
53, 103, 44,
39, 140, 21,
6, 158, 21,
-25, 147, 43,
-37, 114, 75,
-23, 77, 98,
40, 70, 76,
15, 98, 44,
11, 112, 35,
0, 117, 31,
-11, 112, 35,
-15, 98, 44,
-18, 84, 54,
2, 81, 64,
18, 84, 54,
79, 193, 36,
98, 142, 81,
84, 119, 122,
41, 118, 149,
-6, 129, 153,
-31, 157, 126,
-22, 205, 70,
25, 218, 30,
81, 259, 91,
80, 245, 100,
84, 253, 113,
64, 232, 131,
47, 257, 125,
39, 250, 114,
39, 264, 105,
56, 261, 89,
-16, 88, 127,
57, 79, 101,
-27, 105, 122,
-40, 121, 101,
-45, 122, 102,
-35, 107, 124,
74, 108, 61,
71, 94, 88,
78, 94, 85,
79, 108, 59,
-48, 102, 95,
68, 89, 55,
59, 152, 21,
73, 119, 51,
80, 118, 48,
59, 160, 15,
-35, 171, 47,
-48, 133, 92,
-41, 132, 90,
-35, 163, 54,
52, 119, 14,
-48, 130, 48,
12, 172, 15,
53, 157, 18,
61, 165, 8,
12, 184, 6,
-30, 167, 46,
4, 173, 17,
4, 185, 8,
-38, 176, 43,
-24, 145, 24,
26, 139, 7,
-1, 170, 160,
53, 160, 152,
103, 158, 124,
60, 246, 110,
48, 157, 161,
38, 121, 159,
-1, 130, 162,
0, 165, 169,
87, 120, 132,
51, 120, 155,
60, 155, 157,
104, 153, 133,
20, 79, 118,
53, 124, 151,
61, 153, 153,
98, 150, 133,
84, 124, 132,
44, 155, 159,
36, 126, 157,
2, 134, 160,
4, 161, 165,
-44, 0, 32,
-47, 91, 51,
47, 91, 51,
44, 0, 32,
44, 31, -28,
46, 108, 17,
-46, 108, 17,
-44, 31, -28,
11, 102, 47,
-11, 102, 47,
-11, 112, 28,
11, 112, 28,
41, 24, 41,
-41, 24, 41,
40, 52, -15,
-40, 52, -15,
45, 68, 48,
44, 89, 6,
-45, 68, 48,
-44, 89, 6,
-81, 65, 42,
-57, 90, 50,
-49, 62, 36,
-51, 47, 33,
-51, 62, 2,
-49, 74, 12,
-57, 102, 26,
-81, 80, 11,
81, 65, 42,
57, 90, 50,
49, 62, 36,
51, 47, 33,
51, 62, 2,
49, 74, 12,
57, 102, 26,
81, 80, 11,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -21, 7,
5, -21, 7,
6, -27, 0,
-5, -27, 0,
-53, -54, 56,
-46, -17, 23,
0, -13, 19,
0, -54, 56,
0, -84, 20,
-1, -40, -13,
-45, -44, -9,
-53, -84, 20,
53, -54, 56,
46, -17, 23,
0, -9, 11,
0, -54, 56,
0, -84, 20,
1, -40, -13,
45, -44, -9,
53, -84, 20,
55, 62, 6,
55, 50, 30,
78, 64, 37,
78, 76, 13,
-55, 50, 30,
-55, 62, 6,
-78, 76, 13,
-78, 64, 37,
-110, 22, 9,
-94, 13, 4,
-94, 18, -7,
-110, 28, -2,
-127, 0, 1,
-116, 11, 8,
-103, 3, 4,
-113, -8, -2,
-113, 2, -25,
-103, 13, -15,
-116, 21, -11,
-127, 11, -20,
-124, -4, -12,
-11, -78, 28,
-41, -78, 28,
-41, -61, 48,
-11, -61, 48,
11, -61, 48,
41, -61, 48,
41, -78, 28,
11, -78, 28,
38, -95, 68,
38, -67, 54,
13, -67, 54,
13, -95, 68,
13, -106, 47,
13, -82, 35,
38, -82, 35,
38, -106, 47,
13, -86, 64,
38, -86, 64,
38, -97, 43,
13, -97, 43,
-38, -95, 68,
-38, -67, 54,
-13, -67, 54,
-13, -95, 68,
-13, -106, 47,
-13, -82, 35,
-38, -82, 35,
-38, -106, 47,
-13, -86, 64,
-38, -86, 64,
-38, -97, 43,
-13, -97, 43,
-65, -110, 109,
-52, -76, 94,
-18, -73, 98,
-13, -106, 116,
-5, -135, 62,
-10, -118, 52,
-41, -120, 48,
-44, -137, 56,
-39, -89, 124,
-10, -93, 80,
-5, -118, 94,
-55, -96, 74,
-59, -122, 86,
65, -110, 109,
52, -76, 94,
18, -73, 98,
13, -106, 116,
5, -135, 62,
10, -118, 52,
41, -120, 48,
44, -137, 56,
39, -89, 124,
10, -93, 80,
5, -118, 94,
55, -96, 74,
59, -122, 86,
110, 22, 9,
94, 13, 4,
94, 18, -7,
110, 28, -2,
127, 0, 1,
116, 11, 8,
103, 3, 4,
113, -8, -2,
113, 2, -25,
103, 13, -15,
116, 21, -11,
127, 11, -20,
124, -4, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:20 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_20[]={
94, 129, 61,
70, 178, 20,
19, 200, 16,
-22, 190, 57,
-37, 147, 113,
-20, 123, 143,
37, 105, 135,
90, 108, 99,
-1, 119, 136,
37, 117, 124,
71, 109, 107,
78, 131, 68,
68, 169, 29,
20, 187, 27,
-20, 180, 64,
-20, 144, 106,
53, 104, 41,
39, 139, 17,
7, 158, 18,
-23, 148, 42,
-36, 115, 76,
-22, 80, 99,
41, 71, 74,
15, 98, 43,
11, 112, 33,
0, 117, 29,
-11, 112, 33,
-15, 98, 43,
-18, 85, 53,
2, 82, 64,
18, 85, 53,
81, 192, 28,
101, 143, 75,
88, 121, 117,
46, 122, 145,
0, 133, 152,
-25, 160, 125,
-18, 206, 68,
28, 217, 25,
88, 260, 81,
87, 247, 91,
91, 254, 103,
72, 234, 123,
55, 259, 117,
47, 252, 107,
47, 266, 97,
63, 262, 80,
-13, 91, 127,
59, 81, 98,
-24, 108, 123,
-37, 123, 101,
-42, 124, 103,
-31, 110, 125,
75, 109, 57,
72, 95, 85,
80, 95, 81,
80, 108, 55,
-46, 104, 96,
68, 89, 52,
60, 151, 16,
74, 119, 46,
81, 118, 43,
60, 159, 9,
-33, 171, 46,
-45, 135, 93,
-38, 134, 90,
-32, 163, 53,
51, 118, 10,
-47, 131, 49,
14, 172, 11,
54, 156, 13,
61, 163, 3,
13, 183, 2,
-28, 167, 45,
5, 173, 14,
5, 184, 5,
-36, 176, 41,
-23, 145, 24,
25, 138, 4,
5, 174, 157,
60, 164, 147,
108, 160, 116,
68, 248, 102,
55, 160, 156,
44, 125, 155,
4, 134, 161,
8, 169, 166,
91, 123, 127,
56, 123, 151,
67, 158, 152,
110, 155, 126,
23, 81, 117,
59, 127, 147,
68, 156, 147,
103, 153, 126,
88, 127, 126,
51, 158, 154,
42, 129, 153,
8, 137, 158,
11, 165, 162,
-44, 0, 33,
-47, 91, 49,
47, 91, 49,
44, 0, 33,
44, 30, -29,
46, 108, 15,
-46, 108, 15,
-44, 30, -29,
11, 102, 46,
-11, 102, 46,
-11, 112, 26,
11, 112, 26,
41, 24, 41,
-41, 24, 41,
40, 52, -16,
-40, 52, -16,
45, 69, 47,
44, 89, 5,
-45, 69, 47,
-44, 89, 5,
-81, 65, 41,
-57, 90, 49,
-49, 62, 35,
-51, 47, 32,
-51, 62, 1,
-49, 74, 11,
-57, 102, 25,
-81, 80, 10,
81, 65, 41,
57, 90, 49,
49, 62, 35,
51, 47, 32,
51, 62, 1,
49, 74, 11,
57, 102, 25,
81, 80, 10,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -20, 6,
5, -20, 6,
6, -26, -1,
-5, -26, -1,
-53, -55, 55,
-46, -17, 23,
0, -13, 19,
0, -55, 55,
0, -84, 18,
-1, -39, -13,
-45, -43, -10,
-53, -84, 18,
53, -55, 55,
46, -17, 23,
0, -9, 11,
0, -55, 55,
0, -84, 18,
1, -39, -13,
45, -43, -10,
53, -84, 18,
55, 62, 5,
55, 50, 30,
78, 64, 36,
78, 76, 12,
-55, 50, 30,
-55, 62, 5,
-78, 76, 12,
-78, 64, 36,
-110, 22, 8,
-94, 12, 4,
-94, 18, -7,
-110, 28, -3,
-127, 0, 1,
-116, 11, 7,
-103, 3, 4,
-113, -8, -2,
-113, 2, -25,
-103, 12, -15,
-116, 20, -11,
-127, 10, -20,
-124, -4, -12,
-11, -77, 26,
-41, -77, 26,
-41, -61, 47,
-11, -61, 47,
11, -61, 47,
41, -61, 47,
41, -77, 26,
11, -77, 26,
38, -95, 68,
38, -68, 53,
13, -68, 53,
13, -95, 68,
13, -107, 48,
13, -82, 34,
38, -82, 34,
38, -107, 48,
13, -86, 64,
38, -86, 64,
38, -98, 43,
13, -98, 43,
-38, -95, 68,
-38, -68, 53,
-13, -68, 53,
-13, -95, 68,
-13, -107, 48,
-13, -82, 34,
-38, -82, 34,
-38, -107, 48,
-13, -86, 64,
-38, -86, 64,
-38, -98, 43,
-13, -98, 43,
-65, -107, 110,
-52, -74, 93,
-18, -71, 97,
-13, -103, 117,
-5, -134, 64,
-10, -118, 53,
-41, -120, 49,
-44, -138, 59,
-39, -86, 124,
-10, -92, 80,
-5, -116, 95,
-55, -96, 74,
-59, -121, 88,
65, -107, 110,
52, -74, 93,
18, -71, 97,
13, -103, 117,
5, -134, 64,
10, -118, 53,
41, -120, 49,
44, -138, 59,
39, -86, 124,
10, -92, 80,
5, -116, 95,
55, -96, 74,
59, -121, 88,
110, 22, 8,
94, 12, 4,
94, 18, -7,
110, 28, -3,
127, 0, 1,
116, 11, 7,
103, 3, 4,
113, -8, -2,
113, 2, -25,
103, 12, -15,
116, 20, -11,
127, 10, -20,
124, -4, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:21 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_21[]={
96, 130, 55,
71, 177, 14,
21, 200, 11,
-19, 191, 54,
-32, 149, 112,
-15, 126, 142,
41, 108, 132,
93, 110, 94,
3, 122, 135,
41, 120, 122,
74, 111, 103,
80, 132, 62,
70, 168, 23,
22, 187, 23,
-17, 181, 62,
-16, 147, 105,
53, 104, 37,
40, 139, 14,
8, 157, 16,
-22, 148, 42,
-34, 117, 77,
-20, 82, 100,
41, 73, 73,
15, 99, 42,
11, 112, 32,
0, 117, 28,
-11, 112, 32,
-15, 99, 42,
-18, 86, 52,
2, 83, 64,
18, 86, 52,
84, 192, 21,
104, 144, 68,
92, 123, 111,
52, 125, 142,
4, 137, 150,
-20, 163, 124,
-13, 206, 65,
31, 217, 19,
95, 261, 71,
94, 248, 82,
99, 256, 93,
80, 236, 115,
64, 261, 109,
55, 253, 99,
54, 267, 89,
70, 263, 72,
-10, 94, 127,
61, 83, 96,
-20, 111, 123,
-34, 126, 102,
-39, 127, 104,
-27, 113, 126,
76, 109, 53,
74, 97, 81,
81, 96, 77,
81, 109, 50,
-43, 107, 98,
68, 90, 48,
61, 150, 11,
75, 119, 42,
81, 119, 38,
61, 158, 4,
-30, 172, 45,
-42, 137, 93,
-35, 136, 91,
-30, 164, 52,
51, 117, 7,
-46, 132, 50,
15, 171, 8,
55, 155, 8,
62, 162, -1,
14, 182, -1,
-25, 167, 44,
6, 172, 11,
6, 183, 2,
-33, 177, 40,
-22, 144, 23,
25, 137, 2,
12, 177, 154,
66, 167, 141,
114, 162, 109,
75, 249, 93,
62, 164, 151,
50, 129, 152,
10, 138, 159,
15, 173, 163,
96, 126, 121,
62, 127, 147,
74, 162, 146,
115, 158, 118,
25, 84, 116,
64, 131, 143,
74, 159, 142,
109, 155, 119,
93, 129, 121,
57, 161, 149,
47, 133, 150,
14, 141, 156,
18, 169, 159,
-44, 0, 33,
-47, 91, 48,
47, 91, 48,
44, 0, 33,
44, 30, -29,
46, 107, 14,
-46, 107, 14,
-44, 30, -29,
11, 102, 45,
-11, 102, 45,
-11, 112, 25,
11, 112, 25,
41, 24, 41,
-41, 24, 41,
40, 51, -16,
-40, 51, -16,
45, 69, 46,
44, 89, 4,
-45, 69, 46,
-44, 89, 4,
-81, 65, 40,
-57, 90, 48,
-49, 62, 35,
-51, 47, 31,
-51, 61, 0,
-49, 74, 10,
-57, 102, 23,
-81, 80, 9,
81, 65, 40,
57, 90, 48,
49, 62, 35,
51, 47, 31,
51, 61, 0,
49, 74, 10,
57, 102, 23,
81, 80, 9,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -20, 6,
5, -20, 6,
6, -26, -1,
-5, -26, -1,
-53, -55, 54,
-46, -17, 23,
0, -13, 19,
0, -55, 54,
0, -83, 17,
-1, -38, -14,
-45, -43, -10,
-53, -83, 17,
53, -55, 54,
46, -17, 23,
0, -9, 12,
0, -55, 54,
0, -83, 17,
1, -38, -14,
45, -43, -10,
53, -83, 17,
55, 62, 5,
55, 50, 29,
78, 64, 36,
78, 76, 11,
-55, 50, 29,
-55, 62, 5,
-78, 76, 11,
-78, 64, 36,
-110, 22, 8,
-94, 12, 3,
-94, 18, -8,
-110, 28, -3,
-127, 0, 1,
-116, 10, 7,
-103, 3, 4,
-113, -9, -2,
-113, 1, -25,
-103, 12, -15,
-116, 20, -11,
-127, 10, -21,
-124, -4, -12,
-11, -77, 25,
-41, -77, 25,
-41, -61, 46,
-11, -61, 46,
11, -61, 46,
41, -61, 46,
41, -77, 25,
11, -77, 25,
38, -94, 68,
38, -68, 51,
13, -68, 51,
13, -94, 68,
13, -107, 49,
13, -82, 32,
38, -82, 32,
38, -107, 49,
13, -86, 63,
38, -86, 63,
38, -99, 43,
13, -99, 43,
-38, -94, 68,
-38, -68, 51,
-13, -68, 51,
-13, -94, 68,
-13, -107, 49,
-13, -82, 32,
-38, -82, 32,
-38, -107, 49,
-13, -86, 63,
-38, -86, 63,
-38, -99, 43,
-13, -99, 43,
-65, -105, 111,
-52, -72, 92,
-18, -69, 96,
-13, -100, 118,
-5, -134, 66,
-10, -118, 54,
-41, -121, 50,
-44, -138, 61,
-39, -83, 124,
-10, -91, 80,
-5, -115, 96,
-55, -95, 74,
-59, -119, 89,
65, -105, 111,
52, -72, 92,
18, -69, 96,
13, -100, 118,
5, -134, 66,
10, -118, 54,
41, -121, 50,
44, -138, 61,
39, -83, 124,
10, -91, 80,
5, -115, 96,
55, -95, 74,
59, -119, 89,
110, 22, 8,
94, 12, 3,
94, 18, -8,
110, 28, -3,
127, 0, 1,
116, 10, 7,
103, 3, 4,
113, -9, -2,
113, 1, -25,
103, 12, -15,
116, 20, -11,
127, 10, -21,
124, -4, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:22 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_22[]={
98, 131, 49,
73, 177, 8,
24, 199, 7,
-15, 192, 52,
-28, 152, 112,
-10, 129, 142,
45, 111, 130,
96, 112, 89,
7, 125, 134,
45, 122, 119,
78, 114, 99,
82, 133, 57,
72, 168, 17,
24, 186, 19,
-13, 182, 60,
-12, 149, 105,
54, 104, 34,
40, 138, 10,
9, 157, 13,
-20, 148, 41,
-32, 118, 77,
-18, 84, 101,
42, 74, 71,
15, 99, 41,
11, 112, 30,
0, 117, 26,
-11, 112, 30,
-15, 99, 41,
-18, 87, 52,
3, 84, 64,
18, 87, 52,
87, 191, 14,
107, 145, 61,
97, 126, 106,
57, 128, 139,
10, 140, 149,
-15, 165, 122,
-9, 207, 62,
34, 216, 14,
102, 262, 62,
101, 249, 73,
107, 257, 84,
88, 238, 107,
73, 263, 101,
63, 255, 92,
62, 268, 81,
78, 263, 63,
-6, 97, 128,
63, 85, 93,
-17, 114, 124,
-31, 128, 102,
-35, 129, 105,
-24, 116, 126,
77, 110, 49,
76, 98, 77,
83, 98, 73,
82, 109, 46,
-41, 109, 100,
68, 90, 45,
62, 149, 6,
76, 120, 37,
82, 119, 34,
61, 157, 0,
-28, 172, 44,
-38, 139, 94,
-32, 138, 91,
-28, 164, 51,
50, 116, 3,
-45, 132, 51,
16, 170, 5,
55, 155, 3,
63, 161, -7,
15, 181, -5,
-23, 168, 43,
8, 171, 8,
7, 182, -1,
-31, 177, 39,
-22, 144, 22,
25, 136, 0,
20, 181, 151,
73, 170, 136,
119, 164, 101,
83, 251, 85,
69, 167, 146,
56, 132, 149,
17, 142, 157,
23, 176, 159,
100, 128, 115,
67, 130, 143,
81, 165, 141,
121, 160, 111,
28, 87, 115,
70, 134, 138,
81, 162, 136,
114, 158, 112,
98, 132, 115,
64, 165, 145,
53, 137, 147,
20, 145, 154,
25, 173, 156,
-44, 0, 33,
-47, 91, 47,
47, 91, 47,
44, 0, 33,
44, 29, -29,
46, 107, 13,
-46, 107, 13,
-44, 29, -29,
11, 102, 44,
-11, 102, 44,
-11, 112, 23,
11, 112, 23,
41, 24, 41,
-41, 24, 41,
40, 51, -17,
-40, 51, -17,
45, 69, 45,
44, 88, 2,
-45, 69, 45,
-44, 88, 2,
-81, 65, 39,
-57, 90, 47,
-49, 62, 34,
-51, 47, 31,
-51, 61, 0,
-49, 73, 9,
-57, 101, 22,
-81, 79, 8,
81, 65, 39,
57, 90, 47,
49, 62, 34,
51, 47, 31,
51, 61, 0,
49, 73, 9,
57, 101, 22,
81, 79, 8,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -20, 6,
5, -20, 6,
6, -25, -2,
-5, -25, -2,
-53, -55, 53,
-46, -17, 22,
0, -12, 19,
0, -55, 53,
0, -83, 15,
-1, -37, -15,
-45, -42, -11,
-53, -83, 15,
53, -55, 53,
46, -17, 22,
0, -9, 12,
0, -55, 53,
0, -83, 15,
1, -37, -15,
45, -42, -11,
53, -83, 15,
55, 61, 4,
55, 50, 28,
78, 65, 35,
78, 76, 10,
-55, 50, 28,
-55, 61, 4,
-78, 76, 10,
-78, 65, 35,
-110, 22, 8,
-94, 12, 3,
-94, 17, -8,
-110, 27, -3,
-127, 0, 1,
-116, 10, 7,
-103, 2, 4,
-113, -9, -2,
-113, 0, -25,
-103, 11, -15,
-116, 19, -12,
-127, 9, -21,
-124, -5, -12,
-11, -77, 23,
-41, -77, 23,
-41, -61, 45,
-11, -61, 45,
11, -61, 45,
41, -61, 45,
41, -77, 23,
11, -77, 23,
38, -94, 69,
38, -68, 50,
13, -68, 50,
13, -94, 69,
13, -108, 49,
13, -82, 31,
38, -82, 31,
38, -108, 49,
13, -86, 63,
38, -86, 63,
38, -100, 43,
13, -100, 43,
-38, -94, 69,
-38, -68, 50,
-13, -68, 50,
-13, -94, 69,
-13, -108, 49,
-13, -82, 31,
-38, -82, 31,
-38, -108, 49,
-13, -86, 63,
-38, -86, 63,
-38, -100, 43,
-13, -100, 43,
-65, -102, 112,
-52, -71, 91,
-18, -68, 96,
-13, -98, 118,
-5, -134, 68,
-10, -119, 55,
-41, -122, 52,
-44, -138, 63,
-39, -80, 124,
-10, -90, 80,
-5, -113, 97,
-55, -94, 74,
-59, -118, 90,
65, -102, 112,
52, -71, 91,
18, -68, 96,
13, -98, 118,
5, -134, 68,
10, -119, 55,
41, -122, 52,
44, -138, 63,
39, -80, 124,
10, -90, 80,
5, -113, 97,
55, -94, 74,
59, -118, 90,
110, 22, 8,
94, 12, 3,
94, 17, -8,
110, 27, -3,
127, 0, 1,
116, 10, 7,
103, 2, 4,
113, -9, -2,
113, 0, -25,
103, 11, -15,
116, 19, -12,
127, 9, -21,
124, -5, -12,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:23 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_23[]={
96, 137, 44,
71, 177, -1,
21, 195, -6,
-19, 190, 37,
-33, 156, 100,
-16, 138, 132,
40, 122, 123,
93, 122, 84,
2, 134, 124,
40, 132, 111,
74, 124, 93,
79, 139, 51,
69, 169, 8,
21, 184, 6,
-18, 182, 46,
-17, 153, 93,
53, 107, 30,
40, 137, 3,
8, 154, 3,
-22, 147, 30,
-34, 120, 69,
-20, 90, 96,
41, 81, 69,
15, 101, 36,
11, 112, 25,
0, 117, 20,
-11, 112, 25,
-15, 101, 36,
-18, 90, 48,
2, 87, 60,
18, 90, 48,
84, 192, 3,
104, 153, 54,
92, 137, 99,
50, 140, 130,
3, 150, 138,
-21, 171, 109,
-14, 207, 45,
30, 213, 0,
93, 266, 43,
92, 255, 55,
98, 264, 65,
78, 247, 89,
62, 269, 81,
53, 260, 72,
53, 272, 61,
69, 267, 44,
-10, 105, 121,
61, 95, 90,
-21, 120, 115,
-34, 131, 92,
-39, 132, 94,
-28, 122, 117,
76, 115, 44,
74, 106, 73,
81, 106, 70,
81, 115, 42,
-44, 112, 91,
68, 96, 42,
61, 149, 0,
75, 124, 32,
81, 123, 29,
61, 156, -8,
-31, 170, 31,
-42, 141, 83,
-36, 140, 80,
-31, 163, 39,
51, 116, 0,
-46, 130, 41,
14, 167, -5,
55, 154, -4,
62, 160, -15,
14, 176, -16,
-26, 166, 30,
6, 168, -2,
6, 177, -13,
-34, 174, 26,
-23, 141, 13,
25, 134, -7,
11, 190, 136,
65, 182, 124,
112, 176, 92,
73, 257, 66,
61, 180, 134,
49, 145, 139,
9, 153, 146,
14, 187, 145,
95, 141, 109,
60, 143, 134,
72, 178, 129,
114, 173, 101,
25, 96, 110,
63, 146, 130,
73, 175, 125,
108, 170, 102,
92, 144, 108,
56, 177, 133,
46, 149, 137,
13, 156, 142,
17, 183, 142,
-44, 1, 32,
-47, 92, 43,
47, 92, 43,
44, 1, 32,
44, 26, -31,
46, 106, 7,
-46, 106, 7,
-44, 26, -31,
11, 103, 38,
-11, 103, 38,
-11, 111, 18,
11, 111, 18,
41, 25, 39,
-41, 25, 39,
40, 49, -19,
-40, 49, -19,
45, 70, 41,
44, 87, -1,
-45, 70, 41,
-44, 87, -1,
-81, 65, 36,
-57, 91, 42,
-49, 63, 31,
-51, 47, 29,
-51, 60, -3,
-49, 73, 6,
-57, 101, 17,
-81, 78, 4,
81, 65, 36,
57, 91, 42,
49, 63, 31,
51, 47, 29,
51, 60, -3,
49, 73, 6,
57, 101, 17,
81, 78, 4,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -18, 5,
5, -18, 5,
6, -23, -3,
-5, -23, -3,
-53, -57, 49,
-46, -17, 21,
0, -12, 18,
0, -57, 49,
0, -82, 9,
-1, -34, -17,
-45, -39, -14,
-53, -82, 9,
53, -57, 49,
46, -17, 21,
0, -9, 12,
0, -57, 49,
0, -82, 9,
1, -34, -17,
45, -39, -14,
53, -82, 9,
55, 60, 1,
55, 50, 26,
78, 65, 32,
78, 75, 7,
-55, 50, 26,
-55, 60, 1,
-78, 75, 7,
-78, 65, 32,
-110, 21, 7,
-94, 11, 3,
-94, 16, -9,
-110, 26, -5,
-127, -1, 1,
-116, 9, 7,
-103, 1, 4,
-113, -10, -1,
-113, -1, -25,
-103, 10, -16,
-116, 17, -12,
-127, 7, -21,
-124, -7, -11,
-11, -76, 18,
-41, -76, 18,
-41, -62, 40,
-11, -62, 40,
11, -62, 40,
41, -62, 40,
41, -76, 18,
11, -76, 18,
38, -96, 61,
38, -69, 45,
13, -69, 45,
13, -96, 61,
13, -109, 41,
13, -82, 25,
38, -82, 25,
38, -109, 41,
13, -88, 56,
38, -88, 56,
38, -100, 36,
13, -100, 36,
-38, -96, 61,
-38, -69, 45,
-13, -69, 45,
-13, -96, 61,
-13, -109, 41,
-13, -82, 25,
-38, -82, 25,
-38, -109, 41,
-13, -88, 56,
-38, -88, 56,
-38, -100, 36,
-13, -100, 36,
-65, -108, 103,
-52, -75, 85,
-18, -72, 90,
-13, -104, 110,
-5, -136, 58,
-10, -120, 47,
-41, -122, 42,
-44, -139, 52,
-39, -86, 117,
-10, -94, 73,
-5, -117, 88,
-55, -97, 67,
-59, -122, 81,
65, -108, 103,
52, -75, 85,
18, -72, 90,
13, -104, 110,
5, -136, 58,
10, -120, 47,
41, -122, 42,
44, -139, 52,
39, -86, 117,
10, -94, 73,
5, -117, 88,
55, -97, 67,
59, -122, 81,
110, 21, 7,
94, 11, 3,
94, 16, -9,
110, 26, -5,
127, -1, 1,
116, 9, 7,
103, 1, 4,
113, -10, -1,
113, -1, -25,
103, 10, -16,
116, 17, -12,
127, 7, -21,
124, -7, -11,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:24 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_24[]={
93, 144, 38,
69, 177, -11,
18, 192, -19,
-24, 188, 23,
-38, 160, 87,
-22, 146, 121,
35, 133, 116,
89, 132, 80,
-3, 143, 115,
35, 142, 103,
70, 134, 88,
77, 145, 44,
67, 170, 0,
19, 182, -5,
-22, 181, 32,
-22, 158, 81,
53, 110, 27,
39, 137, -3,
7, 151, -6,
-24, 145, 20,
-36, 122, 60,
-22, 95, 91,
41, 87, 67,
15, 102, 32,
11, 112, 19,
0, 116, 14,
-11, 112, 19,
-15, 102, 32,
-18, 93, 45,
2, 91, 56,
18, 93, 45,
80, 193, -7,
100, 160, 47,
87, 149, 93,
44, 152, 122,
-3, 160, 126,
-28, 176, 95,
-20, 206, 29,
26, 211, -15,
85, 271, 25,
84, 260, 38,
88, 271, 47,
68, 255, 72,
52, 275, 60,
43, 265, 52,
43, 276, 40,
60, 270, 24,
-14, 113, 114,
58, 104, 87,
-25, 127, 106,
-38, 135, 82,
-43, 136, 84,
-33, 129, 108,
74, 121, 40,
72, 115, 70,
79, 115, 66,
79, 121, 38,
-47, 115, 83,
68, 101, 40,
60, 149, -8,
73, 128, 27,
80, 128, 25,
60, 155, -16,
-34, 167, 18,
-46, 143, 72,
-39, 142, 69,
-33, 161, 26,
52, 116, -5,
-48, 129, 31,
13, 163, -16,
54, 153, -12,
61, 158, -23,
13, 171, -28,
-29, 163, 18,
5, 164, -13,
5, 172, -24,
-37, 170, 12,
-23, 137, 3,
25, 131, -14,
2, 200, 121,
57, 193, 112,
106, 187, 82,
64, 262, 48,
52, 192, 122,
42, 158, 130,
2, 164, 134,
4, 198, 130,
89, 153, 102,
54, 156, 126,
64, 191, 118,
107, 185, 92,
22, 105, 105,
56, 159, 121,
65, 187, 114,
101, 182, 93,
86, 157, 101,
48, 189, 121,
39, 161, 127,
5, 167, 131,
8, 194, 128,
-44, 1, 32,
-47, 93, 38,
47, 93, 38,
44, 1, 32,
44, 23, -32,
46, 105, 2,
-46, 105, 2,
-44, 23, -32,
11, 104, 33,
-11, 104, 33,
-11, 111, 12,
11, 111, 12,
41, 26, 38,
-41, 26, 38,
40, 46, -22,
-40, 46, -22,
45, 70, 38,
44, 86, -5,
-45, 70, 38,
-44, 86, -5,
-81, 66, 33,
-57, 92, 37,
-49, 63, 28,
-51, 47, 26,
-51, 58, -6,
-49, 72, 2,
-57, 100, 12,
-81, 77, 0,
81, 66, 33,
57, 92, 37,
49, 63, 28,
51, 47, 26,
51, 58, -6,
49, 72, 2,
57, 100, 12,
81, 77, 0,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -17, 3,
5, -17, 3,
6, -21, -5,
-5, -21, -5,
-53, -59, 45,
-46, -17, 20,
0, -12, 17,
0, -59, 45,
0, -80, 3,
-1, -31, -19,
-45, -36, -16,
-53, -80, 3,
53, -59, 45,
46, -17, 20,
0, -9, 12,
0, -59, 45,
0, -80, 3,
1, -31, -19,
45, -36, -16,
53, -80, 3,
55, 59, -1,
55, 50, 23,
78, 65, 28,
78, 74, 3,
-55, 50, 23,
-55, 59, -1,
-78, 74, 3,
-78, 65, 28,
-110, 20, 6,
-94, 10, 2,
-94, 14, -9,
-110, 24, -6,
-127, -2, 1,
-116, 9, 6,
-103, 1, 3,
-113, -11, -1,
-113, -3, -24,
-103, 8, -16,
-116, 16, -13,
-127, 5, -21,
-124, -8, -11,
-11, -75, 12,
-41, -75, 12,
-41, -63, 36,
-11, -63, 36,
11, -63, 36,
41, -63, 36,
41, -75, 12,
11, -75, 12,
38, -98, 54,
38, -71, 40,
13, -71, 40,
13, -98, 54,
13, -109, 33,
13, -82, 19,
38, -82, 19,
38, -109, 33,
13, -90, 50,
38, -90, 50,
38, -101, 29,
13, -101, 29,
-38, -98, 54,
-38, -71, 40,
-13, -71, 40,
-13, -98, 54,
-13, -109, 33,
-13, -82, 19,
-38, -82, 19,
-38, -109, 33,
-13, -90, 50,
-38, -90, 50,
-38, -101, 29,
-13, -101, 29,
-65, -113, 95,
-52, -79, 80,
-18, -77, 84,
-13, -109, 102,
-5, -138, 47,
-10, -121, 38,
-41, -123, 33,
-44, -141, 42,
-39, -93, 110,
-10, -97, 66,
-5, -121, 79,
-55, -100, 59,
-59, -125, 72,
65, -113, 95,
52, -79, 80,
18, -77, 84,
13, -109, 102,
5, -138, 47,
10, -121, 38,
41, -123, 33,
44, -141, 42,
39, -93, 110,
10, -97, 66,
5, -121, 79,
55, -100, 59,
59, -125, 72,
110, 20, 6,
94, 10, 2,
94, 14, -9,
110, 24, -6,
127, -2, 1,
116, 9, 6,
103, 1, 3,
113, -11, -1,
113, -3, -24,
103, 8, -16,
116, 16, -13,
127, 5, -21,
124, -8, -11,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:25 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_25[]={
91, 150, 32,
67, 177, -21,
16, 189, -32,
-28, 187, 8,
-44, 164, 75,
-28, 154, 110,
30, 144, 109,
85, 142, 75,
-8, 152, 105,
30, 152, 96,
66, 144, 82,
74, 151, 38,
65, 171, -9,
16, 180, -17,
-26, 181, 18,
-27, 162, 70,
53, 113, 23,
39, 136, -10,
6, 148, -15,
-26, 143, 9,
-39, 123, 51,
-24, 100, 85,
40, 93, 65,
15, 104, 27,
11, 112, 13,
0, 116, 8,
-11, 112, 13,
-15, 104, 27,
-18, 96, 41,
2, 94, 52,
18, 96, 41,
77, 195, -18,
96, 168, 40,
82, 160, 87,
38, 164, 113,
-10, 170, 115,
-34, 182, 81,
-25, 205, 13,
23, 208, -30,
76, 275, 6,
75, 266, 20,
78, 278, 28,
58, 263, 54,
41, 281, 40,
34, 270, 33,
33, 280, 19,
52, 273, 5,
-18, 121, 107,
56, 113, 84,
-30, 134, 97,
-42, 139, 72,
-47, 139, 74,
-37, 135, 99,
73, 127, 36,
69, 123, 66,
77, 123, 63,
78, 126, 34,
-49, 118, 74,
68, 106, 38,
59, 149, -15,
72, 133, 22,
79, 132, 20,
59, 154, -24,
-37, 165, 5,
-50, 145, 60,
-43, 145, 58,
-36, 159, 14,
52, 116, -9,
-49, 127, 22,
12, 160, -27,
53, 152, -20,
60, 157, -31,
12, 167, -39,
-31, 161, 5,
3, 161, -24,
3, 168, -36,
-39, 167, 0,
-24, 134, -6,
26, 129, -21,
-6, 210, 106,
48, 205, 100,
99, 199, 73,
55, 268, 29,
44, 204, 110,
35, 170, 121,
-5, 175, 123,
-4, 209, 116,
84, 166, 95,
47, 169, 117,
56, 203, 106,
100, 198, 83,
18, 114, 101,
50, 172, 112,
57, 199, 103,
94, 195, 84,
80, 169, 94,
39, 201, 109,
32, 174, 118,
-1, 177, 119,
0, 205, 114,
-44, 2, 32,
-47, 94, 33,
47, 94, 33,
44, 2, 32,
44, 21, -33,
46, 104, -2,
-46, 104, -2,
-44, 21, -33,
11, 104, 28,
-11, 104, 28,
-11, 110, 7,
11, 110, 7,
41, 26, 37,
-41, 26, 37,
40, 44, -24,
-40, 44, -24,
45, 71, 34,
44, 84, -9,
-45, 71, 34,
-44, 84, -9,
-81, 66, 29,
-57, 92, 33,
-49, 63, 24,
-51, 47, 24,
-51, 57, -8,
-49, 71, 0,
-57, 100, 7,
-81, 76, -3,
81, 66, 29,
57, 92, 33,
49, 63, 24,
51, 47, 24,
51, 57, -8,
49, 71, 0,
57, 100, 7,
81, 76, -3,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -15, 2,
5, -15, 2,
6, -19, -6,
-5, -19, -6,
-53, -60, 40,
-46, -17, 19,
0, -11, 16,
0, -60, 40,
0, -79, -2,
-1, -28, -21,
-45, -33, -19,
-53, -79, -2,
53, -60, 40,
46, -17, 19,
0, -9, 12,
0, -60, 40,
0, -79, -2,
1, -28, -21,
45, -33, -19,
53, -79, -2,
55, 58, -4,
55, 50, 21,
78, 65, 25,
78, 73, 0,
-55, 50, 21,
-55, 58, -4,
-78, 73, 0,
-78, 65, 25,
-110, 19, 5,
-94, 9, 2,
-94, 13, -10,
-110, 23, -7,
-127, -3, 1,
-116, 8, 6,
-103, 0, 3,
-113, -12, 0,
-113, -6, -24,
-103, 6, -17,
-116, 14, -14,
-127, 3, -22,
-124, -10, -11,
-11, -75, 7,
-41, -75, 7,
-41, -64, 31,
-11, -64, 31,
11, -64, 31,
41, -64, 31,
41, -75, 7,
11, -75, 7,
38, -101, 47,
38, -72, 35,
13, -72, 35,
13, -101, 47,
13, -110, 25,
13, -81, 13,
38, -81, 13,
38, -110, 25,
13, -92, 43,
38, -92, 43,
38, -101, 21,
13, -101, 21,
-38, -101, 47,
-38, -72, 35,
-13, -72, 35,
-13, -101, 47,
-13, -110, 25,
-13, -81, 13,
-38, -81, 13,
-38, -110, 25,
-13, -92, 43,
-38, -92, 43,
-38, -101, 21,
-13, -101, 21,
-65, -119, 87,
-52, -83, 74,
-18, -81, 79,
-13, -115, 94,
-5, -140, 37,
-10, -122, 29,
-41, -124, 24,
-44, -142, 32,
-39, -99, 104,
-10, -100, 59,
-5, -126, 70,
-55, -103, 52,
-59, -129, 63,
65, -119, 87,
52, -83, 74,
18, -81, 79,
13, -115, 94,
5, -140, 37,
10, -122, 29,
41, -124, 24,
44, -142, 32,
39, -99, 104,
10, -100, 59,
5, -126, 70,
55, -103, 52,
59, -129, 63,
110, 19, 5,
94, 9, 2,
94, 13, -10,
110, 23, -7,
127, -3, 1,
116, 8, 6,
103, 0, 3,
113, -12, 0,
113, -6, -24,
103, 6, -17,
116, 14, -14,
127, 3, -22,
124, -10, -11,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:26 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_26[]={
88, 156, 27,
64, 177, -31,
13, 185, -46,
-32, 185, -6,
-49, 168, 62,
-34, 163, 100,
25, 155, 102,
82, 153, 70,
-14, 160, 96,
25, 161, 88,
62, 154, 77,
71, 158, 32,
63, 172, -19,
13, 178, -30,
-30, 180, 4,
-32, 166, 58,
53, 117, 19,
38, 136, -17,
5, 146, -25,
-28, 141, 0,
-41, 125, 43,
-26, 106, 80,
39, 100, 63,
15, 106, 23,
11, 113, 8,
0, 116, 2,
-11, 113, 8,
-15, 106, 23,
-18, 99, 37,
1, 97, 48,
18, 99, 37,
74, 196, -29,
92, 176, 33,
77, 172, 80,
31, 176, 105,
-17, 180, 104,
-41, 187, 67,
-30, 205, -3,
19, 206, -45,
67, 280, -11,
66, 272, 2,
69, 284, 10,
49, 271, 36,
31, 288, 20,
24, 275, 13,
24, 283, -1,
43, 276, -14,
-22, 129, 100,
53, 123, 81,
-34, 140, 88,
-46, 142, 62,
-51, 143, 63,
-42, 141, 89,
72, 132, 32,
67, 132, 63,
75, 131, 60,
77, 132, 31,
-52, 122, 66,
67, 111, 35,
58, 149, -23,
71, 137, 18,
78, 136, 16,
58, 154, -32,
-39, 162, -7,
-54, 148, 49,
-47, 147, 48,
-39, 158, 1,
53, 116, -13,
-50, 125, 12,
11, 156, -37,
52, 151, -28,
60, 155, -40,
10, 162, -51,
-34, 159, -6,
2, 157, -35,
2, 163, -48,
-42, 164, -14,
-25, 130, -15,
26, 126, -28,
-15, 219, 91,
40, 217, 88,
92, 210, 63,
46, 274, 11,
35, 217, 98,
28, 183, 112,
-12, 186, 112,
-13, 219, 101,
78, 178, 88,
40, 182, 109,
48, 216, 95,
93, 210, 74,
15, 123, 96,
43, 184, 104,
49, 212, 92,
87, 207, 75,
75, 181, 86,
31, 213, 97,
25, 186, 108,
-8, 188, 108,
-9, 215, 99,
-44, 2, 32,
-47, 94, 29,
47, 94, 29,
44, 2, 32,
44, 18, -34,
46, 103, -7,
-46, 103, -7,
-44, 18, -34,
11, 105, 23,
-11, 105, 23,
-11, 110, 1,
11, 110, 1,
41, 27, 35,
-41, 27, 35,
40, 42, -27,
-40, 42, -27,
45, 72, 31,
44, 83, -14,
-45, 72, 31,
-44, 83, -14,
-81, 67, 26,
-57, 93, 28,
-49, 63, 21,
-51, 47, 21,
-51, 55, -11,
-49, 70, -4,
-57, 99, 2,
-81, 75, -7,
81, 67, 26,
57, 93, 28,
49, 63, 21,
51, 47, 21,
51, 55, -11,
49, 70, -4,
57, 99, 2,
81, 75, -7,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -14, 1,
5, -14, 1,
6, -17, -8,
-5, -17, -8,
-53, -62, 36,
-46, -16, 18,
0, -11, 16,
0, -62, 36,
0, -77, -7,
-1, -25, -23,
-45, -30, -22,
-53, -77, -7,
53, -62, 36,
46, -16, 18,
0, -9, 12,
0, -62, 36,
0, -77, -7,
1, -25, -23,
45, -30, -22,
53, -77, -7,
55, 57, -7,
55, 50, 18,
78, 66, 22,
78, 72, -4,
-55, 50, 18,
-55, 57, -7,
-78, 72, -4,
-78, 66, 22,
-110, 19, 4,
-94, 8, 1,
-94, 11, -11,
-110, 22, -8,
-127, -4, 1,
-116, 7, 5,
-103, 0, 3,
-113, -14, 0,
-113, -8, -24,
-103, 4, -17,
-116, 12, -15,
-127, 0, -22,
-124, -12, -10,
-11, -74, 1,
-41, -74, 1,
-41, -65, 26,
-11, -65, 26,
11, -65, 26,
41, -65, 26,
41, -74, 1,
11, -74, 1,
38, -103, 40,
38, -73, 29,
13, -73, 29,
13, -103, 40,
13, -111, 17,
13, -81, 7,
38, -81, 7,
38, -111, 17,
13, -94, 36,
38, -94, 36,
38, -102, 14,
13, -102, 14,
-38, -103, 40,
-38, -73, 29,
-13, -73, 29,
-13, -103, 40,
-13, -111, 17,
-13, -81, 7,
-38, -81, 7,
-38, -111, 17,
-13, -94, 36,
-38, -94, 36,
-38, -102, 14,
-13, -102, 14,
-65, -124, 78,
-52, -88, 68,
-18, -86, 73,
-13, -121, 86,
-5, -142, 27,
-10, -123, 20,
-41, -125, 15,
-44, -144, 21,
-39, -106, 97,
-10, -103, 51,
-5, -130, 61,
-55, -105, 45,
-59, -132, 53,
65, -124, 78,
52, -88, 68,
18, -86, 73,
13, -121, 86,
5, -142, 27,
10, -123, 20,
41, -125, 15,
44, -144, 21,
39, -106, 97,
10, -103, 51,
5, -130, 61,
55, -105, 45,
59, -132, 53,
110, 19, 4,
94, 8, 1,
94, 11, -11,
110, 22, -8,
127, -4, 1,
116, 7, 5,
103, 0, 3,
113, -14, 0,
113, -8, -24,
103, 4, -17,
116, 12, -15,
127, 0, -22,
124, -12, -10,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:27 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_27[]={
86, 163, 21,
62, 177, -40,
10, 182, -59,
-36, 184, -21,
-54, 172, 49,
-40, 171, 89,
20, 166, 95,
78, 163, 66,
-19, 169, 87,
20, 171, 80,
58, 164, 71,
68, 164, 25,
60, 173, -28,
10, 176, -42,
-34, 180, -9,
-37, 171, 46,
53, 120, 15,
38, 135, -24,
4, 143, -35,
-29, 139, -10,
-43, 126, 34,
-28, 111, 74,
39, 106, 61,
15, 107, 18,
11, 113, 2,
0, 115, -4,
-11, 113, 2,
-15, 107, 18,
-18, 102, 34,
1, 101, 44,
18, 102, 34,
70, 197, -40,
88, 183, 26,
72, 183, 74,
25, 188, 96,
-24, 190, 93,
-47, 192, 54,
-36, 204, -19,
15, 203, -60,
58, 284, -30,
57, 277, -14,
59, 291, -7,
39, 280, 19,
20, 294, 0,
15, 280, -6,
14, 287, -21,
34, 279, -33,
-26, 137, 93,
51, 132, 78,
-39, 147, 80,
-50, 146, 52,
-55, 146, 53,
-46, 148, 80,
70, 138, 28,
65, 140, 59,
73, 140, 56,
76, 138, 27,
-55, 125, 57,
67, 117, 33,
57, 149, -30,
70, 141, 13,
77, 141, 11,
57, 153, -40,
-42, 159, -20,
-57, 150, 38,
-50, 149, 37,
-42, 156, -10,
54, 116, -18,
-52, 123, 2,
9, 153, -48,
51, 151, -36,
59, 154, -48,
9, 158, -62,
-37, 157, -18,
0, 154, -46,
0, 158, -60,
-45, 161, -27,
-25, 127, -25,
26, 124, -35,
-24, 229, 76,
32, 228, 76,
86, 221, 54,
36, 279, -7,
27, 229, 86,
21, 196, 103,
-20, 197, 100,
-22, 230, 86,
72, 191, 82,
33, 195, 100,
39, 229, 83,
86, 223, 65,
12, 133, 91,
36, 197, 95,
41, 224, 81,
80, 219, 66,
69, 193, 79,
23, 225, 85,
18, 198, 99,
-16, 199, 96,
-18, 226, 85,
-44, 3, 32,
-47, 95, 24,
47, 95, 24,
44, 3, 32,
44, 15, -35,
46, 102, -12,
-46, 102, -12,
-44, 15, -35,
11, 105, 18,
-11, 105, 18,
-11, 109, -3,
11, 109, -3,
41, 28, 34,
-41, 28, 34,
40, 40, -29,
-40, 40, -29,
45, 73, 27,
44, 81, -18,
-45, 73, 27,
-44, 81, -18,
-81, 67, 23,
-57, 94, 24,
-49, 64, 18,
-51, 48, 19,
-51, 54, -14,
-49, 69, -8,
-57, 99, -2,
-81, 74, -11,
81, 67, 23,
57, 94, 24,
49, 64, 18,
51, 48, 19,
51, 54, -14,
49, 69, -8,
57, 99, -2,
81, 74, -11,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -13, 0,
5, -13, 0,
6, -15, -9,
-5, -15, -9,
-53, -64, 32,
-46, -16, 16,
0, -11, 15,
0, -64, 32,
0, -76, -13,
-1, -22, -26,
-45, -27, -24,
-53, -76, -13,
53, -64, 32,
46, -16, 16,
0, -9, 12,
0, -64, 32,
0, -76, -13,
1, -22, -26,
45, -27, -24,
53, -76, -13,
55, 55, -10,
55, 50, 16,
78, 66, 19,
78, 71, -7,
-55, 50, 16,
-55, 55, -10,
-78, 71, -7,
-78, 66, 19,
-110, 18, 2,
-94, 7, 0,
-94, 9, -12,
-110, 20, -10,
-127, -5, 1,
-116, 6, 5,
-103, -1, 3,
-113, -15, 0,
-113, -10, -24,
-103, 2, -17,
-116, 10, -16,
-127, -1, -22,
-124, -13, -10,
-11, -73, -3,
-41, -73, -3,
-41, -66, 22,
-11, -66, 22,
11, -66, 22,
41, -66, 22,
41, -73, -3,
11, -73, -3,
38, -105, 32,
38, -75, 24,
13, -75, 24,
13, -105, 32,
13, -112, 9,
13, -81, 1,
38, -81, 1,
38, -112, 9,
13, -96, 30,
38, -96, 30,
38, -102, 6,
13, -102, 6,
-38, -105, 32,
-38, -75, 24,
-13, -75, 24,
-13, -105, 32,
-13, -112, 9,
-13, -81, 1,
-38, -81, 1,
-38, -112, 9,
-13, -96, 30,
-38, -96, 30,
-38, -102, 6,
-13, -102, 6,
-65, -129, 70,
-52, -92, 62,
-18, -90, 67,
-13, -127, 78,
-5, -143, 17,
-10, -124, 11,
-41, -126, 6,
-44, -145, 11,
-39, -112, 90,
-10, -106, 44,
-5, -134, 53,
-55, -108, 37,
-59, -136, 44,
65, -129, 70,
52, -92, 62,
18, -90, 67,
13, -127, 78,
5, -143, 17,
10, -124, 11,
41, -126, 6,
44, -145, 11,
39, -112, 90,
10, -106, 44,
5, -134, 53,
55, -108, 37,
59, -136, 44,
110, 18, 2,
94, 7, 0,
94, 9, -12,
110, 20, -10,
127, -5, 1,
116, 6, 5,
103, -1, 3,
113, -15, 0,
113, -10, -24,
103, 2, -17,
116, 10, -16,
127, -1, -22,
124, -13, -10,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:28 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_28[]={
83, 169, 16,
60, 177, -50,
8, 178, -72,
-41, 182, -35,
-60, 176, 37,
-46, 179, 79,
15, 177, 88,
75, 173, 61,
-25, 178, 77,
15, 181, 72,
54, 174, 65,
65, 170, 19,
58, 174, -37,
8, 174, -54,
-39, 179, -23,
-42, 175, 35,
52, 123, 11,
38, 134, -31,
3, 140, -45,
-31, 138, -21,
-45, 128, 25,
-30, 116, 69,
38, 113, 58,
15, 109, 13,
11, 113, -3,
0, 115, -10,
-11, 113, -3,
-15, 109, 13,
-18, 105, 30,
1, 104, 40,
18, 105, 30,
67, 198, -51,
85, 191, 19,
66, 195, 67,
19, 200, 88,
-31, 200, 82,
-54, 198, 40,
-41, 203, -35,
11, 200, -75,
50, 289, -49,
49, 283, -32,
49, 298, -26,
29, 288, 1,
10, 300, -20,
5, 285, -25,
5, 291, -42,
26, 282, -52,
-30, 145, 86,
49, 142, 74,
-43, 154, 71,
-53, 150, 42,
-59, 150, 42,
-51, 154, 71,
69, 144, 24,
63, 149, 55,
71, 148, 53,
74, 143, 23,
-58, 128, 49,
67, 122, 31,
56, 149, -37,
68, 145, 8,
76, 145, 7,
56, 152, -48,
-45, 157, -33,
-61, 152, 27,
-54, 151, 26,
-45, 154, -22,
55, 116, -22,
-53, 121, -7,
8, 150, -59,
50, 150, -44,
58, 152, -56,
8, 153, -74,
-39, 154, -31,
0, 150, -57,
0, 154, -72,
-48, 157, -40,
-26, 124, -34,
27, 121, -42,
-33, 238, 61,
24, 240, 64,
79, 233, 45,
27, 285, -25,
18, 242, 74,
14, 209, 94,
-27, 208, 89,
-31, 241, 72,
67, 203, 75,
27, 208, 92,
31, 241, 72,
79, 235, 56,
9, 142, 87,
30, 210, 86,
33, 236, 70,
73, 231, 57,
63, 205, 72,
14, 237, 73,
11, 210, 89,
-23, 210, 85,
-27, 236, 71,
-44, 3, 32,
-47, 96, 19,
47, 96, 19,
44, 3, 32,
44, 13, -37,
46, 101, -18,
-46, 101, -18,
-44, 13, -37,
11, 106, 13,
-11, 106, 13,
-11, 109, -9,
11, 109, -9,
41, 29, 33,
-41, 29, 33,
40, 38, -31,
-40, 38, -31,
45, 74, 24,
44, 80, -22,
-45, 74, 24,
-44, 80, -22,
-81, 68, 19,
-57, 95, 19,
-49, 64, 15,
-51, 48, 17,
-51, 53, -17,
-49, 68, -11,
-57, 98, -7,
-81, 73, -14,
81, 68, 19,
57, 95, 19,
49, 64, 15,
51, 48, 17,
51, 53, -17,
49, 68, -11,
57, 98, -7,
81, 73, -14,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -11, 0,
5, -11, 0,
6, -13, -11,
-5, -13, -11,
-53, -65, 27,
-46, -16, 15,
0, -10, 14,
0, -65, 27,
0, -74, -19,
-1, -18, -28,
-45, -24, -27,
-53, -74, -19,
53, -65, 27,
46, -16, 15,
0, -9, 12,
0, -65, 27,
0, -74, -19,
1, -18, -28,
45, -24, -27,
53, -74, -19,
55, 54, -13,
55, 51, 13,
78, 66, 15,
78, 70, -11,
-55, 51, 13,
-55, 54, -13,
-78, 70, -11,
-78, 66, 15,
-110, 17, 1,
-94, 6, 0,
-94, 8, -12,
-110, 19, -11,
-127, -6, 1,
-116, 6, 4,
-103, -2, 3,
-113, -16, 0,
-113, -13, -24,
-103, 0, -18,
-116, 9, -17,
-127, -3, -23,
-124, -15, -9,
-11, -72, -9,
-41, -72, -9,
-41, -67, 17,
-11, -67, 17,
11, -67, 17,
41, -67, 17,
41, -72, -9,
11, -72, -9,
38, -108, 25,
38, -76, 19,
13, -76, 19,
13, -108, 25,
13, -112, 1,
13, -81, -4,
38, -81, -4,
38, -112, 1,
13, -98, 23,
38, -98, 23,
38, -103, 0,
13, -103, 0,
-38, -108, 25,
-38, -76, 19,
-13, -76, 19,
-13, -108, 25,
-13, -112, 1,
-13, -81, -4,
-38, -81, -4,
-38, -112, 1,
-13, -98, 23,
-38, -98, 23,
-38, -103, 0,
-13, -103, 0,
-65, -135, 62,
-52, -96, 56,
-18, -95, 62,
-13, -133, 70,
-5, -145, 7,
-10, -125, 2,
-41, -126, -2,
-44, -146, 1,
-39, -119, 83,
-10, -109, 37,
-5, -138, 44,
-55, -111, 30,
-59, -140, 35,
65, -135, 62,
52, -96, 56,
18, -95, 62,
13, -133, 70,
5, -145, 7,
10, -125, 2,
41, -126, -2,
44, -146, 1,
39, -119, 83,
10, -109, 37,
5, -138, 44,
55, -111, 30,
59, -140, 35,
110, 17, 1,
94, 6, 0,
94, 8, -12,
110, 19, -11,
127, -6, 1,
116, 6, 4,
103, -2, 3,
113, -16, 0,
113, -13, -24,
103, 0, -18,
116, 9, -17,
127, -3, -23,
124, -15, -9,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:29 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_29[]={
81, 176, 10,
58, 177, -60,
5, 175, -86,
-45, 181, -50,
-65, 180, 24,
-52, 188, 68,
10, 188, 81,
71, 184, 56,
-31, 187, 68,
10, 190, 64,
50, 184, 60,
62, 176, 12,
56, 175, -46,
5, 172, -67,
-43, 179, -37,
-47, 180, 23,
52, 126, 7,
37, 134, -38,
2, 138, -54,
-33, 136, -31,
-47, 129, 17,
-32, 122, 63,
38, 119, 56,
15, 111, 9,
11, 113, -8,
0, 114, -16,
-11, 113, -8,
-15, 111, 9,
-18, 108, 27,
0, 107, 36,
18, 108, 27,
64, 199, -62,
81, 199, 13,
61, 206, 61,
12, 212, 79,
-38, 209, 71,
-60, 203, 26,
-47, 202, -52,
7, 198, -89,
41, 293, -67,
40, 289, -49,
40, 305, -44,
19, 296, -16,
0, 306, -40,
-3, 290, -45,
-4, 295, -63,
17, 285, -72,
-34, 153, 79,
46, 151, 71,
-47, 160, 62,
-57, 153, 32,
-63, 153, 32,
-55, 161, 62,
67, 149, 20,
60, 157, 52,
68, 157, 50,
73, 149, 19,
-60, 131, 40,
67, 127, 28,
56, 149, -45,
67, 150, 3,
75, 149, 2,
56, 151, -56,
-48, 154, -46,
-65, 154, 15,
-57, 154, 15,
-48, 153, -35,
56, 115, -27,
-54, 119, -16,
7, 146, -69,
49, 149, -52,
58, 151, -64,
7, 149, -85,
-42, 152, -43,
-1, 147, -68,
-1, 149, -84,
-51, 154, -54,
-27, 120, -44,
27, 119, -49,
-42, 248, 46,
16, 252, 52,
73, 244, 35,
18, 291, -44,
10, 254, 62,
7, 221, 85,
-35, 219, 77,
-40, 251, 57,
61, 216, 68,
20, 221, 83,
23, 254, 60,
72, 248, 46,
6, 151, 82,
23, 222, 78,
25, 249, 59,
67, 244, 47,
57, 218, 65,
6, 249, 61,
4, 223, 80,
-31, 221, 73,
-35, 247, 57,
-44, 4, 32,
-47, 97, 15,
47, 97, 15,
44, 4, 32,
44, 10, -38,
46, 100, -23,
-46, 100, -23,
-44, 10, -38,
11, 106, 8,
-11, 106, 8,
-11, 108, -14,
11, 108, -14,
41, 30, 31,
-41, 30, 31,
40, 35, -34,
-40, 35, -34,
45, 74, 20,
44, 79, -26,
-45, 74, 20,
-44, 79, -26,
-81, 68, 16,
-57, 95, 15,
-49, 64, 12,
-51, 48, 14,
-51, 51, -20,
-49, 67, -15,
-57, 98, -12,
-81, 72, -18,
81, 68, 16,
57, 95, 15,
49, 64, 12,
51, 48, 14,
51, 51, -20,
49, 67, -15,
57, 98, -12,
81, 72, -18,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -10, -1,
5, -10, -1,
6, -11, -12,
-5, -11, -12,
-53, -67, 23,
-46, -16, 14,
0, -10, 13,
0, -67, 23,
0, -73, -25,
-1, -15, -30,
-45, -21, -29,
-53, -73, -25,
53, -67, 23,
46, -16, 14,
0, -9, 12,
0, -67, 23,
0, -73, -25,
1, -15, -30,
45, -21, -29,
53, -73, -25,
55, 53, -16,
55, 51, 11,
78, 67, 12,
78, 69, -15,
-55, 51, 11,
-55, 53, -16,
-78, 69, -15,
-78, 67, 12,
-110, 16, 0,
-94, 5, 0,
-94, 6, -13,
-110, 17, -12,
-127, -7, 2,
-116, 5, 4,
-103, -3, 3,
-113, -17, 1,
-113, -15, -24,
-103, -1, -18,
-116, 7, -18,
-127, -5, -23,
-124, -17, -9,
-11, -72, -14,
-41, -72, -14,
-41, -68, 13,
-11, -68, 13,
11, -68, 13,
41, -68, 13,
41, -72, -14,
11, -72, -14,
38, -110, 18,
38, -77, 14,
13, -77, 14,
13, -110, 18,
13, -113, -6,
13, -80, -10,
38, -80, -10,
38, -113, -6,
13, -100, 17,
38, -100, 17,
38, -103, -7,
13, -103, -7,
-38, -110, 18,
-38, -77, 14,
-13, -77, 14,
-13, -110, 18,
-13, -113, -6,
-13, -80, -10,
-38, -80, -10,
-38, -113, -6,
-13, -100, 17,
-38, -100, 17,
-38, -103, -7,
-13, -103, -7,
-65, -140, 53,
-52, -100, 51,
-18, -100, 56,
-13, -139, 62,
-5, -147, -2,
-10, -127, -6,
-41, -127, -11,
-44, -148, -9,
-39, -125, 76,
-10, -113, 30,
-5, -142, 35,
-55, -114, 23,
-59, -143, 26,
65, -140, 53,
52, -100, 51,
18, -100, 56,
13, -139, 62,
5, -147, -2,
10, -127, -6,
41, -127, -11,
44, -148, -9,
39, -125, 76,
10, -113, 30,
5, -142, 35,
55, -114, 23,
59, -143, 26,
110, 16, 0,
94, 5, 0,
94, 6, -13,
110, 17, -12,
127, -7, 2,
116, 5, 4,
103, -3, 3,
113, -17, 1,
113, -15, -24,
103, -1, -18,
116, 7, -18,
127, -5, -23,
124, -17, -9,
};

/* ============================================================
          Raw Data Array(Vertex)
 ============================================================ */
/* #:30 name:#<POLYHEDRON_246> */
static s16 vtxgrp_frake_select_30[]={
78, 182, 5,
55, 178, -70,
2, 171, -99,
-49, 179, -65,
-70, 184, 12,
-58, 196, 58,
5, 199, 75,
68, 194, 52,
-36, 196, 58,
5, 200, 56,
46, 194, 54,
60, 182, 6,
54, 177, -55,
2, 170, -79,
-47, 178, -51,
-52, 184, 11,
52, 129, 3,
37, 133, -45,
1, 135, -64,
-35, 134, -42,
-49, 131, 8,
-34, 127, 58,
37, 126, 54,
15, 112, 4,
11, 114, -14,
0, 114, -22,
-11, 114, -14,
-15, 112, 4,
-18, 111, 23,
0, 110, 32,
18, 111, 23,
61, 200, -73,
77, 206, 6,
56, 218, 55,
6, 224, 71,
-44, 219, 59,
-67, 209, 12,
-52, 202, -68,
3, 195, -104,
32, 298, -86,
31, 295, -67,
30, 312, -63,
9, 304, -33,
-10, 313, -61,
-13, 295, -65,
-14, 298, -83,
8, 289, -91,
-38, 162, 72,
44, 160, 68,
-52, 167, 53,
-61, 157, 22,
-67, 157, 22,
-60, 167, 52,
66, 155, 16,
58, 165, 48,
66, 165, 46,
72, 155, 15,
-63, 135, 32,
66, 133, 26,
55, 149, -52,
66, 154, -1,
74, 154, -1,
55, 150, -64,
-51, 152, -59,
-69, 156, 4,
-61, 156, 4,
-51, 151, -47,
56, 115, -31,
-56, 117, -26,
6, 143, -80,
48, 148, -60,
57, 149, -73,
5, 144, -97,
-45, 150, -56,
-3, 143, -80,
-3, 144, -96,
-53, 151, -67,
-27, 117, -54,
28, 116, -56,
-50, 258, 31,
8, 263, 39,
66, 256, 26,
9, 296, -62,
1, 267, 49,
0, 234, 76,
-42, 230, 66,
-49, 262, 43,
56, 228, 61,
13, 234, 75,
15, 267, 49,
66, 260, 37,
3, 160, 77,
16, 235, 69,
17, 261, 48,
60, 256, 38,
52, 230, 58,
-1, 261, 49,
-2, 235, 70,
-38, 231, 62,
-44, 257, 43,
-44, 4, 31,
-47, 97, 10,
47, 97, 10,
44, 4, 31,
44, 7, -39,
46, 99, -28,
-46, 99, -28,
-44, 7, -39,
11, 107, 2,
-11, 107, 2,
-11, 108, -20,
11, 108, -20,
41, 30, 30,
-41, 30, 30,
40, 33, -36,
-40, 33, -36,
45, 75, 17,
44, 77, -31,
-45, 75, 17,
-44, 77, -31,
-81, 69, 13,
-57, 96, 10,
-49, 64, 9,
-51, 48, 12,
-51, 50, -23,
-49, 66, -18,
-57, 97, -17,
-81, 71, -22,
81, 69, 13,
57, 96, 10,
49, 64, 9,
51, 48, 12,
51, 50, -23,
49, 66, -18,
57, 97, -17,
81, 71, -22,
-30, -1, 22,
30, -1, 22,
29, -1, -37,
-30, -1, -37,
-5, -9, -3,
5, -9, -3,
6, -9, -14,
-5, -9, -14,
-53, -69, 19,
-46, -16, 13,
0, -9, 12,
0, -69, 19,
0, -72, -31,
-1, -12, -32,
-45, -19, -32,
-53, -72, -31,
53, -69, 19,
46, -16, 13,
0, -9, 12,
0, -69, 19,
0, -72, -31,
1, -12, -32,
45, -19, -32,
53, -72, -31,
55, 52, -19,
55, 51, 8,
78, 67, 9,
78, 68, -18,
-55, 51, 8,
-55, 52, -19,
-78, 68, -18,
-78, 67, 9,
-110, 15, 0,
-94, 4, 0,
-94, 5, -14,
-110, 16, -13,
-127, -8, 2,
-116, 4, 3,
-103, -4, 3,
-113, -18, 1,
-113, -17, -24,
-103, -3, -19,
-116, 5, -18,
-127, -7, -23,
-124, -18, -9,
-11, -71, -20,
-41, -71, -20,
-41, -69, 8,
-11, -69, 8,
11, -69, 8,
41, -69, 8,
41, -71, -20,
11, -71, -20,
38, -112, 11,
38, -78, 9,
13, -78, 9,
13, -112, 11,
13, -114, -14,
13, -80, -16,
38, -80, -16,
38, -114, -14,
13, -102, 10,
38, -102, 10,
38, -103, -15,
13, -103, -15,
-38, -112, 11,
-38, -78, 9,
-13, -78, 9,
-13, -112, 11,
-13, -114, -14,
-13, -80, -16,
-38, -80, -16,
-38, -114, -14,
-13, -102, 10,
-38, -102, 10,
-38, -103, -15,
-13, -103, -15,
-65, -145, 45,
-52, -104, 45,
-18, -104, 50,
-13, -145, 54,
-5, -149, -13,
-10, -128, -15,
-41, -128, -20,
-44, -149, -19,
-39, -132, 69,
-10, -116, 23,
-5, -146, 26,
-55, -116, 15,
-59, -147, 16,
65, -145, 45,
52, -104, 45,
18, -104, 50,
13, -145, 54,
5, -149, -13,
10, -128, -15,
41, -128, -20,
44, -149, -19,
39, -132, 69,
10, -116, 23,
5, -146, 26,
55, -116, 15,
59, -147, 16,
110, 15, 0,
94, 4, 0,
94, 5, -14,
110, 16, -13,
127, -8, 2,
116, 4, 3,
103, -4, 3,
113, -18, 1,
113, -17, -24,
103, -3, -19,
116, 5, -18,
127, -7, -23,
124, -18, -9,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:0 */
static s8 vtxnvgrp_frake_select_0[]={
0, -126, 0,
0, -50, -116,
0, -58, -112,
0, -58, -112,
0, -126, 0,
0, -126, 0,
64, 90, 61,
0, 126, 0,
113, -1, -56,
113, -1, -56,
0, 126, 0,
0, 99, -78,
0, 99, -78,
0, 126, 0,
-113, -1, -56,
-113, -1, -56,
0, 126, 0,
0, -126, 0,
0, -126, 0,
-113, 0, -57,
0, -126, 0,
64, 90, 61,
0, -126, 0,
0, -126, 0,
113, 0, -57,
0, 114, -54,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 114, -54,
-113, 0, -57,
-113, 0, -57,
0, 114, -54,
0, -126, 0,
0, -126, 0,
-72, 0, -104,
0, -53, -115,
0, -53, -115,
72, 0, -104,
0, -126, 0,
0, -126, 0,
0, 114, -54,
113, 0, -57,
0, 126, 0,
-102, 0, 75,
-71, 89, 53,
0, 126, 0,
0, 126, 0,
126, 0, -9,
122, 0, 32,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -58, -112,
0, -58, -112,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
-122, 0, 32,
-126, 0, -9,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, -5,
0, 126, -5,
0, 126, 0,
0, 126, 0,
0, 126, 0,
102, 0, 75,
122, 0, 32,
122, 0, 32,
102, 0, 75,
125, 0, 18,
-125, 0, 18,
-102, 0, 75,
-122, 0, 32,
-122, 0, 32,
-102, 0, 75,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
70, 0, 105,
0, 126, 0,
0, 126, 0,
0, -126, 0,
113, 0, -57,
64, 90, 61,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -53, -115,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
118, 0, -46,
0, -126, 0,
0, -126, 0,
-124, 0, -24,
-126, 0, -9,
-126, 0, -9,
0, -126, 0,
0, -126, 0,
0, -126, 0,
118, 0, -46,
0, -126, 0,
118, 0, -46,
86, 89, -24,
0, 126, 0,
0, 126, 0,
86, 89, -24,
-124, 0, -24,
-124, 0, -24,
86, 89, -24,
0, -126, 0,
0, -126, 0,
86, 89, -24,
118, 0, -46,
64, 90, 61,
-118, 0, -46,
0, -126, 0,
0, -126, 0,
-118, 0, -46,
0, -126, 0,
0, -126, 0,
0, -126, 0,
126, 0, -9,
126, 0, -9,
124, 0, -24,
64, 90, 61,
0, 126, 0,
-86, 89, -24,
-118, 0, -46,
-118, 0, -46,
-86, 89, -24,
0, -126, 0,
0, -126, 0,
-86, 89, -24,
124, 0, -24,
124, 0, -24,
-86, 89, -24,
0, 126, 0,
113, -1, -56,
0, -126, 0,
64, 90, 61,
64, 90, 61,
0, -126, 0,
126, 0, -9,
126, 0, -9,
123, 0, -28,
0, 126, 0,
0, 126, 0,
-4, 126, 0,
113, -1, -56,
-126, -4, -11,
-87, -91, -8,
0, -126, 0,
0, -126, 0,
-87, -91, -8,
123, 0, -28,
123, 0, -28,
-87, -91, -8,
-4, 126, 0,
-4, 126, 0,
-87, -91, -8,
-126, -4, -11,
0, 126, 0,
-123, 0, -28,
-126, 0, -9,
-126, 0, -9,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
-113, -1, -56,
-113, -1, -56,
4, 126, 0,
0, 126, 0,
4, 126, 0,
-82, 91, -31,
-123, 0, -28,
-123, 0, -28,
-82, 91, -31,
0, -126, 0,
0, -126, 0,
-82, 91, -31,
126, -4, -11,
126, -4, -11,
-82, 91, -31,
4, 126, 0,
0, 99, -78,
0, -126, 0,
113, -1, -56,
113, -1, -56,
0, -126, 0,
0, 126, 0,
0, 126, 0,
-80, 94, -27,
0, 126, -5,
0, 126, -5,
-80, 94, -27,
0, 99, -78,
-94, -61, -58,
-46, -110, -42,
0, -126, 0,
0, -126, 0,
-46, -110, -42,
89, 89, 9,
89, 89, 9,
-46, -110, -42,
-80, 94, -27,
-80, 94, -27,
-46, -110, -42,
-94, -61, -58,
-113, -1, -56,
0, -126, 0,
0, 99, -78,
0, 99, -78,
80, 94, -27,
0, 126, -5,
0, 126, -5,
80, 94, -27,
0, 126, 0,
0, 126, 0,
0, -126, 0,
-113, -1, -56,
0, -126, 0,
46, -110, -42,
94, -61, -58,
94, -61, -58,
46, -110, -42,
80, 94, -27,
80, 94, -27,
46, -110, -42,
-121, 0, -36,
-121, 0, -36,
46, -110, -42,
0, -126, 0,
0, -126, 0,
0, 0, 126,
-125, 0, 18,
125, 0, 18,
0, 0, 126,
0, -126, 0,
0, -126, 0,
64, 90, 61,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -50, -116,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -50, -116,
0, -126, 0,
0, -126, 0,
0, -50, -116,
125, 0, 18,
0, -126, 0,
122, 0, 32,
-122, 0, 32,
0, -126, 0,
-125, 0, 18,
0, -126, 0,
126, 0, -9,
122, 0, 32,
-122, 0, 32,
-126, 0, -9,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -127, 0,
0, 126, 0,
0, 0, 126,
39, 0, 120,
0, 126, 0,
39, 0, 120,
102, 0, 75,
0, 126, 0,
102, 0, 75,
70, 0, 105,
-71, 89, 53,
0, 0, 126,
0, 126, 0,
0, 126, 0,
-70, 0, 105,
-102, 0, 75,
0, 126, 0,
0, 126, 0,
-70, 0, 105,
0, -126, 0,
0, -127, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
-89, 0, 89,
-125, 0, 18,
-125, 0, 18,
45, -89, 77,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -127, 0,
0, -126, 0,
0, -126, 0,
-25, 0, 124,
125, 0, 18,
125, 0, 18,
89, -89, 11,
0, -126, 0,
89, -89, 11,
0, -126, 0,
0, -126, 0,
-25, 0, 124,
89, -89, 11,
125, 0, 18,
0, -127, 0,
-25, 0, 124,
0, -126, 0,
0, -126, 0,
0, -127, 0,
0, -126, 0,
-125, 0, 18,
-89, 0, 89,
45, -89, 77,
0, -126, 0,
0, -126, 0,
-89, 0, 89,
0, -126, 0,
0, -127, 0,
0, -126, 0,
0, -126, 0,
45, -89, 77,
0, -127, 0,
125, 0, 18,
39, 0, 120,
0, 0, 126,
0, 0, 126,
-71, 89, 53,
-125, 0, 18,
0, 126, 0,
-121, 0, -36,
0, -126, 0,
80, 94, -27,
-121, 0, -36,
0, 126, 0,
0, 99, -78,
94, -61, -58,
80, 94, -27,
0, -126, 0,
94, -61, -58,
0, 99, -78,
-80, 94, -27,
-94, -61, -58,
0, 99, -78,
0, 126, 0,
89, 89, 9,
-80, 94, -27,
0, -126, 0,
89, 89, 9,
0, 126, 0,
0, 99, -78,
-94, -61, -58,
0, -126, 0,
-113, -1, -56,
126, -4, -11,
4, 126, 0,
0, -126, 0,
126, -4, -11,
-113, -1, -56,
-126, 0, -9,
-123, 0, -28,
0, -126, 0,
0, 126, 0,
4, 126, 0,
-123, 0, -28,
-4, 126, 0,
-126, -4, -11,
113, -1, -56,
123, 0, -28,
-4, 126, 0,
0, 126, 0,
0, -126, 0,
123, 0, -28,
126, 0, -9,
113, -1, -56,
-126, -4, -11,
0, -126, 0,
124, 0, -24,
0, 126, 0,
64, 90, 61,
0, -126, 0,
124, 0, -24,
126, 0, -9,
-118, 0, -46,
0, -126, 0,
0, -126, 0,
64, 90, 61,
0, 126, 0,
-118, 0, -46,
0, -126, 0,
0, -126, 0,
118, 0, -46,
-126, 0, -9,
-124, 0, -24,
0, -126, 0,
0, -126, 0,
0, 126, 0,
-124, 0, -24,
118, 0, -46,
0, 126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, 126, 0,
70, 0, 105,
0, 126, 0,
0, 126, 0,
-70, 0, 105,
0, 126, 0,
-102, 0, 75,
-70, 0, 105,
0, 126, 0,
-125, 0, 18,
-71, 89, 53,
-102, 0, 75,
102, 0, 75,
39, 0, 120,
125, 0, 18,
0, 126, 0,
70, 0, 105,
102, 0, 75,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
-126, 0, -9,
-122, 0, 32,
0, 126, 0,
0, -58, -112,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -58, -112,
0, 126, 0,
122, 0, 32,
126, 0, -9,
0, 114, -54,
72, 0, -104,
-72, 0, -104,
72, 0, -104,
0, -53, -115,
-72, 0, -104,
0, 114, -54,
-72, 0, -104,
0, 114, -54,
0, -126, 0,
72, 0, -104,
0, 114, -54,
0, 114, -54,
-72, 0, -104,
0, -126, 0,
0, 126, 0,
0, 126, 0,
0, 114, -54,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 114, -54,
0, 126, 0,
0, 126, 0,
0, 126, 0,
-113, 0, -57,
0, -126, 0,
0, 126, 0,
0, 126, 0,
-113, -1, -56,
113, -1, -56,
0, 126, 0,
0, 126, 0,
64, 90, 61,
113, 0, -57,
0, 126, 0,
0, -58, -112,
0, -50, -116,
0, -126, 0,
0, -58, -112,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -50, -116,
0, -127, 0,
0, -126, 0,
-25, 0, 124,
-25, 0, 124,
0, -127, 0,
89, -89, 11,
89, -89, 11,
0, -127, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -127, 0,
45, -89, 77,
0, -126, 0,
0, -127, 0,
0, -127, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -127, 0,
-89, 0, 89,
-89, 0, 89,
0, -127, 0,
45, -89, 77,
0, -127, 0,
0, -126, 0,
45, -89, 77,
0, -126, 0,
0, -126, 0,
0, -127, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
45, -89, 77,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -127, 0,
0, -126, 0,
0, -126, 0,
-25, 0, 124,
0, -126, 0,
0, -127, 0,
0, -126, 0,
0, -126, 0,
-25, 0, 124,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -127, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
0, -126, 0,
-15, -6, 125,
0, -126, 0,
89, 82, -34,
-89, 82, -34,
3, 126, 0,
17, -5, 125,
-34, -116, 36,
-15, -6, 125,
-15, -6, 125,
-63, 102, 40,
0, 126, 2,
0, 126, 2,
63, 102, 40,
0, 126, 2,
0, 126, 2,
63, 102, 40,
17, -5, 125,
126, -3, 2,
89, 82, -34,
3, 126, 0,
-126, -3, 2,
88, -62, -66,
126, -3, 2,
-3, 126, 0,
-89, 82, -34,
-126, -3, 2,
0, 126, 0,
0, 126, 2,
0, 126, 0,
-89, 82, -34,
-88, -62, -66,
-126, -3, 2,
-126, -3, 2,
-88, -62, -66,
88, -62, -66,
126, -3, 2,
88, -62, -66,
89, 82, -34,
63, 102, 40,
34, -116, 36,
17, -5, 125,
0, 126, 2,
-63, 102, 40,
63, 102, 40,
-15, -6, 125,
-34, -116, 36,
-63, 102, 40,
17, -5, 125,
34, -116, 36,
-34, -116, 36,
-89, 82, -34,
-3, 126, 0,
3, 126, 0,
-34, -116, 36,
0, 114, -54,
0, 114, -54,
34, -116, 36,
0, 126, 0,
0, 114, -54,
63, 102, 40,
0, 126, 0,
0, 126, 0,
-63, 102, 40,
0, 126, 0,
0, 126, 0,
-34, -116, 36,
0, 114, -54,
0, 126, 0,
63, 102, 40,
-63, 102, 40,
0, 126, 0,
-63, 102, 40,
-34, -116, 36,
0, 126, 0,
0, -126, 0,
3, 126, 0,
0, 126, 0,
0, -126, 0,
126, -3, 2,
0, -126, 0,
0, 126, 0,
-3, 126, 0,
0, 126, 0,
0, 126, 0,
-3, 126, 0,
0, -126, 0,
-104, -65, -32,
88, -87, -22,
-41, -97, 69,
45, 88, -79,
-105, 70, 9,
74, 99, -24,
37, -51, -109,
45, 88, -79,
88, -87, -22,
-105, 70, 9,
-41, -97, 69,
-48, 61, 100,
-105, 70, 9,
-104, -65, -32,
-41, -97, 69,
45, 88, -79,
74, 99, -24,
88, -87, -22,
-105, 70, 9,
-48, 61, 100,
74, 99, -24,
-104, -65, -32,
37, -51, -109,
88, -87, -22,
-41, -97, 69,
0, -126, 0,
-15, -6, 125,
88, -87, -22,
0, 126, 0,
0, -126, 0,
74, 99, -24,
-48, 61, 100,
0, 126, 0,
-48, 61, 100,
-15, -6, 125,
0, 126, 2,
40, -97, 69,
-88, -87, -22,
104, -65, -32,
-74, 99, -24,
105, 70, 9,
-46, 87, -79,
-88, -87, -22,
-46, 87, -79,
-37, -51, -109,
47, 61, 100,
40, -97, 69,
105, 70, 9,
40, -97, 69,
104, -65, -32,
105, 70, 9,
-88, -87, -22,
-74, 99, -24,
-46, 87, -79,
-74, 99, -24,
47, 61, 100,
105, 70, 9,
-88, -87, -22,
-37, -51, -109,
104, -65, -32,
40, -97, 69,
0, 126, 2,
17, -5, 125,
47, 61, 100,
0, 126, 0,
0, 126, 2,
-74, 99, -24,
-88, -87, -22,
0, 126, 0,
-88, -87, -22,
40, -97, 69,
0, -126, 0,
47, 61, 100,
0, 126, 2,
40, -97, 69,
-15, -6, 125,
-48, 61, 100,
-41, -97, 69,
2, -126, -4,
0, -126, 0,
-2, -126, -3,
0, 126, 0,
0, 126, 0,
0, 126, 0,
0, 126, 0,
-2, -126, -3,
0, 126, 0,
0, 126, 0,
2, -126, -4,
-2, -126, -3,
0, 126, 0,
0, -126, 0,
-89, 82, -34,
0, -126, 0,
88, -62, -66,
-88, -62, -66,
0, -126, 0,
89, 82, -34,
88, -62, -66,
0, 126, 0,
-89, 82, -34,
89, 82, -34,
74, -51, 88,
-70, -52, 92,
116, -1, -50,
-77, 87, 49,
2, 126, -1,
-1, 126, -3,
-70, -52, 92,
-77, 87, 49,
-113, -1, -56,
84, 84, 43,
116, -1, -50,
2, 126, -1,
84, 84, 43,
74, -51, 88,
116, -1, -50,
-77, 87, 49,
-1, 126, -3,
-113, -1, -56,
-77, 87, 49,
84, 84, 43,
2, 126, -1,
-70, -52, 92,
-113, -1, -56,
116, -1, -50,
116, -1, -50,
-113, -1, -56,
0, -126, 0,
-113, -1, -56,
-1, 126, -3,
-2, -126, -3,
-1, 126, -3,
0, 126, 0,
0, 126, 0,
2, 126, -1,
0, -126, 0,
0, 126, 0,
-116, -1, -50,
70, -51, 92,
-74, -52, 88,
2, 126, -3,
-2, 126, -1,
77, 87, 49,
113, -1, -56,
77, 87, 49,
70, -51, 92,
-2, 126, -1,
-116, -1, -50,
-84, 84, 43,
-116, -1, -50,
-74, -52, 88,
-84, 84, 43,
113, -1, -56,
2, 126, -3,
77, 87, 49,
-2, 126, -1,
-84, 84, 43,
77, 87, 49,
-116, -1, -50,
113, -1, -56,
70, -51, 92,
-116, -1, -50,
-2, 126, -1,
0, -126, 0,
2, 126, -3,
0, 126, 0,
0, 126, 0,
2, 126, -3,
2, -126, -4,
0, 126, 0,
113, -1, -56,
0, -126, 0,
2, -126, -4,
-46, 87, -79,
35, 74, -96,
-37, -51, -109,
-37, -51, -109,
109, -6, -64,
104, -65, -32,
104, -65, -32,
109, -6, -64,
105, 70, 9,
105, 70, 9,
82, 64, -71,
-46, 87, -79,
37, -51, -109,
-30, 22, -121,
45, 88, -79,
45, 88, -79,
-82, 64, -71,
-105, 70, 9,
-105, 70, 9,
-82, 64, -71,
-104, -65, -32,
-104, -65, -32,
-109, -3, -64,
37, -51, -109,
-75, -73, -70,
71, -97, 38,
30, 22, -121,
71, -97, 38,
82, 64, -71,
109, -6, -64,
87, 77, 49,
35, 74, -96,
82, 64, -71,
-57, 100, -51,
-75, -73, -70,
35, 74, -96,
-70, -98, 37,
-30, 22, -121,
-109, -3, -64,
58, 100, -52,
-82, 64, -71,
-35, 74, -96,
-88, 76, 49,
-70, -98, 37,
-82, 64, -71,
-35, 74, -96,
-30, 22, -121,
58, 100, -52,
-96, -82, 6,
76, -79, -62,
-59, -104, 41,
44, 96, -70,
-102, 67, 33,
55, 103, -48,
48, -58, -101,
44, 96, -70,
76, -79, -62,
-102, 67, 33,
-59, -104, 41,
-82, 81, 51,
-102, 67, 33,
-96, -82, 6,
-59, -104, 41,
44, 96, -70,
55, 103, -48,
76, -79, -62,
-102, 67, 33,
-82, 81, 51,
55, 103, -48,
-96, -82, 6,
48, -58, -101,
76, -79, -62,
44, 96, -70,
-43, 108, -50,
-102, 67, 33,
-102, 67, 33,
-43, 108, -50,
-96, -82, 6,
-96, -82, 6,
-43, 108, -50,
48, -58, -101,
48, -58, -101,
-43, 108, -50,
44, 96, -70,
55, 103, -48,
-88, 76, 49,
58, 100, -52,
-82, 81, 51,
-59, -104, 41,
-88, 76, 49,
-59, -104, 41,
76, -79, -62,
-70, -98, 37,
76, -79, -62,
55, 103, -48,
75, -74, -69,
-77, 87, 49,
21, 82, 93,
84, 84, 43,
84, 84, 43,
21, 82, 93,
74, -51, 88,
74, -51, 88,
45, 38, 112,
-70, -52, 92,
-70, -52, 92,
-49, 34, 111,
-77, 87, 49,
70, -51, 92,
49, 34, 111,
-74, -52, 88,
-74, -52, 88,
-20, 82, 93,
-84, 84, 43,
-84, 84, 43,
-20, 82, 93,
77, 87, 49,
77, 87, 49,
49, 34, 111,
70, -51, 92,
-89, -89, 0,
-86, -92, 9,
90, -89, 0,
89, 90, 0,
80, 97, 13,
-89, 89, 0,
88, -90, 6,
80, 97, 13,
90, -89, 0,
-76, 99, 17,
-86, -92, 9,
-89, 89, 0,
-89, -89, 0,
-27, -120, -29,
-89, 89, 0,
-89, 89, 0,
-70, 100, -30,
89, 90, 0,
89, 90, 0,
81, -96, -12,
90, -89, 0,
90, -89, 0,
81, -96, -12,
-89, -89, 0,
81, -96, -12,
-27, -120, -29,
-89, -89, 0,
89, 90, 0,
87, 91, -5,
81, -96, -12,
-70, 100, -30,
87, 91, -5,
89, 90, 0,
-27, -120, -29,
-70, 100, -30,
-89, 89, 0,
-86, -92, 9,
-89, -89, 0,
-89, 89, 0,
80, 97, 13,
89, 90, 0,
90, -89, 0,
80, 97, 13,
-76, 99, 17,
-89, 89, 0,
-86, -92, 9,
88, -90, 6,
90, -89, 0,
80, 97, 13,
49, 34, 111,
21, 84, 92,
88, -90, 6,
-86, -92, 9,
49, 34, 111,
-86, -92, 9,
-76, 99, 17,
-45, 37, 112,
-76, 99, 17,
21, 84, 92,
-20, 82, 93,
-89, -89, 0,
86, -92, 9,
89, -89, 0,
89, 89, 0,
-80, 97, 13,
-89, 89, 0,
-89, -89, 0,
-80, 97, 13,
-88, -91, 6,
89, 89, 0,
86, -92, 9,
75, 100, 17,
89, 89, 0,
27, -120, -29,
89, -89, 0,
-89, 89, 0,
70, 100, -30,
89, 89, 0,
-89, -89, 0,
-80, -97, -12,
-89, 89, 0,
89, -89, 0,
-80, -97, -12,
-89, -89, 0,
89, -89, 0,
27, -120, -29,
-80, -97, -12,
-80, -97, -12,
-88, 90, -5,
-89, 89, 0,
-89, 89, 0,
-88, 90, -5,
70, 100, -30,
89, 89, 0,
70, 100, -30,
27, -120, -29,
89, 89, 0,
89, -89, 0,
86, -92, 9,
-89, -89, 0,
-89, 89, 0,
-80, 97, 13,
89, 89, 0,
75, 100, 17,
-80, 97, 13,
-89, -89, 0,
-88, -91, 6,
86, -92, 9,
86, -92, 9,
-49, 34, 111,
45, 38, 112,
-88, -91, 6,
-80, 97, 13,
-49, 34, 111,
-80, 97, 13,
75, 100, 17,
-21, 84, 92,
75, 100, 17,
45, 38, 112,
21, 82, 93,
-111, 0, 60,
0, 113, 56,
0, 126, 0,
86, 88, -27,
-88, 89, -15,
1, 126, 0,
-1, -56, 113,
0, -56, 113,
0, 113, 56,
0, -56, 113,
-88, 89, -15,
55, 0, 114,
0, 113, 56,
85, -90, -26,
1, 126, 0,
55, 0, 114,
0, -127, 0,
0, -56, 113,
0, -56, 113,
0, -127, 0,
85, -90, -26,
85, -90, -26,
0, -127, 0,
86, 88, -27,
86, 88, -27,
0, -127, 0,
55, 0, 114,
-1, -56, 113,
-111, 0, 60,
-88, 89, -15,
0, 113, 56,
0, 113, 56,
-1, -56, 113,
1, 126, 0,
0, 127, 0,
0, 113, 56,
0, 127, 0,
0, 113, 56,
0, 113, 56,
0, 113, 56,
-111, 0, 60,
-1, -56, 113,
-111, 0, 60,
0, 126, 0,
-88, 89, -15,
85, -90, -26,
86, 88, -27,
1, 126, 0,
0, -56, 113,
-1, -56, 113,
-88, 89, -15,
0, -56, 113,
85, -90, -26,
0, 113, 56,
86, 88, -27,
55, 0, 114,
-88, 89, -15,
0, 113, 56,
0, 127, 0,
0, 126, 0,
-88, 89, -15,
0, 126, 0,
-80, -97, -12,
0, 126, 0,
0, 127, 0,
-88, 90, -5,
0, 127, 0,
1, 126, 0,
70, 100, -30,
1, 126, 0,
-88, 89, -15,
27, -120, -29,
0, 126, 0,
0, 113, 56,
111, 0, 60,
-1, 126, 0,
-73, 89, 51,
-102, -1, 75,
0, 113, 56,
0, -55, 114,
1, -57, 113,
0, -89, 89,
-73, 89, 51,
0, -55, 114,
-1, 126, 0,
-86, 88, -27,
0, 113, 56,
0, -55, 114,
0, -127, 0,
0, -89, 89,
-86, 88, -27,
0, -127, 0,
0, -55, 114,
-102, -1, 75,
0, -127, 0,
-86, 88, -27,
0, -89, 89,
0, -127, 0,
-102, -1, 75,
-73, 89, 51,
111, 0, 60,
1, -57, 113,
1, -57, 113,
0, 113, 56,
0, 113, 56,
0, 113, 56,
0, 127, 0,
-1, 126, 0,
0, 113, 56,
0, 113, 56,
0, 127, 0,
1, -57, 113,
111, 0, 60,
0, 113, 56,
-73, 89, 51,
0, 126, 0,
111, 0, 60,
-1, 126, 0,
-102, -1, 75,
-86, 88, -27,
-73, 89, 51,
1, -57, 113,
0, -55, 114,
0, 113, 56,
-86, 88, -27,
0, -55, 114,
-73, 89, 51,
0, -89, 89,
-102, -1, 75,
0, 126, 0,
0, 127, 0,
0, 113, 56,
-73, 89, 51,
-27, -120, -29,
81, -96, -12,
-1, 126, 0,
-70, 100, -30,
-27, -120, -29,
0, 127, 0,
87, 91, -5,
-70, 100, -30,
0, 126, 0,
81, -96, -12,
87, 91, -5,
0, 126, 0,
-2, 126, -1,
2, 126, -3,
-1, 126, -3,
2, 126, -1,
0, 126, 0,
87, 77, 49,
-55, 102, -48,
-57, 100, -51,
-57, 100, -51,
-76, -80, -61,
-75, -73, -70,
71, -97, 38,
81, 83, 50,
87, 77, 49,
60, -103, 42,
-76, -80, -61,
102, -74, 7,
-55, 102, -48,
97, 74, 33,
-45, 95, -70,
-76, -80, -61,
-45, 95, -70,
-48, -59, -101,
81, 83, 50,
60, -103, 42,
97, 74, 33,
60, -103, 42,
102, -74, 7,
97, 74, 33,
-76, -80, -61,
-55, 102, -48,
-45, 95, -70,
-55, 102, -48,
81, 83, 50,
97, 74, 33,
-76, -80, -61,
-48, -59, -101,
102, -74, 7,
97, 74, 33,
-4, 27, -124,
-45, 95, -70,
102, -74, 7,
-4, 27, -124,
97, 74, 33,
-48, -59, -101,
-4, 27, -124,
102, -74, 7,
-45, 95, -70,
-4, 27, -124,
-48, -59, -101,
-75, -73, -70,
-76, -80, -61,
71, -97, 38,
-76, -80, -61,
60, -103, 42,
71, -97, 38,
71, -97, 38,
60, -103, 42,
81, 83, 50,
-57, 100, -51,
-55, 102, -48,
-76, -80, -61,
87, 77, 49,
81, 83, 50,
-55, 102, -48,
0, 126, 0,
-73, 89, 51,
81, -96, -12,
0, 127, 0,
0, 126, 0,
87, 91, -5,
-1, 126, 0,
0, 127, 0,
-70, 100, -30,
-73, 89, 51,
-1, 126, 0,
-27, -120, -29,
-88, 89, -15,
-80, -97, -12,
27, -120, -29,
1, 126, 0,
27, -120, -29,
70, 100, -30,
0, 127, 0,
70, 100, -30,
-88, 90, -5,
0, 126, 0,
-88, 90, -5,
-80, -97, -12,
75, 100, 17,
86, -92, 9,
45, 38, 112,
75, 100, 17,
21, 82, 93,
-21, 84, 92,
-80, 97, 13,
-21, 84, 92,
-49, 34, 111,
86, -92, 9,
-88, -91, 6,
-49, 34, 111,
-76, 99, 17,
80, 97, 13,
21, 84, 92,
-76, 99, 17,
-20, 82, 93,
-45, 37, 112,
-86, -92, 9,
-45, 37, 112,
49, 34, 111,
80, 97, 13,
88, -90, 6,
49, 34, 111,
77, 87, 49,
21, 84, 92,
49, 34, 111,
-20, 82, 93,
21, 84, 92,
77, 87, 49,
-74, -52, 88,
-45, 37, 112,
-20, 82, 93,
49, 34, 111,
-45, 37, 112,
-74, -52, 88,
-49, 34, 111,
-21, 84, 92,
-77, 87, 49,
45, 38, 112,
-49, 34, 111,
-70, -52, 92,
21, 82, 93,
45, 38, 112,
74, -51, 88,
-77, 87, 49,
-21, 84, 92,
21, 82, 93,
55, 103, -48,
58, 100, -52,
75, -74, -69,
76, -79, -62,
75, -74, -69,
-70, -98, 37,
-59, -104, 41,
-70, -98, 37,
-88, 76, 49,
55, 103, -48,
-82, 81, 51,
-88, 76, 49,
-30, 22, -121,
75, -74, -69,
58, 100, -52,
-70, -98, 37,
-109, -3, -64,
-82, 64, -71,
58, 100, -52,
-88, 76, 49,
-82, 64, -71,
-70, -98, 37,
75, -74, -69,
-30, 22, -121,
-75, -73, -70,
30, 22, -121,
35, 74, -96,
87, 77, 49,
-57, 100, -51,
35, 74, -96,
71, -97, 38,
87, 77, 49,
82, 64, -71,
71, -97, 38,
109, -6, -64,
30, 22, -121,
-109, -3, -64,
-30, 22, -121,
37, -51, -109,
-82, 64, -71,
-109, -3, -64,
-104, -65, -32,
45, 88, -79,
-35, 74, -96,
-82, 64, -71,
-30, 22, -121,
-35, 74, -96,
45, 88, -79,
82, 64, -71,
35, 74, -96,
-46, 87, -79,
109, -6, -64,
82, 64, -71,
105, 70, 9,
-37, -51, -109,
30, 22, -121,
109, -6, -64,
35, 74, -96,
30, 22, -121,
-37, -51, -109,
113, -1, -56,
-116, -1, -50,
0, -126, 0,
2, 126, -3,
113, -1, -56,
2, -126, -4,
-2, 126, -1,
0, 126, 0,
0, -126, 0,
2, 126, -1,
116, -1, -50,
0, -126, 0,
-1, 126, -3,
0, 126, 0,
-2, -126, -3,
-113, -1, -56,
-2, -126, -3,
0, -126, 0,
0, 126, 0,
0, 126, 0,
-89, 82, -34,
0, -126, 0,
0, 126, 0,
89, 82, -34,
0, -126, 0,
0, -126, 0,
88, -62, -66,
0, -126, 0,
-88, -62, -66,
-89, 82, -34,
0, 126, 0,
0, 126, 0,
0, 126, 0,
2, -126, -4,
0, -126, 0,
0, -126, 0,
40, -97, 69,
17, -5, 125,
0, -126, 0,
-88, -87, -22,
0, -126, 0,
0, 126, 0,
47, 61, 100,
-74, 99, -24,
0, 126, 0,
-48, 61, 100,
0, 126, 2,
0, 126, 0,
88, -87, -22,
74, 99, -24,
0, 126, 0,
-41, -97, 69,
88, -87, -22,
0, -126, 0,
-3, 126, 0,
-126, -3, 2,
0, -126, 0,
0, 126, 0,
3, 126, 0,
-3, 126, 0,
0, -126, 0,
-126, -3, 2,
126, -3, 2,
0, -126, 0,
126, -3, 2,
3, 126, 0,
34, -116, 36,
63, 102, 40,
0, 126, 0,
-34, -116, 36,
34, -116, 36,
0, 114, -54,
0, 126, 2,
0, 126, 2,
0, 126, 0,
0, -126, 0,
17, -5, 125,
-15, -6, 125,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:1 */
static s8 vtxnvgrp_frake_select_1[]={
-4, -126, -12,
0, -114, -55,
0, -117, -48,
0, -117, -48,
4, -126, -12,
50, -113, 24,
-42, -73, -94,
51, 86, -77,
28, -104, -66,
28, -104, -66,
0, 113, -57,
0, 3, -126,
0, 3, -126,
0, 113, -57,
-28, -104, -66,
-28, -104, -66,
-51, 86, -77,
42, -73, -94,
42, -73, -94,
-111, -12, -58,
-37, -118, -24,
-42, -73, -94,
49, -116, 9,
37, -118, -24,
111, -12, -58,
45, -34, -113,
51, 86, -77,
51, 86, -77,
58, 93, -62,
0, 113, -57,
0, 113, -57,
-58, 93, -62,
-51, 86, -77,
-51, 86, -77,
-45, -34, -113,
-111, -12, -58,
-111, -12, -58,
-45, -34, -113,
-37, -118, -24,
-37, -118, -24,
-55, -70, -89,
0, -105, -70,
0, -105, -70,
55, -70, -89,
37, -118, -24,
37, -118, -24,
45, -34, -113,
111, -12, -58,
0, 122, 35,
-73, 87, 54,
-39, 51, 109,
45, 115, -26,
55, 113, -12,
126, -2, -8,
122, 6, 32,
33, -121, 17,
50, -113, 24,
50, -113, 24,
33, -121, 17,
0, -117, -48,
0, -117, -48,
-33, -121, 17,
-50, -113, 24,
-50, -113, 24,
-33, -121, 17,
-122, 6, 32,
-126, -2, -8,
-55, 113, -12,
-45, 115, -26,
-45, 115, -26,
0, 125, -18,
0, 122, -33,
0, 122, -33,
0, 125, -18,
45, 115, -26,
55, 113, -12,
73, 87, 54,
122, 6, 32,
122, 6, 32,
73, 87, 54,
119, 28, 31,
-119, 28, 31,
-73, 87, 54,
-122, 6, 32,
-122, 6, 32,
-73, 87, 54,
-55, 113, -12,
-55, 113, -12,
0, 126, 5,
0, 125, -18,
0, 125, -18,
0, 126, 5,
55, 113, -12,
66, 78, 73,
0, 126, 5,
0, 122, 35,
37, -118, -24,
111, -12, -58,
-42, -73, -94,
-37, -118, -24,
-49, -116, 9,
42, -73, -94,
0, -105, -70,
37, -118, -24,
-37, -118, -24,
37, -118, -24,
0, -125, 17,
-37, -118, -24,
-4, -126, -12,
96, -74, -36,
42, -73, -94,
42, -73, -94,
-116, 38, -34,
-126, -2, -8,
-126, -2, -8,
-43, -119, 6,
-50, -113, 24,
-50, -113, 24,
96, -74, -36,
-4, -126, -12,
96, -74, -36,
-4, -15, -125,
49, 112, -31,
49, 112, -31,
-4, -15, -125,
-116, 38, -34,
-116, 38, -34,
-4, -15, -125,
-43, -119, 6,
-43, -119, 6,
-4, -15, -125,
96, -74, -36,
-42, -73, -94,
-96, -74, -36,
4, -126, -12,
4, -126, -12,
-96, -74, -36,
50, -113, 24,
50, -113, 24,
43, -119, 6,
126, -2, -8,
126, -2, -8,
116, 38, -34,
-42, -73, -94,
-49, 112, -31,
4, -15, -125,
-96, -74, -36,
-96, -74, -36,
4, -15, -125,
43, -119, 6,
43, -119, 6,
4, -15, -125,
116, 38, -34,
116, 38, -34,
4, -15, -125,
-49, 112, -31,
28, -104, -66,
-41, -119, 2,
-42, -73, -94,
-42, -73, -94,
-41, -119, 2,
126, -2, -8,
126, -2, -8,
118, -41, -21,
45, 115, -26,
45, 115, -26,
-52, 108, -39,
28, -104, -66,
-117, -47, -1,
-12, -17, -125,
-41, -119, 2,
-41, -119, 2,
-12, -17, -125,
118, -41, -21,
118, -41, -21,
-12, -17, -125,
-52, 108, -39,
-52, 108, -39,
-12, -17, -125,
-117, -47, -1,
-45, 115, -26,
-118, -41, -21,
-126, -2, -8,
-126, -2, -8,
41, -119, 2,
42, -73, -94,
42, -73, -94,
41, -119, 2,
-28, -104, -66,
-28, -104, -66,
52, 108, -39,
-45, 115, -26,
52, 108, -39,
12, -17, -125,
-118, -41, -21,
-118, -41, -21,
12, -17, -125,
41, -119, 2,
41, -119, 2,
12, -17, -125,
117, -47, -1,
117, -47, -1,
12, -17, -125,
52, 108, -39,
0, 3, -126,
14, -125, 11,
28, -104, -66,
28, -104, -66,
14, -125, 11,
45, 115, -26,
45, 115, -26,
-80, 70, -69,
0, 122, -33,
0, 122, -33,
-80, 70, -69,
0, 3, -126,
-88, -87, -24,
11, -38, -120,
14, -125, 11,
14, -125, 11,
11, -38, -120,
122, 6, -31,
122, 6, -31,
11, -38, -120,
-80, 70, -69,
-80, 70, -69,
11, -38, -120,
-88, -87, -24,
-28, -104, -66,
-14, -125, 11,
0, 3, -126,
0, 3, -126,
80, 70, -69,
0, 122, -33,
0, 122, -33,
80, 70, -69,
-45, 115, -26,
-45, 115, -26,
-14, -125, 11,
-28, -104, -66,
-14, -125, 11,
-11, -38, -120,
88, -87, -24,
88, -87, -24,
-11, -38, -120,
80, 70, -69,
80, 70, -69,
-11, -38, -120,
-122, 6, -31,
-122, 6, -31,
-11, -38, -120,
-14, -125, 11,
0, -103, 74,
0, -1, 126,
-119, 28, 31,
119, 28, 31,
0, -1, 126,
0, -103, 74,
49, -116, 9,
-42, -73, -94,
4, -126, -12,
-49, -116, 9,
-4, -126, -12,
42, -73, -94,
-49, -116, 9,
0, -114, -55,
-4, -126, -12,
49, -116, 9,
4, -126, -12,
0, -114, -55,
-49, -116, 9,
0, -125, 17,
0, -114, -55,
119, 28, 31,
33, -121, 17,
122, 6, 32,
-122, 6, 32,
-33, -121, 17,
-119, 28, 31,
50, -113, 24,
126, -2, -8,
122, 6, 32,
-122, 6, 32,
-126, -2, -8,
-50, -113, 24,
-26, -92, 82,
-24, -120, 29,
-8, -85, 93,
24, -120, 29,
8, -85, 93,
-3, -123, 30,
0, 122, 35,
0, -1, 126,
39, 51, 109,
0, 122, 35,
39, 51, 109,
73, 87, 54,
0, 122, 35,
73, 87, 54,
66, 78, 73,
-39, 51, 109,
0, -1, 126,
0, 122, 35,
0, 122, 35,
-66, 78, 73,
-73, 87, 54,
0, 122, 35,
0, 126, 5,
-66, 78, 73,
0, -103, 74,
6, -122, 32,
0, -125, 17,
0, -125, 17,
-29, -121, 22,
-33, -121, 17,
-33, -121, 17,
-72, -2, 104,
-119, 28, 31,
-119, 28, 31,
13, -4, 126,
0, -103, 74,
33, -121, 17,
29, -121, 22,
0, -125, 17,
0, -125, 17,
-6, -122, 32,
0, -103, 74,
0, -103, 74,
-13, -4, 126,
119, 28, 31,
119, 28, 31,
72, -2, 104,
33, -121, 17,
72, -2, 104,
29, -121, 22,
33, -121, 17,
-13, -4, 126,
72, -2, 104,
119, 28, 31,
-6, -122, 32,
-13, -4, 126,
0, -103, 74,
29, -121, 22,
-6, -122, 32,
0, -125, 17,
-119, 28, 31,
-72, -2, 104,
13, -4, 126,
-33, -121, 17,
-29, -121, 22,
-72, -2, 104,
0, -125, 17,
6, -122, 32,
-29, -121, 22,
0, -103, 74,
13, -4, 126,
6, -122, 32,
119, 28, 31,
39, 51, 109,
0, -1, 126,
0, -1, 126,
-39, 51, 109,
-119, 28, 31,
-45, 115, -26,
-122, 6, -31,
-14, -125, 11,
80, 70, -69,
-122, 6, -31,
-45, 115, -26,
0, 3, -126,
88, -87, -24,
80, 70, -69,
-14, -125, 11,
88, -87, -24,
0, 3, -126,
-80, 70, -69,
-88, -87, -24,
0, 3, -126,
45, 115, -26,
122, 6, -31,
-80, 70, -69,
14, -125, 11,
122, 6, -31,
45, 115, -26,
0, 3, -126,
-88, -87, -24,
14, -125, 11,
-28, -104, -66,
117, -47, -1,
52, 108, -39,
41, -119, 2,
117, -47, -1,
-28, -104, -66,
-126, -2, -8,
-118, -41, -21,
41, -119, 2,
-45, 115, -26,
52, 108, -39,
-118, -41, -21,
-52, 108, -39,
-117, -47, -1,
28, -104, -66,
118, -41, -21,
-52, 108, -39,
45, 115, -26,
-41, -119, 2,
118, -41, -21,
126, -2, -8,
28, -104, -66,
-117, -47, -1,
-41, -119, 2,
116, 38, -34,
-49, 112, -31,
-42, -73, -94,
43, -119, 6,
116, 38, -34,
126, -2, -8,
-96, -74, -36,
43, -119, 6,
50, -113, 24,
-42, -73, -94,
-49, 112, -31,
-96, -74, -36,
-50, -113, 24,
-43, -119, 6,
96, -74, -36,
-126, -2, -8,
-116, 38, -34,
-43, -119, 6,
42, -73, -94,
49, 112, -31,
-116, 38, -34,
96, -74, -36,
49, 112, -31,
42, -73, -94,
0, -125, 17,
-49, -116, 9,
-37, -118, -24,
0, 126, 5,
66, 78, 73,
55, 113, -12,
-55, 113, -12,
-66, 78, 73,
0, 126, 5,
-73, 87, 54,
-66, 78, 73,
-55, 113, -12,
-119, 28, 31,
-39, 51, 109,
-73, 87, 54,
73, 87, 54,
39, 51, 109,
119, 28, 31,
55, 113, -12,
66, 78, 73,
73, 87, 54,
0, 125, -18,
55, 113, -12,
45, 115, -26,
-45, 115, -26,
-55, 113, -12,
0, 125, -18,
-126, -2, -8,
-122, 6, 32,
-55, 113, -12,
0, -117, -48,
0, -125, 17,
-33, -121, 17,
33, -121, 17,
0, -125, 17,
0, -117, -48,
55, 113, -12,
122, 6, 32,
126, -2, -8,
45, -34, -113,
55, -70, -89,
-55, -70, -89,
55, -70, -89,
0, -105, -70,
-55, -70, -89,
45, -34, -113,
-55, -70, -89,
-45, -34, -113,
37, -118, -24,
55, -70, -89,
45, -34, -113,
-45, -34, -113,
-55, -70, -89,
-37, -118, -24,
-51, 86, -77,
-58, 93, -62,
-45, -34, -113,
0, 113, -57,
0, 116, -50,
-58, 93, -62,
58, 93, -62,
0, 116, -50,
0, 113, -57,
45, -34, -113,
58, 93, -62,
51, 86, -77,
-51, 86, -77,
-111, -12, -58,
42, -73, -94,
0, 113, -57,
-51, 86, -77,
-28, -104, -66,
28, -104, -66,
51, 86, -77,
0, 113, -57,
-42, -73, -94,
111, -12, -58,
51, 86, -77,
0, -117, -48,
0, -114, -55,
4, -126, -12,
0, -117, -48,
-50, -113, 24,
-4, -126, -12,
0, -125, 17,
49, -116, 9,
0, -114, -55,
-6, -122, 32,
26, -92, 82,
-13, -4, 126,
-13, -4, 126,
-3, -123, 30,
72, -2, 104,
72, -2, 104,
-3, -123, 30,
29, -121, 22,
29, -121, 22,
26, -92, 82,
-6, -122, 32,
13, -4, 126,
-26, -92, 82,
6, -122, 32,
6, -122, 32,
-26, -92, 82,
-29, -121, 22,
-29, -121, 22,
3, -123, 30,
-72, -2, 104,
-72, -2, 104,
3, -123, 30,
13, -4, 126,
3, -123, 30,
-24, -120, 29,
13, -4, 126,
-29, -121, 22,
-8, -85, 93,
3, -123, 30,
-26, -92, 82,
-8, -85, 93,
-29, -121, 22,
13, -4, 126,
-24, -120, 29,
-26, -92, 82,
29, -121, 22,
8, -85, 93,
26, -92, 82,
-3, -123, 30,
8, -85, 93,
29, -121, 22,
-13, -4, 126,
24, -120, 29,
-3, -123, 30,
26, -92, 82,
24, -120, 29,
-13, -4, 126,
24, -120, 29,
26, -92, 82,
8, -85, 93,
-24, -120, 29,
3, -123, 30,
-8, -85, 93,
37, -118, -24,
49, -116, 9,
0, -125, 17,
12, -123, 25,
-18, -15, 124,
-12, -123, 25,
93, 30, -80,
-93, 30, -80,
78, 98, -15,
19, -15, 124,
-92, -84, 20,
-18, -15, 124,
-18, -15, 124,
-18, 125, 12,
-13, 125, 11,
-13, 125, 11,
18, 125, 12,
13, 125, 12,
13, 125, 12,
18, 125, 12,
19, -15, 124,
85, -91, 22,
93, 30, -80,
78, 98, -15,
-85, -91, 22,
92, -87, 1,
85, -91, 22,
-78, 98, -15,
-93, 30, -80,
-85, -91, 22,
-35, 110, -52,
-13, 125, 11,
35, 110, -52,
-93, 30, -80,
-92, -87, 1,
-85, -91, 22,
-85, -91, 22,
-92, -87, 1,
92, -87, 1,
85, -91, 22,
92, -87, 1,
93, 30, -80,
18, 125, 12,
92, -84, 20,
19, -15, 124,
-13, 125, 11,
-18, 125, 12,
18, 125, 12,
-18, -15, 124,
-92, -84, 20,
-18, 125, 12,
19, -15, 124,
92, -84, 20,
-92, -84, 20,
-93, 30, -80,
-78, 98, -15,
78, 98, -15,
-92, -84, 20,
45, -34, -113,
-45, -34, -113,
92, -84, 20,
58, 93, -62,
45, -34, -113,
18, 125, 12,
0, 116, -50,
58, 93, -62,
-18, 125, 12,
-58, 93, -62,
0, 116, -50,
-92, -84, 20,
-45, -34, -113,
-58, 93, -62,
18, 125, 12,
-18, 125, 12,
0, 116, -50,
-18, 125, 12,
-92, -84, 20,
-58, 93, -62,
12, -123, 25,
78, 98, -15,
35, 110, -52,
-12, -123, 25,
85, -91, 22,
12, -123, 25,
35, 110, -52,
-78, 98, -15,
-35, 110, -52,
-35, 110, -52,
-78, 98, -15,
-12, -123, 25,
-108, -49, 44,
65, -108, 2,
-48, -13, 116,
37, 8, -120,
-104, 38, -61,
94, 72, -44,
51, -112, -29,
37, 8, -120,
65, -108, 2,
-104, 38, -61,
-48, -13, 116,
-35, 118, 26,
-104, 38, -61,
-108, -49, 44,
-48, -13, 116,
37, 8, -120,
94, 72, -44,
65, -108, 2,
-104, 38, -61,
-35, 118, 26,
94, 72, -44,
-108, -49, 44,
51, -112, -29,
65, -108, 2,
-48, -13, 116,
-12, -123, 25,
-18, -15, 124,
65, -108, 2,
-35, 110, -52,
-12, -123, 25,
94, 72, -44,
-35, 118, 26,
-35, 110, -52,
-35, 118, 26,
-18, -15, 124,
-13, 125, 11,
47, -12, 116,
-65, -108, 2,
108, -49, 44,
-94, 72, -44,
104, 38, -61,
-37, 8, -120,
-65, -108, 2,
-37, 8, -120,
-51, -112, -29,
35, 118, 27,
47, -12, 116,
104, 38, -61,
47, -12, 116,
108, -49, 44,
104, 38, -61,
-65, -108, 2,
-94, 72, -44,
-37, 8, -120,
-94, 72, -44,
35, 118, 27,
104, 38, -61,
-65, -108, 2,
-51, -112, -29,
108, -49, 44,
47, -12, 116,
13, 125, 12,
19, -15, 124,
35, 118, 27,
35, 110, -52,
13, 125, 12,
-94, 72, -44,
-65, -108, 2,
35, 110, -52,
-65, -108, 2,
47, -12, 116,
12, -123, 25,
35, 118, 27,
13, 125, 12,
47, -12, 116,
-18, -15, 124,
-35, 118, 26,
-48, -13, 116,
72, -91, -50,
-26, -123, 6,
-90, -56, -68,
12, 34, -121,
35, 58, -107,
-12, 34, -121,
-12, 34, -121,
-90, -56, -68,
12, 34, -121,
-12, 34, -121,
72, -91, -50,
-90, -56, -68,
-35, 58, -107,
-26, -123, 6,
-93, 30, -80,
-26, -123, 6,
92, -87, 1,
-92, -87, 1,
25, -124, 3,
93, 30, -80,
92, -87, 1,
35, 58, -107,
-93, 30, -80,
93, 30, -80,
101, -70, 29,
-83, -83, 47,
88, -52, -74,
-68, 53, 92,
48, 100, -60,
-64, 96, -52,
-83, -83, 47,
-68, 53, 92,
-80, -50, -83,
75, 52, 88,
88, -52, -74,
48, 100, -60,
75, 52, 88,
101, -70, 29,
88, -52, -74,
-68, 53, 92,
-64, 96, -52,
-80, -50, -83,
-68, 53, 92,
75, 52, 88,
48, 100, -60,
-83, -83, 47,
-80, -50, -83,
88, -52, -74,
88, -52, -74,
-80, -50, -83,
-26, -123, 6,
-80, -50, -83,
-64, 96, -52,
-90, -56, -68,
-64, 96, -52,
-35, 58, -107,
12, 34, -121,
48, 100, -60,
-26, -123, 6,
-35, 58, -107,
-90, -51, -73,
83, -82, 48,
-101, -70, 29,
68, 92, -54,
-48, 100, -60,
68, 53, 92,
89, -66, -61,
68, 53, 92,
83, -82, 48,
-48, 100, -60,
-90, -51, -73,
-75, 52, 88,
-90, -51, -73,
-101, -70, 29,
-75, 52, 88,
89, -66, -61,
68, 92, -54,
68, 53, 92,
-48, 100, -60,
-75, 52, 88,
68, 53, 92,
-90, -51, -73,
89, -66, -61,
83, -82, 48,
-90, -51, -73,
-48, 100, -60,
25, -124, 3,
68, 92, -54,
-12, 34, -121,
35, 58, -107,
68, 92, -54,
72, -91, -50,
-12, 34, -121,
89, -66, -61,
25, -124, 3,
72, -91, -50,
-37, 8, -120,
18, -96, -80,
-51, -112, -29,
-51, -112, -29,
57, -107, -35,
108, -49, 44,
108, -49, 44,
57, -107, -35,
104, 38, -61,
104, 38, -61,
112, -17, -55,
-37, 8, -120,
51, -112, -29,
-24, -116, -43,
37, 8, -120,
37, 8, -120,
-112, -17, -55,
-104, 38, -61,
-104, 38, -61,
-112, -17, -55,
-108, -49, 44,
-108, -49, 44,
-57, -107, -35,
51, -112, -29,
-43, -118, -13,
92, -44, 75,
24, -116, -43,
92, -44, 75,
112, -17, -55,
57, -107, -35,
58, 112, 9,
18, -96, -80,
112, -17, -55,
-80, 32, -92,
-43, -118, -13,
18, -96, -80,
-92, -44, 75,
-24, -116, -43,
-57, -107, -35,
80, 32, -92,
-112, -17, -55,
-18, -96, -80,
-58, 112, 9,
-92, -44, 75,
-112, -17, -55,
-18, -96, -80,
-24, -116, -43,
80, 32, -92,
-104, -44, 57,
38, -120, -7,
-87, -52, 75,
41, 15, -119,
-101, 69, -30,
87, 44, -80,
33, -119, -25,
41, 15, -119,
38, -120, -7,
-101, 69, -30,
-87, -52, 75,
-40, 119, 10,
-101, 69, -30,
-104, -44, 57,
-87, -52, 75,
41, 15, -119,
87, 44, -80,
38, -120, -7,
-101, 69, -30,
-40, 119, 10,
87, 44, -80,
-104, -44, 57,
33, -119, -25,
38, -120, -7,
41, 15, -119,
-70, -45, -95,
-101, 69, -30,
-101, 69, -30,
-70, -45, -95,
-104, -44, 57,
-104, -44, 57,
-70, -45, -95,
33, -119, -25,
33, -119, -25,
-70, -45, -95,
41, 15, -119,
87, 44, -80,
-58, 112, 9,
80, 32, -92,
-40, 119, 10,
-87, -52, 75,
-58, 112, 9,
-87, -52, 75,
38, -120, -7,
-92, -44, 75,
38, -120, -7,
87, 44, -80,
43, -118, -13,
-68, 53, 92,
31, -80, 92,
75, 52, 88,
75, 52, 88,
31, -80, 92,
101, -70, 29,
101, -70, 29,
8, -98, 79,
-83, -83, 47,
-83, -83, 47,
-9, -99, 78,
-68, 53, 92,
83, -82, 48,
9, -99, 78,
-101, -70, 29,
-101, -70, 29,
-31, -80, 92,
-75, 52, 88,
-75, 52, 88,
-31, -80, 92,
68, 53, 92,
68, 53, 92,
9, -99, 78,
83, -82, 48,
89, -85, 28,
-43, -107, 52,
-89, -85, 28,
-86, 90, -19,
86, 92, -8,
86, 90, -19,
54, -103, 49,
86, 92, -8,
-89, -85, 28,
-86, 93, -6,
-43, -107, 52,
86, 90, -19,
89, -85, 28,
86, -73, 56,
86, 90, -19,
86, 90, -19,
8, 122, -31,
-86, 90, -19,
-86, 90, -19,
-92, -26, 82,
-89, -85, 28,
-89, -85, 28,
-92, -26, 82,
89, -85, 28,
-92, -26, 82,
86, -73, 56,
89, -85, 28,
-86, 90, -19,
-43, 116, -26,
-92, -26, 82,
8, 122, -31,
-43, 116, -26,
-86, 90, -19,
86, -73, 56,
8, 122, -31,
86, 90, -19,
-43, -107, 52,
89, -85, 28,
86, 90, -19,
86, 92, -8,
-86, 90, -19,
-89, -85, 28,
86, 92, -8,
-86, 93, -6,
86, 90, -19,
-43, -107, 52,
54, -103, 49,
-89, -85, 28,
86, 92, -8,
9, -99, 78,
41, -76, 91,
54, -103, 49,
-43, -107, 52,
9, -99, 78,
-43, -107, 52,
-86, 93, -6,
-8, -98, 79,
-86, 93, -6,
41, -76, 91,
-31, -80, 92,
89, -85, 28,
43, -107, 52,
-89, -85, 28,
-86, 90, -19,
-86, 92, -8,
86, 90, -19,
89, -85, 28,
-86, 92, -8,
-54, -103, 49,
-86, 90, -19,
43, -107, 52,
86, 93, -6,
-86, 90, -19,
-86, -73, 56,
-89, -85, 28,
86, 90, -19,
-8, 122, -31,
-86, 90, -19,
89, -85, 28,
92, -26, 82,
86, 90, -19,
-89, -85, 28,
92, -26, 82,
89, -85, 28,
-89, -85, 28,
-86, -73, 56,
92, -26, 82,
92, -26, 82,
43, 116, -26,
86, 90, -19,
86, 90, -19,
43, 116, -26,
-8, 122, -31,
-86, 90, -19,
-8, 122, -31,
-86, -73, 56,
-86, 90, -19,
-89, -85, 28,
43, -107, 52,
89, -85, 28,
86, 90, -19,
-86, 92, -8,
-86, 90, -19,
86, 93, -6,
-86, 92, -8,
89, -85, 28,
-54, -103, 49,
43, -107, 52,
43, -107, 52,
-9, -99, 78,
8, -98, 79,
-54, -103, 49,
-86, 92, -8,
-9, -99, 78,
-86, 92, -8,
86, 93, -6,
-41, -76, 91,
86, 93, -6,
8, -98, 79,
31, -80, 92,
78, -19, -97,
-29, -23, -121,
24, 120, -31,
-58, 32, 107,
110, 21, 58,
-31, 121, -21,
111, -57, 18,
12, -122, 30,
-76, -23, -98,
12, -122, 30,
110, 21, 58,
53, 30, 110,
-76, -23, -98,
-122, -21, -24,
-31, 121, -21,
53, 30, 110,
-1, -120, 39,
12, -122, 30,
12, -122, 30,
-1, -120, 39,
-122, -21, -24,
-122, -21, -24,
-1, -120, 39,
-58, 32, 107,
-58, 32, 107,
-1, -120, 39,
53, 30, 110,
111, -57, 18,
78, -19, -97,
110, 21, 58,
-76, -23, -98,
-29, -23, -121,
111, -57, 18,
-31, 121, -21,
-6, 121, -37,
-76, -23, -98,
-6, 121, -37,
-29, -23, -121,
-76, -23, -98,
-29, -23, -121,
78, -19, -97,
111, -57, 18,
78, -19, -97,
24, 120, -31,
110, 21, 58,
-122, -21, -24,
-58, 32, 107,
-31, 121, -21,
12, -122, 30,
111, -57, 18,
110, 21, 58,
12, -122, 30,
-122, -21, -24,
-76, -23, -98,
-58, 32, 107,
53, 30, 110,
110, 21, 58,
-29, -23, -121,
-6, 121, -37,
24, 120, -31,
110, 21, 58,
24, 120, -31,
92, -26, 82,
24, 120, -31,
-6, 121, -37,
43, 116, -26,
-6, 121, -37,
-31, 121, -21,
-8, 122, -31,
-31, 121, -21,
110, 21, 58,
-86, -73, 56,
-24, 120, -31,
29, -23, -121,
-78, -19, -97,
31, 121, -21,
-110, 21, 58,
58, 32, 107,
76, -23, -98,
-12, -122, 30,
-111, -57, 18,
-53, 30, 110,
-110, 21, 58,
-12, -122, 30,
31, 121, -21,
122, -21, -24,
76, -23, -98,
-12, -122, 30,
1, -120, 39,
-53, 30, 110,
122, -21, -24,
1, -120, 39,
-12, -122, 30,
58, 32, 107,
1, -120, 39,
122, -21, -24,
-53, 30, 110,
1, -120, 39,
58, 32, 107,
-110, 21, 58,
-78, -19, -97,
-111, -57, 18,
-111, -57, 18,
29, -23, -121,
76, -23, -98,
76, -23, -98,
6, 121, -37,
31, 121, -21,
76, -23, -98,
29, -23, -121,
6, 121, -37,
-111, -57, 18,
-78, -19, -97,
29, -23, -121,
-110, 21, 58,
-24, 120, -31,
-78, -19, -97,
31, 121, -21,
58, 32, 107,
122, -21, -24,
-110, 21, 58,
-111, -57, 18,
-12, -122, 30,
76, -23, -98,
122, -21, -24,
-12, -122, 30,
-110, 21, 58,
-53, 30, 110,
58, 32, 107,
-24, 120, -31,
6, 121, -37,
29, -23, -121,
-110, 21, 58,
86, -73, 56,
-92, -26, 82,
31, 121, -21,
8, 122, -31,
86, -73, 56,
6, 121, -37,
-43, 116, -26,
8, 122, -31,
-24, 120, -31,
-92, -26, 82,
-43, 116, -26,
35, 58, -107,
-48, 100, -60,
68, 92, -54,
-64, 96, -52,
48, 100, -60,
-35, 58, -107,
58, 112, 9,
-87, 44, -80,
-80, 32, -92,
-80, 32, -92,
-38, -120, -7,
-43, -118, -13,
92, -44, 75,
40, 119, 10,
58, 112, 9,
87, -52, 75,
-38, -120, -7,
104, -44, 57,
-87, 44, -80,
101, 69, -30,
-41, 15, -119,
-38, -120, -7,
-41, 15, -119,
-33, -119, -25,
40, 119, 10,
87, -52, 75,
101, 69, -30,
87, -52, 75,
104, -44, 57,
101, 69, -30,
-38, -120, -7,
-87, 44, -80,
-41, 15, -119,
-87, 44, -80,
40, 119, 10,
101, 69, -30,
-38, -120, -7,
-33, -119, -25,
104, -44, 57,
101, 69, -30,
70, -45, -95,
-41, 15, -119,
104, -44, 57,
70, -45, -95,
101, 69, -30,
-33, -119, -25,
70, -45, -95,
104, -44, 57,
-41, 15, -119,
70, -45, -95,
-33, -119, -25,
-43, -118, -13,
-38, -120, -7,
92, -44, 75,
-38, -120, -7,
87, -52, 75,
92, -44, 75,
92, -44, 75,
87, -52, 75,
40, 119, 10,
-80, 32, -92,
-87, 44, -80,
-38, -120, -7,
58, 112, 9,
40, 119, 10,
-87, 44, -80,
-24, 120, -31,
-110, 21, 58,
-92, -26, 82,
6, 121, -37,
-24, 120, -31,
-43, 116, -26,
31, 121, -21,
6, 121, -37,
8, 122, -31,
-110, 21, 58,
31, 121, -21,
86, -73, 56,
110, 21, 58,
92, -26, 82,
-86, -73, 56,
-31, 121, -21,
-86, -73, 56,
-8, 122, -31,
-6, 121, -37,
-8, 122, -31,
43, 116, -26,
24, 120, -31,
43, 116, -26,
92, -26, 82,
86, 93, -6,
43, -107, 52,
8, -98, 79,
86, 93, -6,
31, -80, 92,
-41, -76, 91,
-86, 92, -8,
-41, -76, 91,
-9, -99, 78,
43, -107, 52,
-54, -103, 49,
-9, -99, 78,
-86, 93, -6,
86, 92, -8,
41, -76, 91,
-86, 93, -6,
-31, -80, 92,
-8, -98, 79,
-43, -107, 52,
-8, -98, 79,
9, -99, 78,
86, 92, -8,
54, -103, 49,
9, -99, 78,
68, 53, 92,
41, -76, 91,
9, -99, 78,
-31, -80, 92,
41, -76, 91,
68, 53, 92,
-101, -70, 29,
-8, -98, 79,
-31, -80, 92,
9, -99, 78,
-8, -98, 79,
-101, -70, 29,
-9, -99, 78,
-41, -76, 91,
-68, 53, 92,
8, -98, 79,
-9, -99, 78,
-83, -83, 47,
31, -80, 92,
8, -98, 79,
101, -70, 29,
-68, 53, 92,
-41, -76, 91,
31, -80, 92,
87, 44, -80,
80, 32, -92,
43, -118, -13,
38, -120, -7,
43, -118, -13,
-92, -44, 75,
-87, -52, 75,
-92, -44, 75,
-58, 112, 9,
87, 44, -80,
-40, 119, 10,
-58, 112, 9,
-24, -116, -43,
43, -118, -13,
80, 32, -92,
-92, -44, 75,
-57, -107, -35,
-112, -17, -55,
80, 32, -92,
-58, 112, 9,
-112, -17, -55,
-92, -44, 75,
43, -118, -13,
-24, -116, -43,
-43, -118, -13,
24, -116, -43,
18, -96, -80,
58, 112, 9,
-80, 32, -92,
18, -96, -80,
92, -44, 75,
58, 112, 9,
112, -17, -55,
92, -44, 75,
57, -107, -35,
24, -116, -43,
-57, -107, -35,
-24, -116, -43,
51, -112, -29,
-112, -17, -55,
-57, -107, -35,
-108, -49, 44,
37, 8, -120,
-18, -96, -80,
-112, -17, -55,
-24, -116, -43,
-18, -96, -80,
37, 8, -120,
112, -17, -55,
18, -96, -80,
-37, 8, -120,
57, -107, -35,
112, -17, -55,
104, 38, -61,
-51, -112, -29,
24, -116, -43,
57, -107, -35,
18, -96, -80,
24, -116, -43,
-51, -112, -29,
89, -66, -61,
-90, -51, -73,
25, -124, 3,
68, 92, -54,
89, -66, -61,
72, -91, -50,
-48, 100, -60,
35, 58, -107,
25, -124, 3,
48, 100, -60,
88, -52, -74,
-26, -123, 6,
-64, 96, -52,
12, 34, -121,
-90, -56, -68,
-80, -50, -83,
-90, -56, -68,
-26, -123, 6,
35, 58, -107,
-35, 58, -107,
-93, 30, -80,
25, -124, 3,
35, 58, -107,
93, 30, -80,
-26, -123, 6,
25, -124, 3,
92, -87, 1,
-26, -123, 6,
-92, -87, 1,
-93, 30, -80,
12, 34, -121,
-35, 58, -107,
35, 58, -107,
72, -91, -50,
25, -124, 3,
-26, -123, 6,
47, -12, 116,
19, -15, 124,
12, -123, 25,
-65, -108, 2,
12, -123, 25,
35, 110, -52,
35, 118, 27,
-94, 72, -44,
35, 110, -52,
-35, 118, 26,
-13, 125, 11,
-35, 110, -52,
65, -108, 2,
94, 72, -44,
-35, 110, -52,
-48, -13, 116,
65, -108, 2,
-12, -123, 25,
-78, 98, -15,
-85, -91, 22,
-12, -123, 25,
35, 110, -52,
78, 98, -15,
-78, 98, -15,
-12, -123, 25,
-85, -91, 22,
85, -91, 22,
12, -123, 25,
85, -91, 22,
78, 98, -15,
92, -84, 20,
18, 125, 12,
58, 93, -62,
-92, -84, 20,
92, -84, 20,
45, -34, -113,
-13, 125, 11,
13, 125, 12,
35, 110, -52,
12, -123, 25,
19, -15, 124,
-18, -15, 124,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:2 */
static s8 vtxnvgrp_frake_select_2[]={
-6, -126, -14,
0, -116, -50,
0, -119, -44,
0, -119, -44,
6, -126, -14,
60, -107, 31,
-26, -78, -95,
58, 73, -85,
16, -103, -71,
16, -103, -71,
0, 103, -73,
0, -8, -126,
0, -8, -126,
0, 103, -73,
-16, -103, -71,
-16, -103, -71,
-58, 73, -85,
26, -78, -95,
26, -78, -95,
-111, -17, -58,
-45, -115, -26,
-26, -78, -95,
57, -112, 14,
45, -115, -26,
111, -17, -58,
42, -44, -111,
58, 73, -85,
58, 73, -85,
71, 73, -74,
0, 103, -73,
0, 103, -73,
-71, 73, -74,
-58, 73, -85,
-58, 73, -85,
-42, -44, -111,
-111, -17, -58,
-111, -17, -58,
-42, -44, -111,
-45, -115, -26,
-45, -115, -26,
-52, -72, -89,
0, -104, -72,
0, -104, -72,
52, -72, -89,
45, -115, -26,
45, -115, -26,
42, -44, -111,
111, -17, -58,
0, 119, 42,
-76, 87, 50,
-38, 66, 101,
57, 107, -33,
66, 106, -17,
126, -3, -9,
122, 8, 31,
43, -116, 23,
60, -107, 31,
60, -107, 31,
43, -116, 23,
0, -119, -44,
0, -119, -44,
-43, -116, 23,
-60, -107, 31,
-60, -107, 31,
-43, -116, 23,
-122, 8, 31,
-126, -3, -9,
-66, 106, -17,
-57, 107, -33,
-57, 107, -33,
0, 124, -24,
0, 120, -40,
0, 120, -40,
0, 124, -24,
57, 107, -33,
66, 106, -17,
76, 87, 50,
122, 8, 31,
122, 8, 31,
76, 87, 50,
117, 29, 36,
-117, 29, 36,
-76, 87, 50,
-122, 8, 31,
-122, 8, 31,
-76, 87, 50,
-66, 106, -17,
-66, 106, -17,
0, 126, 5,
0, 124, -24,
0, 124, -24,
0, 126, 5,
66, 106, -17,
64, 85, 67,
0, 126, 5,
0, 119, 42,
45, -115, -26,
111, -17, -58,
-26, -78, -95,
-45, -115, -26,
-57, -112, 14,
26, -78, -95,
0, -104, -72,
45, -115, -26,
-45, -115, -26,
45, -115, -26,
0, -124, 23,
-45, -115, -26,
-6, -126, -14,
90, -83, -32,
26, -78, -95,
26, -78, -95,
-112, 44, -39,
-126, -3, -9,
-126, -3, -9,
-52, -115, 8,
-60, -107, 31,
-60, -107, 31,
90, -83, -32,
-6, -126, -14,
90, -83, -32,
-4, -21, -125,
57, 105, -40,
57, 105, -40,
-4, -21, -125,
-112, 44, -39,
-112, 44, -39,
-4, -21, -125,
-52, -115, 8,
-52, -115, 8,
-4, -21, -125,
90, -83, -32,
-26, -78, -95,
-90, -83, -32,
6, -126, -14,
6, -126, -14,
-90, -83, -32,
60, -107, 31,
60, -107, 31,
52, -115, 8,
126, -3, -9,
126, -3, -9,
112, 44, -39,
-26, -78, -95,
-57, 105, -40,
4, -21, -125,
-90, -83, -32,
-90, -83, -32,
4, -21, -125,
52, -115, 8,
52, -115, 8,
4, -21, -125,
112, 44, -39,
112, 44, -39,
4, -21, -125,
-57, 105, -40,
16, -103, -71,
-48, -117, 2,
-26, -78, -95,
-26, -78, -95,
-48, -117, 2,
126, -3, -9,
126, -3, -9,
114, -51, -19,
57, 107, -33,
57, 107, -33,
-43, 107, -51,
16, -103, -71,
-120, -39, 0,
-12, -23, -124,
-48, -117, 2,
-48, -117, 2,
-12, -23, -124,
114, -51, -19,
114, -51, -19,
-12, -23, -124,
-43, 107, -51,
-43, 107, -51,
-12, -23, -124,
-120, -39, 0,
-57, 107, -33,
-114, -51, -19,
-126, -3, -9,
-126, -3, -9,
48, -117, 2,
26, -78, -95,
26, -78, -95,
48, -117, 2,
-16, -103, -71,
-16, -103, -71,
43, 107, -51,
-57, 107, -33,
43, 107, -51,
12, -23, -124,
-114, -51, -19,
-114, -51, -19,
12, -23, -124,
48, -117, 2,
48, -117, 2,
12, -23, -124,
120, -39, 0,
120, -39, 0,
12, -23, -124,
43, 107, -51,
0, -8, -126,
19, -124, 15,
16, -103, -71,
16, -103, -71,
19, -124, 15,
57, 107, -33,
57, 107, -33,
-76, 69, -74,
0, 120, -40,
0, 120, -40,
-76, 69, -74,
0, -8, -126,
-91, -85, -21,
11, -51, -115,
19, -124, 15,
19, -124, 15,
11, -51, -115,
122, 8, -33,
122, 8, -33,
11, -51, -115,
-76, 69, -74,
-76, 69, -74,
11, -51, -115,
-91, -85, -21,
-16, -103, -71,
-19, -124, 15,
0, -8, -126,
0, -8, -126,
76, 69, -74,
0, 120, -40,
0, 120, -40,
76, 69, -74,
-57, 107, -33,
-57, 107, -33,
-19, -124, 15,
-16, -103, -71,
-19, -124, 15,
-11, -51, -115,
91, -85, -21,
91, -85, -21,
-11, -51, -115,
76, 69, -74,
76, 69, -74,
-11, -51, -115,
-122, 8, -33,
-122, 8, -33,
-11, -51, -115,
-19, -124, 15,
0, -83, 95,
0, 4, 126,
-117, 29, 36,
117, 29, 36,
0, 4, 126,
0, -83, 95,
57, -112, 14,
-26, -78, -95,
6, -126, -14,
-57, -112, 14,
-6, -126, -14,
26, -78, -95,
-57, -112, 14,
0, -116, -50,
-6, -126, -14,
57, -112, 14,
6, -126, -14,
0, -116, -50,
-57, -112, 14,
0, -124, 23,
0, -116, -50,
117, 29, 36,
43, -116, 23,
122, 8, 31,
-122, 8, 31,
-43, -116, 23,
-117, 29, 36,
60, -107, 31,
126, -3, -9,
122, 8, 31,
-122, 8, 31,
-126, -3, -9,
-60, -107, 31,
-33, -76, 95,
-32, -116, 39,
-7, -71, 104,
32, -116, 39,
7, -71, 104,
-4, -119, 41,
0, 119, 42,
0, 4, 126,
38, 66, 101,
0, 119, 42,
38, 66, 101,
76, 87, 50,
0, 119, 42,
76, 87, 50,
64, 85, 67,
-38, 66, 101,
0, 4, 126,
0, 119, 42,
0, 119, 42,
-64, 85, 67,
-76, 87, 50,
0, 119, 42,
0, 126, 5,
-64, 85, 67,
0, -83, 95,
8, -118, 43,
0, -124, 23,
0, -124, 23,
-35, -117, 30,
-43, -116, 23,
-43, -116, 23,
-72, -1, 104,
-117, 29, 36,
-117, 29, 36,
13, -4, 126,
0, -83, 95,
43, -116, 23,
35, -117, 30,
0, -124, 23,
0, -124, 23,
-8, -118, 43,
0, -83, 95,
0, -83, 95,
-13, -4, 126,
117, 29, 36,
117, 29, 36,
72, -1, 104,
43, -116, 23,
72, -1, 104,
35, -117, 30,
43, -116, 23,
-13, -4, 126,
72, -1, 104,
117, 29, 36,
-8, -118, 43,
-13, -4, 126,
0, -83, 95,
35, -117, 30,
-8, -118, 43,
0, -124, 23,
-117, 29, 36,
-72, -1, 104,
13, -4, 126,
-43, -116, 23,
-35, -117, 30,
-72, -1, 104,
0, -124, 23,
8, -118, 43,
-35, -117, 30,
0, -83, 95,
13, -4, 126,
8, -118, 43,
117, 29, 36,
38, 66, 101,
0, 4, 126,
0, 4, 126,
-38, 66, 101,
-117, 29, 36,
-57, 107, -33,
-122, 8, -33,
-19, -124, 15,
76, 69, -74,
-122, 8, -33,
-57, 107, -33,
0, -8, -126,
91, -85, -21,
76, 69, -74,
-19, -124, 15,
91, -85, -21,
0, -8, -126,
-76, 69, -74,
-91, -85, -21,
0, -8, -126,
57, 107, -33,
122, 8, -33,
-76, 69, -74,
19, -124, 15,
122, 8, -33,
57, 107, -33,
0, -8, -126,
-91, -85, -21,
19, -124, 15,
-16, -103, -71,
120, -39, 0,
43, 107, -51,
48, -117, 2,
120, -39, 0,
-16, -103, -71,
-126, -3, -9,
-114, -51, -19,
48, -117, 2,
-57, 107, -33,
43, 107, -51,
-114, -51, -19,
-43, 107, -51,
-120, -39, 0,
16, -103, -71,
114, -51, -19,
-43, 107, -51,
57, 107, -33,
-48, -117, 2,
114, -51, -19,
126, -3, -9,
16, -103, -71,
-120, -39, 0,
-48, -117, 2,
112, 44, -39,
-57, 105, -40,
-26, -78, -95,
52, -115, 8,
112, 44, -39,
126, -3, -9,
-90, -83, -32,
52, -115, 8,
60, -107, 31,
-26, -78, -95,
-57, 105, -40,
-90, -83, -32,
-60, -107, 31,
-52, -115, 8,
90, -83, -32,
-126, -3, -9,
-112, 44, -39,
-52, -115, 8,
26, -78, -95,
57, 105, -40,
-112, 44, -39,
90, -83, -32,
57, 105, -40,
26, -78, -95,
0, -124, 23,
-57, -112, 14,
-45, -115, -26,
0, 126, 5,
64, 85, 67,
66, 106, -17,
-66, 106, -17,
-64, 85, 67,
0, 126, 5,
-76, 87, 50,
-64, 85, 67,
-66, 106, -17,
-117, 29, 36,
-38, 66, 101,
-76, 87, 50,
76, 87, 50,
38, 66, 101,
117, 29, 36,
66, 106, -17,
64, 85, 67,
76, 87, 50,
0, 124, -24,
66, 106, -17,
57, 107, -33,
-57, 107, -33,
-66, 106, -17,
0, 124, -24,
-126, -3, -9,
-122, 8, 31,
-66, 106, -17,
0, -119, -44,
0, -124, 23,
-43, -116, 23,
43, -116, 23,
0, -124, 23,
0, -119, -44,
66, 106, -17,
122, 8, 31,
126, -3, -9,
42, -44, -111,
52, -72, -89,
-52, -72, -89,
52, -72, -89,
0, -104, -72,
-52, -72, -89,
42, -44, -111,
-52, -72, -89,
-42, -44, -111,
45, -115, -26,
52, -72, -89,
42, -44, -111,
-42, -44, -111,
-52, -72, -89,
-45, -115, -26,
-58, 73, -85,
-71, 73, -74,
-42, -44, -111,
0, 103, -73,
0, 108, -66,
-71, 73, -74,
71, 73, -74,
0, 108, -66,
0, 103, -73,
42, -44, -111,
71, 73, -74,
58, 73, -85,
-58, 73, -85,
-111, -17, -58,
26, -78, -95,
0, 103, -73,
-58, 73, -85,
-16, -103, -71,
16, -103, -71,
58, 73, -85,
0, 103, -73,
-26, -78, -95,
111, -17, -58,
58, 73, -85,
0, -119, -44,
0, -116, -50,
6, -126, -14,
0, -119, -44,
-60, -107, 31,
-6, -126, -14,
0, -124, 23,
57, -112, 14,
0, -116, -50,
-8, -118, 43,
33, -76, 95,
-13, -4, 126,
-13, -4, 126,
-4, -119, 41,
72, -1, 104,
72, -1, 104,
-4, -119, 41,
35, -117, 30,
35, -117, 30,
33, -76, 95,
-8, -118, 43,
13, -4, 126,
-33, -76, 95,
8, -118, 43,
8, -118, 43,
-33, -76, 95,
-35, -117, 30,
-35, -117, 30,
4, -119, 41,
-72, -1, 104,
-72, -1, 104,
4, -119, 41,
13, -4, 126,
4, -119, 41,
-32, -116, 39,
13, -4, 126,
-35, -117, 30,
-7, -71, 104,
4, -119, 41,
-33, -76, 95,
-7, -71, 104,
-35, -117, 30,
13, -4, 126,
-32, -116, 39,
-33, -76, 95,
35, -117, 30,
7, -71, 104,
33, -76, 95,
-4, -119, 41,
7, -71, 104,
35, -117, 30,
-13, -4, 126,
32, -116, 39,
-4, -119, 41,
33, -76, 95,
32, -116, 39,
-13, -4, 126,
32, -116, 39,
33, -76, 95,
7, -71, 104,
-32, -116, 39,
4, -119, 41,
-7, -71, 104,
45, -115, -26,
57, -112, 14,
0, -124, 23,
17, -120, 37,
-17, -7, 125,
-17, -120, 37,
94, 31, -78,
-94, 31, -78,
80, 95, -23,
18, -7, 125,
-89, -90, 0,
-17, -7, 125,
-17, -7, 125,
-19, 125, 10,
-16, 125, 5,
-16, 125, 5,
19, 125, 10,
16, 125, 5,
16, 125, 5,
19, 125, 10,
18, -7, 125,
84, -88, 33,
94, 31, -78,
80, 95, -23,
-84, -88, 33,
91, -88, 5,
84, -88, 33,
-80, 95, -23,
-94, 31, -78,
-84, -88, 33,
-41, 102, -61,
-16, 125, 5,
41, 102, -61,
-94, 31, -78,
-91, -88, 5,
-84, -88, 33,
-84, -88, 33,
-91, -88, 5,
91, -88, 5,
84, -88, 33,
91, -88, 5,
94, 31, -78,
19, 125, 10,
89, -90, 0,
18, -7, 125,
-16, 125, 5,
-19, 125, 10,
19, 125, 10,
-17, -7, 125,
-89, -90, 0,
-19, 125, 10,
18, -7, 125,
89, -90, 0,
-89, -90, 0,
-94, 31, -78,
-80, 95, -23,
80, 95, -23,
-89, -90, 0,
42, -44, -111,
-42, -44, -111,
89, -90, 0,
71, 73, -74,
42, -44, -111,
19, 125, 10,
0, 108, -66,
71, 73, -74,
-19, 125, 10,
-71, 73, -74,
0, 108, -66,
-89, -90, 0,
-42, -44, -111,
-71, 73, -74,
19, 125, 10,
-19, 125, 10,
0, 108, -66,
-19, 125, 10,
-89, -90, 0,
-71, 73, -74,
17, -120, 37,
80, 95, -23,
41, 102, -61,
-17, -120, 37,
84, -88, 33,
17, -120, 37,
41, 102, -61,
-80, 95, -23,
-41, 102, -61,
-41, 102, -61,
-80, 95, -23,
-17, -120, 37,
-107, -49, 46,
69, -105, 10,
-47, -6, 117,
38, 2, -120,
-103, 37, -62,
93, 67, -54,
50, -113, -24,
38, 2, -120,
69, -105, 10,
-103, 37, -62,
-47, -6, 117,
-38, 118, 23,
-103, 37, -62,
-107, -49, 46,
-47, -6, 117,
38, 2, -120,
93, 67, -54,
69, -105, 10,
-103, 37, -62,
-38, 118, 23,
93, 67, -54,
-107, -49, 46,
50, -113, -24,
69, -105, 10,
-47, -6, 117,
-17, -120, 37,
-17, -7, 125,
69, -105, 10,
-41, 102, -61,
-17, -120, 37,
93, 67, -54,
-38, 118, 23,
-41, 102, -61,
-38, 118, 23,
-17, -7, 125,
-16, 125, 5,
47, -6, 117,
-69, -105, 10,
107, -49, 46,
-93, 67, -54,
103, 37, -62,
-38, 2, -120,
-69, -105, 10,
-38, 2, -120,
-50, -113, -24,
38, 118, 23,
47, -6, 117,
103, 37, -62,
47, -6, 117,
107, -49, 46,
103, 37, -62,
-69, -105, 10,
-93, 67, -54,
-38, 2, -120,
-93, 67, -54,
38, 118, 23,
103, 37, -62,
-69, -105, 10,
-50, -113, -24,
107, -49, 46,
47, -6, 117,
16, 125, 5,
18, -7, 125,
38, 118, 23,
41, 102, -61,
16, 125, 5,
-93, 67, -54,
-69, -105, 10,
41, 102, -61,
-69, -105, 10,
47, -6, 117,
17, -120, 37,
38, 118, 23,
16, 125, 5,
47, -6, 117,
-17, -7, 125,
-38, 118, 23,
-47, -6, 117,
81, -89, -39,
-32, -122, 12,
-96, -55, -61,
26, 24, -121,
43, 31, -115,
-26, 24, -121,
-26, 24, -121,
-96, -55, -61,
26, 24, -121,
-26, 24, -121,
81, -89, -39,
-96, -55, -61,
-43, 31, -115,
-32, -122, 12,
-94, 31, -78,
-32, -122, 12,
91, -88, 5,
-91, -88, 5,
30, -123, 7,
94, 31, -78,
91, -88, 5,
43, 31, -115,
-94, 31, -78,
94, 31, -78,
112, -55, 22,
-85, -77, 53,
83, -57, -75,
-68, 61, 87,
30, 96, -77,
-58, 91, -65,
-85, -77, 53,
-68, 61, 87,
-77, -58, -81,
75, 59, 82,
83, -57, -75,
30, 96, -77,
75, 59, 82,
112, -55, 22,
83, -57, -75,
-68, 61, 87,
-58, 91, -65,
-77, -58, -81,
-68, 61, 87,
75, 59, 82,
30, 96, -77,
-85, -77, 53,
-77, -58, -81,
83, -57, -75,
83, -57, -75,
-77, -58, -81,
-32, -122, 12,
-77, -58, -81,
-58, 91, -65,
-96, -55, -61,
-58, 91, -65,
-43, 31, -115,
26, 24, -121,
30, 96, -77,
-32, -122, 12,
-43, 31, -115,
-88, -55, -72,
85, -75, 55,
-112, -55, 22,
66, 85, -66,
-30, 96, -77,
68, 61, 87,
90, -73, -50,
68, 61, 87,
85, -75, 55,
-30, 96, -77,
-88, -55, -72,
-75, 59, 82,
-88, -55, -72,
-112, -55, 22,
-75, 59, 82,
90, -73, -50,
66, 85, -66,
68, 61, 87,
-30, 96, -77,
-75, 59, 82,
68, 61, 87,
-88, -55, -72,
90, -73, -50,
85, -75, 55,
-88, -55, -72,
-30, 96, -77,
30, -123, 7,
66, 85, -66,
-26, 24, -121,
43, 31, -115,
66, 85, -66,
81, -89, -39,
-26, 24, -121,
90, -73, -50,
30, -123, 7,
81, -89, -39,
-38, 2, -120,
20, -94, -81,
-50, -113, -24,
-50, -113, -24,
61, -106, -31,
107, -49, 46,
107, -49, 46,
61, -106, -31,
103, 37, -62,
103, 37, -62,
110, -20, -59,
-38, 2, -120,
50, -113, -24,
-26, -117, -41,
38, 2, -120,
38, 2, -120,
-110, -20, -59,
-103, 37, -62,
-103, 37, -62,
-110, -20, -59,
-107, -49, 46,
-107, -49, 46,
-61, -106, -31,
50, -113, -24,
-46, -117, -7,
89, -39, 80,
26, -117, -41,
89, -39, 80,
110, -20, -59,
61, -106, -31,
60, 111, 3,
20, -94, -81,
110, -20, -59,
-78, 27, -95,
-46, -117, -7,
20, -94, -81,
-89, -39, 80,
-26, -117, -41,
-61, -106, -31,
78, 27, -95,
-110, -20, -59,
-20, -94, -81,
-60, 111, 3,
-89, -39, 80,
-110, -20, -59,
-20, -94, -81,
-26, -117, -41,
78, 27, -95,
-103, -44, 59,
41, -119, 1,
-82, -48, 82,
39, 10, -120,
-99, 69, -37,
86, 42, -82,
33, -120, -20,
39, 10, -120,
41, -119, 1,
-99, 69, -37,
-82, -48, 82,
-42, 119, 4,
-99, 69, -37,
-103, -44, 59,
-82, -48, 82,
39, 10, -120,
86, 42, -82,
41, -119, 1,
-99, 69, -37,
-42, 119, 4,
86, 42, -82,
-103, -44, 59,
33, -120, -20,
41, -119, 1,
39, 10, -120,
-68, -64, -85,
-99, 69, -37,
-99, 69, -37,
-68, -64, -85,
-103, -44, 59,
-103, -44, 59,
-68, -64, -85,
33, -120, -20,
33, -120, -20,
-68, -64, -85,
39, 10, -120,
86, 42, -82,
-60, 111, 3,
78, 27, -95,
-42, 119, 4,
-82, -48, 82,
-60, 111, 3,
-82, -48, 82,
41, -119, 1,
-89, -39, 80,
41, -119, 1,
86, 42, -82,
46, -117, -7,
-68, 61, 87,
19, -86, 91,
75, 59, 82,
75, 59, 82,
19, -86, 91,
112, -55, 22,
112, -55, 22,
5, -95, 83,
-85, -77, 53,
-85, -77, 53,
-5, -96, 82,
-68, 61, 87,
85, -75, 55,
5, -96, 82,
-112, -55, 22,
-112, -55, 22,
-19, -86, 91,
-75, 59, 82,
-75, 59, 82,
-19, -86, 91,
68, 61, 87,
68, 61, 87,
5, -96, 82,
85, -75, 55,
89, -80, 40,
-26, -104, 67,
-89, -80, 40,
-85, 89, -28,
85, 91, -19,
85, 89, -28,
35, -102, 66,
85, 91, -19,
-89, -80, 40,
-84, 93, -18,
-26, -104, 67,
85, 89, -28,
89, -80, 40,
82, -24, 93,
85, 89, -28,
85, 89, -28,
15, 118, -42,
-85, 89, -28,
-85, 89, -28,
-96, 58, 58,
-89, -80, 40,
-89, -80, 40,
-96, 58, 58,
89, -80, 40,
-96, 58, 58,
82, -24, 93,
89, -80, 40,
-85, 89, -28,
-55, 107, -36,
-96, 58, 58,
15, 118, -42,
-55, 107, -36,
-85, 89, -28,
82, -24, 93,
15, 118, -42,
85, 89, -28,
-26, -104, 67,
89, -80, 40,
85, 89, -28,
85, 91, -19,
-85, 89, -28,
-89, -80, 40,
85, 91, -19,
-84, 93, -18,
85, 89, -28,
-26, -104, 67,
35, -102, 66,
-89, -80, 40,
85, 91, -19,
5, -96, 82,
27, -84, 91,
35, -102, 66,
-26, -104, 67,
5, -96, 82,
-26, -104, 67,
-84, 93, -18,
-5, -95, 83,
-84, 93, -18,
27, -84, 91,
-19, -86, 91,
89, -80, 40,
26, -104, 67,
-89, -80, 40,
-85, 89, -28,
-85, 91, -19,
85, 89, -28,
89, -80, 40,
-85, 91, -19,
-35, -102, 66,
-85, 89, -28,
26, -104, 67,
84, 93, -18,
-85, 89, -28,
-82, -24, 93,
-89, -80, 40,
85, 89, -28,
-15, 118, -42,
-85, 89, -28,
89, -80, 40,
96, 58, 58,
85, 89, -28,
-89, -80, 40,
96, 58, 58,
89, -80, 40,
-89, -80, 40,
-82, -24, 93,
96, 58, 58,
96, 58, 58,
55, 107, -36,
85, 89, -28,
85, 89, -28,
55, 107, -36,
-15, 118, -42,
-85, 89, -28,
-15, 118, -42,
-82, -24, 93,
-85, 89, -28,
-89, -80, 40,
26, -104, 67,
89, -80, 40,
85, 89, -28,
-85, 91, -19,
-85, 89, -28,
84, 93, -18,
-85, 91, -19,
89, -80, 40,
-35, -102, 66,
26, -104, 67,
26, -104, 67,
-5, -96, 82,
5, -95, 83,
-35, -102, 66,
-85, 91, -19,
-5, -96, 82,
-85, 91, -19,
84, 93, -18,
-27, -84, 91,
84, 93, -18,
5, -95, 83,
19, -86, 91,
79, -26, -95,
-35, -30, -118,
38, 113, -41,
-60, 45, 101,
109, 39, 51,
-45, 115, -25,
107, -64, 19,
29, -115, 43,
-87, -32, -85,
29, -115, 43,
109, 39, 51,
55, 42, 106,
-87, -32, -85,
-121, -34, -11,
-45, 115, -25,
55, 42, 106,
-4, -113, 57,
29, -115, 43,
29, -115, 43,
-4, -113, 57,
-121, -34, -11,
-121, -34, -11,
-4, -113, 57,
-60, 45, 101,
-60, 45, 101,
-4, -113, 57,
55, 42, 106,
107, -64, 19,
79, -26, -95,
109, 39, 51,
-87, -32, -85,
-35, -30, -118,
107, -64, 19,
-45, 115, -25,
-13, 115, -51,
-87, -32, -85,
-13, 115, -51,
-35, -30, -118,
-87, -32, -85,
-35, -30, -118,
79, -26, -95,
107, -64, 19,
79, -26, -95,
38, 113, -41,
109, 39, 51,
-121, -34, -11,
-60, 45, 101,
-45, 115, -25,
29, -115, 43,
107, -64, 19,
109, 39, 51,
29, -115, 43,
-121, -34, -11,
-87, -32, -85,
-60, 45, 101,
55, 42, 106,
109, 39, 51,
-35, -30, -118,
-13, 115, -51,
38, 113, -41,
109, 39, 51,
38, 113, -41,
96, 58, 58,
38, 113, -41,
-13, 115, -51,
55, 107, -36,
-13, 115, -51,
-45, 115, -25,
-15, 118, -42,
-45, 115, -25,
109, 39, 51,
-82, -24, 93,
-38, 113, -41,
35, -30, -118,
-79, -26, -95,
45, 115, -25,
-109, 39, 51,
60, 45, 101,
87, -32, -85,
-29, -115, 43,
-107, -64, 19,
-55, 42, 106,
-109, 39, 51,
-29, -115, 43,
45, 115, -25,
121, -34, -11,
87, -32, -85,
-29, -115, 43,
4, -113, 57,
-55, 42, 106,
121, -34, -11,
4, -113, 57,
-29, -115, 43,
60, 45, 101,
4, -113, 57,
121, -34, -11,
-55, 42, 106,
4, -113, 57,
60, 45, 101,
-109, 39, 51,
-79, -26, -95,
-107, -64, 19,
-107, -64, 19,
35, -30, -118,
87, -32, -85,
87, -32, -85,
13, 115, -51,
45, 115, -25,
87, -32, -85,
35, -30, -118,
13, 115, -51,
-107, -64, 19,
-79, -26, -95,
35, -30, -118,
-109, 39, 51,
-38, 113, -41,
-79, -26, -95,
45, 115, -25,
60, 45, 101,
121, -34, -11,
-109, 39, 51,
-107, -64, 19,
-29, -115, 43,
87, -32, -85,
121, -34, -11,
-29, -115, 43,
-109, 39, 51,
-55, 42, 106,
60, 45, 101,
-38, 113, -41,
13, 115, -51,
35, -30, -118,
-109, 39, 51,
82, -24, 93,
-96, 58, 58,
45, 115, -25,
15, 118, -42,
82, -24, 93,
13, 115, -51,
-55, 107, -36,
15, 118, -42,
-38, 113, -41,
-96, 58, 58,
-55, 107, -36,
43, 31, -115,
-30, 96, -77,
66, 85, -66,
-58, 91, -65,
30, 96, -77,
-43, 31, -115,
60, 111, 3,
-86, 42, -82,
-78, 27, -95,
-78, 27, -95,
-41, -119, 1,
-46, -117, -7,
89, -39, 80,
42, 119, 4,
60, 111, 3,
82, -48, 82,
-41, -119, 1,
103, -44, 59,
-86, 42, -82,
99, 69, -37,
-39, 10, -120,
-41, -119, 1,
-39, 10, -120,
-33, -120, -20,
42, 119, 4,
82, -48, 82,
99, 69, -37,
82, -48, 82,
103, -44, 59,
99, 69, -37,
-41, -119, 1,
-86, 42, -82,
-39, 10, -120,
-86, 42, -82,
42, 119, 4,
99, 69, -37,
-41, -119, 1,
-33, -120, -20,
103, -44, 59,
99, 69, -37,
68, -64, -85,
-39, 10, -120,
103, -44, 59,
68, -64, -85,
99, 69, -37,
-33, -120, -20,
68, -64, -85,
103, -44, 59,
-39, 10, -120,
68, -64, -85,
-33, -120, -20,
-46, -117, -7,
-41, -119, 1,
89, -39, 80,
-41, -119, 1,
82, -48, 82,
89, -39, 80,
89, -39, 80,
82, -48, 82,
42, 119, 4,
-78, 27, -95,
-86, 42, -82,
-41, -119, 1,
60, 111, 3,
42, 119, 4,
-86, 42, -82,
-38, 113, -41,
-109, 39, 51,
-96, 58, 58,
13, 115, -51,
-38, 113, -41,
-55, 107, -36,
45, 115, -25,
13, 115, -51,
15, 118, -42,
-109, 39, 51,
45, 115, -25,
82, -24, 93,
109, 39, 51,
96, 58, 58,
-82, -24, 93,
-45, 115, -25,
-82, -24, 93,
-15, 118, -42,
-13, 115, -51,
-15, 118, -42,
55, 107, -36,
38, 113, -41,
55, 107, -36,
96, 58, 58,
84, 93, -18,
26, -104, 67,
5, -95, 83,
84, 93, -18,
19, -86, 91,
-27, -84, 91,
-85, 91, -19,
-27, -84, 91,
-5, -96, 82,
26, -104, 67,
-35, -102, 66,
-5, -96, 82,
-84, 93, -18,
85, 91, -19,
27, -84, 91,
-84, 93, -18,
-19, -86, 91,
-5, -95, 83,
-26, -104, 67,
-5, -95, 83,
5, -96, 82,
85, 91, -19,
35, -102, 66,
5, -96, 82,
68, 61, 87,
27, -84, 91,
5, -96, 82,
-19, -86, 91,
27, -84, 91,
68, 61, 87,
-112, -55, 22,
-5, -95, 83,
-19, -86, 91,
5, -96, 82,
-5, -95, 83,
-112, -55, 22,
-5, -96, 82,
-27, -84, 91,
-68, 61, 87,
5, -95, 83,
-5, -96, 82,
-85, -77, 53,
19, -86, 91,
5, -95, 83,
112, -55, 22,
-68, 61, 87,
-27, -84, 91,
19, -86, 91,
86, 42, -82,
78, 27, -95,
46, -117, -7,
41, -119, 1,
46, -117, -7,
-89, -39, 80,
-82, -48, 82,
-89, -39, 80,
-60, 111, 3,
86, 42, -82,
-42, 119, 4,
-60, 111, 3,
-26, -117, -41,
46, -117, -7,
78, 27, -95,
-89, -39, 80,
-61, -106, -31,
-110, -20, -59,
78, 27, -95,
-60, 111, 3,
-110, -20, -59,
-89, -39, 80,
46, -117, -7,
-26, -117, -41,
-46, -117, -7,
26, -117, -41,
20, -94, -81,
60, 111, 3,
-78, 27, -95,
20, -94, -81,
89, -39, 80,
60, 111, 3,
110, -20, -59,
89, -39, 80,
61, -106, -31,
26, -117, -41,
-61, -106, -31,
-26, -117, -41,
50, -113, -24,
-110, -20, -59,
-61, -106, -31,
-107, -49, 46,
38, 2, -120,
-20, -94, -81,
-110, -20, -59,
-26, -117, -41,
-20, -94, -81,
38, 2, -120,
110, -20, -59,
20, -94, -81,
-38, 2, -120,
61, -106, -31,
110, -20, -59,
103, 37, -62,
-50, -113, -24,
26, -117, -41,
61, -106, -31,
20, -94, -81,
26, -117, -41,
-50, -113, -24,
90, -73, -50,
-88, -55, -72,
30, -123, 7,
66, 85, -66,
90, -73, -50,
81, -89, -39,
-30, 96, -77,
43, 31, -115,
30, -123, 7,
30, 96, -77,
83, -57, -75,
-32, -122, 12,
-58, 91, -65,
26, 24, -121,
-96, -55, -61,
-77, -58, -81,
-96, -55, -61,
-32, -122, 12,
43, 31, -115,
-43, 31, -115,
-94, 31, -78,
30, -123, 7,
43, 31, -115,
94, 31, -78,
-32, -122, 12,
30, -123, 7,
91, -88, 5,
-32, -122, 12,
-91, -88, 5,
-94, 31, -78,
26, 24, -121,
-43, 31, -115,
43, 31, -115,
81, -89, -39,
30, -123, 7,
-32, -122, 12,
47, -6, 117,
18, -7, 125,
17, -120, 37,
-69, -105, 10,
17, -120, 37,
41, 102, -61,
38, 118, 23,
-93, 67, -54,
41, 102, -61,
-38, 118, 23,
-16, 125, 5,
-41, 102, -61,
69, -105, 10,
93, 67, -54,
-41, 102, -61,
-47, -6, 117,
69, -105, 10,
-17, -120, 37,
-80, 95, -23,
-84, -88, 33,
-17, -120, 37,
41, 102, -61,
80, 95, -23,
-80, 95, -23,
-17, -120, 37,
-84, -88, 33,
84, -88, 33,
17, -120, 37,
84, -88, 33,
80, 95, -23,
89, -90, 0,
19, 125, 10,
71, 73, -74,
-89, -90, 0,
89, -90, 0,
42, -44, -111,
-16, 125, 5,
16, 125, 5,
41, 102, -61,
17, -120, 37,
18, -7, 125,
-17, -7, 125,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:3 */
static s8 vtxnvgrp_frake_select_3[]={
-8, -125, -14,
0, -118, -45,
0, -120, -39,
0, -120, -39,
8, -125, -14,
67, -101, 36,
-13, -80, -97,
63, 62, -90,
7, -101, -75,
7, -101, -75,
0, 92, -86,
0, -20, -125,
0, -20, -125,
0, 92, -86,
-7, -101, -75,
-7, -101, -75,
-63, 62, -90,
13, -80, -97,
13, -80, -97,
-110, -21, -59,
-50, -113, -27,
-13, -80, -97,
63, -108, 19,
50, -113, -27,
110, -21, -59,
38, -48, -110,
63, 62, -90,
63, 62, -90,
80, 57, -79,
0, 92, -86,
0, 92, -86,
-80, 57, -79,
-63, 62, -90,
-63, 62, -90,
-38, -48, -110,
-110, -21, -59,
-110, -21, -59,
-38, -48, -110,
-50, -113, -27,
-50, -113, -27,
-50, -73, -90,
0, -103, -74,
0, -103, -74,
50, -73, -90,
50, -113, -27,
50, -113, -27,
38, -48, -110,
110, -21, -59,
0, 117, 48,
-80, 85, 48,
-37, 77, 93,
67, 99, -39,
75, 100, -20,
126, -3, -9,
122, 10, 30,
52, -112, 28,
67, -101, 36,
67, -101, 36,
52, -112, 28,
0, -120, -39,
0, -120, -39,
-52, -112, 28,
-67, -101, 36,
-67, -101, 36,
-52, -112, 28,
-122, 10, 30,
-126, -3, -9,
-75, 100, -20,
-67, 99, -39,
-67, 99, -39,
0, 123, -31,
0, 117, -47,
0, 117, -47,
0, 123, -31,
67, 99, -39,
75, 100, -20,
80, 85, 48,
122, 10, 30,
122, 10, 30,
80, 85, 48,
116, 29, 42,
-116, 29, 42,
-80, 85, 48,
-122, 10, 30,
-122, 10, 30,
-80, 85, 48,
-75, 100, -20,
-75, 100, -20,
0, 126, 4,
0, 123, -31,
0, 123, -31,
0, 126, 4,
75, 100, -20,
63, 90, 62,
0, 126, 4,
0, 117, 48,
50, -113, -27,
110, -21, -59,
-13, -80, -97,
-50, -113, -27,
-63, -108, 19,
13, -80, -97,
0, -103, -74,
50, -113, -27,
-50, -113, -27,
50, -113, -27,
0, -123, 30,
-50, -113, -27,
-8, -125, -14,
85, -89, -29,
13, -80, -97,
13, -80, -97,
-108, 47, -46,
-126, -3, -9,
-126, -3, -9,
-58, -111, 10,
-67, -101, 36,
-67, -101, 36,
85, -89, -29,
-8, -125, -14,
85, -89, -29,
-4, -27, -123,
63, 98, -49,
63, 98, -49,
-4, -27, -123,
-108, 47, -46,
-108, 47, -46,
-4, -27, -123,
-58, -111, 10,
-58, -111, 10,
-4, -27, -123,
85, -89, -29,
-13, -80, -97,
-85, -89, -29,
8, -125, -14,
8, -125, -14,
-85, -89, -29,
67, -101, 36,
67, -101, 36,
58, -111, 10,
126, -3, -9,
126, -3, -9,
108, 47, -46,
-13, -80, -97,
-63, 98, -49,
4, -27, -123,
-85, -89, -29,
-85, -89, -29,
4, -27, -123,
58, -111, 10,
58, -111, 10,
4, -27, -123,
108, 47, -46,
108, 47, -46,
4, -27, -123,
-63, 98, -49,
7, -101, -75,
-53, -114, 3,
-13, -80, -97,
-13, -80, -97,
-53, -114, 3,
126, -3, -9,
126, -3, -9,
111, -58, -18,
67, 99, -39,
67, 99, -39,
-36, 104, -62,
7, -101, -75,
-122, -32, 0,
-12, -30, -122,
-53, -114, 3,
-53, -114, 3,
-12, -30, -122,
111, -58, -18,
111, -58, -18,
-12, -30, -122,
-36, 104, -62,
-36, 104, -62,
-12, -30, -122,
-122, -32, 0,
-67, 99, -39,
-111, -58, -18,
-126, -3, -9,
-126, -3, -9,
53, -114, 3,
13, -80, -97,
13, -80, -97,
53, -114, 3,
-7, -101, -75,
-7, -101, -75,
36, 104, -62,
-67, 99, -39,
36, 104, -62,
12, -30, -122,
-111, -58, -18,
-111, -58, -18,
12, -30, -122,
53, -114, 3,
53, -114, 3,
12, -30, -122,
122, -32, 0,
122, -32, 0,
12, -30, -122,
36, 104, -62,
0, -20, -125,
23, -123, 19,
7, -101, -75,
7, -101, -75,
23, -123, 19,
67, 99, -39,
67, 99, -39,
-72, 67, -79,
0, 117, -47,
0, 117, -47,
-72, 67, -79,
0, -20, -125,
-93, -83, -19,
9, -64, -109,
23, -123, 19,
23, -123, 19,
9, -64, -109,
121, 9, -34,
121, 9, -34,
9, -64, -109,
-72, 67, -79,
-72, 67, -79,
9, -64, -109,
-93, -83, -19,
-7, -101, -75,
-23, -123, 19,
0, -20, -125,
0, -20, -125,
72, 67, -79,
0, 117, -47,
0, 117, -47,
72, 67, -79,
-67, 99, -39,
-67, 99, -39,
-23, -123, 19,
-7, -101, -75,
-23, -123, 19,
-9, -64, -109,
93, -83, -19,
93, -83, -19,
-9, -64, -109,
72, 67, -79,
72, 67, -79,
-9, -64, -109,
-121, 9, -34,
-121, 9, -34,
-9, -64, -109,
-23, -123, 19,
0, -61, 111,
0, 10, 126,
-116, 29, 42,
116, 29, 42,
0, 10, 126,
0, -61, 111,
63, -108, 19,
-13, -80, -97,
8, -125, -14,
-63, -108, 19,
-8, -125, -14,
13, -80, -97,
-63, -108, 19,
0, -118, -45,
-8, -125, -14,
63, -108, 19,
8, -125, -14,
0, -118, -45,
-63, -108, 19,
0, -123, 30,
0, -118, -45,
116, 29, 42,
52, -112, 28,
122, 10, 30,
-122, 10, 30,
-52, -112, 28,
-116, 29, 42,
67, -101, 36,
126, -3, -9,
122, 10, 30,
-122, 10, 30,
-126, -3, -9,
-67, -101, 36,
-39, -62, 103,
-38, -110, 48,
-6, -60, 111,
38, -110, 48,
6, -60, 111,
-5, -115, 52,
0, 117, 48,
0, 10, 126,
37, 77, 93,
0, 117, 48,
37, 77, 93,
80, 85, 48,
0, 117, 48,
80, 85, 48,
63, 90, 62,
-37, 77, 93,
0, 10, 126,
0, 117, 48,
0, 117, 48,
-63, 90, 62,
-80, 85, 48,
0, 117, 48,
0, 126, 4,
-63, 90, 62,
0, -61, 111,
9, -114, 54,
0, -123, 30,
0, -123, 30,
-40, -113, 38,
-52, -112, 28,
-52, -112, 28,
-73, 0, 103,
-116, 29, 42,
-116, 29, 42,
14, -3, 126,
0, -61, 111,
52, -112, 28,
40, -113, 38,
0, -123, 30,
0, -123, 30,
-9, -114, 54,
0, -61, 111,
0, -61, 111,
-14, -3, 126,
116, 29, 42,
116, 29, 42,
73, 0, 103,
52, -112, 28,
73, 0, 103,
40, -113, 38,
52, -112, 28,
-14, -3, 126,
73, 0, 103,
116, 29, 42,
-9, -114, 54,
-14, -3, 126,
0, -61, 111,
40, -113, 38,
-9, -114, 54,
0, -123, 30,
-116, 29, 42,
-73, 0, 103,
14, -3, 126,
-52, -112, 28,
-40, -113, 38,
-73, 0, 103,
0, -123, 30,
9, -114, 54,
-40, -113, 38,
0, -61, 111,
14, -3, 126,
9, -114, 54,
116, 29, 42,
37, 77, 93,
0, 10, 126,
0, 10, 126,
-37, 77, 93,
-116, 29, 42,
-67, 99, -39,
-121, 9, -34,
-23, -123, 19,
72, 67, -79,
-121, 9, -34,
-67, 99, -39,
0, -20, -125,
93, -83, -19,
72, 67, -79,
-23, -123, 19,
93, -83, -19,
0, -20, -125,
-72, 67, -79,
-93, -83, -19,
0, -20, -125,
67, 99, -39,
121, 9, -34,
-72, 67, -79,
23, -123, 19,
121, 9, -34,
67, 99, -39,
0, -20, -125,
-93, -83, -19,
23, -123, 19,
-7, -101, -75,
122, -32, 0,
36, 104, -62,
53, -114, 3,
122, -32, 0,
-7, -101, -75,
-126, -3, -9,
-111, -58, -18,
53, -114, 3,
-67, 99, -39,
36, 104, -62,
-111, -58, -18,
-36, 104, -62,
-122, -32, 0,
7, -101, -75,
111, -58, -18,
-36, 104, -62,
67, 99, -39,
-53, -114, 3,
111, -58, -18,
126, -3, -9,
7, -101, -75,
-122, -32, 0,
-53, -114, 3,
108, 47, -46,
-63, 98, -49,
-13, -80, -97,
58, -111, 10,
108, 47, -46,
126, -3, -9,
-85, -89, -29,
58, -111, 10,
67, -101, 36,
-13, -80, -97,
-63, 98, -49,
-85, -89, -29,
-67, -101, 36,
-58, -111, 10,
85, -89, -29,
-126, -3, -9,
-108, 47, -46,
-58, -111, 10,
13, -80, -97,
63, 98, -49,
-108, 47, -46,
85, -89, -29,
63, 98, -49,
13, -80, -97,
0, -123, 30,
-63, -108, 19,
-50, -113, -27,
0, 126, 4,
63, 90, 62,
75, 100, -20,
-75, 100, -20,
-63, 90, 62,
0, 126, 4,
-80, 85, 48,
-63, 90, 62,
-75, 100, -20,
-116, 29, 42,
-37, 77, 93,
-80, 85, 48,
80, 85, 48,
37, 77, 93,
116, 29, 42,
75, 100, -20,
63, 90, 62,
80, 85, 48,
0, 123, -31,
75, 100, -20,
67, 99, -39,
-67, 99, -39,
-75, 100, -20,
0, 123, -31,
-126, -3, -9,
-122, 10, 30,
-75, 100, -20,
0, -120, -39,
0, -123, 30,
-52, -112, 28,
52, -112, 28,
0, -123, 30,
0, -120, -39,
75, 100, -20,
122, 10, 30,
126, -3, -9,
38, -48, -110,
50, -73, -90,
-50, -73, -90,
50, -73, -90,
0, -103, -74,
-50, -73, -90,
38, -48, -110,
-50, -73, -90,
-38, -48, -110,
50, -113, -27,
50, -73, -90,
38, -48, -110,
-38, -48, -110,
-50, -73, -90,
-50, -113, -27,
-63, 62, -90,
-80, 57, -79,
-38, -48, -110,
0, 92, -86,
0, 98, -79,
-80, 57, -79,
80, 57, -79,
0, 98, -79,
0, 92, -86,
38, -48, -110,
80, 57, -79,
63, 62, -90,
-63, 62, -90,
-110, -21, -59,
13, -80, -97,
0, 92, -86,
-63, 62, -90,
-7, -101, -75,
7, -101, -75,
63, 62, -90,
0, 92, -86,
-13, -80, -97,
110, -21, -59,
63, 62, -90,
0, -120, -39,
0, -118, -45,
8, -125, -14,
0, -120, -39,
-67, -101, 36,
-8, -125, -14,
0, -123, 30,
63, -108, 19,
0, -118, -45,
-9, -114, 54,
39, -62, 103,
-14, -3, 126,
-14, -3, 126,
-5, -115, 52,
73, 0, 103,
73, 0, 103,
-5, -115, 52,
40, -113, 38,
40, -113, 38,
39, -62, 103,
-9, -114, 54,
14, -3, 126,
-39, -62, 103,
9, -114, 54,
9, -114, 54,
-39, -62, 103,
-40, -113, 38,
-40, -113, 38,
5, -115, 52,
-73, 0, 103,
-73, 0, 103,
5, -115, 52,
14, -3, 126,
5, -115, 52,
-38, -110, 48,
14, -3, 126,
-40, -113, 38,
-6, -60, 111,
5, -115, 52,
-39, -62, 103,
-6, -60, 111,
-40, -113, 38,
14, -3, 126,
-38, -110, 48,
-39, -62, 103,
40, -113, 38,
6, -60, 111,
39, -62, 103,
-5, -115, 52,
6, -60, 111,
40, -113, 38,
-14, -3, 126,
38, -110, 48,
-5, -115, 52,
39, -62, 103,
38, -110, 48,
-14, -3, 126,
38, -110, 48,
39, -62, 103,
6, -60, 111,
-38, -110, 48,
5, -115, 52,
-6, -60, 111,
50, -113, -27,
63, -108, 19,
0, -123, 30,
23, -114, 49,
-17, 0, 125,
-23, -114, 49,
94, 32, -78,
-94, 32, -78,
81, 92, -31,
17, 0, 125,
-69, -103, -24,
-17, 0, 125,
-17, 0, 125,
-20, 125, 8,
-20, 125, -1,
-20, 125, -1,
20, 125, 8,
21, 125, -1,
21, 125, -1,
20, 125, 8,
17, 0, 125,
84, -83, 44,
94, 32, -78,
81, 92, -31,
-84, -83, 44,
89, -89, 10,
84, -83, 44,
-81, 92, -31,
-94, 32, -78,
-84, -83, 44,
-47, 94, -69,
-20, 125, -1,
47, 94, -69,
-94, 32, -78,
-89, -89, 10,
-84, -83, 44,
-84, -83, 44,
-89, -89, 10,
89, -89, 10,
84, -83, 44,
89, -89, 10,
94, 32, -78,
20, 125, 8,
69, -103, -24,
17, 0, 125,
-20, 125, -1,
-20, 125, 8,
20, 125, 8,
-17, 0, 125,
-69, -103, -24,
-20, 125, 8,
17, 0, 125,
69, -103, -24,
-69, -103, -24,
-94, 32, -78,
-81, 92, -31,
81, 92, -31,
-69, -103, -24,
38, -48, -110,
-38, -48, -110,
69, -103, -24,
80, 57, -79,
38, -48, -110,
20, 125, 8,
0, 98, -79,
80, 57, -79,
-20, 125, 8,
-80, 57, -79,
0, 98, -79,
-69, -103, -24,
-38, -48, -110,
-80, 57, -79,
20, 125, 8,
-20, 125, 8,
0, 98, -79,
-20, 125, 8,
-69, -103, -24,
-80, 57, -79,
23, -114, 49,
81, 92, -31,
47, 94, -69,
-23, -114, 49,
84, -83, 44,
23, -114, 49,
47, 94, -69,
-81, 92, -31,
-47, 94, -69,
-47, 94, -69,
-81, 92, -31,
-23, -114, 49,
-106, -50, 48,
73, -101, 19,
-47, 0, 117,
39, -2, -120,
-102, 37, -64,
91, 61, -62,
49, -115, -18,
39, -2, -120,
73, -101, 19,
-102, 37, -64,
-47, 0, 117,
-42, 118, 19,
-102, 37, -64,
-106, -50, 48,
-47, 0, 117,
39, -2, -120,
91, 61, -62,
73, -101, 19,
-102, 37, -64,
-42, 118, 19,
91, 61, -62,
-106, -50, 48,
49, -115, -18,
73, -101, 19,
-47, 0, 117,
-23, -114, 49,
-17, 0, 125,
73, -101, 19,
-47, 94, -69,
-23, -114, 49,
91, 61, -62,
-42, 118, 19,
-47, 94, -69,
-42, 118, 19,
-17, 0, 125,
-20, 125, -1,
47, 0, 117,
-73, -101, 19,
106, -50, 48,
-91, 61, -62,
102, 37, -64,
-39, -2, -120,
-73, -101, 19,
-39, -2, -120,
-49, -115, -18,
42, 118, 19,
47, 0, 117,
102, 37, -64,
47, 0, 117,
106, -50, 48,
102, 37, -64,
-73, -101, 19,
-91, 61, -62,
-39, -2, -120,
-91, 61, -62,
42, 118, 19,
102, 37, -64,
-73, -101, 19,
-49, -115, -18,
106, -50, 48,
47, 0, 117,
21, 125, -1,
17, 0, 125,
42, 118, 19,
47, 94, -69,
21, 125, -1,
-91, 61, -62,
-73, -101, 19,
47, 94, -69,
-73, -101, 19,
47, 0, 117,
23, -114, 49,
42, 118, 19,
21, 125, -1,
47, 0, 117,
-17, 0, 125,
-42, 118, 19,
-47, 0, 117,
89, -85, -28,
-37, -119, 18,
-101, -52, -55,
39, 18, -119,
48, 12, -116,
-39, 18, -119,
-39, 18, -119,
-101, -52, -55,
39, 18, -119,
-39, 18, -119,
89, -85, -28,
-101, -52, -55,
-48, 12, -116,
-37, -119, 18,
-94, 32, -78,
-37, -119, 18,
89, -89, 10,
-89, -89, 10,
34, -121, 11,
94, 32, -78,
89, -89, 10,
48, 12, -116,
-94, 32, -78,
94, 32, -78,
125, -18, -7,
-89, -66, 60,
79, -67, -73,
-68, 72, 78,
-7, 87, -91,
-9, 90, -88,
-89, -66, 60,
-68, 72, 78,
-76, -68, -74,
77, 68, 74,
79, -67, -73,
-7, 87, -91,
77, 68, 74,
125, -18, -7,
79, -67, -73,
-68, 72, 78,
-9, 90, -88,
-76, -68, -74,
-68, 72, 78,
77, 68, 74,
-7, 87, -91,
-89, -66, 60,
-76, -68, -74,
79, -67, -73,
79, -67, -73,
-76, -68, -74,
-37, -119, 18,
-76, -68, -74,
-9, 90, -88,
-101, -52, -55,
-9, 90, -88,
-48, 12, -116,
39, 18, -119,
-7, 87, -91,
-37, -119, 18,
-48, 12, -116,
-110, -41, -47,
-89, -63, 64,
-125, -18, -7,
57, 76, -83,
7, 87, -91,
72, 70, 77,
98, -75, -27,
72, 70, 77,
-89, -63, 64,
7, 87, -91,
-110, -41, -47,
-77, 68, 74,
-110, -41, -47,
-125, -18, -7,
-77, 68, 74,
98, -75, -27,
57, 76, -83,
72, 70, 77,
7, 87, -91,
-77, 68, 74,
72, 70, 77,
-110, -41, -47,
98, -75, -27,
-89, -63, 64,
-110, -41, -47,
7, 87, -91,
34, -121, 11,
57, 76, -83,
-39, 18, -119,
48, 12, -116,
57, 76, -83,
89, -85, -28,
-39, 18, -119,
98, -75, -27,
34, -121, 11,
89, -85, -28,
-39, -2, -120,
22, -93, -82,
-49, -115, -18,
-49, -115, -18,
65, -105, -27,
106, -50, 48,
106, -50, 48,
65, -105, -27,
102, 37, -64,
102, 37, -64,
107, -23, -62,
-39, -2, -120,
49, -115, -18,
-27, -117, -40,
39, -2, -120,
39, -2, -120,
-107, -23, -62,
-102, 37, -64,
-102, 37, -64,
-107, -23, -62,
-106, -50, 48,
-106, -50, 48,
-65, -105, -27,
49, -115, -18,
-49, -116, -1,
87, -33, 85,
27, -117, -40,
87, -33, 85,
107, -23, -62,
65, -105, -27,
63, 109, -2,
22, -93, -82,
107, -23, -62,
-77, 22, -98,
-49, -116, -1,
22, -93, -82,
-87, -33, 85,
-27, -117, -40,
-65, -105, -27,
77, 22, -98,
-107, -23, -62,
-22, -93, -82,
-63, 109, -2,
-87, -33, 85,
-107, -23, -62,
-22, -93, -82,
-27, -117, -40,
77, 22, -98,
-102, -43, 60,
45, -118, 10,
-78, -44, 89,
38, 5, -120,
-97, 67, -45,
85, 39, -85,
33, -121, -15,
38, 5, -120,
45, -118, 10,
-97, 67, -45,
-78, -44, 89,
-43, 119, -1,
-97, 67, -45,
-102, -43, 60,
-78, -44, 89,
38, 5, -120,
85, 39, -85,
45, -118, 10,
-97, 67, -45,
-43, 119, -1,
85, 39, -85,
-102, -43, 60,
33, -121, -15,
45, -118, 10,
38, 5, -120,
-67, -77, -74,
-97, 67, -45,
-97, 67, -45,
-67, -77, -74,
-102, -43, 60,
-102, -43, 60,
-67, -77, -74,
33, -121, -15,
33, -121, -15,
-67, -77, -74,
38, 5, -120,
85, 39, -85,
-63, 109, -2,
77, 22, -98,
-43, 119, -1,
-78, -44, 89,
-63, 109, -2,
-78, -44, 89,
45, -118, 10,
-87, -33, 85,
45, -118, 10,
85, 39, -85,
49, -116, -1,
-68, 72, 78,
2, -91, 88,
77, 68, 74,
77, 68, 74,
2, -91, 88,
125, -18, -7,
125, -18, -7,
0, -92, 87,
-89, -66, 60,
-89, -66, 60,
0, -92, 86,
-68, 72, 78,
-89, -63, 64,
0, -92, 86,
-125, -18, -7,
-125, -18, -7,
-2, -91, 88,
-77, 68, 74,
-77, 68, 74,
-2, -91, 88,
72, 70, 77,
72, 70, 77,
0, -92, 86,
-89, -63, 64,
89, -72, 53,
-4, -95, 83,
-89, -72, 53,
-84, 86, -39,
83, 86, -41,
84, 86, -39,
6, -95, 83,
83, 86, -41,
-89, -72, 53,
-82, 86, -41,
-4, -95, 83,
84, 86, -39,
89, -72, 53,
76, 36, 94,
84, 86, -39,
84, 86, -39,
23, 112, -54,
-84, 86, -39,
-84, 86, -39,
-99, 66, 42,
-89, -72, 53,
-89, -72, 53,
-99, 66, 42,
89, -72, 53,
-99, 66, 42,
76, 36, 94,
89, -72, 53,
-84, 86, -39,
-64, 97, -48,
-99, 66, 42,
23, 112, -54,
-64, 97, -48,
-84, 86, -39,
76, 36, 94,
23, 112, -54,
84, 86, -39,
-4, -95, 83,
89, -72, 53,
84, 86, -39,
83, 86, -41,
-84, 86, -39,
-89, -72, 53,
83, 86, -41,
-82, 86, -41,
84, 86, -39,
-4, -95, 83,
6, -95, 83,
-89, -72, 53,
83, 86, -41,
0, -92, 86,
3, -91, 88,
6, -95, 83,
-4, -95, 83,
0, -92, 86,
-4, -95, 83,
-82, 86, -41,
0, -92, 87,
-82, 86, -41,
3, -91, 88,
-2, -91, 88,
89, -72, 53,
5, -95, 83,
-89, -72, 53,
-84, 86, -39,
-83, 86, -41,
84, 86, -39,
89, -72, 53,
-83, 86, -41,
-6, -95, 83,
-84, 86, -39,
5, -95, 83,
82, 86, -41,
-84, 86, -39,
-76, 36, 94,
-89, -72, 53,
84, 86, -39,
-23, 112, -54,
-84, 86, -39,
89, -72, 53,
99, 66, 42,
84, 86, -39,
-89, -72, 53,
99, 66, 42,
89, -72, 53,
-89, -72, 53,
-76, 36, 94,
99, 66, 42,
99, 66, 42,
64, 97, -48,
84, 86, -39,
84, 86, -39,
64, 97, -48,
-23, 112, -54,
-84, 86, -39,
-23, 112, -54,
-76, 36, 94,
-84, 86, -39,
-89, -72, 53,
5, -95, 83,
89, -72, 53,
84, 86, -39,
-83, 86, -41,
-84, 86, -39,
82, 86, -41,
-83, 86, -41,
89, -72, 53,
-6, -95, 83,
5, -95, 83,
5, -95, 83,
0, -92, 86,
0, -92, 87,
-6, -95, 83,
-83, 86, -41,
0, -92, 86,
-83, 86, -41,
82, 86, -41,
-3, -91, 88,
82, 86, -41,
0, -92, 87,
2, -91, 88,
81, -33, -91,
-40, -37, -114,
51, 103, -51,
-62, 60, 92,
105, 58, 40,
-56, 109, -29,
104, -69, 20,
46, -105, 53,
-94, -43, -73,
46, -105, 53,
105, 58, 40,
57, 54, 99,
-94, -43, -73,
-118, -45, 1,
-56, 109, -29,
57, 54, 99,
-7, -99, 78,
46, -105, 53,
46, -105, 53,
-7, -99, 78,
-118, -45, 1,
-118, -45, 1,
-7, -99, 78,
-62, 60, 92,
-62, 60, 92,
-7, -99, 78,
57, 54, 99,
104, -69, 20,
81, -33, -91,
105, 58, 40,
-94, -43, -73,
-40, -37, -114,
104, -69, 20,
-56, 109, -29,
-22, 106, -65,
-94, -43, -73,
-22, 106, -65,
-40, -37, -114,
-94, -43, -73,
-40, -37, -114,
81, -33, -91,
104, -69, 20,
81, -33, -91,
51, 103, -51,
105, 58, 40,
-118, -45, 1,
-62, 60, 92,
-56, 109, -29,
46, -105, 53,
104, -69, 20,
105, 58, 40,
46, -105, 53,
-118, -45, 1,
-94, -43, -73,
-62, 60, 92,
57, 54, 99,
105, 58, 40,
-40, -37, -114,
-22, 106, -65,
51, 103, -51,
105, 58, 40,
51, 103, -51,
99, 66, 42,
51, 103, -51,
-22, 106, -65,
64, 97, -48,
-22, 106, -65,
-56, 109, -29,
-23, 112, -54,
-56, 109, -29,
105, 58, 40,
-76, 36, 94,
-51, 103, -51,
40, -37, -114,
-81, -33, -91,
56, 109, -29,
-105, 58, 40,
62, 60, 92,
94, -43, -73,
-46, -105, 53,
-104, -69, 20,
-57, 54, 99,
-105, 58, 40,
-46, -105, 53,
56, 109, -29,
118, -45, 1,
94, -43, -73,
-46, -105, 53,
7, -99, 78,
-57, 54, 99,
118, -45, 1,
7, -99, 78,
-46, -105, 53,
62, 60, 92,
7, -99, 78,
118, -45, 1,
-57, 54, 99,
7, -99, 78,
62, 60, 92,
-105, 58, 40,
-81, -33, -91,
-104, -69, 20,
-104, -69, 20,
40, -37, -114,
94, -43, -73,
94, -43, -73,
22, 106, -65,
56, 109, -29,
94, -43, -73,
40, -37, -114,
22, 106, -65,
-104, -69, 20,
-81, -33, -91,
40, -37, -114,
-105, 58, 40,
-51, 103, -51,
-81, -33, -91,
56, 109, -29,
62, 60, 92,
118, -45, 1,
-105, 58, 40,
-104, -69, 20,
-46, -105, 53,
94, -43, -73,
118, -45, 1,
-46, -105, 53,
-105, 58, 40,
-57, 54, 99,
62, 60, 92,
-51, 103, -51,
22, 106, -65,
40, -37, -114,
-105, 58, 40,
76, 36, 94,
-99, 66, 42,
56, 109, -29,
23, 112, -54,
76, 36, 94,
22, 106, -65,
-64, 97, -48,
23, 112, -54,
-51, 103, -51,
-99, 66, 42,
-64, 97, -48,
48, 12, -116,
7, 87, -91,
57, 76, -83,
-9, 90, -88,
-7, 87, -91,
-48, 12, -116,
63, 109, -2,
-85, 39, -85,
-77, 22, -98,
-77, 22, -98,
-45, -118, 10,
-49, -116, -1,
87, -33, 85,
43, 119, -1,
63, 109, -2,
78, -44, 89,
-45, -118, 10,
102, -43, 60,
-85, 39, -85,
97, 67, -45,
-38, 5, -120,
-45, -118, 10,
-38, 5, -120,
-33, -121, -15,
43, 119, -1,
78, -44, 89,
97, 67, -45,
78, -44, 89,
102, -43, 60,
97, 67, -45,
-45, -118, 10,
-85, 39, -85,
-38, 5, -120,
-85, 39, -85,
43, 119, -1,
97, 67, -45,
-45, -118, 10,
-33, -121, -15,
102, -43, 60,
97, 67, -45,
67, -77, -74,
-38, 5, -120,
102, -43, 60,
67, -77, -74,
97, 67, -45,
-33, -121, -15,
67, -77, -74,
102, -43, 60,
-38, 5, -120,
67, -77, -74,
-33, -121, -15,
-49, -116, -1,
-45, -118, 10,
87, -33, 85,
-45, -118, 10,
78, -44, 89,
87, -33, 85,
87, -33, 85,
78, -44, 89,
43, 119, -1,
-77, 22, -98,
-85, 39, -85,
-45, -118, 10,
63, 109, -2,
43, 119, -1,
-85, 39, -85,
-51, 103, -51,
-105, 58, 40,
-99, 66, 42,
22, 106, -65,
-51, 103, -51,
-64, 97, -48,
56, 109, -29,
22, 106, -65,
23, 112, -54,
-105, 58, 40,
56, 109, -29,
76, 36, 94,
105, 58, 40,
99, 66, 42,
-76, 36, 94,
-56, 109, -29,
-76, 36, 94,
-23, 112, -54,
-22, 106, -65,
-23, 112, -54,
64, 97, -48,
51, 103, -51,
64, 97, -48,
99, 66, 42,
82, 86, -41,
5, -95, 83,
0, -92, 87,
82, 86, -41,
2, -91, 88,
-3, -91, 88,
-83, 86, -41,
-3, -91, 88,
0, -92, 86,
5, -95, 83,
-6, -95, 83,
0, -92, 86,
-82, 86, -41,
83, 86, -41,
3, -91, 88,
-82, 86, -41,
-2, -91, 88,
0, -92, 87,
-4, -95, 83,
0, -92, 87,
0, -92, 86,
83, 86, -41,
6, -95, 83,
0, -92, 86,
72, 70, 77,
3, -91, 88,
0, -92, 86,
-2, -91, 88,
3, -91, 88,
72, 70, 77,
-125, -18, -7,
0, -92, 87,
-2, -91, 88,
0, -92, 86,
0, -92, 87,
-125, -18, -7,
0, -92, 86,
-3, -91, 88,
-68, 72, 78,
0, -92, 87,
0, -92, 86,
-89, -66, 60,
2, -91, 88,
0, -92, 87,
125, -18, -7,
-68, 72, 78,
-3, -91, 88,
2, -91, 88,
85, 39, -85,
77, 22, -98,
49, -116, -1,
45, -118, 10,
49, -116, -1,
-87, -33, 85,
-78, -44, 89,
-87, -33, 85,
-63, 109, -2,
85, 39, -85,
-43, 119, -1,
-63, 109, -2,
-27, -117, -40,
49, -116, -1,
77, 22, -98,
-87, -33, 85,
-65, -105, -27,
-107, -23, -62,
77, 22, -98,
-63, 109, -2,
-107, -23, -62,
-87, -33, 85,
49, -116, -1,
-27, -117, -40,
-49, -116, -1,
27, -117, -40,
22, -93, -82,
63, 109, -2,
-77, 22, -98,
22, -93, -82,
87, -33, 85,
63, 109, -2,
107, -23, -62,
87, -33, 85,
65, -105, -27,
27, -117, -40,
-65, -105, -27,
-27, -117, -40,
49, -115, -18,
-107, -23, -62,
-65, -105, -27,
-106, -50, 48,
39, -2, -120,
-22, -93, -82,
-107, -23, -62,
-27, -117, -40,
-22, -93, -82,
39, -2, -120,
107, -23, -62,
22, -93, -82,
-39, -2, -120,
65, -105, -27,
107, -23, -62,
102, 37, -64,
-49, -115, -18,
27, -117, -40,
65, -105, -27,
22, -93, -82,
27, -117, -40,
-49, -115, -18,
98, -75, -27,
-110, -41, -47,
34, -121, 11,
57, 76, -83,
98, -75, -27,
89, -85, -28,
7, 87, -91,
48, 12, -116,
34, -121, 11,
-7, 87, -91,
79, -67, -73,
-37, -119, 18,
-9, 90, -88,
39, 18, -119,
-101, -52, -55,
-76, -68, -74,
-101, -52, -55,
-37, -119, 18,
48, 12, -116,
-48, 12, -116,
-94, 32, -78,
34, -121, 11,
48, 12, -116,
94, 32, -78,
-37, -119, 18,
34, -121, 11,
89, -89, 10,
-37, -119, 18,
-89, -89, 10,
-94, 32, -78,
39, 18, -119,
-48, 12, -116,
48, 12, -116,
89, -85, -28,
34, -121, 11,
-37, -119, 18,
47, 0, 117,
17, 0, 125,
23, -114, 49,
-73, -101, 19,
23, -114, 49,
47, 94, -69,
42, 118, 19,
-91, 61, -62,
47, 94, -69,
-42, 118, 19,
-20, 125, -1,
-47, 94, -69,
73, -101, 19,
91, 61, -62,
-47, 94, -69,
-47, 0, 117,
73, -101, 19,
-23, -114, 49,
-81, 92, -31,
-84, -83, 44,
-23, -114, 49,
47, 94, -69,
81, 92, -31,
-81, 92, -31,
-23, -114, 49,
-84, -83, 44,
84, -83, 44,
23, -114, 49,
84, -83, 44,
81, 92, -31,
69, -103, -24,
20, 125, 8,
80, 57, -79,
-69, -103, -24,
69, -103, -24,
38, -48, -110,
-20, 125, -1,
21, 125, -1,
47, 94, -69,
23, -114, 49,
17, 0, 125,
-17, 0, 125,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:4 */
static s8 vtxnvgrp_frake_select_4[]={
-10, -125, -14,
0, -120, -39,
0, -121, -35,
0, -121, -35,
10, -125, -14,
72, -95, 40,
-3, -79, -99,
67, 52, -93,
0, -99, -78,
0, -99, -78,
0, 82, -96,
0, -32, -122,
0, -32, -122,
0, 82, -96,
0, -99, -78,
0, -99, -78,
-67, 52, -93,
3, -79, -99,
3, -79, -99,
-109, -24, -59,
-55, -110, -27,
-3, -79, -99,
67, -104, 24,
55, -110, -27,
109, -24, -59,
34, -50, -111,
67, 52, -93,
67, 52, -93,
85, 45, -81,
0, 82, -96,
0, 82, -96,
-85, 45, -81,
-67, 52, -93,
-67, 52, -93,
-34, -50, -111,
-109, -24, -59,
-109, -24, -59,
-34, -50, -111,
-55, -110, -27,
-55, -110, -27,
-49, -72, -91,
0, -101, -75,
0, -101, -75,
49, -72, -91,
55, -110, -27,
55, -110, -27,
34, -50, -111,
109, -24, -59,
0, 115, 53,
-83, 83, 47,
-37, 86, 85,
75, 91, -43,
81, 94, -24,
126, -4, -10,
122, 11, 29,
59, -107, 33,
72, -95, 40,
72, -95, 40,
59, -107, 33,
0, -121, -35,
0, -121, -35,
-59, -107, 33,
-72, -95, 40,
-72, -95, 40,
-59, -107, 33,
-122, 11, 29,
-126, -4, -10,
-81, 94, -24,
-75, 91, -43,
-75, 91, -43,
0, 121, -38,
0, 115, -53,
0, 115, -53,
0, 121, -38,
75, 91, -43,
81, 94, -24,
83, 83, 47,
122, 11, 29,
122, 11, 29,
83, 83, 47,
114, 29, 46,
-114, 29, 46,
-83, 83, 47,
-122, 11, 29,
-122, 11, 29,
-83, 83, 47,
-81, 94, -24,
-81, 94, -24,
0, 126, 3,
0, 121, -38,
0, 121, -38,
0, 126, 3,
81, 94, -24,
62, 93, 58,
0, 126, 3,
0, 115, 53,
55, -110, -27,
109, -24, -59,
-3, -79, -99,
-55, -110, -27,
-67, -104, 24,
3, -79, -99,
0, -101, -75,
55, -110, -27,
-55, -110, -27,
55, -110, -27,
0, -121, 36,
-55, -110, -27,
-10, -125, -14,
82, -93, -25,
3, -79, -99,
3, -79, -99,
-105, 48, -52,
-126, -4, -10,
-126, -4, -10,
-63, -108, 12,
-72, -95, 40,
-72, -95, 40,
82, -93, -25,
-10, -125, -14,
82, -93, -25,
-4, -33, -122,
66, 90, -58,
66, 90, -58,
-4, -33, -122,
-105, 48, -52,
-105, 48, -52,
-4, -33, -122,
-63, -108, 12,
-63, -108, 12,
-4, -33, -122,
82, -93, -25,
-3, -79, -99,
-82, -93, -25,
10, -125, -14,
10, -125, -14,
-82, -93, -25,
72, -95, 40,
72, -95, 40,
63, -108, 12,
126, -4, -10,
126, -4, -10,
105, 48, -52,
-3, -79, -99,
-66, 90, -58,
4, -33, -122,
-82, -93, -25,
-82, -93, -25,
4, -33, -122,
63, -108, 12,
63, -108, 12,
4, -33, -122,
105, 48, -52,
105, 48, -52,
4, -33, -122,
-66, 90, -58,
0, -99, -78,
-57, -113, 3,
-3, -79, -99,
-3, -79, -99,
-57, -113, 3,
126, -4, -10,
126, -4, -10,
108, -64, -16,
75, 91, -43,
75, 91, -43,
-30, 99, -73,
0, -99, -78,
-123, -28, 0,
-12, -36, -120,
-57, -113, 3,
-57, -113, 3,
-12, -36, -120,
108, -64, -16,
108, -64, -16,
-12, -36, -120,
-30, 99, -73,
-30, 99, -73,
-12, -36, -120,
-123, -28, 0,
-75, 91, -43,
-108, -64, -16,
-126, -4, -10,
-126, -4, -10,
57, -113, 3,
3, -79, -99,
3, -79, -99,
57, -113, 3,
0, -99, -78,
0, -99, -78,
30, 99, -73,
-75, 91, -43,
30, 99, -73,
12, -36, -120,
-108, -64, -16,
-108, -64, -16,
12, -36, -120,
57, -113, 3,
57, -113, 3,
12, -36, -120,
123, -28, 0,
123, -28, 0,
12, -36, -120,
30, 99, -73,
0, -32, -122,
27, -121, 23,
0, -99, -78,
0, -99, -78,
27, -121, 23,
75, 91, -43,
75, 91, -43,
-68, 66, -84,
0, 115, -53,
0, 115, -53,
-68, 66, -84,
0, -32, -122,
-95, -81, -17,
7, -75, -101,
27, -121, 23,
27, -121, 23,
7, -75, -101,
121, 10, -36,
121, 10, -36,
7, -75, -101,
-68, 66, -84,
-68, 66, -84,
7, -75, -101,
-95, -81, -17,
0, -99, -78,
-27, -121, 23,
0, -32, -122,
0, -32, -122,
68, 66, -84,
0, 115, -53,
0, 115, -53,
68, 66, -84,
-75, 91, -43,
-75, 91, -43,
-27, -121, 23,
0, -99, -78,
-27, -121, 23,
-7, -75, -101,
95, -81, -17,
95, -81, -17,
-7, -75, -101,
68, 66, -84,
68, 66, -84,
-7, -75, -101,
-121, 10, -36,
-121, 10, -36,
-7, -75, -101,
-27, -121, 23,
0, -40, 120,
0, 15, 126,
-114, 29, 46,
114, 29, 46,
0, 15, 126,
0, -40, 120,
67, -104, 24,
-3, -79, -99,
10, -125, -14,
-67, -104, 24,
-10, -125, -14,
3, -79, -99,
-67, -104, 24,
0, -120, -39,
-10, -125, -14,
67, -104, 24,
10, -125, -14,
0, -120, -39,
-67, -104, 24,
0, -121, 36,
0, -120, -39,
114, 29, 46,
59, -107, 33,
122, 11, 29,
-122, 11, 29,
-59, -107, 33,
-114, 29, 46,
72, -95, 40,
126, -4, -10,
122, 11, 29,
-122, 11, 29,
-126, -4, -10,
-72, -95, 40,
-43, -51, 107,
-43, -104, 57,
-4, -50, 116,
43, -104, 57,
4, -50, 116,
-6, -110, 62,
0, 115, 53,
0, 15, 126,
37, 86, 85,
0, 115, 53,
37, 86, 85,
83, 83, 47,
0, 115, 53,
83, 83, 47,
62, 93, 58,
-37, 86, 85,
0, 15, 126,
0, 115, 53,
0, 115, 53,
-62, 93, 58,
-83, 83, 47,
0, 115, 53,
0, 126, 3,
-62, 93, 58,
0, -40, 120,
11, -109, 63,
0, -121, 37,
0, -121, 37,
-44, -109, 46,
-59, -107, 33,
-59, -107, 33,
-74, 2, 102,
-114, 29, 46,
-114, 29, 46,
14, -1, 126,
0, -40, 120,
59, -107, 33,
44, -109, 46,
0, -121, 37,
0, -121, 37,
-11, -109, 63,
0, -40, 120,
0, -40, 120,
-14, -1, 126,
114, 29, 46,
114, 29, 46,
74, 2, 102,
59, -107, 33,
74, 2, 102,
44, -109, 46,
59, -107, 33,
-14, -1, 126,
74, 2, 102,
114, 29, 46,
-11, -109, 63,
-14, -1, 126,
0, -40, 120,
44, -109, 46,
-11, -109, 63,
0, -121, 37,
-114, 29, 46,
-74, 2, 102,
14, -1, 126,
-59, -107, 33,
-44, -109, 46,
-74, 2, 102,
0, -121, 37,
11, -109, 63,
-44, -109, 46,
0, -40, 120,
14, -1, 126,
11, -109, 63,
114, 29, 46,
37, 86, 85,
0, 15, 126,
0, 15, 126,
-37, 86, 85,
-114, 29, 46,
-75, 91, -43,
-121, 10, -36,
-27, -121, 23,
68, 66, -84,
-121, 10, -36,
-75, 91, -43,
0, -32, -122,
95, -81, -17,
68, 66, -84,
-27, -121, 23,
95, -81, -17,
0, -32, -122,
-68, 66, -84,
-95, -81, -17,
0, -32, -122,
75, 91, -43,
121, 10, -36,
-68, 66, -84,
27, -121, 23,
121, 10, -36,
75, 91, -43,
0, -32, -122,
-95, -81, -17,
27, -121, 23,
0, -99, -78,
123, -28, 0,
30, 99, -73,
57, -113, 3,
123, -28, 0,
0, -99, -78,
-126, -4, -10,
-108, -64, -16,
57, -113, 3,
-75, 91, -43,
30, 99, -73,
-108, -64, -16,
-30, 99, -73,
-123, -28, 0,
0, -99, -78,
108, -64, -16,
-30, 99, -73,
75, 91, -43,
-57, -113, 3,
108, -64, -16,
126, -4, -10,
0, -99, -78,
-123, -28, 0,
-57, -113, 3,
105, 48, -52,
-66, 90, -58,
-3, -79, -99,
63, -108, 12,
105, 48, -52,
126, -4, -10,
-82, -93, -25,
63, -108, 12,
72, -95, 40,
-3, -79, -99,
-66, 90, -58,
-82, -93, -25,
-72, -95, 40,
-63, -108, 12,
82, -93, -25,
-126, -4, -10,
-105, 48, -52,
-63, -108, 12,
3, -79, -99,
66, 90, -58,
-105, 48, -52,
82, -93, -25,
66, 90, -58,
3, -79, -99,
0, -121, 36,
-67, -104, 24,
-55, -110, -27,
0, 126, 3,
62, 93, 58,
81, 94, -24,
-81, 94, -24,
-62, 93, 58,
0, 126, 3,
-83, 83, 47,
-62, 93, 58,
-81, 94, -24,
-114, 29, 46,
-37, 86, 85,
-83, 83, 47,
83, 83, 47,
37, 86, 85,
114, 29, 46,
81, 94, -24,
62, 93, 58,
83, 83, 47,
0, 121, -38,
81, 94, -24,
75, 91, -43,
-75, 91, -43,
-81, 94, -24,
0, 121, -38,
-126, -4, -10,
-122, 11, 29,
-81, 94, -24,
0, -121, -35,
0, -121, 37,
-59, -107, 33,
59, -107, 33,
0, -121, 37,
0, -121, -35,
81, 94, -24,
122, 11, 29,
126, -4, -10,
34, -50, -111,
49, -72, -91,
-49, -72, -91,
49, -72, -91,
0, -101, -75,
-49, -72, -91,
34, -50, -111,
-49, -72, -91,
-34, -50, -111,
55, -110, -27,
49, -72, -91,
34, -50, -111,
-34, -50, -111,
-49, -72, -91,
-55, -110, -27,
-67, 52, -93,
-85, 45, -81,
-34, -50, -111,
0, 82, -96,
0, 88, -90,
-85, 45, -81,
85, 45, -81,
0, 88, -90,
0, 82, -96,
34, -50, -111,
85, 45, -81,
67, 52, -93,
-67, 52, -93,
-109, -24, -59,
3, -79, -99,
0, 82, -96,
-67, 52, -93,
0, -99, -78,
0, -99, -78,
67, 52, -93,
0, 82, -96,
-3, -79, -99,
109, -24, -59,
67, 52, -93,
0, -121, -35,
0, -120, -39,
10, -125, -14,
0, -121, -35,
-72, -95, 40,
-10, -125, -14,
0, -121, 36,
67, -104, 24,
0, -120, -39,
-11, -109, 63,
43, -51, 107,
-14, -1, 126,
-14, -1, 126,
-6, -110, 62,
74, 2, 102,
74, 2, 102,
-6, -110, 62,
44, -109, 46,
44, -109, 46,
43, -51, 107,
-11, -109, 63,
14, -1, 126,
-43, -51, 107,
11, -109, 63,
11, -109, 63,
-43, -51, 107,
-44, -109, 46,
-44, -109, 46,
6, -110, 62,
-74, 2, 102,
-74, 2, 102,
6, -110, 62,
14, -1, 126,
6, -110, 62,
-43, -104, 57,
14, -1, 126,
-44, -109, 46,
-4, -50, 116,
6, -110, 62,
-43, -51, 107,
-4, -50, 116,
-44, -109, 46,
14, -1, 126,
-43, -104, 57,
-43, -51, 107,
44, -109, 46,
4, -50, 116,
43, -51, 107,
-6, -110, 62,
4, -50, 116,
44, -109, 46,
-14, -1, 126,
43, -104, 57,
-6, -110, 62,
43, -51, 107,
43, -104, 57,
-14, -1, 126,
43, -104, 57,
43, -51, 107,
4, -50, 116,
-43, -104, 57,
6, -110, 62,
-4, -50, 116,
55, -110, -27,
67, -104, 24,
0, -121, 36,
29, -107, 60,
-16, 8, 125,
-29, -107, 60,
94, 32, -78,
-94, 32, -78,
82, 88, -39,
16, 8, 125,
-39, -114, -37,
-16, 8, 125,
-16, 8, 125,
-21, 124, 6,
-25, 124, -8,
-25, 124, -8,
21, 124, 6,
25, 124, -8,
25, 124, -8,
21, 124, 6,
16, 8, 125,
84, -77, 55,
94, 32, -78,
82, 88, -39,
-84, -77, 55,
88, -89, 16,
84, -77, 55,
-82, 88, -39,
-94, 32, -78,
-84, -77, 55,
-53, 86, -76,
-25, 124, -8,
53, 86, -76,
-94, 32, -78,
-88, -89, 16,
-84, -77, 55,
-84, -77, 55,
-88, -89, 16,
88, -89, 16,
84, -77, 55,
88, -89, 16,
94, 32, -78,
21, 124, 6,
39, -114, -37,
16, 8, 125,
-25, 124, -8,
-21, 124, 6,
21, 124, 6,
-16, 8, 125,
-39, -114, -37,
-21, 124, 6,
16, 8, 125,
39, -114, -37,
-39, -114, -37,
-94, 32, -78,
-82, 88, -39,
82, 88, -39,
-39, -114, -37,
34, -50, -111,
-34, -50, -111,
39, -114, -37,
85, 45, -81,
34, -50, -111,
21, 124, 6,
0, 88, -90,
85, 45, -81,
-21, 124, 6,
-85, 45, -81,
0, 88, -90,
-39, -114, -37,
-34, -50, -111,
-85, 45, -81,
21, 124, 6,
-21, 124, 6,
0, 88, -90,
-21, 124, 6,
-39, -114, -37,
-85, 45, -81,
29, -107, 60,
82, 88, -39,
53, 86, -76,
-29, -107, 60,
84, -77, 55,
29, -107, 60,
53, 86, -76,
-82, 88, -39,
-53, 86, -76,
-53, 86, -76,
-82, 88, -39,
-29, -107, 60,
-104, -50, 50,
76, -97, 27,
-47, 7, 117,
40, -8, -120,
-102, 36, -65,
91, 53, -70,
48, -116, -12,
40, -8, -120,
76, -97, 27,
-102, 36, -65,
-47, 7, 117,
-46, 117, 15,
-102, 36, -65,
-104, -50, 50,
-47, 7, 117,
40, -8, -120,
91, 53, -70,
76, -97, 27,
-102, 36, -65,
-46, 117, 15,
91, 53, -70,
-104, -50, 50,
48, -116, -12,
76, -97, 27,
-47, 7, 117,
-29, -107, 60,
-16, 8, 125,
76, -97, 27,
-53, 86, -76,
-29, -107, 60,
91, 53, -70,
-46, 117, 15,
-53, 86, -76,
-46, 117, 15,
-16, 8, 125,
-25, 124, -8,
47, 7, 117,
-76, -97, 27,
104, -50, 50,
-91, 53, -70,
102, 36, -65,
-40, -8, -120,
-76, -97, 27,
-40, -8, -120,
-48, -116, -12,
45, 117, 15,
47, 7, 117,
102, 36, -65,
47, 7, 117,
104, -50, 50,
102, 36, -65,
-76, -97, 27,
-91, 53, -70,
-40, -8, -120,
-91, 53, -70,
45, 117, 15,
102, 36, -65,
-76, -97, 27,
-48, -116, -12,
104, -50, 50,
47, 7, 117,
25, 124, -8,
16, 8, 125,
45, 117, 15,
53, 86, -76,
25, 124, -8,
-91, 53, -70,
-76, -97, 27,
53, 86, -76,
-76, -97, 27,
47, 7, 117,
29, -107, 60,
45, 117, 15,
25, 124, -8,
47, 7, 117,
-16, 8, 125,
-46, 117, 15,
-47, 7, 117,
96, -80, -18,
-43, -116, 25,
105, 48, 50,
51, 13, -115,
52, 0, -115,
-51, 13, -115,
-51, 13, -115,
105, 48, 50,
51, 13, -115,
-51, 13, -115,
96, -80, -18,
105, 48, 50,
-52, 0, -115,
-43, -116, 25,
-94, 32, -78,
-43, -116, 25,
88, -89, 16,
-88, -89, 16,
37, -120, 16,
94, 32, -78,
88, -89, 16,
52, 0, -115,
-94, 32, -78,
94, 32, -78,
-114, -17, 51,
85, -56, 75,
-76, 79, 63,
69, -83, -65,
-49, 65, -97,
79, 53, -83,
85, -56, 75,
69, -83, -65,
75, 80, 62,
-78, -78, -62,
-76, 79, 63,
-49, 65, -97,
-78, -78, -62,
-114, -17, 51,
-76, 79, 63,
69, -83, -65,
79, 53, -83,
75, 80, 62,
69, -83, -65,
-78, -78, -62,
-49, 65, -97,
85, -56, 75,
75, 80, 62,
-76, 79, 63,
-76, 79, 63,
75, 80, 62,
-43, -116, 25,
75, 80, 62,
79, 53, -83,
105, 48, 50,
79, 53, -83,
-52, 0, -115,
51, 13, -115,
-49, 65, -97,
-43, -116, 25,
-52, 0, -115,
65, 85, 67,
-84, -51, 80,
114, -17, 51,
-42, 60, -102,
49, 65, -97,
-68, -84, -65,
95, 65, 52,
-68, -84, -65,
-84, -51, 80,
49, 65, -97,
65, 85, 67,
78, -78, -62,
65, 85, 67,
114, -17, 51,
78, -78, -62,
95, 65, 52,
-42, 60, -102,
-68, -84, -65,
49, 65, -97,
78, -78, -62,
-68, -84, -65,
65, 85, 67,
95, 65, 52,
-84, -51, 80,
65, 85, 67,
49, 65, -97,
37, -120, 16,
-42, 60, -102,
-51, 13, -115,
52, 0, -115,
-42, 60, -102,
96, -80, -18,
-51, 13, -115,
95, 65, 52,
37, -120, 16,
96, -80, -18,
-40, -8, -120,
25, -91, -83,
-48, -116, -12,
-48, -116, -12,
69, -103, -24,
104, -50, 50,
104, -50, 50,
69, -103, -24,
102, 36, -65,
102, 36, -65,
105, -27, -65,
-40, -8, -120,
48, -116, -12,
-28, -117, -38,
40, -8, -120,
40, -8, -120,
-105, -27, -65,
-102, 36, -65,
-102, 36, -65,
-105, -27, -65,
-104, -50, 50,
-104, -50, 50,
-69, -103, -24,
48, -116, -12,
-53, -115, 5,
85, -27, 90,
28, -117, -38,
85, -27, 90,
105, -27, -65,
69, -103, -24,
66, 108, -9,
25, -91, -83,
105, -27, -65,
-75, 17, -100,
-53, -115, 5,
25, -91, -83,
-85, -27, 90,
-28, -117, -38,
-69, -103, -24,
75, 17, -100,
-105, -27, -65,
-25, -91, -83,
-66, 108, -9,
-85, -27, 90,
-105, -27, -65,
-25, -91, -83,
-28, -117, -38,
75, 17, -100,
-102, -42, 62,
49, -115, 20,
-74, -38, 95,
37, 0, -121,
-96, 65, -51,
84, 36, -87,
33, -122, -9,
37, 0, -121,
49, -115, 20,
-96, 65, -51,
-74, -38, 95,
-45, 118, -7,
-96, 65, -51,
-102, -42, 62,
-74, -38, 95,
37, 0, -121,
84, 36, -87,
49, -115, 20,
-96, 65, -51,
-45, 118, -7,
84, 36, -87,
-102, -42, 62,
33, -122, -9,
49, -115, 20,
37, 0, -121,
-67, -84, -65,
-96, 65, -51,
-96, 65, -51,
-67, -84, -65,
-102, -42, 62,
-102, -42, 62,
-67, -84, -65,
33, -122, -9,
33, -122, -9,
-67, -84, -65,
37, 0, -121,
84, 36, -87,
-66, 108, -9,
75, 17, -100,
-45, 118, -7,
-74, -38, 95,
-66, 108, -9,
-74, -38, 95,
49, -115, 20,
-85, -27, 90,
49, -115, 20,
84, 36, -87,
53, -115, 5,
69, -83, -65,
-13, -95, 82,
-78, -78, -62,
-78, -78, -62,
-13, -95, 82,
-114, -17, 51,
-114, -17, 51,
-5, -88, 91,
85, -56, 75,
85, -56, 75,
5, -87, 91,
69, -83, -65,
-84, -51, 80,
-5, -87, 91,
114, -17, 51,
114, -17, 51,
13, -95, 82,
78, -78, -62,
78, -78, -62,
13, -95, 82,
-68, -84, -65,
-68, -84, -65,
-5, -87, 91,
-84, -51, 80,
89, -61, 65,
16, -79, 98,
-89, -61, 65,
-82, 82, -50,
-105, 43, -55,
82, 82, -50,
-23, -78, 96,
-105, 43, -55,
-89, -61, 65,
-83, 56, -77,
16, -79, 98,
82, 82, -50,
89, -61, 65,
71, 64, 83,
82, 82, -50,
82, 82, -50,
32, 103, -65,
-82, 82, -50,
-82, 82, -50,
-101, 65, 38,
-89, -61, 65,
-89, -61, 65,
-101, 65, 38,
89, -61, 65,
-101, 65, 38,
71, 64, 83,
89, -61, 65,
-82, 82, -50,
-71, 86, -59,
-101, 65, 38,
32, 103, -65,
-71, 86, -59,
-82, 82, -50,
71, 64, 83,
32, 103, -65,
82, 82, -50,
16, -79, 98,
89, -61, 65,
82, 82, -50,
-105, 43, -55,
-82, 82, -50,
-89, -61, 65,
-105, 43, -55,
-83, 56, -77,
82, 82, -50,
16, -79, 98,
-23, -78, 96,
-89, -61, 65,
-105, 43, -55,
-5, -87, 91,
-20, -96, 80,
-23, -78, 96,
16, -79, 98,
-5, -87, 91,
16, -79, 98,
-83, 56, -77,
5, -88, 91,
-83, 56, -77,
-20, -96, 80,
13, -95, 82,
89, -61, 65,
-16, -79, 98,
-89, -61, 65,
-82, 82, -50,
105, 43, -55,
82, 82, -50,
89, -61, 65,
105, 43, -55,
23, -78, 96,
-82, 82, -50,
-16, -79, 98,
83, 56, -77,
-82, 82, -50,
-71, 64, 83,
-89, -61, 65,
82, 82, -50,
-32, 103, -65,
-82, 82, -50,
89, -61, 65,
101, 65, 38,
82, 82, -50,
-89, -61, 65,
101, 65, 38,
89, -61, 65,
-89, -61, 65,
-71, 64, 83,
101, 65, 38,
101, 65, 38,
71, 86, -59,
82, 82, -50,
82, 82, -50,
71, 86, -59,
-32, 103, -65,
-82, 82, -50,
-32, 103, -65,
-71, 64, 83,
-82, 82, -50,
-89, -61, 65,
-16, -79, 98,
89, -61, 65,
82, 82, -50,
105, 43, -55,
-82, 82, -50,
83, 56, -77,
105, 43, -55,
89, -61, 65,
23, -78, 96,
-16, -79, 98,
-16, -79, 98,
5, -87, 91,
-5, -88, 91,
23, -78, 96,
105, 43, -55,
5, -87, 91,
105, 43, -55,
83, 56, -77,
20, -96, 80,
83, 56, -77,
-5, -88, 91,
-13, -95, 82,
82, -41, -87,
-43, -45, -110,
61, 92, -62,
-63, 75, 79,
100, 71, 29,
-65, 103, -32,
102, -71, 21,
59, -94, 59,
-97, -53, -61,
59, -94, 59,
100, 71, 29,
59, 66, 90,
-97, -53, -61,
-114, -53, 12,
-65, 103, -32,
59, 66, 90,
-10, -81, 96,
59, -94, 59,
59, -94, 59,
-10, -81, 96,
-114, -53, 12,
-114, -53, 12,
-10, -81, 96,
-63, 75, 79,
-63, 75, 79,
-10, -81, 96,
59, 66, 90,
102, -71, 21,
82, -41, -87,
100, 71, 29,
-97, -53, -61,
-43, -45, -110,
102, -71, 21,
-65, 103, -32,
-31, 94, -78,
-97, -53, -61,
-31, 94, -78,
-43, -45, -110,
-97, -53, -61,
-43, -45, -110,
82, -41, -87,
102, -71, 21,
82, -41, -87,
61, 92, -62,
100, 71, 29,
-114, -53, 12,
-63, 75, 79,
-65, 103, -32,
59, -94, 59,
102, -71, 21,
100, 71, 29,
59, -94, 59,
-114, -53, 12,
-97, -53, -61,
-63, 75, 79,
59, 66, 90,
100, 71, 29,
-43, -45, -110,
-31, 94, -78,
61, 92, -62,
100, 71, 29,
61, 92, -62,
101, 65, 38,
61, 92, -62,
-31, 94, -78,
71, 86, -59,
-31, 94, -78,
-65, 103, -32,
-32, 103, -65,
-65, 103, -32,
100, 71, 29,
-71, 64, 83,
-61, 92, -62,
43, -45, -110,
-82, -41, -87,
65, 103, -32,
-100, 71, 29,
63, 75, 79,
97, -53, -61,
-59, -94, 59,
-102, -71, 21,
-59, 66, 90,
-100, 71, 29,
-59, -94, 59,
65, 103, -32,
114, -53, 12,
97, -53, -61,
-59, -94, 59,
10, -81, 96,
-59, 66, 90,
114, -53, 12,
10, -81, 96,
-59, -94, 59,
63, 75, 79,
10, -81, 96,
114, -53, 12,
-59, 66, 90,
10, -81, 96,
63, 75, 79,
-100, 71, 29,
-82, -41, -87,
-102, -71, 21,
-102, -71, 21,
43, -45, -110,
97, -53, -61,
97, -53, -61,
31, 94, -78,
65, 103, -32,
97, -53, -61,
43, -45, -110,
31, 94, -78,
-102, -71, 21,
-82, -41, -87,
43, -45, -110,
-100, 71, 29,
-61, 92, -62,
-82, -41, -87,
65, 103, -32,
63, 75, 79,
114, -53, 12,
-100, 71, 29,
-102, -71, 21,
-59, -94, 59,
97, -53, -61,
114, -53, 12,
-59, -94, 59,
-100, 71, 29,
-59, 66, 90,
63, 75, 79,
-61, 92, -62,
31, 94, -78,
43, -45, -110,
-100, 71, 29,
71, 64, 83,
-101, 65, 38,
65, 103, -32,
32, 103, -65,
71, 64, 83,
31, 94, -78,
-71, 86, -59,
32, 103, -65,
-61, 92, -62,
-101, 65, 38,
-71, 86, -59,
52, 0, -115,
49, 65, -97,
-42, 60, -102,
79, 53, -83,
-49, 65, -97,
-52, 0, -115,
66, 108, -9,
-84, 36, -87,
-75, 17, -100,
-75, 17, -100,
-49, -115, 20,
-53, -115, 5,
85, -27, 90,
45, 118, -7,
66, 108, -9,
74, -38, 95,
-49, -115, 20,
102, -42, 62,
-84, 36, -87,
96, 65, -51,
-37, 0, -121,
-49, -115, 20,
-37, 0, -121,
-33, -122, -9,
45, 118, -7,
74, -38, 95,
96, 65, -51,
74, -38, 95,
102, -42, 62,
96, 65, -51,
-49, -115, 20,
-84, 36, -87,
-37, 0, -121,
-84, 36, -87,
45, 118, -7,
96, 65, -51,
-49, -115, 20,
-33, -122, -9,
102, -42, 62,
96, 65, -51,
67, -84, -65,
-37, 0, -121,
102, -42, 62,
67, -84, -65,
96, 65, -51,
-33, -122, -9,
67, -84, -65,
102, -42, 62,
-37, 0, -121,
67, -84, -65,
-33, -122, -9,
-53, -115, 5,
-49, -115, 20,
85, -27, 90,
-49, -115, 20,
74, -38, 95,
85, -27, 90,
85, -27, 90,
74, -38, 95,
45, 118, -7,
-75, 17, -100,
-84, 36, -87,
-49, -115, 20,
66, 108, -9,
45, 118, -7,
-84, 36, -87,
-61, 92, -62,
-100, 71, 29,
-101, 65, 38,
31, 94, -78,
-61, 92, -62,
-71, 86, -59,
65, 103, -32,
31, 94, -78,
32, 103, -65,
-100, 71, 29,
65, 103, -32,
71, 64, 83,
100, 71, 29,
101, 65, 38,
-71, 64, 83,
-65, 103, -32,
-71, 64, 83,
-32, 103, -65,
-31, 94, -78,
-32, 103, -65,
71, 86, -59,
61, 92, -62,
71, 86, -59,
101, 65, 38,
83, 56, -77,
-16, -79, 98,
-5, -88, 91,
83, 56, -77,
-13, -95, 82,
20, -96, 80,
105, 43, -55,
20, -96, 80,
5, -87, 91,
-16, -79, 98,
23, -78, 96,
5, -87, 91,
-83, 56, -77,
-105, 43, -55,
-20, -96, 80,
-83, 56, -77,
13, -95, 82,
5, -88, 91,
16, -79, 98,
5, -88, 91,
-5, -87, 91,
-105, 43, -55,
-23, -78, 96,
-5, -87, 91,
-68, -84, -65,
-20, -96, 80,
-5, -87, 91,
13, -95, 82,
-20, -96, 80,
-68, -84, -65,
114, -17, 51,
5, -88, 91,
13, -95, 82,
-5, -87, 91,
5, -88, 91,
114, -17, 51,
5, -87, 91,
20, -96, 80,
69, -83, -65,
-5, -88, 91,
5, -87, 91,
85, -56, 75,
-13, -95, 82,
-5, -88, 91,
-114, -17, 51,
69, -83, -65,
20, -96, 80,
-13, -95, 82,
84, 36, -87,
75, 17, -100,
53, -115, 5,
49, -115, 20,
53, -115, 5,
-85, -27, 90,
-74, -38, 95,
-85, -27, 90,
-66, 108, -9,
84, 36, -87,
-45, 118, -7,
-66, 108, -9,
-28, -117, -38,
53, -115, 5,
75, 17, -100,
-85, -27, 90,
-69, -103, -24,
-105, -27, -65,
75, 17, -100,
-66, 108, -9,
-105, -27, -65,
-85, -27, 90,
53, -115, 5,
-28, -117, -38,
-53, -115, 5,
28, -117, -38,
25, -91, -83,
66, 108, -9,
-75, 17, -100,
25, -91, -83,
85, -27, 90,
66, 108, -9,
105, -27, -65,
85, -27, 90,
69, -103, -24,
28, -117, -38,
-69, -103, -24,
-28, -117, -38,
48, -116, -12,
-105, -27, -65,
-69, -103, -24,
-104, -50, 50,
40, -8, -120,
-25, -91, -83,
-105, -27, -65,
-28, -117, -38,
-25, -91, -83,
40, -8, -120,
105, -27, -65,
25, -91, -83,
-40, -8, -120,
69, -103, -24,
105, -27, -65,
102, 36, -65,
-48, -116, -12,
28, -117, -38,
69, -103, -24,
25, -91, -83,
28, -117, -38,
-48, -116, -12,
95, 65, 52,
65, 85, 67,
37, -120, 16,
-42, 60, -102,
95, 65, 52,
96, -80, -18,
49, 65, -97,
52, 0, -115,
37, -120, 16,
-49, 65, -97,
-76, 79, 63,
-43, -116, 25,
79, 53, -83,
51, 13, -115,
105, 48, 50,
75, 80, 62,
105, 48, 50,
-43, -116, 25,
52, 0, -115,
-52, 0, -115,
-94, 32, -78,
37, -120, 16,
52, 0, -115,
94, 32, -78,
-43, -116, 25,
37, -120, 16,
88, -89, 16,
-43, -116, 25,
-88, -89, 16,
-94, 32, -78,
51, 13, -115,
-52, 0, -115,
52, 0, -115,
96, -80, -18,
37, -120, 16,
-43, -116, 25,
47, 7, 117,
16, 8, 125,
29, -107, 60,
-76, -97, 27,
29, -107, 60,
53, 86, -76,
45, 117, 15,
-91, 53, -70,
53, 86, -76,
-46, 117, 15,
-25, 124, -8,
-53, 86, -76,
76, -97, 27,
91, 53, -70,
-53, 86, -76,
-47, 7, 117,
76, -97, 27,
-29, -107, 60,
-82, 88, -39,
-84, -77, 55,
-29, -107, 60,
53, 86, -76,
82, 88, -39,
-82, 88, -39,
-29, -107, 60,
-84, -77, 55,
84, -77, 55,
29, -107, 60,
84, -77, 55,
82, 88, -39,
39, -114, -37,
21, 124, 6,
85, 45, -81,
-39, -114, -37,
39, -114, -37,
34, -50, -111,
-25, 124, -8,
25, 124, -8,
53, 86, -76,
29, -107, 60,
16, 8, 125,
-16, 8, 125,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:5 */
static s8 vtxnvgrp_frake_select_5[]={
-12, -125, -16,
0, -121, -36,
0, -122, -33,
0, -122, -33,
12, -125, -16,
76, -91, 43,
4, -75, -101,
70, 45, -95,
-6, -95, -83,
-6, -95, -83,
0, 75, -102,
0, -41, -120,
0, -41, -120,
0, 75, -102,
6, -95, -83,
6, -95, -83,
-70, 45, -95,
-4, -75, -101,
-4, -75, -101,
-108, -26, -60,
-59, -108, -30,
4, -75, -101,
71, -101, 28,
59, -108, -30,
108, -26, -60,
30, -48, -113,
70, 45, -95,
70, 45, -95,
89, 38, -81,
0, 75, -102,
0, 75, -102,
-89, 38, -81,
-70, 45, -95,
-70, 45, -95,
-30, -48, -113,
-108, -26, -60,
-108, -26, -60,
-30, -48, -113,
-59, -108, -30,
-59, -108, -30,
-49, -69, -94,
0, -98, -79,
0, -98, -79,
49, -69, -94,
59, -108, -30,
59, -108, -30,
30, -48, -113,
108, -26, -60,
0, 111, 60,
-86, 79, 47,
-37, 91, 80,
82, 84, -46,
87, 88, -25,
126, -4, -11,
123, 11, 28,
65, -102, 36,
76, -91, 43,
76, -91, 43,
65, -102, 36,
0, -122, -33,
0, -122, -33,
-65, -102, 36,
-76, -91, 43,
-76, -91, 43,
-65, -102, 36,
-123, 11, 28,
-126, -4, -11,
-87, 88, -25,
-82, 84, -46,
-82, 84, -46,
0, 119, -43,
0, 112, -58,
0, 112, -58,
0, 119, -43,
82, 84, -46,
87, 88, -25,
86, 79, 47,
123, 11, 28,
123, 11, 28,
86, 79, 47,
112, 28, 51,
-112, 28, 51,
-86, 79, 47,
-123, 11, 28,
-123, 11, 28,
-86, 79, 47,
-87, 88, -25,
-87, 88, -25,
0, 126, 3,
0, 119, -43,
0, 119, -43,
0, 126, 3,
87, 88, -25,
61, 95, 56,
0, 126, 3,
0, 111, 60,
59, -108, -30,
108, -26, -60,
4, -75, -101,
-59, -108, -30,
-71, -101, 28,
-4, -75, -101,
0, -98, -79,
59, -108, -30,
-59, -108, -30,
59, -108, -30,
0, -120, 41,
-59, -108, -30,
-12, -125, -16,
79, -95, -24,
-4, -75, -101,
-4, -75, -101,
-102, 49, -57,
-126, -4, -11,
-126, -4, -11,
-68, -106, 13,
-76, -91, 43,
-76, -91, 43,
79, -95, -24,
-12, -125, -16,
79, -95, -24,
-4, -38, -121,
69, 84, -64,
69, 84, -64,
-4, -38, -121,
-102, 49, -57,
-102, 49, -57,
-4, -38, -121,
-68, -106, 13,
-68, -106, 13,
-4, -38, -121,
79, -95, -24,
4, -75, -101,
-79, -95, -24,
12, -125, -16,
12, -125, -16,
-79, -95, -24,
76, -91, 43,
76, -91, 43,
68, -106, 13,
126, -4, -11,
126, -4, -11,
102, 49, -57,
4, -75, -101,
-69, 84, -64,
4, -38, -121,
-79, -95, -24,
-79, -95, -24,
4, -38, -121,
68, -106, 13,
68, -106, 13,
4, -38, -121,
102, 49, -57,
102, 49, -57,
4, -38, -121,
-69, 84, -64,
-6, -95, -83,
-59, -112, 2,
4, -75, -101,
4, -75, -101,
-59, -112, 2,
126, -4, -11,
126, -4, -11,
105, -69, -15,
82, 84, -46,
82, 84, -46,
-25, 94, -80,
-6, -95, -83,
-124, -24, -1,
-12, -40, -119,
-59, -112, 2,
-59, -112, 2,
-12, -40, -119,
105, -69, -15,
105, -69, -15,
-12, -40, -119,
-25, 94, -80,
-25, 94, -80,
-12, -40, -119,
-124, -24, -1,
-82, 84, -46,
-105, -69, -15,
-126, -4, -11,
-126, -4, -11,
59, -112, 2,
-4, -75, -101,
-4, -75, -101,
59, -112, 2,
6, -95, -83,
6, -95, -83,
25, 94, -80,
-82, 84, -46,
25, 94, -80,
12, -40, -119,
-105, -69, -15,
-105, -69, -15,
12, -40, -119,
59, -112, 2,
59, -112, 2,
12, -40, -119,
124, -24, -1,
124, -24, -1,
12, -40, -119,
25, 94, -80,
0, -41, -120,
31, -120, 26,
-6, -95, -83,
-6, -95, -83,
31, -120, 26,
82, 84, -46,
82, 84, -46,
-64, 65, -87,
0, 112, -58,
0, 112, -58,
-64, 65, -87,
0, -41, -120,
-97, -79, -17,
4, -84, -94,
31, -120, 26,
31, -120, 26,
4, -84, -94,
120, 11, -37,
120, 11, -37,
4, -84, -94,
-64, 65, -87,
-64, 65, -87,
4, -84, -94,
-97, -79, -17,
6, -95, -83,
-31, -120, 26,
0, -41, -120,
0, -41, -120,
64, 65, -87,
0, 112, -58,
0, 112, -58,
64, 65, -87,
-82, 84, -46,
-82, 84, -46,
-31, -120, 26,
6, -95, -83,
-31, -120, 26,
-4, -84, -94,
97, -79, -17,
97, -79, -17,
-4, -84, -94,
64, 65, -87,
64, 65, -87,
-4, -84, -94,
-120, 11, -37,
-120, 11, -37,
-4, -84, -94,
-31, -120, 26,
0, -23, 124,
0, 16, 125,
-112, 28, 51,
112, 28, 51,
0, 16, 125,
0, -23, 124,
71, -101, 28,
4, -75, -101,
12, -125, -16,
-71, -101, 28,
-12, -125, -16,
-4, -75, -101,
-71, -101, 28,
0, -121, -36,
-12, -125, -16,
71, -101, 28,
12, -125, -16,
0, -121, -36,
-71, -101, 28,
0, -120, 41,
0, -121, -36,
112, 28, 51,
65, -102, 36,
123, 11, 28,
-123, 11, 28,
-65, -102, 36,
-112, 28, 51,
76, -91, 43,
126, -4, -11,
123, 11, 28,
-123, 11, 28,
-126, -4, -11,
-76, -91, 43,
-47, -42, 109,
-47, -99, 63,
-3, -44, 118,
47, -99, 63,
3, -44, 118,
-6, -105, 70,
0, 111, 60,
0, 16, 125,
37, 91, 80,
0, 111, 60,
37, 91, 80,
86, 79, 47,
0, 111, 60,
86, 79, 47,
61, 95, 56,
-37, 91, 80,
0, 16, 125,
0, 111, 60,
0, 111, 60,
-61, 95, 56,
-86, 79, 47,
0, 111, 60,
0, 126, 3,
-61, 95, 56,
0, -23, 124,
12, -105, 69,
0, -119, 41,
0, -119, 41,
-48, -104, 52,
-65, -102, 36,
-65, -102, 36,
-75, 2, 102,
-112, 28, 51,
-112, 28, 51,
15, -1, 126,
0, -23, 124,
65, -102, 36,
48, -104, 52,
0, -119, 41,
0, -119, 41,
-12, -105, 69,
0, -23, 124,
0, -23, 124,
-15, -1, 126,
112, 28, 51,
112, 28, 51,
75, 2, 102,
65, -102, 36,
75, 2, 102,
48, -104, 52,
65, -102, 36,
-15, -1, 126,
75, 2, 102,
112, 28, 51,
-12, -105, 69,
-15, -1, 126,
0, -23, 124,
48, -104, 52,
-12, -105, 69,
0, -119, 41,
-112, 28, 51,
-75, 2, 102,
15, -1, 126,
-65, -102, 36,
-48, -104, 52,
-75, 2, 102,
0, -119, 41,
12, -105, 69,
-48, -104, 52,
0, -23, 124,
15, -1, 126,
12, -105, 69,
112, 28, 51,
37, 91, 80,
0, 16, 125,
0, 16, 125,
-37, 91, 80,
-112, 28, 51,
-82, 84, -46,
-120, 11, -37,
-31, -120, 26,
64, 65, -87,
-120, 11, -37,
-82, 84, -46,
0, -41, -120,
97, -79, -17,
64, 65, -87,
-31, -120, 26,
97, -79, -17,
0, -41, -120,
-64, 65, -87,
-97, -79, -17,
0, -41, -120,
82, 84, -46,
120, 11, -37,
-64, 65, -87,
31, -120, 26,
120, 11, -37,
82, 84, -46,
0, -41, -120,
-97, -79, -17,
31, -120, 26,
6, -95, -83,
124, -24, -1,
25, 94, -80,
59, -112, 2,
124, -24, -1,
6, -95, -83,
-126, -4, -11,
-105, -69, -15,
59, -112, 2,
-82, 84, -46,
25, 94, -80,
-105, -69, -15,
-25, 94, -80,
-124, -24, -1,
-6, -95, -83,
105, -69, -15,
-25, 94, -80,
82, 84, -46,
-59, -112, 2,
105, -69, -15,
126, -4, -11,
-6, -95, -83,
-124, -24, -1,
-59, -112, 2,
102, 49, -57,
-69, 84, -64,
4, -75, -101,
68, -106, 13,
102, 49, -57,
126, -4, -11,
-79, -95, -24,
68, -106, 13,
76, -91, 43,
4, -75, -101,
-69, 84, -64,
-79, -95, -24,
-76, -91, 43,
-68, -106, 13,
79, -95, -24,
-126, -4, -11,
-102, 49, -57,
-68, -106, 13,
-4, -75, -101,
69, 84, -64,
-102, 49, -57,
79, -95, -24,
69, 84, -64,
-4, -75, -101,
0, -120, 41,
-71, -101, 28,
-59, -108, -30,
0, 126, 3,
61, 95, 56,
87, 88, -25,
-87, 88, -25,
-61, 95, 56,
0, 126, 3,
-86, 79, 47,
-61, 95, 56,
-87, 88, -25,
-112, 28, 51,
-37, 91, 80,
-86, 79, 47,
86, 79, 47,
37, 91, 80,
112, 28, 51,
87, 88, -25,
61, 95, 56,
86, 79, 47,
0, 119, -43,
87, 88, -25,
82, 84, -46,
-82, 84, -46,
-87, 88, -25,
0, 119, -43,
-126, -4, -11,
-123, 11, 28,
-87, 88, -25,
0, -122, -33,
0, -119, 41,
-65, -102, 36,
65, -102, 36,
0, -119, 41,
0, -122, -33,
87, 88, -25,
123, 11, 28,
126, -4, -11,
30, -48, -113,
49, -69, -94,
-49, -69, -94,
49, -69, -94,
0, -98, -79,
-49, -69, -94,
30, -48, -113,
-49, -69, -94,
-30, -48, -113,
59, -108, -30,
49, -69, -94,
30, -48, -113,
-30, -48, -113,
-49, -69, -94,
-59, -108, -30,
-70, 45, -95,
-89, 38, -81,
-30, -48, -113,
0, 75, -102,
0, 81, -97,
-89, 38, -81,
89, 38, -81,
0, 81, -97,
0, 75, -102,
30, -48, -113,
89, 38, -81,
70, 45, -95,
-70, 45, -95,
-108, -26, -60,
-4, -75, -101,
0, 75, -102,
-70, 45, -95,
6, -95, -83,
-6, -95, -83,
70, 45, -95,
0, 75, -102,
4, -75, -101,
108, -26, -60,
70, 45, -95,
0, -122, -33,
0, -121, -36,
12, -125, -16,
0, -122, -33,
-76, -91, 43,
-12, -125, -16,
0, -120, 41,
71, -101, 28,
0, -121, -36,
-12, -105, 69,
47, -42, 109,
-15, -1, 126,
-15, -1, 126,
-6, -105, 70,
75, 2, 102,
75, 2, 102,
-6, -105, 70,
48, -104, 52,
48, -104, 52,
47, -42, 109,
-12, -105, 69,
15, -1, 126,
-47, -42, 109,
12, -105, 69,
12, -105, 69,
-47, -42, 109,
-48, -104, 52,
-48, -104, 52,
6, -105, 70,
-75, 2, 102,
-75, 2, 102,
6, -105, 70,
15, -1, 126,
6, -105, 70,
-47, -99, 63,
15, -1, 126,
-48, -104, 52,
-3, -44, 118,
6, -105, 70,
-47, -42, 109,
-3, -44, 118,
-48, -104, 52,
15, -1, 126,
-47, -99, 63,
-47, -42, 109,
48, -104, 52,
3, -44, 118,
47, -42, 109,
-6, -105, 70,
3, -44, 118,
48, -104, 52,
-15, -1, 126,
47, -99, 63,
-6, -105, 70,
47, -42, 109,
47, -99, 63,
-15, -1, 126,
47, -99, 63,
47, -42, 109,
3, -44, 118,
-47, -99, 63,
6, -105, 70,
-3, -44, 118,
59, -108, -30,
71, -101, 28,
0, -120, 41,
35, -99, 70,
-15, 15, 125,
-35, -99, 70,
93, 32, -79,
-93, 32, -79,
83, 83, -46,
16, 15, 125,
6, -118, -44,
-15, 15, 125,
-15, 15, 125,
-23, 124, 5,
-29, 122, -14,
-29, 122, -14,
23, 124, 5,
29, 122, -14,
29, 122, -14,
23, 124, 5,
16, 15, 125,
84, -69, 64,
93, 32, -79,
83, 83, -46,
-84, -69, 64,
87, -89, 20,
84, -69, 64,
-83, 83, -46,
-93, 32, -79,
-84, -69, 64,
-56, 78, -81,
-29, 122, -14,
56, 78, -81,
-93, 32, -79,
-87, -89, 20,
-84, -69, 64,
-84, -69, 64,
-87, -89, 20,
87, -89, 20,
84, -69, 64,
87, -89, 20,
93, 32, -79,
23, 124, 5,
-6, -118, -44,
16, 15, 125,
-29, 122, -14,
-23, 124, 5,
23, 124, 5,
-15, 15, 125,
6, -118, -44,
-23, 124, 5,
16, 15, 125,
-6, -118, -44,
6, -118, -44,
-93, 32, -79,
-83, 83, -46,
83, 83, -46,
6, -118, -44,
30, -48, -113,
-30, -48, -113,
-6, -118, -44,
89, 38, -81,
30, -48, -113,
23, 124, 5,
0, 81, -97,
89, 38, -81,
-23, 124, 5,
-89, 38, -81,
0, 81, -97,
6, -118, -44,
-30, -48, -113,
-89, 38, -81,
23, 124, 5,
-23, 124, 5,
0, 81, -97,
-23, 124, 5,
6, -118, -44,
-89, 38, -81,
35, -99, 70,
83, 83, -46,
56, 78, -81,
-35, -99, 70,
84, -69, 64,
35, -99, 70,
56, 78, -81,
-83, 83, -46,
-56, 78, -81,
-56, 78, -81,
-83, 83, -46,
-35, -99, 70,
-103, -51, 52,
80, -91, 34,
-48, 13, 116,
40, -12, -119,
-101, 36, -66,
90, 46, -75,
47, -117, -6,
40, -12, -119,
80, -91, 34,
-101, 36, -66,
-48, 13, 116,
-50, 115, 13,
-101, 36, -66,
-103, -51, 52,
-48, 13, 116,
40, -12, -119,
90, 46, -75,
80, -91, 34,
-101, 36, -66,
-50, 115, 13,
90, 46, -75,
-103, -51, 52,
47, -117, -6,
80, -91, 34,
-48, 13, 116,
-35, -99, 70,
-15, 15, 125,
80, -91, 34,
-56, 78, -81,
-35, -99, 70,
90, 46, -75,
-50, 115, 13,
-56, 78, -81,
-50, 115, 13,
-15, 15, 125,
-29, 122, -14,
47, 13, 116,
-80, -91, 34,
103, -51, 52,
-90, 46, -75,
101, 36, -66,
-40, -12, -119,
-80, -91, 34,
-40, -12, -119,
-47, -117, -6,
49, 115, 13,
47, 13, 116,
101, 36, -66,
47, 13, 116,
103, -51, 52,
101, 36, -66,
-80, -91, 34,
-90, 46, -75,
-40, -12, -119,
-90, 46, -75,
49, 115, 13,
101, 36, -66,
-80, -91, 34,
-47, -117, -6,
103, -51, 52,
47, 13, 116,
29, 122, -14,
16, 15, 125,
49, 115, 13,
56, 78, -81,
29, 122, -14,
-90, 46, -75,
-80, -91, 34,
56, 78, -81,
-80, -91, 34,
47, 13, 116,
35, -99, 70,
49, 115, 13,
29, 122, -14,
47, 13, 116,
-15, 15, 125,
-50, 115, 13,
-48, 13, 116,
101, -75, -6,
-49, -112, 29,
109, 45, 45,
62, 9, -109,
55, -8, -113,
-62, 9, -110,
-62, 9, -110,
109, 45, 45,
62, 9, -109,
-62, 9, -110,
101, -75, -6,
109, 45, 45,
-55, -8, -113,
-49, -112, 29,
-93, 32, -79,
-49, -112, 29,
87, -89, 20,
-87, -89, 20,
42, -117, 20,
93, 32, -79,
87, -89, 20,
55, -8, -113,
-93, 32, -79,
93, 32, -79,
-100, -19, 75,
80, -40, 89,
-76, 90, 46,
69, -94, -47,
-69, 35, -99,
87, 28, -87,
80, -40, 89,
69, -94, -47,
75, 91, 44,
-78, -87, -47,
-76, 90, 46,
-69, 35, -99,
-78, -87, -47,
-100, -19, 75,
-76, 90, 46,
69, -94, -47,
87, 28, -87,
75, 91, 44,
69, -94, -47,
-78, -87, -47,
-69, 35, -99,
80, -40, 89,
75, 91, 44,
-76, 90, 46,
-76, 90, 46,
75, 91, 44,
-49, -112, 29,
75, 91, 44,
87, 28, -87,
109, 45, 45,
87, 28, -87,
-55, -8, -113,
62, 9, -109,
-69, 35, -99,
-49, -112, 29,
-55, -8, -113,
70, 93, 48,
-80, -33, 92,
100, -19, 75,
-82, 27, -92,
69, 35, -99,
-69, -94, -47,
-37, 120, 11,
-69, -94, -47,
-80, -33, 92,
69, 35, -99,
70, 93, 48,
78, -87, -47,
70, 93, 48,
100, -19, 75,
78, -87, -47,
-37, 120, 11,
-82, 27, -92,
-69, -94, -47,
69, 35, -99,
78, -87, -47,
-69, -94, -47,
70, 93, 48,
-37, 120, 11,
-80, -33, 92,
70, 93, 48,
69, 35, -99,
42, -117, 20,
-82, 27, -92,
-62, 9, -110,
55, -8, -113,
-82, 27, -92,
101, -75, -6,
-62, 9, -110,
-37, 120, 11,
42, -117, 20,
101, -75, -6,
-40, -12, -119,
27, -88, -86,
-47, -117, -6,
-47, -117, -6,
74, -100, -21,
103, -51, 52,
103, -51, 52,
74, -100, -21,
101, 36, -66,
101, 36, -66,
102, -30, -68,
-40, -12, -119,
47, -117, -6,
-30, -117, -38,
40, -12, -119,
40, -12, -119,
-102, -30, -68,
-101, 36, -66,
-101, 36, -66,
-102, -30, -68,
-103, -51, 52,
-103, -51, 52,
-74, -100, -21,
47, -117, -6,
-57, -112, 10,
83, -21, 93,
30, -117, -38,
83, -21, 93,
102, -30, -68,
74, -100, -21,
68, 105, -14,
27, -88, -86,
102, -30, -68,
-74, 12, -101,
-57, -112, 10,
27, -88, -86,
-83, -21, 93,
-30, -117, -38,
-74, -100, -21,
74, 12, -101,
-102, -30, -68,
-27, -88, -86,
-68, 105, -14,
-83, -21, 93,
-102, -30, -68,
-27, -88, -86,
-30, -117, -38,
74, 12, -101,
-101, -42, 63,
53, -111, 28,
-70, -32, 100,
36, -3, -121,
-95, 62, -56,
83, 33, -89,
33, -122, -5,
36, -3, -121,
53, -111, 28,
-95, 62, -56,
-70, -32, 100,
-47, 117, -12,
-95, 62, -56,
-101, -42, 63,
-70, -32, 100,
36, -3, -121,
83, 33, -89,
53, -111, 28,
-95, 62, -56,
-47, 117, -12,
83, 33, -89,
-101, -42, 63,
33, -122, -5,
53, -111, 28,
36, -3, -121,
-68, -88, -60,
-95, 62, -56,
-95, 62, -56,
-68, -88, -60,
-101, -42, 63,
-101, -42, 63,
-68, -88, -60,
33, -122, -5,
33, -122, -5,
-68, -88, -60,
36, -3, -121,
83, 33, -89,
-68, 105, -14,
74, 12, -101,
-47, 117, -12,
-70, -32, 100,
-68, 105, -14,
-70, -32, 100,
53, -111, 28,
-83, -21, 93,
53, -111, 28,
83, 33, -89,
57, -112, 10,
69, -94, -47,
-22, -97, 78,
-78, -87, -47,
-78, -87, -47,
-22, -97, 78,
-100, -19, 75,
-100, -19, 75,
-11, -81, 96,
80, -40, 89,
80, -40, 89,
12, -79, 97,
69, -94, -47,
-80, -33, 92,
-12, -79, 97,
100, -19, 75,
100, -19, 75,
22, -97, 78,
78, -87, -47,
78, -87, -47,
22, -97, 78,
-69, -94, -47,
-69, -94, -47,
-12, -79, 97,
-80, -33, 92,
89, -49, 75,
33, -52, 110,
-89, -49, 75,
-81, 76, -60,
-114, 4, -54,
81, 76, -60,
-43, -51, 107,
-114, 4, -54,
-89, -49, 75,
-85, 0, -93,
33, -52, 110,
81, 76, -60,
89, -49, 75,
66, 77, 75,
81, 76, -60,
81, 76, -60,
41, 92, -76,
-81, 76, -60,
-81, 76, -60,
-101, 65, 38,
-89, -49, 75,
-89, -49, 75,
-101, 65, 38,
89, -49, 75,
-101, 65, 38,
66, 77, 75,
89, -49, 75,
-81, 76, -60,
-76, 72, -70,
-101, 65, 38,
41, 92, -76,
-76, 72, -70,
-81, 76, -60,
66, 77, 75,
41, 92, -76,
81, 76, -60,
33, -52, 110,
89, -49, 75,
81, 76, -60,
-114, 4, -54,
-81, 76, -60,
-89, -49, 75,
-114, 4, -54,
-85, 0, -93,
81, 76, -60,
33, -52, 110,
-43, -51, 107,
-89, -49, 75,
-114, 4, -54,
-12, -79, 97,
-29, -98, 74,
-43, -51, 107,
33, -52, 110,
-12, -79, 97,
33, -52, 110,
-85, 0, -93,
11, -81, 96,
-85, 0, -93,
-29, -98, 74,
22, -97, 78,
89, -49, 75,
-33, -52, 110,
-89, -49, 75,
-81, 76, -60,
114, 4, -54,
81, 76, -60,
89, -49, 75,
114, 4, -54,
43, -51, 107,
-81, 76, -60,
-33, -52, 110,
85, 0, -93,
-81, 76, -60,
-66, 77, 75,
-89, -49, 75,
81, 76, -60,
-41, 92, -76,
-81, 76, -60,
89, -49, 75,
101, 65, 38,
81, 76, -60,
-89, -49, 75,
101, 65, 38,
89, -49, 75,
-89, -49, 75,
-66, 77, 75,
101, 65, 38,
101, 65, 38,
76, 72, -70,
81, 76, -60,
81, 76, -60,
76, 72, -70,
-41, 92, -76,
-81, 76, -60,
-41, 92, -76,
-66, 77, 75,
-81, 76, -60,
-89, -49, 75,
-33, -52, 110,
89, -49, 75,
81, 76, -60,
114, 4, -54,
-81, 76, -60,
85, 0, -93,
114, 4, -54,
89, -49, 75,
43, -51, 107,
-33, -52, 110,
-33, -52, 110,
12, -79, 97,
-11, -81, 96,
43, -51, 107,
114, 4, -54,
12, -79, 97,
114, 4, -54,
85, 0, -93,
29, -98, 74,
85, 0, -93,
-11, -81, 96,
-22, -97, 78,
83, -48, -82,
-46, -53, -105,
68, 78, -72,
-64, 87, 66,
98, 77, 21,
-72, 97, -35,
101, -73, 22,
66, -86, 63,
-97, -62, -51,
66, -86, 63,
98, 77, 21,
60, 77, 81,
-97, -62, -51,
-110, -58, 22,
-72, 97, -35,
60, 77, 81,
-13, -62, 109,
66, -86, 63,
66, -86, 63,
-13, -62, 109,
-110, -58, 22,
-110, -58, 22,
-13, -62, 109,
-64, 87, 66,
-64, 87, 66,
-13, -62, 109,
60, 77, 81,
101, -73, 22,
83, -48, -82,
98, 77, 21,
-97, -62, -51,
-46, -53, -105,
101, -73, 22,
-72, 97, -35,
-38, 80, -89,
-97, -62, -51,
-38, 80, -89,
-46, -53, -105,
-97, -62, -51,
-46, -53, -105,
83, -48, -82,
101, -73, 22,
83, -48, -82,
68, 78, -72,
98, 77, 21,
-110, -58, 22,
-64, 87, 66,
-72, 97, -35,
66, -86, 63,
101, -73, 22,
98, 77, 21,
66, -86, 63,
-110, -58, 22,
-97, -62, -51,
-64, 87, 66,
60, 77, 81,
98, 77, 21,
-46, -53, -105,
-38, 80, -89,
68, 78, -72,
98, 77, 21,
68, 78, -72,
101, 65, 38,
68, 78, -72,
-38, 80, -89,
76, 72, -70,
-38, 80, -89,
-72, 97, -35,
-41, 92, -76,
-72, 97, -35,
98, 77, 21,
-66, 77, 75,
-68, 78, -72,
46, -53, -105,
-83, -48, -82,
72, 97, -35,
-98, 77, 21,
64, 87, 66,
97, -62, -51,
-66, -86, 64,
-101, -72, 22,
-60, 77, 81,
-98, 77, 21,
-66, -86, 64,
72, 97, -35,
110, -58, 22,
97, -62, -51,
-66, -86, 64,
13, -62, 109,
-60, 77, 81,
110, -58, 22,
13, -62, 109,
-66, -86, 64,
64, 87, 66,
13, -62, 109,
110, -58, 22,
-60, 77, 81,
13, -62, 109,
64, 87, 66,
-98, 77, 21,
-83, -48, -82,
-101, -72, 22,
-101, -72, 22,
46, -53, -105,
97, -62, -51,
97, -62, -51,
38, 80, -89,
72, 97, -35,
97, -62, -51,
46, -53, -105,
38, 80, -89,
-101, -72, 22,
-83, -48, -82,
46, -53, -105,
-98, 77, 21,
-68, 78, -72,
-83, -48, -82,
72, 97, -35,
64, 87, 66,
110, -58, 22,
-98, 77, 21,
-101, -72, 22,
-66, -86, 64,
97, -62, -51,
110, -58, 22,
-66, -86, 64,
-98, 77, 21,
-60, 77, 81,
64, 87, 66,
-68, 78, -72,
38, 80, -89,
46, -53, -105,
-98, 77, 21,
66, 77, 75,
-101, 65, 38,
72, 97, -35,
41, 92, -76,
66, 77, 75,
38, 80, -89,
-76, 72, -70,
41, 92, -76,
-68, 78, -72,
-101, 65, 38,
-76, 72, -70,
55, -8, -113,
69, 35, -99,
-82, 27, -92,
87, 28, -87,
-69, 35, -99,
-55, -8, -113,
68, 105, -14,
-83, 33, -89,
-74, 12, -101,
-74, 12, -101,
-53, -111, 28,
-57, -112, 10,
83, -21, 93,
47, 117, -12,
68, 105, -14,
70, -32, 100,
-53, -111, 28,
101, -42, 63,
-83, 33, -89,
95, 62, -56,
-36, -3, -121,
-53, -111, 28,
-36, -3, -121,
-33, -122, -5,
47, 117, -12,
70, -32, 100,
95, 62, -56,
70, -32, 100,
101, -42, 63,
95, 62, -56,
-53, -111, 28,
-83, 33, -89,
-36, -3, -121,
-83, 33, -89,
47, 117, -12,
95, 62, -56,
-53, -111, 28,
-33, -122, -5,
101, -42, 63,
95, 62, -56,
68, -88, -60,
-36, -3, -121,
101, -42, 63,
68, -88, -60,
95, 62, -56,
-33, -122, -5,
68, -88, -60,
101, -42, 63,
-36, -3, -121,
68, -88, -60,
-33, -122, -5,
-57, -112, 10,
-53, -111, 28,
83, -21, 93,
-53, -111, 28,
70, -32, 100,
83, -21, 93,
83, -21, 93,
70, -32, 100,
47, 117, -12,
-74, 12, -101,
-83, 33, -89,
-53, -111, 28,
68, 105, -14,
47, 117, -12,
-83, 33, -89,
-68, 78, -72,
-98, 77, 21,
-101, 65, 38,
38, 80, -89,
-68, 78, -72,
-76, 72, -70,
72, 97, -35,
38, 80, -89,
41, 92, -76,
-98, 77, 21,
72, 97, -35,
66, 77, 75,
98, 77, 21,
101, 65, 38,
-66, 77, 75,
-72, 97, -35,
-66, 77, 75,
-41, 92, -76,
-38, 80, -89,
-41, 92, -76,
76, 72, -70,
68, 78, -72,
76, 72, -70,
101, 65, 38,
85, 0, -93,
-33, -52, 110,
-11, -81, 96,
85, 0, -93,
-22, -97, 78,
29, -98, 74,
114, 4, -54,
29, -98, 74,
12, -79, 97,
-33, -52, 110,
43, -51, 107,
12, -79, 97,
-85, 0, -93,
-114, 4, -54,
-29, -98, 74,
-85, 0, -93,
22, -97, 78,
11, -81, 96,
33, -52, 110,
11, -81, 96,
-12, -79, 97,
-114, 4, -54,
-43, -51, 107,
-12, -79, 97,
-69, -94, -47,
-29, -98, 74,
-12, -79, 97,
22, -97, 78,
-29, -98, 74,
-69, -94, -47,
100, -19, 75,
11, -81, 96,
22, -97, 78,
-12, -79, 97,
11, -81, 96,
100, -19, 75,
12, -79, 97,
29, -98, 74,
69, -94, -47,
-11, -81, 96,
12, -79, 97,
80, -40, 89,
-22, -97, 78,
-11, -81, 96,
-100, -19, 75,
69, -94, -47,
29, -98, 74,
-22, -97, 78,
83, 33, -89,
74, 12, -101,
57, -112, 10,
53, -111, 28,
57, -112, 10,
-83, -21, 93,
-70, -32, 100,
-83, -21, 93,
-68, 105, -14,
83, 33, -89,
-47, 117, -12,
-68, 105, -14,
-30, -117, -38,
57, -112, 10,
74, 12, -101,
-83, -21, 93,
-74, -100, -21,
-102, -30, -68,
74, 12, -101,
-68, 105, -14,
-102, -30, -68,
-83, -21, 93,
57, -112, 10,
-30, -117, -38,
-57, -112, 10,
30, -117, -38,
27, -88, -86,
68, 105, -14,
-74, 12, -101,
27, -88, -86,
83, -21, 93,
68, 105, -14,
102, -30, -68,
83, -21, 93,
74, -100, -21,
30, -117, -38,
-74, -100, -21,
-30, -117, -38,
47, -117, -6,
-102, -30, -68,
-74, -100, -21,
-103, -51, 52,
40, -12, -119,
-27, -88, -86,
-102, -30, -68,
-30, -117, -38,
-27, -88, -86,
40, -12, -119,
102, -30, -68,
27, -88, -86,
-40, -12, -119,
74, -100, -21,
102, -30, -68,
101, 36, -66,
-47, -117, -6,
30, -117, -38,
74, -100, -21,
27, -88, -86,
30, -117, -38,
-47, -117, -6,
-37, 120, 11,
70, 93, 48,
42, -117, 20,
-82, 27, -92,
-37, 120, 11,
101, -75, -6,
69, 35, -99,
55, -8, -113,
42, -117, 20,
-69, 35, -99,
-76, 90, 46,
-49, -112, 29,
87, 28, -87,
62, 9, -109,
109, 45, 45,
75, 91, 44,
109, 45, 45,
-49, -112, 29,
55, -8, -113,
-55, -8, -113,
-93, 32, -79,
42, -117, 20,
55, -8, -113,
93, 32, -79,
-49, -112, 29,
42, -117, 20,
87, -89, 20,
-49, -112, 29,
-87, -89, 20,
-93, 32, -79,
62, 9, -109,
-55, -8, -113,
55, -8, -113,
101, -75, -6,
42, -117, 20,
-49, -112, 29,
47, 13, 116,
16, 15, 125,
35, -99, 70,
-80, -91, 34,
35, -99, 70,
56, 78, -81,
49, 115, 13,
-90, 46, -75,
56, 78, -81,
-50, 115, 13,
-29, 122, -14,
-56, 78, -81,
80, -91, 34,
90, 46, -75,
-56, 78, -81,
-48, 13, 116,
80, -91, 34,
-35, -99, 70,
-83, 83, -46,
-84, -69, 64,
-35, -99, 70,
56, 78, -81,
83, 83, -46,
-83, 83, -46,
-35, -99, 70,
-84, -69, 64,
84, -69, 64,
35, -99, 70,
84, -69, 64,
83, 83, -46,
-6, -118, -44,
23, 124, 5,
89, 38, -81,
6, -118, -44,
-6, -118, -44,
30, -48, -113,
-29, 122, -14,
29, 122, -14,
56, 78, -81,
35, -99, 70,
16, 15, 125,
-15, 15, 125,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:6 */
static s8 vtxnvgrp_frake_select_6[]={
-14, -124, -18,
0, -122, -33,
0, -123, -30,
0, -123, -30,
14, -124, -18,
79, -87, 44,
11, -72, -103,
72, 39, -96,
-11, -91, -87,
-11, -91, -87,
0, 68, -106,
0, -49, -117,
0, -49, -117,
0, 68, -106,
11, -91, -87,
11, -91, -87,
-72, 39, -96,
-11, -72, -103,
-11, -72, -103,
-108, -26, -60,
-62, -105, -32,
11, -72, -103,
73, -98, 31,
62, -105, -32,
108, -26, -60,
26, -45, -115,
72, 39, -96,
72, 39, -96,
93, 32, -80,
0, 68, -106,
0, 68, -106,
-93, 32, -80,
-72, 39, -96,
-72, 39, -96,
-26, -45, -115,
-108, -26, -60,
-108, -26, -60,
-26, -45, -115,
-62, -105, -32,
-62, -105, -32,
-49, -66, -96,
0, -96, -82,
0, -96, -82,
49, -66, -96,
62, -105, -32,
62, -105, -32,
26, -45, -115,
108, -26, -60,
0, 108, 65,
-89, 76, 47,
-37, 94, 76,
87, 78, -48,
91, 83, -27,
126, -5, -12,
123, 11, 28,
71, -97, 38,
79, -87, 44,
79, -87, 44,
71, -97, 38,
0, -123, -30,
0, -123, -30,
-71, -97, 38,
-79, -87, 44,
-79, -87, 44,
-71, -97, 38,
-123, 11, 28,
-126, -5, -12,
-91, 83, -27,
-87, 78, -48,
-87, 78, -48,
0, 117, -48,
0, 109, -63,
0, 109, -63,
0, 117, -48,
87, 78, -48,
91, 83, -27,
89, 76, 47,
123, 11, 28,
123, 11, 28,
89, 76, 47,
110, 28, 55,
-110, 28, 55,
-89, 76, 47,
-123, 11, 28,
-123, 11, 28,
-89, 76, 47,
-91, 83, -27,
-91, 83, -27,
0, 126, 3,
0, 117, -48,
0, 117, -48,
0, 126, 3,
91, 83, -27,
61, 96, 55,
0, 126, 3,
0, 108, 65,
62, -105, -32,
108, -26, -60,
11, -72, -103,
-62, -105, -32,
-73, -98, 31,
-11, -72, -103,
0, -96, -82,
62, -105, -32,
-62, -105, -32,
62, -105, -32,
0, -118, 45,
-62, -105, -32,
-14, -124, -18,
77, -98, -22,
-11, -72, -103,
-11, -72, -103,
-99, 48, -62,
-126, -5, -12,
-126, -5, -12,
-71, -104, 13,
-79, -87, 44,
-79, -87, 44,
77, -98, -22,
-14, -124, -18,
77, -98, -22,
-4, -42, -119,
71, 78, -70,
71, 78, -70,
-4, -42, -119,
-99, 48, -62,
-99, 48, -62,
-4, -42, -119,
-71, -104, 13,
-71, -104, 13,
-4, -42, -119,
77, -98, -22,
11, -72, -103,
-77, -98, -22,
14, -124, -18,
14, -124, -18,
-77, -98, -22,
79, -87, 44,
79, -87, 44,
71, -104, 13,
126, -5, -12,
126, -5, -12,
99, 48, -62,
11, -72, -103,
-71, 78, -70,
4, -42, -119,
-77, -98, -22,
-77, -98, -22,
4, -42, -119,
71, -104, 13,
71, -104, 13,
4, -42, -119,
99, 48, -62,
99, 48, -62,
4, -42, -119,
-71, 78, -70,
-11, -91, -87,
-61, -111, 1,
11, -72, -103,
11, -72, -103,
-61, -111, 1,
126, -5, -12,
126, -5, -12,
102, -72, -15,
87, 78, -48,
87, 78, -48,
-22, 89, -87,
-11, -91, -87,
-125, -21, -1,
-13, -44, -118,
-61, -111, 1,
-61, -111, 1,
-13, -44, -118,
102, -72, -15,
102, -72, -15,
-13, -44, -118,
-22, 89, -87,
-22, 89, -87,
-13, -44, -118,
-125, -21, -1,
-87, 78, -48,
-102, -72, -15,
-126, -5, -12,
-126, -5, -12,
61, -111, 1,
-11, -72, -103,
-11, -72, -103,
61, -111, 1,
11, -91, -87,
11, -91, -87,
22, 89, -87,
-87, 78, -48,
22, 89, -87,
13, -44, -118,
-102, -72, -15,
-102, -72, -15,
13, -44, -118,
61, -111, 1,
61, -111, 1,
13, -44, -118,
125, -21, -1,
125, -21, -1,
13, -44, -118,
22, 89, -87,
0, -49, -117,
34, -118, 29,
-11, -91, -87,
-11, -91, -87,
34, -118, 29,
87, 78, -48,
87, 78, -48,
-61, 64, -90,
0, 109, -63,
0, 109, -63,
-61, 64, -90,
0, -49, -117,
-99, -76, -16,
1, -91, -87,
34, -118, 29,
34, -118, 29,
1, -91, -87,
120, 12, -38,
120, 12, -38,
1, -91, -87,
-61, 64, -90,
-61, 64, -90,
1, -91, -87,
-99, -76, -16,
11, -91, -87,
-34, -118, 29,
0, -49, -117,
0, -49, -117,
61, 64, -90,
0, 109, -63,
0, 109, -63,
61, 64, -90,
-87, 78, -48,
-87, 78, -48,
-34, -118, 29,
11, -91, -87,
-34, -118, 29,
-1, -91, -87,
99, -76, -16,
99, -76, -16,
-1, -91, -87,
61, 64, -90,
61, 64, -90,
-1, -91, -87,
-120, 12, -38,
-120, 12, -38,
-1, -91, -87,
-34, -118, 29,
0, -9, 126,
0, 18, 125,
-110, 28, 55,
110, 28, 55,
0, 18, 125,
0, -9, 126,
73, -98, 31,
11, -72, -103,
14, -124, -18,
-73, -98, 31,
-14, -124, -18,
-11, -72, -103,
-73, -98, 31,
0, -122, -33,
-14, -124, -18,
73, -98, 31,
14, -124, -18,
0, -122, -33,
-73, -98, 31,
0, -118, 45,
0, -122, -33,
110, 28, 55,
71, -97, 38,
123, 11, 28,
-123, 11, 28,
-71, -97, 38,
-110, 28, 55,
79, -87, 44,
126, -5, -12,
123, 11, 28,
-123, 11, 28,
-126, -5, -12,
-79, -87, 44,
-50, -35, 111,
-50, -94, 68,
-2, -38, 120,
50, -94, 68,
2, -38, 120,
-6, -100, 77,
0, 108, 65,
0, 18, 125,
37, 94, 76,
0, 108, 65,
37, 94, 76,
89, 76, 47,
0, 108, 65,
89, 76, 47,
61, 96, 55,
-37, 94, 76,
0, 18, 125,
0, 108, 65,
0, 108, 65,
-61, 96, 55,
-89, 76, 47,
0, 108, 65,
0, 126, 3,
-61, 96, 55,
0, -9, 126,
13, -101, 74,
0, -118, 46,
0, -118, 46,
-51, -100, 57,
-71, -97, 38,
-71, -97, 38,
-75, 3, 101,
-110, 28, 55,
-110, 28, 55,
16, -1, 125,
0, -9, 126,
71, -97, 38,
51, -100, 57,
0, -118, 46,
0, -118, 46,
-13, -101, 74,
0, -9, 126,
0, -9, 126,
-16, -1, 125,
110, 28, 55,
110, 28, 55,
75, 3, 101,
71, -97, 38,
75, 3, 101,
51, -100, 57,
71, -97, 38,
-16, -1, 125,
75, 3, 101,
110, 28, 55,
-13, -101, 74,
-16, -1, 125,
0, -9, 126,
51, -100, 57,
-13, -101, 74,
0, -118, 46,
-110, 28, 55,
-75, 3, 101,
16, -1, 125,
-71, -97, 38,
-51, -100, 57,
-75, 3, 101,
0, -118, 46,
13, -101, 74,
-51, -100, 57,
0, -9, 126,
16, -1, 125,
13, -101, 74,
110, 28, 55,
37, 94, 76,
0, 18, 125,
0, 18, 125,
-37, 94, 76,
-110, 28, 55,
-87, 78, -48,
-120, 12, -38,
-34, -118, 29,
61, 64, -90,
-120, 12, -38,
-87, 78, -48,
0, -49, -117,
99, -76, -16,
61, 64, -90,
-34, -118, 29,
99, -76, -16,
0, -49, -117,
-61, 64, -90,
-99, -76, -16,
0, -49, -117,
87, 78, -48,
120, 12, -38,
-61, 64, -90,
34, -118, 29,
120, 12, -38,
87, 78, -48,
0, -49, -117,
-99, -76, -16,
34, -118, 29,
11, -91, -87,
125, -21, -1,
22, 89, -87,
61, -111, 1,
125, -21, -1,
11, -91, -87,
-126, -5, -12,
-102, -72, -15,
61, -111, 1,
-87, 78, -48,
22, 89, -87,
-102, -72, -15,
-22, 89, -87,
-125, -21, -1,
-11, -91, -87,
102, -72, -15,
-22, 89, -87,
87, 78, -48,
-61, -111, 1,
102, -72, -15,
126, -5, -12,
-11, -91, -87,
-125, -21, -1,
-61, -111, 1,
99, 48, -62,
-71, 78, -70,
11, -72, -103,
71, -104, 13,
99, 48, -62,
126, -5, -12,
-77, -98, -22,
71, -104, 13,
79, -87, 44,
11, -72, -103,
-71, 78, -70,
-77, -98, -22,
-79, -87, 44,
-71, -104, 13,
77, -98, -22,
-126, -5, -12,
-99, 48, -62,
-71, -104, 13,
-11, -72, -103,
71, 78, -70,
-99, 48, -62,
77, -98, -22,
71, 78, -70,
-11, -72, -103,
0, -118, 45,
-73, -98, 31,
-62, -105, -32,
0, 126, 3,
61, 96, 55,
91, 83, -27,
-91, 83, -27,
-61, 96, 55,
0, 126, 3,
-89, 76, 47,
-61, 96, 55,
-91, 83, -27,
-110, 28, 55,
-37, 94, 76,
-89, 76, 47,
89, 76, 47,
37, 94, 76,
110, 28, 55,
91, 83, -27,
61, 96, 55,
89, 76, 47,
0, 117, -48,
91, 83, -27,
87, 78, -48,
-87, 78, -48,
-91, 83, -27,
0, 117, -48,
-126, -5, -12,
-123, 11, 28,
-91, 83, -27,
0, -123, -30,
0, -118, 46,
-71, -97, 38,
71, -97, 38,
0, -118, 46,
0, -123, -30,
91, 83, -27,
123, 11, 28,
126, -5, -12,
26, -45, -115,
49, -66, -96,
-49, -66, -96,
49, -66, -96,
0, -96, -82,
-49, -66, -96,
26, -45, -115,
-49, -66, -96,
-26, -45, -115,
62, -105, -32,
49, -66, -96,
26, -45, -115,
-26, -45, -115,
-49, -66, -96,
-62, -105, -32,
-72, 39, -96,
-93, 32, -80,
-26, -45, -115,
0, 68, -106,
0, 73, -103,
-93, 32, -80,
93, 32, -80,
0, 73, -103,
0, 68, -106,
26, -45, -115,
93, 32, -80,
72, 39, -96,
-72, 39, -96,
-108, -26, -60,
-11, -72, -103,
0, 68, -106,
-72, 39, -96,
11, -91, -87,
-11, -91, -87,
72, 39, -96,
0, 68, -106,
11, -72, -103,
108, -26, -60,
72, 39, -96,
0, -123, -30,
0, -122, -33,
14, -124, -18,
0, -123, -30,
-79, -87, 44,
-14, -124, -18,
0, -118, 45,
73, -98, 31,
0, -122, -33,
-13, -101, 74,
50, -35, 111,
-16, -1, 125,
-16, -1, 125,
-6, -100, 77,
75, 3, 101,
75, 3, 101,
-6, -100, 77,
51, -100, 57,
51, -100, 57,
50, -35, 111,
-13, -101, 74,
16, -1, 125,
-50, -35, 111,
13, -101, 74,
13, -101, 74,
-50, -35, 111,
-51, -100, 57,
-51, -100, 57,
6, -100, 77,
-75, 3, 101,
-75, 3, 101,
6, -100, 77,
16, -1, 125,
6, -100, 77,
-50, -94, 68,
16, -1, 125,
-51, -100, 57,
-2, -38, 120,
6, -100, 77,
-50, -35, 111,
-2, -38, 120,
-51, -100, 57,
16, -1, 125,
-50, -94, 68,
-50, -35, 111,
51, -100, 57,
2, -38, 120,
50, -35, 111,
-6, -100, 77,
2, -38, 120,
51, -100, 57,
-16, -1, 125,
50, -94, 68,
-6, -100, 77,
50, -35, 111,
50, -94, 68,
-16, -1, 125,
50, -94, 68,
50, -35, 111,
2, -38, 120,
-50, -94, 68,
6, -100, 77,
-2, -38, 120,
62, -105, -32,
73, -98, 31,
0, -118, 45,
40, -90, 79,
-15, 22, 124,
-40, -90, 79,
93, 32, -79,
-93, 32, -79,
84, 78, -53,
15, 22, 124,
124, -12, 22,
-15, 22, 124,
-15, 22, 124,
-24, 124, 5,
-34, 120, -19,
-34, 120, -19,
24, 124, 5,
34, 120, -19,
34, 120, -19,
24, 124, 5,
15, 22, 124,
83, -61, 72,
93, 32, -79,
84, 78, -53,
-83, -61, 72,
86, -89, 24,
83, -61, 72,
-84, 78, -53,
-93, 32, -79,
-83, -61, 72,
-59, 71, -86,
-34, 120, -19,
59, 71, -86,
-93, 32, -79,
-86, -89, 24,
-83, -61, 72,
-83, -61, 72,
-86, -89, 24,
86, -89, 24,
83, -61, 72,
86, -89, 24,
93, 32, -79,
24, 124, 5,
-124, -12, 22,
15, 22, 124,
-34, 120, -19,
-24, 124, 5,
24, 124, 5,
-15, 22, 124,
124, -12, 22,
-24, 124, 5,
15, 22, 124,
-124, -12, 22,
124, -12, 22,
-93, 32, -79,
-84, 78, -53,
84, 78, -53,
124, -12, 22,
26, -45, -115,
-26, -45, -115,
-124, -12, 22,
93, 32, -80,
26, -45, -115,
24, 124, 5,
0, 73, -103,
93, 32, -80,
-24, 124, 5,
-93, 32, -80,
0, 73, -103,
124, -12, 22,
-26, -45, -115,
-93, 32, -80,
24, 124, 5,
-24, 124, 5,
0, 73, -103,
-24, 124, 5,
124, -12, 22,
-93, 32, -80,
40, -90, 79,
84, 78, -53,
59, 71, -86,
-40, -90, 79,
83, -61, 72,
40, -90, 79,
59, 71, -86,
-84, 78, -53,
-59, 71, -86,
-59, 71, -86,
-84, 78, -53,
-40, -90, 79,
-102, -51, 54,
84, -86, 40,
-48, 19, 115,
41, -17, -118,
-101, 36, -67,
90, 39, -79,
46, -118, -1,
41, -17, -118,
84, -86, 40,
-101, 36, -67,
-48, 19, 115,
-54, 114, 10,
-101, 36, -67,
-102, -51, 54,
-48, 19, 115,
41, -17, -118,
90, 39, -79,
84, -86, 40,
-101, 36, -67,
-54, 114, 10,
90, 39, -79,
-102, -51, 54,
46, -118, -1,
84, -86, 40,
-48, 19, 115,
-40, -90, 79,
-15, 22, 124,
84, -86, 40,
-59, 71, -86,
-40, -90, 79,
90, 39, -79,
-54, 114, 10,
-59, 71, -86,
-54, 114, 10,
-15, 22, 124,
-34, 120, -19,
48, 19, 115,
-84, -86, 40,
102, -51, 54,
-90, 39, -79,
101, 36, -67,
-41, -17, -118,
-84, -86, 40,
-41, -17, -118,
-46, -118, -1,
53, 114, 11,
48, 19, 115,
101, 36, -67,
48, 19, 115,
102, -51, 54,
101, 36, -67,
-84, -86, 40,
-90, 39, -79,
-41, -17, -118,
-90, 39, -79,
53, 114, 11,
101, 36, -67,
-84, -86, 40,
-46, -118, -1,
102, -51, 54,
48, 19, 115,
34, 120, -19,
15, 22, 124,
53, 114, 11,
59, 71, -86,
34, 120, -19,
-90, 39, -79,
-84, -86, 40,
59, 71, -86,
-84, -86, 40,
48, 19, 115,
40, -90, 79,
53, 114, 11,
34, 120, -19,
48, 19, 115,
-15, 22, 124,
-54, 114, 10,
-48, 19, 115,
105, -70, 3,
-56, -108, 32,
112, 41, 42,
72, 5, -104,
58, -14, -112,
-72, 5, -104,
-72, 5, -104,
112, 41, 42,
72, 5, -104,
-72, 5, -104,
105, -70, 3,
112, 41, 42,
-58, -14, -112,
-56, -108, 32,
-93, 32, -79,
-56, -108, 32,
86, -89, 24,
-86, -89, 24,
47, -115, 23,
93, 32, -79,
86, -89, 24,
58, -14, -112,
-93, 32, -79,
93, 32, -79,
-90, -12, 87,
77, -24, 97,
-79, 93, 31,
70, -100, -30,
-78, 9, -99,
88, 7, -90,
77, -24, 97,
70, -100, -30,
77, 96, 27,
-79, -93, -32,
-79, 93, 31,
-78, 9, -99,
-79, -93, -32,
-90, -12, 87,
-79, 93, 31,
70, -100, -30,
88, 7, -90,
77, 96, 27,
70, -100, -30,
-79, -93, -32,
-78, 9, -99,
77, -24, 97,
77, 96, 27,
-79, 93, 31,
-79, 93, 31,
77, 96, 27,
-56, -108, 32,
77, 96, 27,
88, 7, -90,
112, 41, 42,
88, 7, -90,
-58, -14, -112,
72, 5, -104,
-78, 9, -99,
-56, -108, 32,
-58, -14, -112,
75, 97, 32,
-77, -18, 99,
90, -12, 87,
-86, 6, -92,
78, 9, -99,
-70, -101, -30,
-51, 115, -11,
-70, -101, -30,
-77, -18, 99,
78, 9, -99,
75, 97, 32,
79, -93, -32,
75, 97, 32,
90, -12, 87,
79, -93, -32,
-51, 115, -11,
-86, 6, -92,
-70, -101, -30,
78, 9, -99,
79, -93, -32,
-70, -101, -30,
75, 97, 32,
-51, 115, -11,
-77, -18, 99,
75, 97, 32,
78, 9, -99,
47, -115, 23,
-86, 6, -92,
-72, 5, -104,
58, -14, -112,
-86, 6, -92,
105, -70, 3,
-72, 5, -104,
-51, 115, -11,
47, -115, 23,
105, -70, 3,
-41, -17, -118,
30, -86, -87,
-46, -118, -1,
-46, -118, -1,
79, -97, -19,
102, -51, 54,
102, -51, 54,
79, -97, -19,
101, 36, -67,
101, 36, -67,
100, -33, -70,
-41, -17, -118,
46, -118, -1,
-32, -116, -37,
41, -17, -118,
41, -17, -118,
-100, -33, -70,
-101, 36, -67,
-101, 36, -67,
-100, -33, -70,
-102, -51, 54,
-102, -51, 54,
-79, -97, -19,
46, -118, -1,
-61, -110, 16,
82, -15, 95,
32, -116, -37,
82, -15, 95,
100, -33, -70,
79, -97, -19,
71, 102, -20,
30, -86, -87,
100, -33, -70,
-74, 7, -102,
-61, -110, 16,
30, -86, -87,
-82, -15, 95,
-32, -116, -37,
-79, -97, -19,
74, 7, -102,
-100, -33, -70,
-30, -86, -87,
-71, 102, -20,
-82, -15, 95,
-100, -33, -70,
-30, -86, -87,
-32, -116, -37,
74, 7, -102,
-100, -42, 64,
57, -107, 36,
-67, -27, 104,
35, -8, -121,
-94, 60, -59,
82, 31, -91,
33, -122, 0,
35, -8, -121,
57, -107, 36,
-94, 60, -59,
-67, -27, 104,
-48, 115, -18,
-94, 60, -59,
-100, -42, 64,
-67, -27, 104,
35, -8, -121,
82, 31, -91,
57, -107, 36,
-94, 60, -59,
-48, 115, -18,
82, 31, -91,
-100, -42, 64,
33, -122, 0,
57, -107, 36,
35, -8, -121,
-69, -90, -56,
-94, 60, -59,
-94, 60, -59,
-69, -90, -56,
-100, -42, 64,
-100, -42, 64,
-69, -90, -56,
33, -122, 0,
33, -122, 0,
-69, -90, -56,
35, -8, -121,
82, 31, -91,
-71, 102, -20,
74, 7, -102,
-48, 115, -18,
-67, -27, 104,
-71, 102, -20,
-67, -27, 104,
57, -107, 36,
-82, -15, 95,
57, -107, 36,
82, 31, -91,
61, -110, 16,
70, -100, -30,
-25, -98, 75,
-79, -93, -32,
-79, -93, -32,
-25, -98, 75,
-90, -12, 87,
-90, -12, 87,
-17, -75, 100,
77, -24, 97,
77, -24, 97,
19, -72, 102,
70, -100, -30,
-77, -18, 99,
-19, -72, 102,
90, -12, 87,
90, -12, 87,
25, -98, 75,
79, -93, -32,
79, -93, -32,
25, -98, 75,
-70, -101, -30,
-70, -101, -30,
-19, -72, 102,
-77, -18, 99,
89, -35, 82,
46, -25, 115,
-89, -35, 82,
-80, 68, -70,
-118, -12, -43,
80, 68, -70,
-55, -22, 111,
-118, -12, -43,
-89, -35, 82,
-84, -37, -86,
46, -25, 115,
80, 68, -70,
89, -35, 82,
61, 86, 70,
80, 68, -70,
80, 68, -70,
50, 80, -84,
-80, 68, -70,
-80, 68, -70,
-101, 65, 38,
-89, -35, 82,
-89, -35, 82,
-101, 65, 38,
89, -35, 82,
-101, 65, 38,
61, 86, 70,
89, -35, 82,
-80, 68, -70,
-81, 58, -78,
-101, 65, 38,
50, 80, -84,
-81, 58, -78,
-80, 68, -70,
61, 86, 70,
50, 80, -84,
80, 68, -70,
46, -25, 115,
89, -35, 82,
80, 68, -70,
-118, -12, -43,
-80, 68, -70,
-89, -35, 82,
-118, -12, -43,
-84, -37, -86,
80, 68, -70,
46, -25, 115,
-55, -22, 111,
-89, -35, 82,
-118, -12, -43,
-19, -72, 102,
-30, -100, 71,
-55, -22, 111,
46, -25, 115,
-19, -72, 102,
46, -25, 115,
-84, -37, -86,
17, -75, 100,
-84, -37, -86,
-30, -100, 71,
25, -98, 75,
89, -35, 82,
-46, -25, 115,
-89, -35, 82,
-80, 68, -70,
118, -12, -43,
80, 68, -70,
89, -35, 82,
118, -12, -43,
55, -22, 111,
-80, 68, -70,
-46, -25, 115,
84, -37, -86,
-80, 68, -70,
-61, 86, 70,
-89, -35, 82,
80, 68, -70,
-50, 80, -84,
-80, 68, -70,
89, -35, 82,
101, 65, 38,
80, 68, -70,
-89, -35, 82,
101, 65, 38,
89, -35, 82,
-89, -35, 82,
-61, 86, 70,
101, 65, 38,
101, 65, 38,
81, 58, -78,
80, 68, -70,
80, 68, -70,
81, 58, -78,
-50, 80, -84,
-80, 68, -70,
-50, 80, -84,
-61, 86, 70,
-80, 68, -70,
-89, -35, 82,
-46, -25, 115,
89, -35, 82,
80, 68, -70,
118, -12, -43,
-80, 68, -70,
84, -37, -86,
118, -12, -43,
89, -35, 82,
55, -22, 111,
-46, -25, 115,
-46, -25, 115,
19, -72, 102,
-17, -75, 100,
55, -22, 111,
118, -12, -43,
19, -72, 102,
118, -12, -43,
84, -37, -86,
30, -100, 71,
84, -37, -86,
-17, -75, 100,
-25, -98, 75,
84, -55, -76,
-48, -60, -100,
75, 64, -79,
-64, 95, 53,
96, 81, 14,
-78, 92, -36,
100, -73, 23,
71, -81, 67,
-97, -69, -42,
71, -81, 67,
96, 81, 14,
60, 86, 70,
-97, -69, -42,
-107, -61, 29,
-78, 92, -36,
60, 86, 70,
-15, -45, 117,
71, -81, 67,
71, -81, 67,
-15, -45, 117,
-107, -61, 29,
-107, -61, 29,
-15, -45, 117,
-64, 95, 53,
-64, 95, 53,
-15, -45, 117,
60, 86, 70,
100, -73, 23,
84, -55, -76,
96, 81, 14,
-97, -69, -42,
-48, -60, -100,
100, -73, 23,
-78, 92, -36,
-44, 66, -98,
-97, -69, -42,
-44, 66, -98,
-48, -60, -100,
-97, -69, -42,
-48, -60, -100,
84, -55, -76,
100, -73, 23,
84, -55, -76,
75, 64, -79,
96, 81, 14,
-107, -61, 29,
-64, 95, 53,
-78, 92, -36,
71, -81, 67,
100, -73, 23,
96, 81, 14,
71, -81, 67,
-107, -61, 29,
-97, -69, -42,
-64, 95, 53,
60, 86, 70,
96, 81, 14,
-48, -60, -100,
-44, 66, -98,
75, 64, -79,
96, 81, 14,
75, 64, -79,
101, 65, 38,
75, 64, -79,
-44, 66, -98,
81, 58, -78,
-44, 66, -98,
-78, 92, -36,
-50, 80, -84,
-78, 92, -36,
96, 81, 14,
-61, 86, 70,
-75, 64, -79,
48, -60, -100,
-84, -55, -76,
78, 92, -36,
-96, 81, 14,
64, 95, 53,
97, -69, -42,
-71, -81, 67,
-100, -73, 23,
-60, 86, 70,
-96, 81, 14,
-71, -81, 67,
78, 92, -36,
107, -61, 29,
97, -69, -42,
-71, -81, 67,
15, -45, 117,
-60, 86, 70,
107, -61, 29,
15, -45, 117,
-71, -81, 67,
64, 95, 53,
15, -45, 117,
107, -61, 29,
-60, 86, 70,
15, -45, 117,
64, 95, 53,
-96, 81, 14,
-84, -55, -76,
-100, -73, 23,
-100, -73, 23,
48, -60, -100,
97, -69, -42,
97, -69, -42,
44, 66, -98,
78, 92, -36,
97, -69, -42,
48, -60, -100,
44, 66, -98,
-100, -73, 23,
-84, -55, -76,
48, -60, -100,
-96, 81, 14,
-75, 64, -79,
-84, -55, -76,
78, 92, -36,
64, 95, 53,
107, -61, 29,
-96, 81, 14,
-100, -73, 23,
-71, -81, 67,
97, -69, -42,
107, -61, 29,
-71, -81, 67,
-96, 81, 14,
-60, 86, 70,
64, 95, 53,
-75, 64, -79,
44, 66, -98,
48, -60, -100,
-96, 81, 14,
61, 86, 70,
-101, 65, 38,
78, 92, -36,
50, 80, -84,
61, 86, 70,
44, 66, -98,
-81, 58, -78,
50, 80, -84,
-75, 64, -79,
-101, 65, 38,
-81, 58, -78,
58, -14, -112,
78, 9, -99,
-86, 6, -92,
88, 7, -90,
-78, 9, -99,
-58, -14, -112,
71, 102, -20,
-82, 31, -91,
-74, 7, -102,
-74, 7, -102,
-57, -107, 36,
-61, -110, 16,
82, -15, 95,
48, 115, -18,
71, 102, -20,
67, -27, 104,
-57, -107, 36,
100, -42, 64,
-82, 31, -91,
94, 60, -59,
-35, -8, -121,
-57, -107, 36,
-35, -8, -121,
-33, -122, 0,
48, 115, -18,
67, -27, 104,
94, 60, -59,
67, -27, 104,
100, -42, 64,
94, 60, -59,
-57, -107, 36,
-82, 31, -91,
-35, -8, -121,
-82, 31, -91,
48, 115, -18,
94, 60, -59,
-57, -107, 36,
-33, -122, 0,
100, -42, 64,
94, 60, -59,
69, -90, -56,
-35, -8, -121,
100, -42, 64,
69, -90, -56,
94, 60, -59,
-33, -122, 0,
69, -90, -56,
100, -42, 64,
-35, -8, -121,
69, -90, -56,
-33, -122, 0,
-61, -110, 16,
-57, -107, 36,
82, -15, 95,
-57, -107, 36,
67, -27, 104,
82, -15, 95,
82, -15, 95,
67, -27, 104,
48, 115, -18,
-74, 7, -102,
-82, 31, -91,
-57, -107, 36,
71, 102, -20,
48, 115, -18,
-82, 31, -91,
-75, 64, -79,
-96, 81, 14,
-101, 65, 38,
44, 66, -98,
-75, 64, -79,
-81, 58, -78,
78, 92, -36,
44, 66, -98,
50, 80, -84,
-96, 81, 14,
78, 92, -36,
61, 86, 70,
96, 81, 14,
101, 65, 38,
-61, 86, 70,
-78, 92, -36,
-61, 86, 70,
-50, 80, -84,
-44, 66, -98,
-50, 80, -84,
81, 58, -78,
75, 64, -79,
81, 58, -78,
101, 65, 38,
84, -37, -86,
-46, -25, 115,
-17, -75, 100,
84, -37, -86,
-25, -98, 75,
30, -100, 71,
118, -12, -43,
30, -100, 71,
19, -72, 102,
-46, -25, 115,
55, -22, 111,
19, -72, 102,
-84, -37, -86,
-118, -12, -43,
-30, -100, 71,
-84, -37, -86,
25, -98, 75,
17, -75, 100,
46, -25, 115,
17, -75, 100,
-19, -72, 102,
-118, -12, -43,
-55, -22, 111,
-19, -72, 102,
-70, -101, -30,
-30, -100, 71,
-19, -72, 102,
25, -98, 75,
-30, -100, 71,
-70, -101, -30,
90, -12, 87,
17, -75, 100,
25, -98, 75,
-19, -72, 102,
17, -75, 100,
90, -12, 87,
19, -72, 102,
30, -100, 71,
70, -100, -30,
-17, -75, 100,
19, -72, 102,
77, -24, 97,
-25, -98, 75,
-17, -75, 100,
-90, -12, 87,
70, -100, -30,
30, -100, 71,
-25, -98, 75,
82, 31, -91,
74, 7, -102,
61, -110, 16,
57, -107, 36,
61, -110, 16,
-82, -15, 95,
-67, -27, 104,
-82, -15, 95,
-71, 102, -20,
82, 31, -91,
-48, 115, -18,
-71, 102, -20,
-32, -116, -37,
61, -110, 16,
74, 7, -102,
-82, -15, 95,
-79, -97, -19,
-100, -33, -70,
74, 7, -102,
-71, 102, -20,
-100, -33, -70,
-82, -15, 95,
61, -110, 16,
-32, -116, -37,
-61, -110, 16,
32, -116, -37,
30, -86, -87,
71, 102, -20,
-74, 7, -102,
30, -86, -87,
82, -15, 95,
71, 102, -20,
100, -33, -70,
82, -15, 95,
79, -97, -19,
32, -116, -37,
-79, -97, -19,
-32, -116, -37,
46, -118, -1,
-100, -33, -70,
-79, -97, -19,
-102, -51, 54,
41, -17, -118,
-30, -86, -87,
-100, -33, -70,
-32, -116, -37,
-30, -86, -87,
41, -17, -118,
100, -33, -70,
30, -86, -87,
-41, -17, -118,
79, -97, -19,
100, -33, -70,
101, 36, -67,
-46, -118, -1,
32, -116, -37,
79, -97, -19,
30, -86, -87,
32, -116, -37,
-46, -118, -1,
-51, 115, -11,
75, 97, 32,
47, -115, 23,
-86, 6, -92,
-51, 115, -11,
105, -70, 3,
78, 9, -99,
58, -14, -112,
47, -115, 23,
-78, 9, -99,
-79, 93, 31,
-56, -108, 32,
88, 7, -90,
72, 5, -104,
112, 41, 42,
77, 96, 27,
112, 41, 42,
-56, -108, 32,
58, -14, -112,
-58, -14, -112,
-93, 32, -79,
47, -115, 23,
58, -14, -112,
93, 32, -79,
-56, -108, 32,
47, -115, 23,
86, -89, 24,
-56, -108, 32,
-86, -89, 24,
-93, 32, -79,
72, 5, -104,
-58, -14, -112,
58, -14, -112,
105, -70, 3,
47, -115, 23,
-56, -108, 32,
48, 19, 115,
15, 22, 124,
40, -90, 79,
-84, -86, 40,
40, -90, 79,
59, 71, -86,
53, 114, 11,
-90, 39, -79,
59, 71, -86,
-54, 114, 10,
-34, 120, -19,
-59, 71, -86,
84, -86, 40,
90, 39, -79,
-59, 71, -86,
-48, 19, 115,
84, -86, 40,
-40, -90, 79,
-84, 78, -53,
-83, -61, 72,
-40, -90, 79,
59, 71, -86,
84, 78, -53,
-84, 78, -53,
-40, -90, 79,
-83, -61, 72,
83, -61, 72,
40, -90, 79,
83, -61, 72,
84, 78, -53,
-124, -12, 22,
24, 124, 5,
93, 32, -80,
124, -12, 22,
-124, -12, 22,
26, -45, -115,
-34, 120, -19,
34, 120, -19,
59, 71, -86,
40, -90, 79,
15, 22, 124,
-15, 22, 124,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:7 */
static s8 vtxnvgrp_frake_select_7[]={
-16, -124, -19,
0, -123, -30,
0, -123, -27,
0, -123, -27,
16, -124, -19,
82, -84, 46,
16, -69, -105,
74, 33, -97,
-15, -87, -91,
-15, -87, -91,
0, 62, -110,
0, -56, -113,
0, -56, -113,
0, 62, -110,
15, -87, -91,
15, -87, -91,
-74, 33, -97,
-16, -69, -105,
-16, -69, -105,
-107, -27, -61,
-64, -104, -34,
16, -69, -105,
75, -95, 34,
64, -104, -34,
107, -27, -61,
22, -42, -117,
74, 33, -97,
74, 33, -97,
95, 28, -78,
0, 62, -110,
0, 62, -110,
-95, 28, -78,
-74, 33, -97,
-74, 33, -97,
-22, -42, -117,
-107, -27, -61,
-107, -27, -61,
-22, -42, -117,
-64, -104, -34,
-64, -104, -34,
-49, -63, -98,
0, -93, -85,
0, -93, -85,
49, -63, -98,
64, -104, -34,
64, -104, -34,
22, -42, -117,
107, -27, -61,
0, 105, 70,
-91, 73, 48,
-36, 97, 72,
91, 72, -49,
95, 79, -28,
126, -6, -13,
123, 11, 27,
75, -93, 40,
82, -84, 46,
82, -84, 46,
75, -93, 40,
0, -123, -27,
0, -123, -27,
-75, -93, 40,
-82, -84, 46,
-82, -84, 46,
-75, -93, 40,
-123, 11, 27,
-126, -6, -13,
-95, 79, -28,
-91, 72, -49,
-91, 72, -49,
0, 115, -53,
0, 107, -68,
0, 107, -68,
0, 115, -53,
91, 72, -49,
95, 79, -28,
91, 73, 48,
123, 11, 27,
123, 11, 27,
91, 73, 48,
108, 27, 59,
-108, 27, 59,
-91, 73, 48,
-123, 11, 27,
-123, 11, 27,
-91, 73, 48,
-95, 79, -28,
-95, 79, -28,
0, 126, 3,
0, 115, -53,
0, 115, -53,
0, 126, 3,
95, 79, -28,
60, 97, 53,
0, 126, 3,
0, 105, 70,
64, -104, -34,
107, -27, -61,
16, -69, -105,
-64, -104, -34,
-75, -95, 34,
-16, -69, -105,
0, -93, -85,
64, -104, -34,
-64, -104, -34,
64, -104, -34,
0, -116, 49,
-64, -104, -34,
-16, -124, -19,
75, -99, -20,
-16, -69, -105,
-16, -69, -105,
-97, 46, -66,
-126, -6, -13,
-126, -6, -13,
-74, -102, 13,
-82, -84, 46,
-82, -84, 46,
75, -99, -20,
-16, -124, -19,
75, -99, -20,
-4, -45, -118,
72, 72, -75,
72, 72, -75,
-4, -45, -118,
-97, 46, -66,
-97, 46, -66,
-4, -45, -118,
-74, -102, 13,
-74, -102, 13,
-4, -45, -118,
75, -99, -20,
16, -69, -105,
-75, -99, -20,
16, -124, -19,
16, -124, -19,
-75, -99, -20,
82, -84, 46,
82, -84, 46,
74, -102, 13,
126, -6, -13,
126, -6, -13,
97, 46, -66,
16, -69, -105,
-72, 72, -75,
4, -45, -118,
-75, -99, -20,
-75, -99, -20,
4, -45, -118,
74, -102, 13,
74, -102, 13,
4, -45, -118,
97, 46, -66,
97, 46, -66,
4, -45, -118,
-72, 72, -75,
-15, -87, -91,
-62, -110, 1,
16, -69, -105,
16, -69, -105,
-62, -110, 1,
126, -6, -13,
126, -6, -13,
100, -75, -14,
91, 72, -49,
91, 72, -49,
-19, 84, -92,
-15, -87, -91,
-125, -18, -2,
-14, -46, -117,
-62, -110, 1,
-62, -110, 1,
-14, -46, -117,
100, -75, -14,
100, -75, -14,
-14, -46, -117,
-19, 84, -92,
-19, 84, -92,
-14, -46, -117,
-125, -18, -2,
-91, 72, -49,
-100, -75, -14,
-126, -6, -13,
-126, -6, -13,
62, -110, 1,
-16, -69, -105,
-16, -69, -105,
62, -110, 1,
15, -87, -91,
15, -87, -91,
19, 84, -92,
-91, 72, -49,
19, 84, -92,
14, -46, -117,
-100, -75, -14,
-100, -75, -14,
14, -46, -117,
62, -110, 1,
62, -110, 1,
14, -46, -117,
125, -18, -2,
125, -18, -2,
14, -46, -117,
19, 84, -92,
0, -56, -113,
37, -117, 31,
-15, -87, -91,
-15, -87, -91,
37, -117, 31,
91, 72, -49,
91, 72, -49,
-58, 63, -93,
0, 107, -68,
0, 107, -68,
-58, 63, -93,
0, -56, -113,
-101, -74, -16,
-1, -97, -81,
37, -117, 31,
37, -117, 31,
-1, -97, -81,
119, 13, -39,
119, 13, -39,
-1, -97, -81,
-58, 63, -93,
-58, 63, -93,
-1, -97, -81,
-101, -74, -16,
15, -87, -91,
-37, -117, 31,
0, -56, -113,
0, -56, -113,
58, 63, -93,
0, 107, -68,
0, 107, -68,
58, 63, -93,
-91, 72, -49,
-91, 72, -49,
-37, -117, 31,
15, -87, -91,
-37, -117, 31,
1, -97, -81,
101, -74, -16,
101, -74, -16,
1, -97, -81,
58, 63, -93,
58, 63, -93,
1, -97, -81,
-119, 13, -39,
-119, 13, -39,
1, -97, -81,
-37, -117, 31,
0, 1, 126,
0, 19, 125,
-108, 27, 59,
108, 27, 59,
0, 19, 125,
0, 1, 126,
75, -95, 34,
16, -69, -105,
16, -124, -19,
-75, -95, 34,
-16, -124, -19,
-16, -69, -105,
-75, -95, 34,
0, -123, -30,
-16, -124, -19,
75, -95, 34,
16, -124, -19,
0, -123, -30,
-75, -95, 34,
0, -116, 49,
0, -123, -30,
108, 27, 59,
75, -93, 40,
123, 11, 27,
-123, 11, 27,
-75, -93, 40,
-108, 27, 59,
82, -84, 46,
126, -6, -13,
123, 11, 27,
-123, 11, 27,
-126, -6, -13,
-82, -84, 46,
-52, -29, 111,
-52, -89, 72,
-1, -33, 122,
52, -89, 72,
1, -33, 122,
-6, -95, 83,
0, 105, 70,
0, 19, 125,
36, 97, 72,
0, 105, 70,
36, 97, 72,
91, 73, 48,
0, 105, 70,
91, 73, 48,
60, 97, 53,
-36, 97, 72,
0, 19, 125,
0, 105, 70,
0, 105, 70,
-60, 97, 53,
-91, 73, 48,
0, 105, 70,
0, 126, 3,
-60, 97, 53,
0, 1, 126,
14, -98, 78,
0, -116, 51,
0, -116, 51,
-54, -96, 61,
-75, -93, 40,
-75, -93, 40,
-76, 4, 101,
-108, 27, 59,
-108, 27, 59,
16, -1, 125,
0, 1, 126,
75, -93, 40,
54, -96, 61,
0, -116, 51,
0, -116, 51,
-14, -98, 78,
0, 1, 126,
0, 1, 126,
-16, -1, 125,
108, 27, 59,
108, 27, 59,
76, 4, 101,
75, -93, 40,
76, 4, 101,
54, -96, 61,
75, -93, 40,
-16, -1, 125,
76, 4, 101,
108, 27, 59,
-14, -98, 78,
-16, -1, 125,
0, 1, 126,
54, -96, 61,
-14, -98, 78,
0, -116, 51,
-108, 27, 59,
-76, 4, 101,
16, -1, 125,
-75, -93, 40,
-54, -96, 61,
-76, 4, 101,
0, -116, 51,
14, -98, 78,
-54, -96, 61,
0, 1, 126,
16, -1, 125,
14, -98, 78,
108, 27, 59,
36, 97, 72,
0, 19, 125,
0, 19, 125,
-36, 97, 72,
-108, 27, 59,
-91, 72, -49,
-119, 13, -39,
-37, -117, 31,
58, 63, -93,
-119, 13, -39,
-91, 72, -49,
0, -56, -113,
101, -74, -16,
58, 63, -93,
-37, -117, 31,
101, -74, -16,
0, -56, -113,
-58, 63, -93,
-101, -74, -16,
0, -56, -113,
91, 72, -49,
119, 13, -39,
-58, 63, -93,
37, -117, 31,
119, 13, -39,
91, 72, -49,
0, -56, -113,
-101, -74, -16,
37, -117, 31,
15, -87, -91,
125, -18, -2,
19, 84, -92,
62, -110, 1,
125, -18, -2,
15, -87, -91,
-126, -6, -13,
-100, -75, -14,
62, -110, 1,
-91, 72, -49,
19, 84, -92,
-100, -75, -14,
-19, 84, -92,
-125, -18, -2,
-15, -87, -91,
100, -75, -14,
-19, 84, -92,
91, 72, -49,
-62, -110, 1,
100, -75, -14,
126, -6, -13,
-15, -87, -91,
-125, -18, -2,
-62, -110, 1,
97, 46, -66,
-72, 72, -75,
16, -69, -105,
74, -102, 13,
97, 46, -66,
126, -6, -13,
-75, -99, -20,
74, -102, 13,
82, -84, 46,
16, -69, -105,
-72, 72, -75,
-75, -99, -20,
-82, -84, 46,
-74, -102, 13,
75, -99, -20,
-126, -6, -13,
-97, 46, -66,
-74, -102, 13,
-16, -69, -105,
72, 72, -75,
-97, 46, -66,
75, -99, -20,
72, 72, -75,
-16, -69, -105,
0, -116, 49,
-75, -95, 34,
-64, -104, -34,
0, 126, 3,
60, 97, 53,
95, 79, -28,
-95, 79, -28,
-60, 97, 53,
0, 126, 3,
-91, 73, 48,
-60, 97, 53,
-95, 79, -28,
-108, 27, 59,
-36, 97, 72,
-91, 73, 48,
91, 73, 48,
36, 97, 72,
108, 27, 59,
95, 79, -28,
60, 97, 53,
91, 73, 48,
0, 115, -53,
95, 79, -28,
91, 72, -49,
-91, 72, -49,
-95, 79, -28,
0, 115, -53,
-126, -6, -13,
-123, 11, 27,
-95, 79, -28,
0, -123, -27,
0, -116, 51,
-75, -93, 40,
75, -93, 40,
0, -116, 51,
0, -123, -27,
95, 79, -28,
123, 11, 27,
126, -6, -13,
22, -42, -117,
49, -63, -98,
-49, -63, -98,
49, -63, -98,
0, -93, -85,
-49, -63, -98,
22, -42, -117,
-49, -63, -98,
-22, -42, -117,
64, -104, -34,
49, -63, -98,
22, -42, -117,
-22, -42, -117,
-49, -63, -98,
-64, -104, -34,
-74, 33, -97,
-95, 28, -78,
-22, -42, -117,
0, 62, -110,
0, 67, -107,
-95, 28, -78,
95, 28, -78,
0, 67, -107,
0, 62, -110,
22, -42, -117,
95, 28, -78,
74, 33, -97,
-74, 33, -97,
-107, -27, -61,
-16, -69, -105,
0, 62, -110,
-74, 33, -97,
15, -87, -91,
-15, -87, -91,
74, 33, -97,
0, 62, -110,
16, -69, -105,
107, -27, -61,
74, 33, -97,
0, -123, -27,
0, -123, -30,
16, -124, -19,
0, -123, -27,
-82, -84, 46,
-16, -124, -19,
0, -116, 49,
75, -95, 34,
0, -123, -30,
-14, -98, 78,
52, -29, 111,
-16, -1, 125,
-16, -1, 125,
-6, -95, 83,
76, 4, 101,
76, 4, 101,
-6, -95, 83,
54, -96, 61,
54, -96, 61,
52, -29, 111,
-14, -98, 78,
16, -1, 125,
-52, -29, 111,
14, -98, 78,
14, -98, 78,
-52, -29, 111,
-54, -96, 61,
-54, -96, 61,
6, -95, 83,
-76, 4, 101,
-76, 4, 101,
6, -95, 83,
16, -1, 125,
6, -95, 83,
-52, -89, 72,
16, -1, 125,
-54, -96, 61,
-1, -33, 122,
6, -95, 83,
-52, -29, 111,
-1, -33, 122,
-54, -96, 61,
16, -1, 125,
-52, -89, 72,
-52, -29, 111,
54, -96, 61,
1, -33, 122,
52, -29, 111,
-6, -95, 83,
1, -33, 122,
54, -96, 61,
-16, -1, 125,
52, -89, 72,
-6, -95, 83,
52, -29, 111,
52, -89, 72,
-16, -1, 125,
52, -89, 72,
52, -29, 111,
1, -33, 122,
-52, -89, 72,
6, -95, 83,
-1, -33, 122,
64, -104, -34,
75, -95, 34,
0, -116, 49,
46, -81, 85,
-15, 28, 122,
-46, -81, 85,
93, 31, -80,
-93, 31, -80,
84, 73, -59,
15, 28, 122,
75, 83, 59,
-15, 28, 122,
-15, 28, 122,
-25, 124, 4,
-38, 118, -24,
-38, 118, -24,
25, 124, 4,
38, 118, -24,
38, 118, -24,
25, 124, 4,
15, 28, 122,
83, -53, 79,
93, 31, -80,
84, 73, -59,
-83, -53, 79,
85, -89, 28,
83, -53, 79,
-84, 73, -59,
-93, 31, -80,
-83, -53, 79,
-61, 64, -89,
-38, 118, -24,
61, 64, -89,
-93, 31, -80,
-85, -89, 28,
-83, -53, 79,
-83, -53, 79,
-85, -89, 28,
85, -89, 28,
83, -53, 79,
85, -89, 28,
93, 31, -80,
25, 124, 4,
-75, 83, 59,
15, 28, 122,
-38, 118, -24,
-25, 124, 4,
25, 124, 4,
-15, 28, 122,
75, 83, 59,
-25, 124, 4,
15, 28, 122,
-75, 83, 59,
75, 83, 59,
-93, 31, -80,
-84, 73, -59,
84, 73, -59,
75, 83, 59,
22, -42, -117,
-22, -42, -117,
-75, 83, 59,
95, 28, -78,
22, -42, -117,
25, 124, 4,
0, 67, -107,
95, 28, -78,
-25, 124, 4,
-95, 28, -78,
0, 67, -107,
75, 83, 59,
-22, -42, -117,
-95, 28, -78,
25, 124, 4,
-25, 124, 4,
0, 67, -107,
-25, 124, 4,
75, 83, 59,
-95, 28, -78,
46, -81, 85,
84, 73, -59,
61, 64, -89,
-46, -81, 85,
83, -53, 79,
46, -81, 85,
61, 64, -89,
-84, 73, -59,
-61, 64, -89,
-61, 64, -89,
-84, 73, -59,
-46, -81, 85,
-101, -51, 55,
86, -80, 46,
-48, 24, 114,
41, -21, -118,
-100, 36, -68,
90, 33, -82,
45, -118, 3,
41, -21, -118,
86, -80, 46,
-100, 36, -68,
-48, 24, 114,
-58, 112, 8,
-100, 36, -68,
-101, -51, 55,
-48, 24, 114,
41, -21, -118,
90, 33, -82,
86, -80, 46,
-100, 36, -68,
-58, 112, 8,
90, 33, -82,
-101, -51, 55,
45, -118, 3,
86, -80, 46,
-48, 24, 114,
-46, -81, 85,
-15, 28, 122,
86, -80, 46,
-61, 64, -89,
-46, -81, 85,
90, 33, -82,
-58, 112, 8,
-61, 64, -89,
-58, 112, 8,
-15, 28, 122,
-38, 118, -24,
48, 24, 114,
-86, -80, 46,
101, -51, 55,
-90, 33, -82,
100, 36, -68,
-41, -21, -118,
-86, -80, 46,
-41, -21, -118,
-45, -118, 3,
57, 112, 9,
48, 24, 114,
100, 36, -68,
48, 24, 114,
101, -51, 55,
100, 36, -68,
-86, -80, 46,
-90, 33, -82,
-41, -21, -118,
-90, 33, -82,
57, 112, 9,
100, 36, -68,
-86, -80, 46,
-45, -118, 3,
101, -51, 55,
48, 24, 114,
38, 118, -24,
15, 28, 122,
57, 112, 9,
61, 64, -89,
38, 118, -24,
-90, 33, -82,
-86, -80, 46,
61, 64, -89,
-86, -80, 46,
48, 24, 114,
46, -81, 85,
57, 112, 9,
38, 118, -24,
48, 24, 114,
-15, 28, 122,
-58, 112, 8,
-48, 24, 114,
107, -66, 11,
-62, -105, 34,
114, 37, 40,
80, 1, -98,
59, -18, -110,
-80, 1, -98,
-80, 1, -98,
114, 37, 40,
80, 1, -98,
-80, 1, -98,
107, -66, 11,
114, 37, 40,
-59, -18, -110,
-62, -105, 34,
-93, 31, -80,
-62, -105, 34,
85, -89, 28,
-85, -89, 28,
51, -112, 26,
93, 31, -80,
85, -89, 28,
59, -18, -110,
-93, 31, -80,
93, 31, -80,
-85, -4, 93,
75, -11, 101,
-83, 92, 23,
71, -103, -18,
-82, -9, -95,
88, -7, -90,
75, -11, 101,
71, -103, -18,
79, 97, 16,
-79, -97, -20,
-83, 92, 23,
-82, -9, -95,
-79, -97, -20,
-85, -4, 93,
-83, 92, 23,
71, -103, -18,
88, -7, -90,
79, 97, 16,
71, -103, -18,
-79, -97, -20,
-82, -9, -95,
75, -11, 101,
79, 97, 16,
-83, 92, 23,
-83, 92, 23,
79, 97, 16,
-62, -105, 34,
79, 97, 16,
88, -7, -90,
114, 37, 40,
88, -7, -90,
-59, -18, -110,
80, 1, -98,
-82, -9, -95,
-62, -105, 34,
-59, -18, -110,
79, 96, 23,
-75, -8, 101,
85, -4, 93,
-87, -9, -91,
82, -9, -95,
-71, -103, -18,
-55, 111, -24,
-71, -103, -18,
-75, -8, 101,
82, -9, -95,
79, 96, 23,
79, -97, -20,
79, 96, 23,
85, -4, 93,
79, -97, -20,
-55, 111, -24,
-87, -9, -91,
-71, -103, -18,
82, -9, -95,
79, -97, -20,
-71, -103, -18,
79, 96, 23,
-55, 111, -24,
-75, -8, 101,
79, 96, 23,
82, -9, -95,
51, -112, 26,
-87, -9, -91,
-80, 1, -98,
59, -18, -110,
-87, -9, -91,
107, -66, 11,
-80, 1, -98,
-55, 111, -24,
51, -112, 26,
107, -66, 11,
-41, -21, -118,
32, -84, -89,
-45, -118, 3,
-45, -118, 3,
83, -93, -16,
101, -51, 55,
101, -51, 55,
83, -93, -16,
100, 36, -68,
100, 36, -68,
98, -37, -71,
-41, -21, -118,
45, -118, 3,
-34, -116, -36,
41, -21, -118,
41, -21, -118,
-98, -37, -71,
-100, 36, -68,
-100, 36, -68,
-98, -37, -71,
-101, -51, 55,
-101, -51, 55,
-83, -93, -16,
45, -118, 3,
-65, -106, 21,
81, -10, 96,
34, -116, -36,
81, -10, 96,
98, -37, -71,
83, -93, -16,
74, 99, -25,
32, -84, -89,
98, -37, -71,
-74, 3, -102,
-65, -106, 21,
32, -84, -89,
-81, -10, 96,
-34, -116, -36,
-83, -93, -16,
74, 3, -102,
-98, -37, -71,
-32, -84, -89,
-74, 99, -25,
-81, -10, 96,
-98, -37, -71,
-32, -84, -89,
-34, -116, -36,
74, 3, -102,
-100, -41, 65,
61, -102, 43,
-64, -20, 107,
34, -12, -121,
-93, 58, -62,
82, 28, -92,
33, -122, 3,
34, -12, -121,
61, -102, 43,
-93, 58, -62,
-64, -20, 107,
-50, 114, -23,
-93, 58, -62,
-100, -41, 65,
-64, -20, 107,
34, -12, -121,
82, 28, -92,
61, -102, 43,
-93, 58, -62,
-50, 114, -23,
82, 28, -92,
-100, -41, 65,
33, -122, 3,
61, -102, 43,
34, -12, -121,
-70, -90, -54,
-93, 58, -62,
-93, 58, -62,
-70, -90, -54,
-100, -41, 65,
-100, -41, 65,
-70, -90, -54,
33, -122, 3,
33, -122, 3,
-70, -90, -54,
34, -12, -121,
82, 28, -92,
-74, 99, -25,
74, 3, -102,
-50, 114, -23,
-64, -20, 107,
-74, 99, -25,
-64, -20, 107,
61, -102, 43,
-81, -10, 96,
61, -102, 43,
82, 28, -92,
65, -106, 21,
71, -103, -18,
-26, -99, 73,
-79, -97, -20,
-79, -97, -20,
-26, -99, 73,
-85, -4, 93,
-85, -4, 93,
-23, -70, 103,
75, -11, 101,
75, -11, 101,
25, -67, 104,
71, -103, -18,
-75, -8, 101,
-25, -67, 104,
85, -4, 93,
85, -4, 93,
26, -99, 73,
79, -97, -20,
79, -97, -20,
26, -99, 73,
-71, -103, -18,
-71, -103, -18,
-25, -67, 104,
-75, -8, 101,
89, -21, 87,
55, -2, 114,
-89, -21, 87,
-79, 59, -79,
-120, -16, -37,
79, 59, -79,
-63, 0, 110,
-120, -16, -37,
-89, -21, 87,
-82, -52, -81,
55, -2, 114,
79, 59, -79,
89, -21, 87,
57, 92, 65,
79, 59, -79,
79, 59, -79,
58, 68, -89,
-79, 59, -79,
-79, 59, -79,
-100, 66, 39,
-89, -21, 87,
-89, -21, 87,
-100, 66, 39,
89, -21, 87,
-100, 66, 39,
57, 92, 65,
89, -21, 87,
-79, 59, -79,
-84, 44, -84,
-100, 66, 39,
58, 68, -89,
-84, 44, -84,
-79, 59, -79,
57, 92, 65,
58, 68, -89,
79, 59, -79,
55, -2, 114,
89, -21, 87,
79, 59, -79,
-120, -16, -37,
-79, 59, -79,
-89, -21, 87,
-120, -16, -37,
-82, -52, -81,
79, 59, -79,
55, -2, 114,
-63, 0, 110,
-89, -21, 87,
-120, -16, -37,
-25, -67, 104,
-30, -101, 70,
-63, 0, 110,
55, -2, 114,
-25, -67, 104,
55, -2, 114,
-82, -52, -81,
23, -70, 103,
-82, -52, -81,
-30, -101, 70,
26, -99, 73,
89, -21, 87,
-55, -2, 114,
-89, -21, 87,
-79, 59, -79,
120, -16, -37,
79, 59, -79,
89, -21, 87,
120, -16, -37,
63, 0, 110,
-79, 59, -79,
-55, -2, 114,
82, -52, -81,
-79, 59, -79,
-57, 92, 65,
-89, -21, 87,
79, 59, -79,
-58, 68, -89,
-79, 59, -79,
89, -21, 87,
100, 66, 39,
79, 59, -79,
-89, -21, 87,
100, 66, 39,
89, -21, 87,
-89, -21, 87,
-57, 92, 65,
100, 66, 39,
100, 66, 39,
84, 44, -84,
79, 59, -79,
79, 59, -79,
84, 44, -84,
-58, 68, -89,
-79, 59, -79,
-58, 68, -89,
-57, 92, 65,
-79, 59, -79,
-89, -21, 87,
-55, -2, 114,
89, -21, 87,
79, 59, -79,
120, -16, -37,
-79, 59, -79,
82, -52, -81,
120, -16, -37,
89, -21, 87,
63, 0, 110,
-55, -2, 114,
-55, -2, 114,
25, -67, 104,
-23, -70, 103,
63, 0, 110,
120, -16, -37,
25, -67, 104,
120, -16, -37,
82, -52, -81,
30, -101, 70,
82, -52, -81,
-23, -70, 103,
-26, -99, 73,
85, -61, -71,
-50, -67, -95,
80, 50, -84,
-64, 100, 43,
95, 82, 9,
-83, 88, -37,
100, -74, 23,
73, -76, 69,
-96, -74, -34,
73, -76, 69,
95, 82, 9,
61, 92, 61,
-96, -74, -34,
-104, -62, 34,
-83, 88, -37,
61, 92, 61,
-16, -32, 121,
73, -76, 69,
73, -76, 69,
-16, -32, 121,
-104, -62, 34,
-104, -62, 34,
-16, -32, 121,
-64, 100, 43,
-64, 100, 43,
-16, -32, 121,
61, 92, 61,
100, -74, 23,
85, -61, -71,
95, 82, 9,
-96, -74, -34,
-50, -67, -95,
100, -74, 23,
-83, 88, -37,
-49, 51, -104,
-96, -74, -34,
-49, 51, -104,
-50, -67, -95,
-96, -74, -34,
-50, -67, -95,
85, -61, -71,
100, -74, 23,
85, -61, -71,
80, 50, -84,
95, 82, 9,
-104, -62, 34,
-64, 100, 43,
-83, 88, -37,
73, -76, 69,
100, -74, 23,
95, 82, 9,
73, -76, 69,
-104, -62, 34,
-96, -74, -34,
-64, 100, 43,
61, 92, 61,
95, 82, 9,
-50, -67, -95,
-49, 51, -104,
80, 50, -84,
95, 82, 9,
80, 50, -84,
100, 66, 39,
80, 50, -84,
-49, 51, -104,
84, 44, -84,
-49, 51, -104,
-83, 88, -37,
-58, 68, -89,
-83, 88, -37,
95, 82, 9,
-57, 92, 65,
-80, 50, -84,
50, -67, -95,
-85, -61, -71,
83, 88, -37,
-95, 82, 9,
64, 100, 43,
96, -74, -34,
-73, -76, 69,
-100, -74, 23,
-61, 92, 61,
-95, 82, 9,
-73, -76, 69,
83, 88, -37,
104, -62, 34,
96, -74, -34,
-73, -76, 69,
16, -32, 121,
-61, 92, 61,
104, -62, 34,
16, -32, 121,
-73, -76, 69,
64, 100, 43,
16, -32, 121,
104, -62, 34,
-61, 92, 61,
16, -32, 121,
64, 100, 43,
-95, 82, 9,
-85, -61, -71,
-100, -74, 23,
-100, -74, 23,
50, -67, -95,
96, -74, -34,
96, -74, -34,
49, 51, -104,
83, 88, -37,
96, -74, -34,
50, -67, -95,
49, 51, -104,
-100, -74, 23,
-85, -61, -71,
50, -67, -95,
-95, 82, 9,
-80, 50, -84,
-85, -61, -71,
83, 88, -37,
64, 100, 43,
104, -62, 34,
-95, 82, 9,
-100, -74, 23,
-73, -76, 69,
96, -74, -34,
104, -62, 34,
-73, -76, 69,
-95, 82, 9,
-61, 92, 61,
64, 100, 43,
-80, 50, -84,
49, 51, -104,
50, -67, -95,
-95, 82, 9,
57, 92, 65,
-100, 66, 39,
83, 88, -37,
58, 68, -89,
57, 92, 65,
49, 51, -104,
-84, 44, -84,
58, 68, -89,
-80, 50, -84,
-100, 66, 39,
-84, 44, -84,
59, -18, -110,
82, -9, -95,
-87, -9, -91,
88, -7, -90,
-82, -9, -95,
-59, -18, -110,
74, 99, -25,
-82, 28, -92,
-74, 3, -102,
-74, 3, -102,
-61, -102, 43,
-65, -106, 21,
81, -10, 96,
50, 114, -23,
74, 99, -25,
64, -20, 107,
-61, -102, 43,
100, -41, 65,
-82, 28, -92,
93, 58, -62,
-34, -12, -121,
-61, -102, 43,
-34, -12, -121,
-33, -122, 3,
50, 114, -23,
64, -20, 107,
93, 58, -62,
64, -20, 107,
100, -41, 65,
93, 58, -62,
-61, -102, 43,
-82, 28, -92,
-34, -12, -121,
-82, 28, -92,
50, 114, -23,
93, 58, -62,
-61, -102, 43,
-33, -122, 3,
100, -41, 65,
93, 58, -62,
70, -90, -54,
-34, -12, -121,
100, -41, 65,
70, -90, -54,
93, 58, -62,
-33, -122, 3,
70, -90, -54,
100, -41, 65,
-34, -12, -121,
70, -90, -54,
-33, -122, 3,
-65, -106, 21,
-61, -102, 43,
81, -10, 96,
-61, -102, 43,
64, -20, 107,
81, -10, 96,
81, -10, 96,
64, -20, 107,
50, 114, -23,
-74, 3, -102,
-82, 28, -92,
-61, -102, 43,
74, 99, -25,
50, 114, -23,
-82, 28, -92,
-80, 50, -84,
-95, 82, 9,
-100, 66, 39,
49, 51, -104,
-80, 50, -84,
-84, 44, -84,
83, 88, -37,
49, 51, -104,
58, 68, -89,
-95, 82, 9,
83, 88, -37,
57, 92, 65,
95, 82, 9,
100, 66, 39,
-57, 92, 65,
-83, 88, -37,
-57, 92, 65,
-58, 68, -89,
-49, 51, -104,
-58, 68, -89,
84, 44, -84,
80, 50, -84,
84, 44, -84,
100, 66, 39,
82, -52, -81,
-55, -2, 114,
-23, -70, 103,
82, -52, -81,
-26, -99, 73,
30, -101, 70,
120, -16, -37,
30, -101, 70,
25, -67, 104,
-55, -2, 114,
63, 0, 110,
25, -67, 104,
-82, -52, -81,
-120, -16, -37,
-30, -101, 70,
-82, -52, -81,
26, -99, 73,
23, -70, 103,
55, -2, 114,
23, -70, 103,
-25, -67, 104,
-120, -16, -37,
-63, 0, 110,
-25, -67, 104,
-71, -103, -18,
-30, -101, 70,
-25, -67, 104,
26, -99, 73,
-30, -101, 70,
-71, -103, -18,
85, -4, 93,
23, -70, 103,
26, -99, 73,
-25, -67, 104,
23, -70, 103,
85, -4, 93,
25, -67, 104,
30, -101, 70,
71, -103, -18,
-23, -70, 103,
25, -67, 104,
75, -11, 101,
-26, -99, 73,
-23, -70, 103,
-85, -4, 93,
71, -103, -18,
30, -101, 70,
-26, -99, 73,
82, 28, -92,
74, 3, -102,
65, -106, 21,
61, -102, 43,
65, -106, 21,
-81, -10, 96,
-64, -20, 107,
-81, -10, 96,
-74, 99, -25,
82, 28, -92,
-50, 114, -23,
-74, 99, -25,
-34, -116, -36,
65, -106, 21,
74, 3, -102,
-81, -10, 96,
-83, -93, -16,
-98, -37, -71,
74, 3, -102,
-74, 99, -25,
-98, -37, -71,
-81, -10, 96,
65, -106, 21,
-34, -116, -36,
-65, -106, 21,
34, -116, -36,
32, -84, -89,
74, 99, -25,
-74, 3, -102,
32, -84, -89,
81, -10, 96,
74, 99, -25,
98, -37, -71,
81, -10, 96,
83, -93, -16,
34, -116, -36,
-83, -93, -16,
-34, -116, -36,
45, -118, 3,
-98, -37, -71,
-83, -93, -16,
-101, -51, 55,
41, -21, -118,
-32, -84, -89,
-98, -37, -71,
-34, -116, -36,
-32, -84, -89,
41, -21, -118,
98, -37, -71,
32, -84, -89,
-41, -21, -118,
83, -93, -16,
98, -37, -71,
100, 36, -68,
-45, -118, 3,
34, -116, -36,
83, -93, -16,
32, -84, -89,
34, -116, -36,
-45, -118, 3,
-55, 111, -24,
79, 96, 23,
51, -112, 26,
-87, -9, -91,
-55, 111, -24,
107, -66, 11,
82, -9, -95,
59, -18, -110,
51, -112, 26,
-82, -9, -95,
-83, 92, 23,
-62, -105, 34,
88, -7, -90,
80, 1, -98,
114, 37, 40,
79, 97, 16,
114, 37, 40,
-62, -105, 34,
59, -18, -110,
-59, -18, -110,
-93, 31, -80,
51, -112, 26,
59, -18, -110,
93, 31, -80,
-62, -105, 34,
51, -112, 26,
85, -89, 28,
-62, -105, 34,
-85, -89, 28,
-93, 31, -80,
80, 1, -98,
-59, -18, -110,
59, -18, -110,
107, -66, 11,
51, -112, 26,
-62, -105, 34,
48, 24, 114,
15, 28, 122,
46, -81, 85,
-86, -80, 46,
46, -81, 85,
61, 64, -89,
57, 112, 9,
-90, 33, -82,
61, 64, -89,
-58, 112, 8,
-38, 118, -24,
-61, 64, -89,
86, -80, 46,
90, 33, -82,
-61, 64, -89,
-48, 24, 114,
86, -80, 46,
-46, -81, 85,
-84, 73, -59,
-83, -53, 79,
-46, -81, 85,
61, 64, -89,
84, 73, -59,
-84, 73, -59,
-46, -81, 85,
-83, -53, 79,
83, -53, 79,
46, -81, 85,
83, -53, 79,
84, 73, -59,
-75, 83, 59,
25, 124, 4,
95, 28, -78,
75, 83, 59,
-75, 83, 59,
22, -42, -117,
-38, 118, -24,
38, 118, -24,
61, 64, -89,
46, -81, 85,
15, 28, 122,
-15, 28, 122,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:8 */
static s8 vtxnvgrp_frake_select_8[]={
-18, -123, -20,
0, -124, -26,
0, -124, -24,
0, -124, -24,
18, -123, -20,
84, -82, 47,
21, -66, -105,
75, 28, -98,
-19, -83, -93,
-19, -83, -93,
0, 57, -113,
0, -62, -110,
0, -62, -110,
0, 57, -113,
19, -83, -93,
19, -83, -93,
-75, 28, -98,
-21, -66, -105,
-21, -66, -105,
-107, -27, -61,
-66, -102, -35,
21, -66, -105,
77, -93, 37,
66, -102, -35,
107, -27, -61,
19, -39, -119,
75, 28, -98,
75, 28, -98,
97, 25, -76,
0, 57, -113,
0, 57, -113,
-97, 25, -76,
-75, 28, -98,
-75, 28, -98,
-19, -39, -119,
-107, -27, -61,
-107, -27, -61,
-19, -39, -119,
-66, -102, -35,
-66, -102, -35,
-49, -61, -99,
0, -91, -88,
0, -91, -88,
49, -61, -99,
66, -102, -35,
66, -102, -35,
19, -39, -119,
107, -27, -61,
0, 103, 74,
-92, 71, 48,
-36, 99, 69,
95, 66, -51,
98, 75, -29,
126, -7, -14,
123, 11, 27,
79, -89, 42,
84, -82, 47,
84, -82, 47,
79, -89, 42,
0, -124, -24,
0, -124, -24,
-79, -89, 42,
-84, -82, 47,
-84, -82, 47,
-79, -89, 42,
-123, 11, 27,
-126, -7, -14,
-98, 75, -29,
-95, 66, -51,
-95, 66, -51,
0, 113, -57,
0, 103, -73,
0, 103, -73,
0, 113, -57,
95, 66, -51,
98, 75, -29,
92, 71, 48,
123, 11, 27,
123, 11, 27,
92, 71, 48,
107, 27, 62,
-107, 27, 62,
-92, 71, 48,
-123, 11, 27,
-123, 11, 27,
-92, 71, 48,
-98, 75, -29,
-98, 75, -29,
0, 126, 2,
0, 113, -57,
0, 113, -57,
0, 126, 2,
98, 75, -29,
60, 98, 51,
0, 126, 2,
0, 103, 74,
66, -102, -35,
107, -27, -61,
21, -66, -105,
-66, -102, -35,
-77, -93, 37,
-21, -66, -105,
0, -91, -88,
66, -102, -35,
-66, -102, -35,
66, -102, -35,
0, -115, 53,
-66, -102, -35,
-18, -123, -20,
74, -101, -19,
-21, -66, -105,
-21, -66, -105,
-95, 44, -70,
-126, -7, -14,
-126, -7, -14,
-76, -100, 14,
-84, -82, 47,
-84, -82, 47,
74, -101, -19,
-18, -123, -20,
74, -101, -19,
-5, -48, -117,
72, 66, -80,
72, 66, -80,
-5, -48, -117,
-95, 44, -70,
-95, 44, -70,
-5, -48, -117,
-76, -100, 14,
-76, -100, 14,
-5, -48, -117,
74, -101, -19,
21, -66, -105,
-74, -101, -19,
18, -123, -20,
18, -123, -20,
-74, -101, -19,
84, -82, 47,
84, -82, 47,
76, -100, 14,
126, -7, -14,
126, -7, -14,
95, 44, -70,
21, -66, -105,
-72, 66, -80,
5, -48, -117,
-74, -101, -19,
-74, -101, -19,
5, -48, -117,
76, -100, 14,
76, -100, 14,
5, -48, -117,
95, 44, -70,
95, 44, -70,
5, -48, -117,
-72, 66, -80,
-19, -83, -93,
-63, -109, 0,
21, -66, -105,
21, -66, -105,
-63, -109, 0,
126, -7, -14,
126, -7, -14,
99, -78, -14,
95, 66, -51,
95, 66, -51,
-16, 79, -97,
-19, -83, -93,
-125, -16, -2,
-14, -49, -116,
-63, -109, 0,
-63, -109, 0,
-14, -49, -116,
99, -78, -14,
99, -78, -14,
-14, -49, -116,
-16, 79, -97,
-16, 79, -97,
-14, -49, -116,
-125, -16, -2,
-95, 66, -51,
-99, -78, -14,
-126, -7, -14,
-126, -7, -14,
63, -109, 0,
-21, -66, -105,
-21, -66, -105,
63, -109, 0,
19, -83, -93,
19, -83, -93,
16, 79, -97,
-95, 66, -51,
16, 79, -97,
14, -49, -116,
-99, -78, -14,
-99, -78, -14,
14, -49, -116,
63, -109, 0,
63, -109, 0,
14, -49, -116,
125, -16, -2,
125, -16, -2,
14, -49, -116,
16, 79, -97,
0, -62, -110,
39, -115, 34,
-19, -83, -93,
-19, -83, -93,
39, -115, 34,
95, 66, -51,
95, 66, -51,
-55, 62, -95,
0, 103, -73,
0, 103, -73,
-55, 62, -95,
0, -62, -110,
-103, -71, -15,
-3, -102, -74,
39, -115, 34,
39, -115, 34,
-3, -102, -74,
119, 13, -40,
119, 13, -40,
-3, -102, -74,
-55, 62, -95,
-55, 62, -95,
-3, -102, -74,
-103, -71, -15,
19, -83, -93,
-39, -115, 34,
0, -62, -110,
0, -62, -110,
55, 62, -95,
0, 103, -73,
0, 103, -73,
55, 62, -95,
-95, 66, -51,
-95, 66, -51,
-39, -115, 34,
19, -83, -93,
-39, -115, 34,
3, -102, -74,
103, -71, -15,
103, -71, -15,
3, -102, -74,
55, 62, -95,
55, 62, -95,
3, -102, -74,
-119, 13, -40,
-119, 13, -40,
3, -102, -74,
-39, -115, 34,
0, 9, 126,
0, 20, 125,
-107, 27, 62,
107, 27, 62,
0, 20, 125,
0, 9, 126,
77, -93, 37,
21, -66, -105,
18, -123, -20,
-77, -93, 37,
-18, -123, -20,
-21, -66, -105,
-77, -93, 37,
0, -124, -26,
-18, -123, -20,
77, -93, 37,
18, -123, -20,
0, -124, -26,
-77, -93, 37,
0, -115, 53,
0, -124, -26,
107, 27, 62,
79, -89, 42,
123, 11, 27,
-123, 11, 27,
-79, -89, 42,
-107, 27, 62,
84, -82, 47,
126, -7, -14,
123, 11, 27,
-123, 11, 27,
-126, -7, -14,
-84, -82, 47,
-54, -23, 112,
-54, -84, 76,
0, -28, 123,
54, -84, 76,
0, -28, 123,
-6, -90, 88,
0, 103, 74,
0, 20, 125,
36, 99, 69,
0, 103, 74,
36, 99, 69,
92, 71, 48,
0, 103, 74,
92, 71, 48,
60, 98, 51,
-36, 99, 69,
0, 20, 125,
0, 103, 74,
0, 103, 74,
-60, 98, 51,
-92, 71, 48,
0, 103, 74,
0, 126, 2,
-60, 98, 51,
0, 9, 126,
15, -95, 82,
0, -114, 55,
0, -114, 55,
-57, -93, 64,
-79, -89, 42,
-79, -89, 42,
-77, 4, 100,
-107, 27, 62,
-107, 27, 62,
17, 0, 125,
0, 9, 126,
79, -89, 42,
57, -93, 64,
0, -114, 55,
0, -114, 55,
-15, -95, 82,
0, 9, 126,
0, 9, 126,
-17, 0, 125,
107, 27, 62,
107, 27, 62,
77, 4, 100,
79, -89, 42,
77, 4, 100,
57, -93, 64,
79, -89, 42,
-17, 0, 125,
77, 4, 100,
107, 27, 62,
-15, -95, 82,
-17, 0, 125,
0, 9, 126,
57, -93, 64,
-15, -95, 82,
0, -114, 55,
-107, 27, 62,
-77, 4, 100,
17, 0, 125,
-79, -89, 42,
-57, -93, 64,
-77, 4, 100,
0, -114, 55,
15, -95, 82,
-57, -93, 64,
0, 9, 126,
17, 0, 125,
15, -95, 82,
107, 27, 62,
36, 99, 69,
0, 20, 125,
0, 20, 125,
-36, 99, 69,
-107, 27, 62,
-95, 66, -51,
-119, 13, -40,
-39, -115, 34,
55, 62, -95,
-119, 13, -40,
-95, 66, -51,
0, -62, -110,
103, -71, -15,
55, 62, -95,
-39, -115, 34,
103, -71, -15,
0, -62, -110,
-55, 62, -95,
-103, -71, -15,
0, -62, -110,
95, 66, -51,
119, 13, -40,
-55, 62, -95,
39, -115, 34,
119, 13, -40,
95, 66, -51,
0, -62, -110,
-103, -71, -15,
39, -115, 34,
19, -83, -93,
125, -16, -2,
16, 79, -97,
63, -109, 0,
125, -16, -2,
19, -83, -93,
-126, -7, -14,
-99, -78, -14,
63, -109, 0,
-95, 66, -51,
16, 79, -97,
-99, -78, -14,
-16, 79, -97,
-125, -16, -2,
-19, -83, -93,
99, -78, -14,
-16, 79, -97,
95, 66, -51,
-63, -109, 0,
99, -78, -14,
126, -7, -14,
-19, -83, -93,
-125, -16, -2,
-63, -109, 0,
95, 44, -70,
-72, 66, -80,
21, -66, -105,
76, -100, 14,
95, 44, -70,
126, -7, -14,
-74, -101, -19,
76, -100, 14,
84, -82, 47,
21, -66, -105,
-72, 66, -80,
-74, -101, -19,
-84, -82, 47,
-76, -100, 14,
74, -101, -19,
-126, -7, -14,
-95, 44, -70,
-76, -100, 14,
-21, -66, -105,
72, 66, -80,
-95, 44, -70,
74, -101, -19,
72, 66, -80,
-21, -66, -105,
0, -115, 53,
-77, -93, 37,
-66, -102, -35,
0, 126, 2,
60, 98, 51,
98, 75, -29,
-98, 75, -29,
-60, 98, 51,
0, 126, 2,
-92, 71, 48,
-60, 98, 51,
-98, 75, -29,
-107, 27, 62,
-36, 99, 69,
-92, 71, 48,
92, 71, 48,
36, 99, 69,
107, 27, 62,
98, 75, -29,
60, 98, 51,
92, 71, 48,
0, 113, -57,
98, 75, -29,
95, 66, -51,
-95, 66, -51,
-98, 75, -29,
0, 113, -57,
-126, -7, -14,
-123, 11, 27,
-98, 75, -29,
0, -124, -24,
0, -114, 55,
-79, -89, 42,
79, -89, 42,
0, -114, 55,
0, -124, -24,
98, 75, -29,
123, 11, 27,
126, -7, -14,
19, -39, -119,
49, -61, -99,
-49, -61, -99,
49, -61, -99,
0, -91, -88,
-49, -61, -99,
19, -39, -119,
-49, -61, -99,
-19, -39, -119,
66, -102, -35,
49, -61, -99,
19, -39, -119,
-19, -39, -119,
-49, -61, -99,
-66, -102, -35,
-75, 28, -98,
-97, 25, -76,
-19, -39, -119,
0, 57, -113,
0, 60, -111,
-97, 25, -76,
97, 25, -76,
0, 60, -111,
0, 57, -113,
19, -39, -119,
97, 25, -76,
75, 28, -98,
-75, 28, -98,
-107, -27, -61,
-21, -66, -105,
0, 57, -113,
-75, 28, -98,
19, -83, -93,
-19, -83, -93,
75, 28, -98,
0, 57, -113,
21, -66, -105,
107, -27, -61,
75, 28, -98,
0, -124, -24,
0, -124, -26,
18, -123, -20,
0, -124, -24,
-84, -82, 47,
-18, -123, -20,
0, -115, 53,
77, -93, 37,
0, -124, -26,
-15, -95, 82,
54, -23, 112,
-17, 0, 125,
-17, 0, 125,
-6, -90, 88,
77, 4, 100,
77, 4, 100,
-6, -90, 88,
57, -93, 64,
57, -93, 64,
54, -23, 112,
-15, -95, 82,
17, 0, 125,
-54, -23, 112,
15, -95, 82,
15, -95, 82,
-54, -23, 112,
-57, -93, 64,
-57, -93, 64,
6, -90, 88,
-77, 4, 100,
-77, 4, 100,
6, -90, 88,
17, 0, 125,
6, -90, 88,
-54, -84, 76,
17, 0, 125,
-57, -93, 64,
0, -28, 123,
6, -90, 88,
-54, -23, 112,
0, -28, 123,
-57, -93, 64,
17, 0, 125,
-54, -84, 76,
-54, -23, 112,
57, -93, 64,
0, -28, 123,
54, -23, 112,
-6, -90, 88,
0, -28, 123,
57, -93, 64,
-17, 0, 125,
54, -84, 76,
-6, -90, 88,
54, -23, 112,
54, -84, 76,
-17, 0, 125,
54, -84, 76,
54, -23, 112,
0, -28, 123,
-54, -84, 76,
6, -90, 88,
0, -28, 123,
66, -102, -35,
77, -93, 37,
0, -115, 53,
51, -71, 91,
-15, 34, 121,
-51, -71, 91,
92, 29, -81,
-92, 29, -81,
85, 68, -65,
15, 34, 121,
54, 95, 62,
-15, 34, 121,
-15, 34, 121,
-26, 124, 4,
-42, 116, -28,
-42, 116, -28,
26, 124, 4,
42, 116, -28,
42, 116, -28,
26, 124, 4,
15, 34, 121,
83, -45, 84,
92, 29, -81,
85, 68, -65,
-83, -45, 84,
84, -88, 32,
83, -45, 84,
-85, 68, -65,
-92, 29, -81,
-83, -45, 84,
-63, 58, -93,
-42, 116, -28,
63, 58, -93,
-92, 29, -81,
-84, -88, 32,
-83, -45, 84,
-83, -45, 84,
-84, -88, 32,
84, -88, 32,
83, -45, 84,
84, -88, 32,
92, 29, -81,
26, 124, 4,
-54, 95, 62,
15, 34, 121,
-42, 116, -28,
-26, 124, 4,
26, 124, 4,
-15, 34, 121,
54, 95, 62,
-26, 124, 4,
15, 34, 121,
-54, 95, 62,
54, 95, 62,
-92, 29, -81,
-85, 68, -65,
85, 68, -65,
54, 95, 62,
19, -39, -119,
-19, -39, -119,
-54, 95, 62,
97, 25, -76,
19, -39, -119,
26, 124, 4,
0, 60, -111,
97, 25, -76,
-26, 124, 4,
-97, 25, -76,
0, 60, -111,
54, 95, 62,
-19, -39, -119,
-97, 25, -76,
26, 124, 4,
-26, 124, 4,
0, 60, -111,
-26, 124, 4,
54, 95, 62,
-97, 25, -76,
51, -71, 91,
85, 68, -65,
63, 58, -93,
-51, -71, 91,
83, -45, 84,
51, -71, 91,
63, 58, -93,
-85, 68, -65,
-63, 58, -93,
-63, 58, -93,
-85, 68, -65,
-51, -71, 91,
-100, -51, 57,
89, -73, 51,
-49, 29, 113,
41, -26, -117,
-100, 35, -69,
90, 28, -84,
44, -118, 9,
41, -26, -117,
89, -73, 51,
-100, 35, -69,
-49, 29, 113,
-61, 110, 6,
-100, 35, -69,
-100, -51, 57,
-49, 29, 113,
41, -26, -117,
90, 28, -84,
89, -73, 51,
-100, 35, -69,
-61, 110, 6,
90, 28, -84,
-100, -51, 57,
44, -118, 9,
89, -73, 51,
-49, 29, 113,
-51, -71, 91,
-15, 34, 121,
89, -73, 51,
-63, 58, -93,
-51, -71, 91,
90, 28, -84,
-61, 110, 6,
-63, 58, -93,
-61, 110, 6,
-15, 34, 121,
-42, 116, -28,
49, 30, 113,
-89, -73, 51,
100, -51, 57,
-90, 28, -84,
100, 35, -69,
-41, -26, -117,
-89, -73, 51,
-41, -26, -117,
-44, -118, 9,
61, 110, 7,
49, 30, 113,
100, 35, -69,
49, 30, 113,
100, -51, 57,
100, 35, -69,
-89, -73, 51,
-90, 28, -84,
-41, -26, -117,
-90, 28, -84,
61, 110, 7,
100, 35, -69,
-89, -73, 51,
-44, -118, 9,
100, -51, 57,
49, 30, 113,
42, 116, -28,
15, 34, 121,
61, 110, 7,
63, 58, -93,
42, 116, -28,
-90, 28, -84,
-89, -73, 51,
63, 58, -93,
-89, -73, 51,
49, 30, 113,
51, -71, 91,
61, 110, 7,
42, 116, -28,
49, 30, 113,
-15, 34, 121,
-61, 110, 6,
-49, 29, 113,
108, -62, 18,
-68, -101, 34,
116, 33, 38,
86, -1, -92,
61, -21, -108,
-87, -2, -92,
-87, -2, -92,
116, 33, 38,
86, -1, -92,
-87, -2, -92,
108, -62, 18,
116, 33, 38,
-61, -21, -108,
-68, -101, 34,
-92, 29, -81,
-68, -101, 34,
84, -88, 32,
-84, -88, 32,
56, -110, 27,
92, 29, -81,
84, -88, 32,
61, -21, -108,
-92, 29, -81,
92, 29, -81,
-82, 1, 96,
74, -3, 103,
-87, 90, 19,
72, -104, -9,
-84, -23, -91,
88, -19, -88,
74, -3, 103,
72, -104, -9,
81, 96, 10,
-78, -98, -12,
-87, 90, 19,
-84, -23, -91,
-78, -98, -12,
-82, 1, 96,
-87, 90, 19,
72, -104, -9,
88, -19, -88,
81, 96, 10,
72, -104, -9,
-78, -98, -12,
-84, -23, -91,
74, -3, 103,
81, 96, 10,
-87, 90, 19,
-87, 90, 19,
81, 96, 10,
-68, -101, 34,
81, 96, 10,
88, -19, -88,
116, 33, 38,
88, -19, -88,
-61, -21, -108,
86, -1, -92,
-84, -23, -91,
-68, -101, 34,
-61, -21, -108,
83, 93, 19,
-74, -1, 102,
82, 1, 96,
-87, -20, -89,
84, -23, -91,
-72, -104, -9,
-58, 108, -32,
-72, -104, -9,
-74, -1, 102,
84, -23, -91,
83, 93, 19,
78, -98, -12,
83, 93, 19,
82, 1, 96,
78, -98, -12,
-58, 108, -32,
-87, -20, -89,
-72, -104, -9,
84, -23, -91,
78, -98, -12,
-72, -104, -9,
83, 93, 19,
-58, 108, -32,
-74, -1, 102,
83, 93, 19,
84, -23, -91,
56, -110, 27,
-87, -20, -89,
-87, -2, -92,
61, -21, -108,
-87, -20, -89,
108, -62, 18,
-87, -2, -92,
-58, 108, -32,
56, -110, 27,
108, -62, 18,
-41, -26, -117,
34, -82, -90,
-44, -118, 9,
-44, -118, 9,
87, -90, -14,
100, -51, 57,
100, -51, 57,
87, -90, -14,
100, 35, -69,
100, 35, -69,
96, -40, -71,
-41, -26, -117,
44, -118, 9,
-35, -116, -35,
41, -26, -117,
41, -26, -117,
-96, -40, -71,
-100, 35, -69,
-100, 35, -69,
-96, -40, -71,
-100, -51, 57,
-100, -51, 57,
-87, -90, -14,
44, -118, 9,
-68, -103, 26,
81, -5, 97,
35, -116, -35,
81, -5, 97,
96, -40, -71,
87, -90, -14,
76, 96, -30,
34, -82, -90,
96, -40, -71,
-74, -1, -102,
-68, -103, 26,
34, -82, -90,
-81, -5, 97,
-35, -116, -35,
-87, -90, -14,
74, -1, -102,
-96, -40, -71,
-34, -82, -90,
-76, 96, -30,
-81, -5, 97,
-96, -40, -71,
-34, -82, -90,
-35, -116, -35,
74, -1, -102,
-100, -41, 66,
65, -96, 49,
-61, -14, 110,
34, -17, -121,
-93, 56, -65,
81, 25, -93,
32, -122, 8,
34, -17, -121,
65, -96, 49,
-93, 56, -65,
-61, -14, 110,
-51, 112, -29,
-93, 56, -65,
-100, -41, 66,
-61, -14, 110,
34, -17, -121,
81, 25, -93,
65, -96, 49,
-93, 56, -65,
-51, 112, -29,
81, 25, -93,
-100, -41, 66,
32, -122, 8,
65, -96, 49,
34, -17, -121,
-71, -91, -52,
-93, 56, -65,
-93, 56, -65,
-71, -91, -52,
-100, -41, 66,
-100, -41, 66,
-71, -91, -52,
32, -122, 8,
32, -122, 8,
-71, -91, -52,
34, -17, -121,
81, 25, -93,
-76, 96, -30,
74, -1, -102,
-51, 112, -29,
-61, -14, 110,
-76, 96, -30,
-61, -14, 110,
65, -96, 49,
-81, -5, 97,
65, -96, 49,
81, 25, -93,
68, -103, 26,
72, -104, -9,
-27, -100, 73,
-78, -98, -12,
-78, -98, -12,
-27, -100, 73,
-82, 1, 96,
-82, 1, 96,
-27, -66, 104,
74, -3, 103,
74, -3, 103,
29, -62, 106,
72, -104, -9,
-74, -1, 102,
-29, -62, 106,
82, 1, 96,
82, 1, 96,
27, -100, 73,
78, -98, -12,
78, -98, -12,
27, -100, 73,
-72, -104, -9,
-72, -104, -9,
-29, -62, 106,
-74, -1, 102,
89, -9, 89,
62, 14, 109,
-89, -9, 89,
-79, 48, -86,
-120, -18, -36,
79, 48, -86,
-68, 17, 105,
-120, -18, -36,
-89, -9, 89,
-79, -57, -80,
62, 14, 109,
79, 48, -86,
89, -9, 89,
54, 96, 62,
79, 48, -86,
79, 48, -86,
64, 56, -93,
-79, 48, -86,
-79, 48, -86,
-99, 67, 39,
-89, -9, 89,
-89, -9, 89,
-99, 67, 39,
89, -9, 89,
-99, 67, 39,
54, 96, 62,
89, -9, 89,
-79, 48, -86,
-86, 31, -87,
-99, 67, 39,
64, 56, -93,
-86, 31, -87,
-79, 48, -86,
54, 96, 62,
64, 56, -93,
79, 48, -86,
62, 14, 109,
89, -9, 89,
79, 48, -86,
-120, -18, -36,
-79, 48, -86,
-89, -9, 89,
-120, -18, -36,
-79, -57, -80,
79, 48, -86,
62, 14, 109,
-68, 17, 105,
-89, -9, 89,
-120, -18, -36,
-29, -62, 106,
-29, -101, 69,
-68, 17, 105,
62, 14, 109,
-29, -62, 106,
62, 14, 109,
-79, -57, -80,
27, -66, 104,
-79, -57, -80,
-29, -101, 69,
27, -100, 73,
89, -9, 89,
-62, 14, 109,
-89, -9, 89,
-79, 48, -86,
120, -18, -36,
79, 48, -86,
89, -9, 89,
120, -18, -36,
68, 17, 105,
-79, 48, -86,
-62, 14, 109,
79, -57, -80,
-79, 48, -86,
-54, 96, 62,
-89, -9, 89,
79, 48, -86,
-64, 56, -93,
-79, 48, -86,
89, -9, 89,
99, 67, 39,
79, 48, -86,
-89, -9, 89,
99, 67, 39,
89, -9, 89,
-89, -9, 89,
-54, 96, 62,
99, 67, 39,
99, 67, 39,
86, 31, -87,
79, 48, -86,
79, 48, -86,
86, 31, -87,
-64, 56, -93,
-79, 48, -86,
-64, 56, -93,
-54, 96, 62,
-79, 48, -86,
-89, -9, 89,
-62, 14, 109,
89, -9, 89,
79, 48, -86,
120, -18, -36,
-79, 48, -86,
79, -57, -80,
120, -18, -36,
89, -9, 89,
68, 17, 105,
-62, 14, 109,
-62, 14, 109,
29, -62, 106,
-27, -66, 104,
68, 17, 105,
120, -18, -36,
29, -62, 106,
120, -18, -36,
79, -57, -80,
29, -101, 69,
79, -57, -80,
-27, -66, 104,
-27, -100, 73,
85, -66, -66,
-51, -72, -90,
84, 37, -87,
-64, 103, 34,
95, 83, 5,
-87, 84, -37,
99, -75, 23,
75, -73, 71,
-95, -78, -28,
75, -73, 71,
95, 83, 5,
61, 97, 53,
-95, -78, -28,
-103, -63, 38,
-87, 84, -37,
61, 97, 53,
-17, -22, 123,
75, -73, 71,
75, -73, 71,
-17, -22, 123,
-103, -63, 38,
-103, -63, 38,
-17, -22, 123,
-64, 103, 34,
-64, 103, 34,
-17, -22, 123,
61, 97, 53,
99, -75, 23,
85, -66, -66,
95, 83, 5,
-95, -78, -28,
-51, -72, -90,
99, -75, 23,
-87, 84, -37,
-53, 38, -108,
-95, -78, -28,
-53, 38, -108,
-51, -72, -90,
-95, -78, -28,
-51, -72, -90,
85, -66, -66,
99, -75, 23,
85, -66, -66,
84, 37, -87,
95, 83, 5,
-103, -63, 38,
-64, 103, 34,
-87, 84, -37,
75, -73, 71,
99, -75, 23,
95, 83, 5,
75, -73, 71,
-103, -63, 38,
-95, -78, -28,
-64, 103, 34,
61, 97, 53,
95, 83, 5,
-51, -72, -90,
-53, 38, -108,
84, 37, -87,
95, 83, 5,
84, 37, -87,
99, 67, 39,
84, 37, -87,
-53, 38, -108,
86, 31, -87,
-53, 38, -108,
-87, 84, -37,
-64, 56, -93,
-87, 84, -37,
95, 83, 5,
-54, 96, 62,
-84, 37, -87,
51, -72, -90,
-85, -66, -66,
87, 84, -37,
-95, 83, 5,
64, 103, 34,
95, -78, -28,
-75, -73, 71,
-99, -75, 23,
-61, 97, 53,
-95, 83, 5,
-75, -73, 71,
87, 84, -37,
103, -63, 38,
95, -78, -28,
-75, -73, 71,
17, -22, 123,
-61, 97, 53,
103, -63, 38,
17, -22, 123,
-75, -73, 71,
64, 103, 34,
17, -22, 123,
103, -63, 38,
-61, 97, 53,
17, -22, 123,
64, 103, 34,
-95, 83, 5,
-85, -66, -66,
-99, -75, 23,
-99, -75, 23,
51, -72, -90,
95, -78, -28,
95, -78, -28,
53, 38, -108,
87, 84, -37,
95, -78, -28,
51, -72, -90,
53, 38, -108,
-99, -75, 23,
-85, -66, -66,
51, -72, -90,
-95, 83, 5,
-84, 37, -87,
-85, -66, -66,
87, 84, -37,
64, 103, 34,
103, -63, 38,
-95, 83, 5,
-99, -75, 23,
-75, -73, 71,
95, -78, -28,
103, -63, 38,
-75, -73, 71,
-95, 83, 5,
-61, 97, 53,
64, 103, 34,
-84, 37, -87,
53, 38, -108,
51, -72, -90,
-95, 83, 5,
54, 96, 62,
-99, 67, 39,
87, 84, -37,
64, 56, -93,
54, 96, 62,
53, 38, -108,
-86, 31, -87,
64, 56, -93,
-84, 37, -87,
-99, 67, 39,
-86, 31, -87,
61, -21, -108,
84, -23, -91,
-87, -20, -89,
88, -19, -88,
-84, -23, -91,
-61, -21, -108,
76, 96, -30,
-81, 25, -93,
-74, -1, -102,
-74, -1, -102,
-65, -96, 49,
-68, -103, 26,
81, -5, 97,
51, 112, -29,
76, 96, -30,
61, -14, 110,
-65, -96, 49,
100, -41, 66,
-81, 25, -93,
93, 56, -65,
-34, -17, -121,
-65, -96, 49,
-34, -17, -121,
-32, -122, 8,
51, 112, -29,
61, -14, 110,
93, 56, -65,
61, -14, 110,
100, -41, 66,
93, 56, -65,
-65, -96, 49,
-81, 25, -93,
-34, -17, -121,
-81, 25, -93,
51, 112, -29,
93, 56, -65,
-65, -96, 49,
-32, -122, 8,
100, -41, 66,
93, 56, -65,
71, -91, -52,
-34, -17, -121,
100, -41, 66,
71, -91, -52,
93, 56, -65,
-32, -122, 8,
71, -91, -52,
100, -41, 66,
-34, -17, -121,
71, -91, -52,
-32, -122, 8,
-68, -103, 26,
-65, -96, 49,
81, -5, 97,
-65, -96, 49,
61, -14, 110,
81, -5, 97,
81, -5, 97,
61, -14, 110,
51, 112, -29,
-74, -1, -102,
-81, 25, -93,
-65, -96, 49,
76, 96, -30,
51, 112, -29,
-81, 25, -93,
-84, 37, -87,
-95, 83, 5,
-99, 67, 39,
53, 38, -108,
-84, 37, -87,
-86, 31, -87,
87, 84, -37,
53, 38, -108,
64, 56, -93,
-95, 83, 5,
87, 84, -37,
54, 96, 62,
95, 83, 5,
99, 67, 39,
-54, 96, 62,
-87, 84, -37,
-54, 96, 62,
-64, 56, -93,
-53, 38, -108,
-64, 56, -93,
86, 31, -87,
84, 37, -87,
86, 31, -87,
99, 67, 39,
79, -57, -80,
-62, 14, 109,
-27, -66, 104,
79, -57, -80,
-27, -100, 73,
29, -101, 69,
120, -18, -36,
29, -101, 69,
29, -62, 106,
-62, 14, 109,
68, 17, 105,
29, -62, 106,
-79, -57, -80,
-120, -18, -36,
-29, -101, 69,
-79, -57, -80,
27, -100, 73,
27, -66, 104,
62, 14, 109,
27, -66, 104,
-29, -62, 106,
-120, -18, -36,
-68, 17, 105,
-29, -62, 106,
-72, -104, -9,
-29, -101, 69,
-29, -62, 106,
27, -100, 73,
-29, -101, 69,
-72, -104, -9,
82, 1, 96,
27, -66, 104,
27, -100, 73,
-29, -62, 106,
27, -66, 104,
82, 1, 96,
29, -62, 106,
29, -101, 69,
72, -104, -9,
-27, -66, 104,
29, -62, 106,
74, -3, 103,
-27, -100, 73,
-27, -66, 104,
-82, 1, 96,
72, -104, -9,
29, -101, 69,
-27, -100, 73,
81, 25, -93,
74, -1, -102,
68, -103, 26,
65, -96, 49,
68, -103, 26,
-81, -5, 97,
-61, -14, 110,
-81, -5, 97,
-76, 96, -30,
81, 25, -93,
-51, 112, -29,
-76, 96, -30,
-35, -116, -35,
68, -103, 26,
74, -1, -102,
-81, -5, 97,
-87, -90, -14,
-96, -40, -71,
74, -1, -102,
-76, 96, -30,
-96, -40, -71,
-81, -5, 97,
68, -103, 26,
-35, -116, -35,
-68, -103, 26,
35, -116, -35,
34, -82, -90,
76, 96, -30,
-74, -1, -102,
34, -82, -90,
81, -5, 97,
76, 96, -30,
96, -40, -71,
81, -5, 97,
87, -90, -14,
35, -116, -35,
-87, -90, -14,
-35, -116, -35,
44, -118, 9,
-96, -40, -71,
-87, -90, -14,
-100, -51, 57,
41, -26, -117,
-34, -82, -90,
-96, -40, -71,
-35, -116, -35,
-34, -82, -90,
41, -26, -117,
96, -40, -71,
34, -82, -90,
-41, -26, -117,
87, -90, -14,
96, -40, -71,
100, 35, -69,
-44, -118, 9,
35, -116, -35,
87, -90, -14,
34, -82, -90,
35, -116, -35,
-44, -118, 9,
-58, 108, -32,
83, 93, 19,
56, -110, 27,
-87, -20, -89,
-58, 108, -32,
108, -62, 18,
84, -23, -91,
61, -21, -108,
56, -110, 27,
-84, -23, -91,
-87, 90, 19,
-68, -101, 34,
88, -19, -88,
86, -1, -92,
116, 33, 38,
81, 96, 10,
116, 33, 38,
-68, -101, 34,
61, -21, -108,
-61, -21, -108,
-92, 29, -81,
56, -110, 27,
61, -21, -108,
92, 29, -81,
-68, -101, 34,
56, -110, 27,
84, -88, 32,
-68, -101, 34,
-84, -88, 32,
-92, 29, -81,
86, -1, -92,
-61, -21, -108,
61, -21, -108,
108, -62, 18,
56, -110, 27,
-68, -101, 34,
49, 30, 113,
15, 34, 121,
51, -71, 91,
-89, -73, 51,
51, -71, 91,
63, 58, -93,
61, 110, 7,
-90, 28, -84,
63, 58, -93,
-61, 110, 6,
-42, 116, -28,
-63, 58, -93,
89, -73, 51,
90, 28, -84,
-63, 58, -93,
-49, 29, 113,
89, -73, 51,
-51, -71, 91,
-85, 68, -65,
-83, -45, 84,
-51, -71, 91,
63, 58, -93,
85, 68, -65,
-85, 68, -65,
-51, -71, 91,
-83, -45, 84,
83, -45, 84,
51, -71, 91,
83, -45, 84,
85, 68, -65,
-54, 95, 62,
26, 124, 4,
97, 25, -76,
54, 95, 62,
-54, 95, 62,
19, -39, -119,
-42, 116, -28,
42, 116, -28,
63, 58, -93,
51, -71, 91,
15, 34, 121,
-15, 34, 121,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:9 */
static s8 vtxnvgrp_frake_select_9[]={
-21, -123, -20,
0, -124, -23,
0, -125, -21,
0, -125, -21,
21, -123, -20,
85, -79, 49,
24, -65, -106,
76, 23, -98,
-22, -80, -95,
-22, -80, -95,
0, 52, -115,
0, -67, -107,
0, -67, -107,
0, 52, -115,
22, -80, -95,
22, -80, -95,
-76, 23, -98,
-24, -65, -106,
-24, -65, -106,
-107, -28, -61,
-67, -101, -37,
24, -65, -106,
78, -91, 40,
67, -101, -37,
107, -28, -61,
17, -36, -120,
76, 23, -98,
76, 23, -98,
99, 22, -75,
0, 52, -115,
0, 52, -115,
-99, 22, -75,
-76, 23, -98,
-76, 23, -98,
-17, -36, -120,
-107, -28, -61,
-107, -28, -61,
-17, -36, -120,
-67, -101, -37,
-67, -101, -37,
-49, -59, -100,
0, -89, -90,
0, -89, -90,
49, -59, -100,
67, -101, -37,
67, -101, -37,
17, -36, -120,
107, -28, -61,
0, 100, 77,
-94, 69, 48,
-36, 101, 67,
97, 61, -52,
100, 71, -30,
125, -8, -14,
123, 11, 26,
82, -85, 44,
85, -79, 49,
85, -79, 49,
82, -85, 44,
0, -125, -21,
0, -125, -21,
-82, -85, 44,
-85, -79, 49,
-85, -79, 49,
-82, -85, 44,
-123, 11, 26,
-125, -8, -14,
-100, 71, -30,
-97, 61, -52,
-97, 61, -52,
0, 110, -61,
0, 100, -77,
0, 100, -77,
0, 110, -61,
97, 61, -52,
100, 71, -30,
94, 69, 48,
123, 11, 26,
123, 11, 26,
94, 69, 48,
105, 27, 65,
-105, 27, 65,
-94, 69, 48,
-123, 11, 26,
-123, 11, 26,
-94, 69, 48,
-100, 71, -30,
-100, 71, -30,
0, 126, 1,
0, 110, -61,
0, 110, -61,
0, 126, 1,
100, 71, -30,
60, 99, 50,
0, 126, 1,
0, 100, 77,
67, -101, -37,
107, -28, -61,
24, -65, -106,
-67, -101, -37,
-78, -91, 40,
-24, -65, -106,
0, -89, -90,
67, -101, -37,
-67, -101, -37,
67, -101, -37,
0, -113, 56,
-67, -101, -37,
-21, -123, -20,
72, -102, -17,
-24, -65, -106,
-24, -65, -106,
-94, 41, -74,
-125, -8, -14,
-125, -8, -14,
-77, -99, 14,
-85, -79, 49,
-85, -79, 49,
72, -102, -17,
-21, -123, -20,
72, -102, -17,
-5, -51, -115,
73, 60, -84,
73, 60, -84,
-5, -51, -115,
-94, 41, -74,
-94, 41, -74,
-5, -51, -115,
-77, -99, 14,
-77, -99, 14,
-5, -51, -115,
72, -102, -17,
24, -65, -106,
-72, -102, -17,
21, -123, -20,
21, -123, -20,
-72, -102, -17,
85, -79, 49,
85, -79, 49,
77, -99, 14,
125, -8, -14,
125, -8, -14,
94, 41, -74,
24, -65, -106,
-73, 60, -84,
5, -51, -115,
-72, -102, -17,
-72, -102, -17,
5, -51, -115,
77, -99, 14,
77, -99, 14,
5, -51, -115,
94, 41, -74,
94, 41, -74,
5, -51, -115,
-73, 60, -84,
-22, -80, -95,
-64, -109, 0,
24, -65, -106,
24, -65, -106,
-64, -109, 0,
125, -8, -14,
125, -8, -14,
97, -80, -14,
97, 61, -52,
97, 61, -52,
-15, 74, -101,
-22, -80, -95,
-126, -15, -2,
-15, -50, -115,
-64, -109, 0,
-64, -109, 0,
-15, -50, -115,
97, -80, -14,
97, -80, -14,
-15, -50, -115,
-15, 74, -101,
-15, 74, -101,
-15, -50, -115,
-126, -15, -2,
-97, 61, -52,
-97, -80, -14,
-125, -8, -14,
-125, -8, -14,
64, -109, 0,
-24, -65, -106,
-24, -65, -106,
64, -109, 0,
22, -80, -95,
22, -80, -95,
15, 74, -101,
-97, 61, -52,
15, 74, -101,
15, -50, -115,
-97, -80, -14,
-97, -80, -14,
15, -50, -115,
64, -109, 0,
64, -109, 0,
15, -50, -115,
126, -15, -2,
126, -15, -2,
15, -50, -115,
15, 74, -101,
0, -67, -107,
41, -114, 37,
-22, -80, -95,
-22, -80, -95,
41, -114, 37,
97, 61, -52,
97, 61, -52,
-53, 60, -97,
0, 100, -77,
0, 100, -77,
-53, 60, -97,
0, -67, -107,
-105, -69, -15,
-5, -106, -68,
41, -114, 37,
41, -114, 37,
-5, -106, -68,
119, 13, -41,
119, 13, -41,
-5, -106, -68,
-53, 60, -97,
-53, 60, -97,
-5, -106, -68,
-105, -69, -15,
22, -80, -95,
-41, -114, 37,
0, -67, -107,
0, -67, -107,
53, 60, -97,
0, 100, -77,
0, 100, -77,
53, 60, -97,
-97, 61, -52,
-97, 61, -52,
-41, -114, 37,
22, -80, -95,
-41, -114, 37,
5, -106, -68,
105, -69, -15,
105, -69, -15,
5, -106, -68,
53, 60, -97,
53, 60, -97,
5, -106, -68,
-119, 13, -41,
-119, 13, -41,
5, -106, -68,
-41, -114, 37,
0, 16, 125,
0, 21, 125,
-105, 27, 65,
105, 27, 65,
0, 21, 125,
0, 16, 125,
78, -91, 40,
24, -65, -106,
21, -123, -20,
-78, -91, 40,
-21, -123, -20,
-24, -65, -106,
-78, -91, 40,
0, -124, -23,
-21, -123, -20,
78, -91, 40,
21, -123, -20,
0, -124, -23,
-78, -91, 40,
0, -113, 56,
0, -124, -23,
105, 27, 65,
82, -85, 44,
123, 11, 26,
-123, 11, 26,
-82, -85, 44,
-105, 27, 65,
85, -79, 49,
125, -8, -14,
123, 11, 26,
-123, 11, 26,
-125, -8, -14,
-85, -79, 49,
-56, -18, 112,
-56, -80, 80,
0, -23, 124,
56, -80, 80,
0, -23, 124,
-5, -85, 93,
0, 100, 77,
0, 21, 125,
36, 101, 67,
0, 100, 77,
36, 101, 67,
94, 69, 48,
0, 100, 77,
94, 69, 48,
60, 99, 50,
-36, 101, 67,
0, 21, 125,
0, 100, 77,
0, 100, 77,
-60, 99, 50,
-94, 69, 48,
0, 100, 77,
0, 126, 1,
-60, 99, 50,
0, 16, 125,
16, -93, 84,
0, -112, 59,
0, -112, 59,
-59, -89, 66,
-82, -85, 44,
-82, -85, 44,
-78, 5, 99,
-105, 27, 65,
-105, 27, 65,
17, 0, 125,
0, 16, 125,
82, -85, 44,
59, -89, 66,
0, -112, 59,
0, -112, 59,
-16, -93, 84,
0, 16, 125,
0, 16, 125,
-17, 0, 125,
105, 27, 65,
105, 27, 65,
78, 5, 99,
82, -85, 44,
78, 5, 99,
59, -89, 66,
82, -85, 44,
-17, 0, 125,
78, 5, 99,
105, 27, 65,
-16, -93, 84,
-17, 0, 125,
0, 16, 125,
59, -89, 66,
-16, -93, 84,
0, -112, 59,
-105, 27, 65,
-78, 5, 99,
17, 0, 125,
-82, -85, 44,
-59, -89, 66,
-78, 5, 99,
0, -112, 59,
16, -93, 84,
-59, -89, 66,
0, 16, 125,
17, 0, 125,
16, -93, 84,
105, 27, 65,
36, 101, 67,
0, 21, 125,
0, 21, 125,
-36, 101, 67,
-105, 27, 65,
-97, 61, -52,
-119, 13, -41,
-41, -114, 37,
53, 60, -97,
-119, 13, -41,
-97, 61, -52,
0, -67, -107,
105, -69, -15,
53, 60, -97,
-41, -114, 37,
105, -69, -15,
0, -67, -107,
-53, 60, -97,
-105, -69, -15,
0, -67, -107,
97, 61, -52,
119, 13, -41,
-53, 60, -97,
41, -114, 37,
119, 13, -41,
97, 61, -52,
0, -67, -107,
-105, -69, -15,
41, -114, 37,
22, -80, -95,
126, -15, -2,
15, 74, -101,
64, -109, 0,
126, -15, -2,
22, -80, -95,
-125, -8, -14,
-97, -80, -14,
64, -109, 0,
-97, 61, -52,
15, 74, -101,
-97, -80, -14,
-15, 74, -101,
-126, -15, -2,
-22, -80, -95,
97, -80, -14,
-15, 74, -101,
97, 61, -52,
-64, -109, 0,
97, -80, -14,
125, -8, -14,
-22, -80, -95,
-126, -15, -2,
-64, -109, 0,
94, 41, -74,
-73, 60, -84,
24, -65, -106,
77, -99, 14,
94, 41, -74,
125, -8, -14,
-72, -102, -17,
77, -99, 14,
85, -79, 49,
24, -65, -106,
-73, 60, -84,
-72, -102, -17,
-85, -79, 49,
-77, -99, 14,
72, -102, -17,
-125, -8, -14,
-94, 41, -74,
-77, -99, 14,
-24, -65, -106,
73, 60, -84,
-94, 41, -74,
72, -102, -17,
73, 60, -84,
-24, -65, -106,
0, -113, 56,
-78, -91, 40,
-67, -101, -37,
0, 126, 1,
60, 99, 50,
100, 71, -30,
-100, 71, -30,
-60, 99, 50,
0, 126, 1,
-94, 69, 48,
-60, 99, 50,
-100, 71, -30,
-105, 27, 65,
-36, 101, 67,
-94, 69, 48,
94, 69, 48,
36, 101, 67,
105, 27, 65,
100, 71, -30,
60, 99, 50,
94, 69, 48,
0, 110, -61,
100, 71, -30,
97, 61, -52,
-97, 61, -52,
-100, 71, -30,
0, 110, -61,
-125, -8, -14,
-123, 11, 26,
-100, 71, -30,
0, -125, -21,
0, -112, 59,
-82, -85, 44,
82, -85, 44,
0, -112, 59,
0, -125, -21,
100, 71, -30,
123, 11, 26,
125, -8, -14,
17, -36, -120,
49, -59, -100,
-49, -59, -100,
49, -59, -100,
0, -89, -90,
-49, -59, -100,
17, -36, -120,
-49, -59, -100,
-17, -36, -120,
67, -101, -37,
49, -59, -100,
17, -36, -120,
-17, -36, -120,
-49, -59, -100,
-67, -101, -37,
-76, 23, -98,
-99, 22, -75,
-17, -36, -120,
0, 52, -115,
0, 54, -114,
-99, 22, -75,
99, 22, -75,
0, 54, -114,
0, 52, -115,
17, -36, -120,
99, 22, -75,
76, 23, -98,
-76, 23, -98,
-107, -28, -61,
-24, -65, -106,
0, 52, -115,
-76, 23, -98,
22, -80, -95,
-22, -80, -95,
76, 23, -98,
0, 52, -115,
24, -65, -106,
107, -28, -61,
76, 23, -98,
0, -125, -21,
0, -124, -23,
21, -123, -20,
0, -125, -21,
-85, -79, 49,
-21, -123, -20,
0, -113, 56,
78, -91, 40,
0, -124, -23,
-16, -93, 84,
56, -18, 112,
-17, 0, 125,
-17, 0, 125,
-5, -85, 93,
78, 5, 99,
78, 5, 99,
-5, -85, 93,
59, -89, 66,
59, -89, 66,
56, -18, 112,
-16, -93, 84,
17, 0, 125,
-56, -18, 112,
16, -93, 84,
16, -93, 84,
-56, -18, 112,
-59, -89, 66,
-59, -89, 66,
5, -85, 93,
-78, 5, 99,
-78, 5, 99,
5, -85, 93,
17, 0, 125,
5, -85, 93,
-56, -80, 80,
17, 0, 125,
-59, -89, 66,
0, -23, 124,
5, -85, 93,
-56, -18, 112,
0, -23, 124,
-59, -89, 66,
17, 0, 125,
-56, -80, 80,
-56, -18, 112,
59, -89, 66,
0, -23, 124,
56, -18, 112,
-5, -85, 93,
0, -23, 124,
59, -89, 66,
-17, 0, 125,
56, -80, 80,
-5, -85, 93,
56, -18, 112,
56, -80, 80,
-17, 0, 125,
56, -80, 80,
56, -18, 112,
0, -23, 124,
-56, -80, 80,
5, -85, 93,
0, -23, 124,
67, -101, -37,
78, -91, 40,
0, -113, 56,
55, -62, 95,
-15, 39, 119,
-55, -62, 95,
92, 28, -81,
-92, 28, -81,
85, 62, -69,
15, 39, 119,
44, 100, 63,
-15, 39, 119,
-15, 39, 119,
-27, 123, 3,
-45, 114, -32,
-45, 114, -32,
27, 123, 3,
45, 114, -32,
45, 114, -32,
27, 123, 3,
15, 39, 119,
83, -37, 88,
92, 28, -81,
85, 62, -69,
-83, -37, 88,
83, -88, 36,
83, -37, 88,
-85, 62, -69,
-92, 28, -81,
-83, -37, 88,
-64, 52, -96,
-45, 114, -32,
64, 52, -96,
-92, 28, -81,
-83, -88, 36,
-83, -37, 88,
-83, -37, 88,
-83, -88, 36,
83, -88, 36,
83, -37, 88,
83, -88, 36,
92, 28, -81,
27, 123, 3,
-44, 100, 63,
15, 39, 119,
-45, 114, -32,
-27, 123, 3,
27, 123, 3,
-15, 39, 119,
44, 100, 63,
-27, 123, 3,
15, 39, 119,
-44, 100, 63,
44, 100, 63,
-92, 28, -81,
-85, 62, -69,
85, 62, -69,
44, 100, 63,
17, -36, -120,
-17, -36, -120,
-44, 100, 63,
99, 22, -75,
17, -36, -120,
27, 123, 3,
0, 54, -114,
99, 22, -75,
-27, 123, 3,
-99, 22, -75,
0, 54, -114,
44, 100, 63,
-17, -36, -120,
-99, 22, -75,
27, 123, 3,
-27, 123, 3,
0, 54, -114,
-27, 123, 3,
44, 100, 63,
-99, 22, -75,
55, -62, 95,
85, 62, -69,
64, 52, -96,
-55, -62, 95,
83, -37, 88,
55, -62, 95,
64, 52, -96,
-85, 62, -69,
-64, 52, -96,
-64, 52, -96,
-85, 62, -69,
-55, -62, 95,
-99, -51, 59,
91, -67, 55,
-50, 34, 111,
42, -30, -115,
-99, 34, -70,
91, 23, -85,
43, -118, 13,
42, -30, -115,
91, -67, 55,
-99, 34, -70,
-50, 34, 111,
-65, 108, 5,
-99, 34, -70,
-99, -51, 59,
-50, 34, 111,
42, -30, -115,
91, 23, -85,
91, -67, 55,
-99, 34, -70,
-65, 108, 5,
91, 23, -85,
-99, -51, 59,
43, -118, 13,
91, -67, 55,
-50, 34, 111,
-55, -62, 95,
-15, 39, 119,
91, -67, 55,
-64, 52, -96,
-55, -62, 95,
91, 23, -85,
-65, 108, 5,
-64, 52, -96,
-65, 108, 5,
-15, 39, 119,
-45, 114, -32,
49, 34, 111,
-91, -67, 55,
99, -51, 59,
-91, 23, -85,
99, 34, -70,
-42, -30, -115,
-91, -67, 55,
-42, -30, -115,
-43, -118, 13,
65, 108, 5,
49, 34, 111,
99, 34, -70,
49, 34, 111,
99, -51, 59,
99, 34, -70,
-91, -67, 55,
-91, 23, -85,
-42, -30, -115,
-91, 23, -85,
65, 108, 5,
99, 34, -70,
-91, -67, 55,
-43, -118, 13,
99, -51, 59,
49, 34, 111,
45, 114, -32,
15, 39, 119,
65, 108, 5,
64, 52, -96,
45, 114, -32,
-91, 23, -85,
-91, -67, 55,
64, 52, -96,
-91, -67, 55,
49, 34, 111,
55, -62, 95,
65, 108, 5,
45, 114, -32,
49, 34, 111,
-15, 39, 119,
-65, 108, 5,
-50, 34, 111,
109, -59, 23,
-73, -98, 32,
117, 29, 37,
92, -5, -86,
62, -24, -107,
-92, -5, -86,
-92, -5, -86,
117, 29, 37,
92, -5, -86,
-92, -5, -86,
109, -59, 23,
117, 29, 37,
-62, -24, -107,
-73, -98, 32,
-92, 28, -81,
-73, -98, 32,
83, -88, 36,
-83, -88, 36,
60, -107, 28,
92, 28, -81,
83, -88, 36,
62, -24, -107,
-92, 28, -81,
92, 28, -81,
-79, 5, 98,
73, 2, 103,
-89, 87, 18,
72, -104, -2,
-86, -32, -87,
88, -27, -86,
73, 2, 103,
72, -104, -2,
83, 95, 6,
-78, -99, -5,
-89, 87, 18,
-86, -32, -87,
-78, -99, -5,
-79, 5, 98,
-89, 87, 18,
72, -104, -2,
88, -27, -86,
83, 95, 6,
72, -104, -2,
-78, -99, -5,
-86, -32, -87,
73, 2, 103,
83, 95, 6,
-89, 87, 18,
-89, 87, 18,
83, 95, 6,
-73, -98, 32,
83, 95, 6,
88, -27, -86,
117, 29, 37,
88, -27, -86,
-62, -24, -107,
92, -5, -86,
-86, -32, -87,
-73, -98, 32,
-62, -24, -107,
86, 91, 18,
-73, 3, 103,
79, 5, 98,
-87, -28, -87,
86, -32, -87,
-72, -104, -2,
-59, 105, -37,
-72, -104, -2,
-73, 3, 103,
86, -32, -87,
86, 91, 18,
78, -99, -5,
86, 91, 18,
79, 5, 98,
78, -99, -5,
-59, 105, -37,
-87, -28, -87,
-72, -104, -2,
86, -32, -87,
78, -99, -5,
-72, -104, -2,
86, 91, 18,
-59, 105, -37,
-73, 3, 103,
86, 91, 18,
86, -32, -87,
60, -107, 28,
-87, -28, -87,
-92, -5, -86,
62, -24, -107,
-87, -28, -87,
109, -59, 23,
-92, -5, -86,
-59, 105, -37,
60, -107, 28,
109, -59, 23,
-42, -30, -115,
36, -80, -90,
-43, -118, 13,
-43, -118, 13,
91, -87, -12,
99, -51, 59,
99, -51, 59,
91, -87, -12,
99, 34, -70,
99, 34, -70,
95, -43, -71,
-42, -30, -115,
43, -118, 13,
-37, -116, -34,
42, -30, -115,
42, -30, -115,
-95, -43, -71,
-99, 34, -70,
-99, 34, -70,
-95, -43, -71,
-99, -51, 59,
-99, -51, 59,
-91, -87, -12,
43, -118, 13,
-72, -99, 31,
80, 0, 97,
37, -116, -34,
80, 0, 97,
95, -43, -71,
91, -87, -12,
79, 92, -35,
36, -80, -90,
95, -43, -71,
-74, -5, -102,
-72, -99, 31,
36, -80, -90,
-80, 0, 97,
-37, -116, -34,
-91, -87, -12,
74, -5, -102,
-95, -43, -71,
-36, -80, -90,
-79, 92, -35,
-80, 0, 97,
-95, -43, -71,
-36, -80, -90,
-37, -116, -34,
74, -5, -102,
-99, -40, 67,
68, -91, 55,
-59, -8, 111,
34, -21, -120,
-92, 54, -67,
81, 22, -94,
32, -122, 12,
34, -21, -120,
68, -91, 55,
-92, 54, -67,
-59, -8, 111,
-52, 110, -34,
-92, 54, -67,
-99, -40, 67,
-59, -8, 111,
34, -21, -120,
81, 22, -94,
68, -91, 55,
-92, 54, -67,
-52, 110, -34,
81, 22, -94,
-99, -40, 67,
32, -122, 12,
68, -91, 55,
34, -21, -120,
-71, -91, -51,
-92, 54, -67,
-92, 54, -67,
-71, -91, -51,
-99, -40, 67,
-99, -40, 67,
-71, -91, -51,
32, -122, 12,
32, -122, 12,
-71, -91, -51,
34, -21, -120,
81, 22, -94,
-79, 92, -35,
74, -5, -102,
-52, 110, -34,
-59, -8, 111,
-79, 92, -35,
-59, -8, 111,
68, -91, 55,
-80, 0, 97,
68, -91, 55,
81, 22, -94,
72, -99, 31,
72, -104, -2,
-26, -100, 72,
-78, -99, -5,
-78, -99, -5,
-26, -100, 72,
-79, 5, 98,
-79, 5, 98,
-30, -62, 106,
73, 2, 103,
73, 2, 103,
32, -59, 107,
72, -104, -2,
-73, 3, 103,
-32, -59, 107,
79, 5, 98,
79, 5, 98,
26, -100, 72,
78, -99, -5,
78, -99, -5,
26, -100, 72,
-72, -104, -2,
-72, -104, -2,
-32, -59, 107,
-73, 3, 103,
89, 0, 89,
67, 27, 104,
-89, 0, 89,
-79, 37, -91,
-119, -21, -38,
79, 37, -91,
-71, 29, 100,
-119, -21, -38,
-89, 0, 89,
-77, -60, -80,
67, 27, 104,
79, 37, -91,
89, 0, 89,
52, 99, 58,
79, 37, -91,
79, 37, -91,
70, 45, -95,
-79, 37, -91,
-79, 37, -91,
-99, 68, 39,
-89, 0, 89,
-89, 0, 89,
-99, 68, 39,
89, 0, 89,
-99, 68, 39,
52, 99, 58,
89, 0, 89,
-79, 37, -91,
-88, 19, -88,
-99, 68, 39,
70, 45, -95,
-88, 19, -88,
-79, 37, -91,
52, 99, 58,
70, 45, -95,
79, 37, -91,
67, 27, 104,
89, 0, 89,
79, 37, -91,
-119, -21, -38,
-79, 37, -91,
-89, 0, 89,
-119, -21, -38,
-77, -60, -80,
79, 37, -91,
67, 27, 104,
-71, 29, 100,
-89, 0, 89,
-119, -21, -38,
-32, -59, 107,
-28, -102, 69,
-71, 29, 100,
67, 27, 104,
-32, -59, 107,
67, 27, 104,
-77, -60, -80,
30, -62, 106,
-77, -60, -80,
-28, -102, 69,
26, -100, 72,
89, 0, 89,
-67, 27, 104,
-89, 0, 89,
-79, 37, -91,
119, -21, -38,
79, 37, -91,
89, 0, 89,
119, -21, -38,
71, 29, 100,
-79, 37, -91,
-67, 27, 104,
77, -60, -80,
-79, 37, -91,
-52, 99, 58,
-89, 0, 89,
79, 37, -91,
-70, 45, -95,
-79, 37, -91,
89, 0, 89,
99, 68, 39,
79, 37, -91,
-89, 0, 89,
99, 68, 39,
89, 0, 89,
-89, 0, 89,
-52, 99, 58,
99, 68, 39,
99, 68, 39,
88, 19, -88,
79, 37, -91,
79, 37, -91,
88, 19, -88,
-70, 45, -95,
-79, 37, -91,
-70, 45, -95,
-52, 99, 58,
-79, 37, -91,
-89, 0, 89,
-67, 27, 104,
89, 0, 89,
79, 37, -91,
119, -21, -38,
-79, 37, -91,
77, -60, -80,
119, -21, -38,
89, 0, 89,
71, 29, 100,
-67, 27, 104,
-67, 27, 104,
32, -59, 107,
-30, -62, 106,
71, 29, 100,
119, -21, -38,
32, -59, 107,
119, -21, -38,
77, -60, -80,
28, -102, 69,
77, -60, -80,
-30, -62, 106,
-26, -100, 72,
86, -70, -61,
-53, -76, -85,
87, 25, -88,
-65, 105, 27,
95, 83, 2,
-89, 81, -36,
99, -75, 23,
76, -70, 72,
-94, -81, -24,
76, -70, 72,
95, 83, 2,
61, 100, 47,
-94, -81, -24,
-101, -63, 41,
-89, 81, -36,
61, 100, 47,
-18, -14, 124,
76, -70, 72,
76, -70, 72,
-18, -14, 124,
-101, -63, 41,
-101, -63, 41,
-18, -14, 124,
-65, 105, 27,
-65, 105, 27,
-18, -14, 124,
61, 100, 47,
99, -75, 23,
86, -70, -61,
95, 83, 2,
-94, -81, -24,
-53, -76, -85,
99, -75, 23,
-89, 81, -36,
-55, 26, -110,
-94, -81, -24,
-55, 26, -110,
-53, -76, -85,
-94, -81, -24,
-53, -76, -85,
86, -70, -61,
99, -75, 23,
86, -70, -61,
87, 25, -88,
95, 83, 2,
-101, -63, 41,
-65, 105, 27,
-89, 81, -36,
76, -70, 72,
99, -75, 23,
95, 83, 2,
76, -70, 72,
-101, -63, 41,
-94, -81, -24,
-65, 105, 27,
61, 100, 47,
95, 83, 2,
-53, -76, -85,
-55, 26, -110,
87, 25, -88,
95, 83, 2,
87, 25, -88,
99, 68, 39,
87, 25, -88,
-55, 26, -110,
88, 19, -88,
-55, 26, -110,
-89, 81, -36,
-70, 45, -95,
-89, 81, -36,
95, 83, 2,
-52, 99, 58,
-87, 25, -88,
53, -76, -85,
-86, -70, -61,
89, 81, -36,
-95, 83, 2,
65, 105, 27,
94, -81, -24,
-76, -70, 72,
-99, -75, 23,
-61, 100, 47,
-95, 83, 2,
-76, -70, 72,
89, 81, -36,
101, -63, 41,
94, -81, -24,
-76, -70, 72,
18, -14, 124,
-61, 100, 47,
101, -63, 41,
18, -14, 124,
-76, -70, 72,
65, 105, 27,
18, -14, 124,
101, -63, 41,
-61, 100, 47,
18, -14, 124,
65, 105, 27,
-95, 83, 2,
-86, -70, -61,
-99, -75, 23,
-99, -75, 23,
53, -76, -85,
94, -81, -24,
94, -81, -24,
55, 26, -110,
89, 81, -36,
94, -81, -24,
53, -76, -85,
55, 26, -110,
-99, -75, 23,
-86, -70, -61,
53, -76, -85,
-95, 83, 2,
-87, 25, -88,
-86, -70, -61,
89, 81, -36,
65, 105, 27,
101, -63, 41,
-95, 83, 2,
-99, -75, 23,
-76, -70, 72,
94, -81, -24,
101, -63, 41,
-76, -70, 72,
-95, 83, 2,
-61, 100, 47,
65, 105, 27,
-87, 25, -88,
55, 26, -110,
53, -76, -85,
-95, 83, 2,
52, 99, 58,
-99, 68, 39,
89, 81, -36,
70, 45, -95,
52, 99, 58,
55, 26, -110,
-88, 19, -88,
70, 45, -95,
-87, 25, -88,
-99, 68, 39,
-88, 19, -88,
62, -24, -107,
86, -32, -87,
-87, -28, -87,
88, -27, -86,
-86, -32, -87,
-62, -24, -107,
79, 92, -35,
-81, 22, -94,
-74, -5, -102,
-74, -5, -102,
-68, -91, 55,
-72, -99, 31,
80, 0, 97,
52, 110, -34,
79, 92, -35,
59, -8, 111,
-68, -91, 55,
99, -40, 67,
-81, 22, -94,
92, 54, -67,
-34, -21, -120,
-68, -91, 55,
-34, -21, -120,
-32, -122, 12,
52, 110, -34,
59, -8, 111,
92, 54, -67,
59, -8, 111,
99, -40, 67,
92, 54, -67,
-68, -91, 55,
-81, 22, -94,
-34, -21, -120,
-81, 22, -94,
52, 110, -34,
92, 54, -67,
-68, -91, 55,
-32, -122, 12,
99, -40, 67,
92, 54, -67,
71, -91, -51,
-34, -21, -120,
99, -40, 67,
71, -91, -51,
92, 54, -67,
-32, -122, 12,
71, -91, -51,
99, -40, 67,
-34, -21, -120,
71, -91, -51,
-32, -122, 12,
-72, -99, 31,
-68, -91, 55,
80, 0, 97,
-68, -91, 55,
59, -8, 111,
80, 0, 97,
80, 0, 97,
59, -8, 111,
52, 110, -34,
-74, -5, -102,
-81, 22, -94,
-68, -91, 55,
79, 92, -35,
52, 110, -34,
-81, 22, -94,
-87, 25, -88,
-95, 83, 2,
-99, 68, 39,
55, 26, -110,
-87, 25, -88,
-88, 19, -88,
89, 81, -36,
55, 26, -110,
70, 45, -95,
-95, 83, 2,
89, 81, -36,
52, 99, 58,
95, 83, 2,
99, 68, 39,
-52, 99, 58,
-89, 81, -36,
-52, 99, 58,
-70, 45, -95,
-55, 26, -110,
-70, 45, -95,
88, 19, -88,
87, 25, -88,
88, 19, -88,
99, 68, 39,
77, -60, -80,
-67, 27, 104,
-30, -62, 106,
77, -60, -80,
-26, -100, 72,
28, -102, 69,
119, -21, -38,
28, -102, 69,
32, -59, 107,
-67, 27, 104,
71, 29, 100,
32, -59, 107,
-77, -60, -80,
-119, -21, -38,
-28, -102, 69,
-77, -60, -80,
26, -100, 72,
30, -62, 106,
67, 27, 104,
30, -62, 106,
-32, -59, 107,
-119, -21, -38,
-71, 29, 100,
-32, -59, 107,
-72, -104, -2,
-28, -102, 69,
-32, -59, 107,
26, -100, 72,
-28, -102, 69,
-72, -104, -2,
79, 5, 98,
30, -62, 106,
26, -100, 72,
-32, -59, 107,
30, -62, 106,
79, 5, 98,
32, -59, 107,
28, -102, 69,
72, -104, -2,
-30, -62, 106,
32, -59, 107,
73, 2, 103,
-26, -100, 72,
-30, -62, 106,
-79, 5, 98,
72, -104, -2,
28, -102, 69,
-26, -100, 72,
81, 22, -94,
74, -5, -102,
72, -99, 31,
68, -91, 55,
72, -99, 31,
-80, 0, 97,
-59, -8, 111,
-80, 0, 97,
-79, 92, -35,
81, 22, -94,
-52, 110, -34,
-79, 92, -35,
-37, -116, -34,
72, -99, 31,
74, -5, -102,
-80, 0, 97,
-91, -87, -12,
-95, -43, -71,
74, -5, -102,
-79, 92, -35,
-95, -43, -71,
-80, 0, 97,
72, -99, 31,
-37, -116, -34,
-72, -99, 31,
37, -116, -34,
36, -80, -90,
79, 92, -35,
-74, -5, -102,
36, -80, -90,
80, 0, 97,
79, 92, -35,
95, -43, -71,
80, 0, 97,
91, -87, -12,
37, -116, -34,
-91, -87, -12,
-37, -116, -34,
43, -118, 13,
-95, -43, -71,
-91, -87, -12,
-99, -51, 59,
42, -30, -115,
-36, -80, -90,
-95, -43, -71,
-37, -116, -34,
-36, -80, -90,
42, -30, -115,
95, -43, -71,
36, -80, -90,
-42, -30, -115,
91, -87, -12,
95, -43, -71,
99, 34, -70,
-43, -118, 13,
37, -116, -34,
91, -87, -12,
36, -80, -90,
37, -116, -34,
-43, -118, 13,
-59, 105, -37,
86, 91, 18,
60, -107, 28,
-87, -28, -87,
-59, 105, -37,
109, -59, 23,
86, -32, -87,
62, -24, -107,
60, -107, 28,
-86, -32, -87,
-89, 87, 18,
-73, -98, 32,
88, -27, -86,
92, -5, -86,
117, 29, 37,
83, 95, 6,
117, 29, 37,
-73, -98, 32,
62, -24, -107,
-62, -24, -107,
-92, 28, -81,
60, -107, 28,
62, -24, -107,
92, 28, -81,
-73, -98, 32,
60, -107, 28,
83, -88, 36,
-73, -98, 32,
-83, -88, 36,
-92, 28, -81,
92, -5, -86,
-62, -24, -107,
62, -24, -107,
109, -59, 23,
60, -107, 28,
-73, -98, 32,
49, 34, 111,
15, 39, 119,
55, -62, 95,
-91, -67, 55,
55, -62, 95,
64, 52, -96,
65, 108, 5,
-91, 23, -85,
64, 52, -96,
-65, 108, 5,
-45, 114, -32,
-64, 52, -96,
91, -67, 55,
91, 23, -85,
-64, 52, -96,
-50, 34, 111,
91, -67, 55,
-55, -62, 95,
-85, 62, -69,
-83, -37, 88,
-55, -62, 95,
64, 52, -96,
85, 62, -69,
-85, 62, -69,
-55, -62, 95,
-83, -37, 88,
83, -37, 88,
55, -62, 95,
83, -37, 88,
85, 62, -69,
-44, 100, 63,
27, 123, 3,
99, 22, -75,
44, 100, 63,
-44, 100, 63,
17, -36, -120,
-45, 114, -32,
45, 114, -32,
64, 52, -96,
55, -62, 95,
15, 39, 119,
-15, 39, 119,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:10 */
static s8 vtxnvgrp_frake_select_10[]={
-23, -123, -21,
0, -125, -20,
0, -125, -18,
0, -125, -18,
23, -123, -21,
87, -77, 50,
27, -64, -106,
77, 18, -98,
-25, -77, -97,
-25, -77, -97,
0, 48, -117,
0, -72, -104,
0, -72, -104,
0, 48, -117,
25, -77, -97,
25, -77, -97,
-77, 18, -98,
-27, -64, -106,
-27, -64, -106,
-107, -28, -62,
-68, -99, -38,
27, -64, -106,
79, -88, 43,
68, -99, -38,
107, -28, -62,
15, -34, -121,
77, 18, -98,
77, 18, -98,
101, 20, -73,
0, 48, -117,
0, 48, -117,
-101, 20, -73,
-77, 18, -98,
-77, 18, -98,
-15, -34, -121,
-107, -28, -62,
-107, -28, -62,
-15, -34, -121,
-68, -99, -38,
-68, -99, -38,
-49, -57, -101,
0, -87, -92,
0, -87, -92,
49, -57, -101,
68, -99, -38,
68, -99, -38,
15, -34, -121,
107, -28, -62,
0, 98, 79,
-95, 68, 48,
-36, 102, 65,
100, 57, -52,
102, 67, -31,
125, -9, -15,
123, 11, 26,
85, -81, 46,
87, -77, 50,
87, -77, 50,
85, -81, 46,
0, -125, -18,
0, -125, -18,
-85, -81, 46,
-87, -77, 50,
-87, -77, 50,
-85, -81, 46,
-123, 11, 26,
-125, -9, -15,
-102, 67, -31,
-100, 57, -52,
-100, 57, -52,
0, 108, -66,
0, 97, -81,
0, 97, -81,
0, 108, -66,
100, 57, -52,
102, 67, -31,
95, 68, 48,
123, 11, 26,
123, 11, 26,
95, 68, 48,
104, 27, 67,
-104, 27, 67,
-95, 68, 48,
-123, 11, 26,
-123, 11, 26,
-95, 68, 48,
-102, 67, -31,
-102, 67, -31,
0, 126, 0,
0, 108, -66,
0, 108, -66,
0, 126, 0,
102, 67, -31,
60, 100, 48,
0, 126, 0,
0, 98, 79,
68, -99, -38,
107, -28, -62,
27, -64, -106,
-68, -99, -38,
-79, -88, 43,
-27, -64, -106,
0, -87, -92,
68, -99, -38,
-68, -99, -38,
68, -99, -38,
0, -112, 59,
-68, -99, -38,
-23, -123, -21,
71, -103, -16,
-27, -64, -106,
-27, -64, -106,
-93, 38, -76,
-125, -9, -15,
-125, -9, -15,
-79, -97, 14,
-87, -77, 50,
-87, -77, 50,
71, -103, -16,
-23, -123, -21,
71, -103, -16,
-5, -54, -114,
73, 55, -87,
73, 55, -87,
-5, -54, -114,
-93, 38, -76,
-93, 38, -76,
-5, -54, -114,
-79, -97, 14,
-79, -97, 14,
-5, -54, -114,
71, -103, -16,
27, -64, -106,
-71, -103, -16,
23, -123, -21,
23, -123, -21,
-71, -103, -16,
87, -77, 50,
87, -77, 50,
79, -97, 14,
125, -9, -15,
125, -9, -15,
93, 38, -76,
27, -64, -106,
-73, 55, -87,
5, -54, -114,
-71, -103, -16,
-71, -103, -16,
5, -54, -114,
79, -97, 14,
79, -97, 14,
5, -54, -114,
93, 38, -76,
93, 38, -76,
5, -54, -114,
-73, 55, -87,
-25, -77, -97,
-64, -109, 0,
27, -64, -106,
27, -64, -106,
-64, -109, 0,
125, -9, -15,
125, -9, -15,
96, -81, -13,
100, 57, -52,
100, 57, -52,
-13, 70, -104,
-25, -77, -97,
-126, -14, -3,
-15, -52, -114,
-64, -109, 0,
-64, -109, 0,
-15, -52, -114,
96, -81, -13,
96, -81, -13,
-15, -52, -114,
-13, 70, -104,
-13, 70, -104,
-15, -52, -114,
-126, -14, -3,
-100, 57, -52,
-96, -81, -13,
-125, -9, -15,
-125, -9, -15,
64, -109, 0,
-27, -64, -106,
-27, -64, -106,
64, -109, 0,
25, -77, -97,
25, -77, -97,
13, 70, -104,
-100, 57, -52,
13, 70, -104,
15, -52, -114,
-96, -81, -13,
-96, -81, -13,
15, -52, -114,
64, -109, 0,
64, -109, 0,
15, -52, -114,
126, -14, -3,
126, -14, -3,
15, -52, -114,
13, 70, -104,
0, -72, -104,
43, -112, 39,
-25, -77, -97,
-25, -77, -97,
43, -112, 39,
100, 57, -52,
100, 57, -52,
-51, 58, -100,
0, 97, -81,
0, 97, -81,
-51, 58, -100,
0, -72, -104,
-106, -67, -14,
-7, -109, -63,
43, -112, 39,
43, -112, 39,
-7, -109, -63,
118, 13, -42,
118, 13, -42,
-7, -109, -63,
-51, 58, -100,
-51, 58, -100,
-7, -109, -63,
-106, -67, -14,
25, -77, -97,
-43, -112, 39,
0, -72, -104,
0, -72, -104,
51, 58, -100,
0, 97, -81,
0, 97, -81,
51, 58, -100,
-100, 57, -52,
-100, 57, -52,
-43, -112, 39,
25, -77, -97,
-43, -112, 39,
7, -109, -63,
106, -67, -14,
106, -67, -14,
7, -109, -63,
51, 58, -100,
51, 58, -100,
7, -109, -63,
-118, 13, -42,
-118, 13, -42,
7, -109, -63,
-43, -112, 39,
0, 21, 125,
0, 22, 125,
-104, 27, 67,
104, 27, 67,
0, 22, 125,
0, 21, 125,
79, -88, 43,
27, -64, -106,
23, -123, -21,
-79, -88, 43,
-23, -123, -21,
-27, -64, -106,
-79, -88, 43,
0, -125, -20,
-23, -123, -21,
79, -88, 43,
23, -123, -21,
0, -125, -20,
-79, -88, 43,
0, -112, 59,
0, -125, -20,
104, 27, 67,
85, -81, 46,
123, 11, 26,
-123, 11, 26,
-85, -81, 46,
-104, 27, 67,
87, -77, 50,
125, -9, -15,
123, 11, 26,
-123, 11, 26,
-125, -9, -15,
-87, -77, 50,
-57, -14, 112,
-57, -76, 83,
1, -19, 125,
57, -76, 83,
-1, -19, 125,
-5, -81, 97,
0, 98, 79,
0, 22, 125,
36, 102, 65,
0, 98, 79,
36, 102, 65,
95, 68, 48,
0, 98, 79,
95, 68, 48,
60, 100, 48,
-36, 102, 65,
0, 22, 125,
0, 98, 79,
0, 98, 79,
-60, 100, 48,
-95, 68, 48,
0, 98, 79,
0, 126, 0,
-60, 100, 48,
0, 21, 125,
16, -91, 86,
0, -110, 62,
0, -110, 62,
-61, -86, 68,
-85, -81, 46,
-85, -81, 46,
-79, 6, 98,
-104, 27, 67,
-104, 27, 67,
18, 0, 125,
0, 21, 125,
85, -81, 46,
61, -86, 68,
0, -110, 62,
0, -110, 62,
-16, -91, 86,
0, 21, 125,
0, 21, 125,
-18, 0, 125,
104, 27, 67,
104, 27, 67,
79, 6, 98,
85, -81, 46,
79, 6, 98,
61, -86, 68,
85, -81, 46,
-18, 0, 125,
79, 6, 98,
104, 27, 67,
-16, -91, 86,
-18, 0, 125,
0, 21, 125,
61, -86, 68,
-16, -91, 86,
0, -110, 62,
-104, 27, 67,
-79, 6, 98,
18, 0, 125,
-85, -81, 46,
-61, -86, 68,
-79, 6, 98,
0, -110, 62,
16, -91, 86,
-61, -86, 68,
0, 21, 125,
18, 0, 125,
16, -91, 86,
104, 27, 67,
36, 102, 65,
0, 22, 125,
0, 22, 125,
-36, 102, 65,
-104, 27, 67,
-100, 57, -52,
-118, 13, -42,
-43, -112, 39,
51, 58, -100,
-118, 13, -42,
-100, 57, -52,
0, -72, -104,
106, -67, -14,
51, 58, -100,
-43, -112, 39,
106, -67, -14,
0, -72, -104,
-51, 58, -100,
-106, -67, -14,
0, -72, -104,
100, 57, -52,
118, 13, -42,
-51, 58, -100,
43, -112, 39,
118, 13, -42,
100, 57, -52,
0, -72, -104,
-106, -67, -14,
43, -112, 39,
25, -77, -97,
126, -14, -3,
13, 70, -104,
64, -109, 0,
126, -14, -3,
25, -77, -97,
-125, -9, -15,
-96, -81, -13,
64, -109, 0,
-100, 57, -52,
13, 70, -104,
-96, -81, -13,
-13, 70, -104,
-126, -14, -3,
-25, -77, -97,
96, -81, -13,
-13, 70, -104,
100, 57, -52,
-64, -109, 0,
96, -81, -13,
125, -9, -15,
-25, -77, -97,
-126, -14, -3,
-64, -109, 0,
93, 38, -76,
-73, 55, -87,
27, -64, -106,
79, -97, 14,
93, 38, -76,
125, -9, -15,
-71, -103, -16,
79, -97, 14,
87, -77, 50,
27, -64, -106,
-73, 55, -87,
-71, -103, -16,
-87, -77, 50,
-79, -97, 14,
71, -103, -16,
-125, -9, -15,
-93, 38, -76,
-79, -97, 14,
-27, -64, -106,
73, 55, -87,
-93, 38, -76,
71, -103, -16,
73, 55, -87,
-27, -64, -106,
0, -112, 59,
-79, -88, 43,
-68, -99, -38,
0, 126, 0,
60, 100, 48,
102, 67, -31,
-102, 67, -31,
-60, 100, 48,
0, 126, 0,
-95, 68, 48,
-60, 100, 48,
-102, 67, -31,
-104, 27, 67,
-36, 102, 65,
-95, 68, 48,
95, 68, 48,
36, 102, 65,
104, 27, 67,
102, 67, -31,
60, 100, 48,
95, 68, 48,
0, 108, -66,
102, 67, -31,
100, 57, -52,
-100, 57, -52,
-102, 67, -31,
0, 108, -66,
-125, -9, -15,
-123, 11, 26,
-102, 67, -31,
0, -125, -18,
0, -110, 62,
-85, -81, 46,
85, -81, 46,
0, -110, 62,
0, -125, -18,
102, 67, -31,
123, 11, 26,
125, -9, -15,
15, -34, -121,
49, -57, -101,
-49, -57, -101,
49, -57, -101,
0, -87, -92,
-49, -57, -101,
15, -34, -121,
-49, -57, -101,
-15, -34, -121,
68, -99, -38,
49, -57, -101,
15, -34, -121,
-15, -34, -121,
-49, -57, -101,
-68, -99, -38,
-77, 18, -98,
-101, 20, -73,
-15, -34, -121,
0, 48, -117,
0, 49, -117,
-101, 20, -73,
101, 20, -73,
0, 49, -117,
0, 48, -117,
15, -34, -121,
101, 20, -73,
77, 18, -98,
-77, 18, -98,
-107, -28, -62,
-27, -64, -106,
0, 48, -117,
-77, 18, -98,
25, -77, -97,
-25, -77, -97,
77, 18, -98,
0, 48, -117,
27, -64, -106,
107, -28, -62,
77, 18, -98,
0, -125, -18,
0, -125, -20,
23, -123, -21,
0, -125, -18,
-87, -77, 50,
-23, -123, -21,
0, -112, 59,
79, -88, 43,
0, -125, -20,
-16, -91, 86,
57, -14, 112,
-18, 0, 125,
-18, 0, 125,
-5, -81, 97,
79, 6, 98,
79, 6, 98,
-5, -81, 97,
61, -86, 68,
61, -86, 68,
57, -14, 112,
-16, -91, 86,
18, 0, 125,
-57, -14, 112,
16, -91, 86,
16, -91, 86,
-57, -14, 112,
-61, -86, 68,
-61, -86, 68,
5, -81, 97,
-79, 6, 98,
-79, 6, 98,
5, -81, 97,
18, 0, 125,
5, -81, 97,
-57, -76, 83,
18, 0, 125,
-61, -86, 68,
1, -19, 125,
5, -81, 97,
-57, -14, 112,
1, -19, 125,
-61, -86, 68,
18, 0, 125,
-57, -76, 83,
-57, -14, 112,
61, -86, 68,
-1, -19, 125,
57, -14, 112,
-5, -81, 97,
-1, -19, 125,
61, -86, 68,
-18, 0, 125,
57, -76, 83,
-5, -81, 97,
57, -14, 112,
57, -76, 83,
-18, 0, 125,
57, -76, 83,
57, -14, 112,
-1, -19, 125,
-57, -76, 83,
5, -81, 97,
1, -19, 125,
68, -99, -38,
79, -88, 43,
0, -112, 59,
58, -54, 98,
-15, 43, 118,
-58, -54, 98,
92, 26, -82,
-92, 26, -82,
85, 57, -74,
15, 43, 118,
38, 103, 63,
-15, 43, 118,
-15, 43, 118,
-28, 123, 2,
-48, 111, -35,
-48, 111, -35,
28, 123, 2,
48, 111, -35,
48, 111, -35,
28, 123, 2,
15, 43, 118,
83, -29, 90,
92, 26, -82,
85, 57, -74,
-83, -29, 90,
83, -87, 40,
83, -29, 90,
-85, 57, -74,
-92, 26, -82,
-83, -29, 90,
-65, 46, -98,
-48, 111, -35,
65, 46, -98,
-92, 26, -82,
-83, -87, 40,
-83, -29, 90,
-83, -29, 90,
-83, -87, 40,
83, -87, 40,
83, -29, 90,
83, -87, 40,
92, 26, -82,
28, 123, 2,
-38, 103, 63,
15, 43, 118,
-48, 111, -35,
-28, 123, 2,
28, 123, 2,
-15, 43, 118,
38, 103, 63,
-28, 123, 2,
15, 43, 118,
-38, 103, 63,
38, 103, 63,
-92, 26, -82,
-85, 57, -74,
85, 57, -74,
38, 103, 63,
15, -34, -121,
-15, -34, -121,
-38, 103, 63,
101, 20, -73,
15, -34, -121,
28, 123, 2,
0, 49, -117,
101, 20, -73,
-28, 123, 2,
-101, 20, -73,
0, 49, -117,
38, 103, 63,
-15, -34, -121,
-101, 20, -73,
28, 123, 2,
-28, 123, 2,
0, 49, -117,
-28, 123, 2,
38, 103, 63,
-101, 20, -73,
58, -54, 98,
85, 57, -74,
65, 46, -98,
-58, -54, 98,
83, -29, 90,
58, -54, 98,
65, 46, -98,
-85, 57, -74,
-65, 46, -98,
-65, 46, -98,
-85, 57, -74,
-58, -54, 98,
-99, -50, 61,
93, -61, 59,
-50, 39, 109,
42, -34, -114,
-99, 34, -71,
91, 19, -85,
41, -118, 18,
42, -34, -114,
93, -61, 59,
-99, 34, -71,
-50, 39, 109,
-69, 106, 4,
-99, 34, -71,
-99, -50, 61,
-50, 39, 109,
42, -34, -114,
91, 19, -85,
93, -61, 59,
-99, 34, -71,
-69, 106, 4,
91, 19, -85,
-99, -50, 61,
41, -118, 18,
93, -61, 59,
-50, 39, 109,
-58, -54, 98,
-15, 43, 118,
93, -61, 59,
-65, 46, -98,
-58, -54, 98,
91, 19, -85,
-69, 106, 4,
-65, 46, -98,
-69, 106, 4,
-15, 43, 118,
-48, 111, -35,
50, 39, 109,
-93, -61, 59,
99, -50, 61,
-91, 19, -85,
99, 34, -71,
-42, -34, -114,
-93, -61, 59,
-42, -34, -114,
-41, -118, 18,
68, 106, 4,
50, 39, 109,
99, 34, -71,
50, 39, 109,
99, -50, 61,
99, 34, -71,
-93, -61, 59,
-91, 19, -85,
-42, -34, -114,
-91, 19, -85,
68, 106, 4,
99, 34, -71,
-93, -61, 59,
-41, -118, 18,
99, -50, 61,
50, 39, 109,
48, 111, -35,
15, 43, 118,
68, 106, 4,
65, 46, -98,
48, 111, -35,
-91, 19, -85,
-93, -61, 59,
65, 46, -98,
-93, -61, 59,
50, 39, 109,
58, -54, 98,
68, 106, 4,
48, 111, -35,
50, 39, 109,
-15, 43, 118,
-69, 106, 4,
-50, 39, 109,
109, -56, 28,
-77, -96, 31,
118, 25, 37,
97, -8, -81,
63, -26, -106,
-97, -8, -81,
-97, -8, -81,
118, 25, 37,
97, -8, -81,
-97, -8, -81,
109, -56, 28,
118, 25, 37,
-63, -26, -106,
-77, -96, 31,
-92, 26, -82,
-77, -96, 31,
83, -87, 40,
-83, -87, 40,
64, -105, 28,
92, 26, -82,
83, -87, 40,
63, -26, -106,
-92, 26, -82,
92, 26, -82,
-78, 9, 99,
73, 6, 103,
-91, 85, 18,
73, -103, 1,
-87, -39, -83,
88, -33, -84,
73, 6, 103,
73, -103, 1,
85, 94, 3,
-78, -99, -1,
-91, 85, 18,
-87, -39, -83,
-78, -99, -1,
-78, 9, 99,
-91, 85, 18,
73, -103, 1,
88, -33, -84,
85, 94, 3,
73, -103, 1,
-78, -99, -1,
-87, -39, -83,
73, 6, 103,
85, 94, 3,
-91, 85, 18,
-91, 85, 18,
85, 94, 3,
-77, -96, 31,
85, 94, 3,
88, -33, -84,
118, 25, 37,
88, -33, -84,
-63, -26, -106,
97, -8, -81,
-87, -39, -83,
-77, -96, 31,
-63, -26, -106,
88, 89, 18,
-73, 7, 103,
78, 9, 99,
-87, -35, -85,
87, -39, -83,
-73, -103, 1,
-60, 103, -41,
-73, -103, 1,
-73, 7, 103,
87, -39, -83,
88, 89, 18,
78, -99, -1,
88, 89, 18,
78, 9, 99,
78, -99, -1,
-60, 103, -41,
-87, -35, -85,
-73, -103, 1,
87, -39, -83,
78, -99, -1,
-73, -103, 1,
88, 89, 18,
-60, 103, -41,
-73, 7, 103,
88, 89, 18,
87, -39, -83,
64, -105, 28,
-87, -35, -85,
-97, -8, -81,
63, -26, -106,
-87, -35, -85,
109, -56, 28,
-97, -8, -81,
-60, 103, -41,
64, -105, 28,
109, -56, 28,
-42, -34, -114,
38, -79, -91,
-41, -118, 18,
-41, -118, 18,
95, -83, -10,
99, -50, 61,
99, -50, 61,
95, -83, -10,
99, 34, -71,
99, 34, -71,
94, -45, -71,
-42, -34, -114,
41, -118, 18,
-38, -116, -33,
42, -34, -114,
42, -34, -114,
-94, -45, -71,
-99, 34, -71,
-99, 34, -71,
-94, -45, -71,
-99, -50, 61,
-99, -50, 61,
-95, -83, -10,
41, -118, 18,
-76, -95, 36,
80, 3, 97,
38, -116, -33,
80, 3, 97,
94, -45, -71,
95, -83, -10,
81, 89, -39,
38, -79, -91,
94, -45, -71,
-75, -8, -101,
-76, -95, 36,
38, -79, -91,
-80, 3, 97,
-38, -116, -33,
-95, -83, -10,
75, -8, -101,
-94, -45, -71,
-38, -79, -91,
-81, 89, -39,
-80, 3, 97,
-94, -45, -71,
-38, -79, -91,
-38, -116, -33,
75, -8, -101,
-99, -38, 68,
71, -85, 59,
-57, -2, 113,
33, -25, -119,
-92, 52, -69,
81, 19, -95,
31, -121, 16,
33, -25, -119,
71, -85, 59,
-92, 52, -69,
-57, -2, 113,
-53, 108, -39,
-92, 52, -69,
-99, -38, 68,
-57, -2, 113,
33, -25, -119,
81, 19, -95,
71, -85, 59,
-92, 52, -69,
-53, 108, -39,
81, 19, -95,
-99, -38, 68,
31, -121, 16,
71, -85, 59,
33, -25, -119,
-72, -91, -50,
-92, 52, -69,
-92, 52, -69,
-72, -91, -50,
-99, -38, 68,
-99, -38, 68,
-72, -91, -50,
31, -121, 16,
31, -121, 16,
-72, -91, -50,
33, -25, -119,
81, 19, -95,
-81, 89, -39,
75, -8, -101,
-53, 108, -39,
-57, -2, 113,
-81, 89, -39,
-57, -2, 113,
71, -85, 59,
-80, 3, 97,
71, -85, 59,
81, 19, -95,
76, -95, 36,
73, -103, 1,
-26, -100, 72,
-78, -99, -1,
-78, -99, -1,
-26, -100, 72,
-78, 9, 99,
-78, 9, 99,
-33, -60, 106,
73, 6, 103,
73, 6, 103,
35, -56, 107,
73, -103, 1,
-73, 7, 103,
-35, -56, 107,
78, 9, 99,
78, 9, 99,
26, -100, 72,
78, -99, -1,
78, -99, -1,
26, -100, 72,
-73, -103, 1,
-73, -103, 1,
-35, -56, 107,
-73, 7, 103,
89, 9, 89,
70, 36, 99,
-89, 9, 89,
-80, 25, -94,
-117, -24, -41,
80, 25, -94,
-73, 38, 95,
-117, -24, -41,
-89, 9, 89,
116, -30, -39,
70, 36, 99,
80, 25, -94,
89, 9, 89,
50, 102, 55,
80, 25, -94,
80, 25, -94,
74, 35, -96,
-80, 25, -94,
-80, 25, -94,
-98, 69, 39,
-89, 9, 89,
-89, 9, 89,
-98, 69, 39,
89, 9, 89,
-98, 69, 39,
50, 102, 55,
89, 9, 89,
-80, 25, -94,
-89, 10, -89,
-98, 69, 39,
74, 35, -96,
-89, 10, -89,
-80, 25, -94,
50, 102, 55,
74, 35, -96,
80, 25, -94,
70, 36, 99,
89, 9, 89,
80, 25, -94,
-117, -24, -41,
-80, 25, -94,
-89, 9, 89,
-117, -24, -41,
116, -30, -39,
80, 25, -94,
70, 36, 99,
-73, 38, 95,
-89, 9, 89,
-117, -24, -41,
-35, -56, 107,
-27, -102, 70,
-73, 38, 95,
70, 36, 99,
-35, -56, 107,
70, 36, 99,
116, -30, -39,
33, -60, 106,
116, -30, -39,
-27, -102, 70,
26, -100, 72,
89, 9, 89,
-70, 36, 99,
-89, 9, 89,
-80, 25, -94,
117, -24, -41,
80, 25, -94,
89, 9, 89,
117, -24, -41,
73, 38, 95,
-80, 25, -94,
-70, 36, 99,
-116, -30, -39,
-80, 25, -94,
-50, 102, 55,
-89, 9, 89,
80, 25, -94,
-74, 35, -96,
-80, 25, -94,
89, 9, 89,
98, 69, 39,
80, 25, -94,
-89, 9, 89,
98, 69, 39,
89, 9, 89,
-89, 9, 89,
-50, 102, 55,
98, 69, 39,
98, 69, 39,
89, 10, -89,
80, 25, -94,
80, 25, -94,
89, 10, -89,
-74, 35, -96,
-80, 25, -94,
-74, 35, -96,
-50, 102, 55,
-80, 25, -94,
-89, 9, 89,
-70, 36, 99,
89, 9, 89,
80, 25, -94,
117, -24, -41,
-80, 25, -94,
-116, -30, -39,
117, -24, -41,
89, 9, 89,
73, 38, 95,
-70, 36, 99,
-70, 36, 99,
35, -56, 107,
-33, -60, 106,
73, 38, 95,
117, -24, -41,
35, -56, 107,
117, -24, -41,
-116, -30, -39,
27, -102, 70,
-116, -30, -39,
-33, -60, 106,
-26, -100, 72,
86, -73, -57,
-54, -80, -82,
89, 15, -88,
-65, 106, 21,
96, 82, 0,
-92, 79, -35,
99, -75, 23,
77, -68, 73,
-93, -83, -20,
77, -68, 73,
96, 82, 0,
62, 102, 41,
-93, -83, -20,
-100, -64, 43,
-92, 79, -35,
62, 102, 41,
-18, -7, 125,
77, -68, 73,
77, -68, 73,
-18, -7, 125,
-100, -64, 43,
-100, -64, 43,
-18, -7, 125,
-65, 106, 21,
-65, 106, 21,
-18, -7, 125,
62, 102, 41,
99, -75, 23,
86, -73, -57,
96, 82, 0,
-93, -83, -20,
-54, -80, -82,
99, -75, 23,
-92, 79, -35,
-57, 16, -111,
-93, -83, -20,
-57, 16, -111,
-54, -80, -82,
-93, -83, -20,
-54, -80, -82,
86, -73, -57,
99, -75, 23,
86, -73, -57,
89, 15, -88,
96, 82, 0,
-100, -64, 43,
-65, 106, 21,
-92, 79, -35,
77, -68, 73,
99, -75, 23,
96, 82, 0,
77, -68, 73,
-100, -64, 43,
-93, -83, -20,
-65, 106, 21,
62, 102, 41,
96, 82, 0,
-54, -80, -82,
-57, 16, -111,
89, 15, -88,
96, 82, 0,
89, 15, -88,
98, 69, 39,
89, 15, -88,
-57, 16, -111,
89, 10, -89,
-57, 16, -111,
-92, 79, -35,
-74, 35, -96,
-92, 79, -35,
96, 82, 0,
-50, 102, 55,
-89, 15, -88,
54, -80, -82,
-86, -73, -57,
92, 79, -35,
-96, 82, 0,
65, 106, 21,
93, -83, -20,
-77, -68, 73,
-99, -75, 23,
-62, 102, 41,
-96, 82, 0,
-77, -68, 73,
92, 79, -35,
100, -64, 43,
93, -83, -20,
-77, -68, 73,
18, -7, 125,
-62, 102, 41,
100, -64, 43,
18, -7, 125,
-77, -68, 73,
65, 106, 21,
18, -7, 125,
100, -64, 43,
-62, 102, 41,
18, -7, 125,
65, 106, 21,
-96, 82, 0,
-86, -73, -57,
-99, -75, 23,
-99, -75, 23,
54, -80, -82,
93, -83, -20,
93, -83, -20,
57, 16, -111,
92, 79, -35,
93, -83, -20,
54, -80, -82,
57, 16, -111,
-99, -75, 23,
-86, -73, -57,
54, -80, -82,
-96, 82, 0,
-89, 15, -88,
-86, -73, -57,
92, 79, -35,
65, 106, 21,
100, -64, 43,
-96, 82, 0,
-99, -75, 23,
-77, -68, 73,
93, -83, -20,
100, -64, 43,
-77, -68, 73,
-96, 82, 0,
-62, 102, 41,
65, 106, 21,
-89, 15, -88,
57, 16, -111,
54, -80, -82,
-96, 82, 0,
50, 102, 55,
-98, 69, 39,
92, 79, -35,
74, 35, -96,
50, 102, 55,
57, 16, -111,
-89, 10, -89,
74, 35, -96,
-89, 15, -88,
-98, 69, 39,
-89, 10, -89,
63, -26, -106,
87, -39, -83,
-87, -35, -85,
88, -33, -84,
-87, -39, -83,
-63, -26, -106,
81, 89, -39,
-81, 19, -95,
-75, -8, -101,
-75, -8, -101,
-71, -85, 59,
-76, -95, 36,
80, 3, 97,
53, 108, -39,
81, 89, -39,
57, -2, 113,
-71, -85, 59,
99, -38, 68,
-81, 19, -95,
92, 52, -69,
-33, -25, -119,
-71, -85, 59,
-33, -25, -119,
-31, -121, 16,
53, 108, -39,
57, -2, 113,
92, 52, -69,
57, -2, 113,
99, -38, 68,
92, 52, -69,
-71, -85, 59,
-81, 19, -95,
-33, -25, -119,
-81, 19, -95,
53, 108, -39,
92, 52, -69,
-71, -85, 59,
-31, -121, 16,
99, -38, 68,
92, 52, -69,
72, -91, -50,
-33, -25, -119,
99, -38, 68,
72, -91, -50,
92, 52, -69,
-31, -121, 16,
72, -91, -50,
99, -38, 68,
-33, -25, -119,
72, -91, -50,
-31, -121, 16,
-76, -95, 36,
-71, -85, 59,
80, 3, 97,
-71, -85, 59,
57, -2, 113,
80, 3, 97,
80, 3, 97,
57, -2, 113,
53, 108, -39,
-75, -8, -101,
-81, 19, -95,
-71, -85, 59,
81, 89, -39,
53, 108, -39,
-81, 19, -95,
-89, 15, -88,
-96, 82, 0,
-98, 69, 39,
57, 16, -111,
-89, 15, -88,
-89, 10, -89,
92, 79, -35,
57, 16, -111,
74, 35, -96,
-96, 82, 0,
92, 79, -35,
50, 102, 55,
96, 82, 0,
98, 69, 39,
-50, 102, 55,
-92, 79, -35,
-50, 102, 55,
-74, 35, -96,
-57, 16, -111,
-74, 35, -96,
89, 10, -89,
89, 15, -88,
89, 10, -89,
98, 69, 39,
-116, -30, -39,
-70, 36, 99,
-33, -60, 106,
-116, -30, -39,
-26, -100, 72,
27, -102, 70,
117, -24, -41,
27, -102, 70,
35, -56, 107,
-70, 36, 99,
73, 38, 95,
35, -56, 107,
116, -30, -39,
-117, -24, -41,
-27, -102, 70,
116, -30, -39,
26, -100, 72,
33, -60, 106,
70, 36, 99,
33, -60, 106,
-35, -56, 107,
-117, -24, -41,
-73, 38, 95,
-35, -56, 107,
-73, -103, 1,
-27, -102, 70,
-35, -56, 107,
26, -100, 72,
-27, -102, 70,
-73, -103, 1,
78, 9, 99,
33, -60, 106,
26, -100, 72,
-35, -56, 107,
33, -60, 106,
78, 9, 99,
35, -56, 107,
27, -102, 70,
73, -103, 1,
-33, -60, 106,
35, -56, 107,
73, 6, 103,
-26, -100, 72,
-33, -60, 106,
-78, 9, 99,
73, -103, 1,
27, -102, 70,
-26, -100, 72,
81, 19, -95,
75, -8, -101,
76, -95, 36,
71, -85, 59,
76, -95, 36,
-80, 3, 97,
-57, -2, 113,
-80, 3, 97,
-81, 89, -39,
81, 19, -95,
-53, 108, -39,
-81, 89, -39,
-38, -116, -33,
76, -95, 36,
75, -8, -101,
-80, 3, 97,
-95, -83, -10,
-94, -45, -71,
75, -8, -101,
-81, 89, -39,
-94, -45, -71,
-80, 3, 97,
76, -95, 36,
-38, -116, -33,
-76, -95, 36,
38, -116, -33,
38, -79, -91,
81, 89, -39,
-75, -8, -101,
38, -79, -91,
80, 3, 97,
81, 89, -39,
94, -45, -71,
80, 3, 97,
95, -83, -10,
38, -116, -33,
-95, -83, -10,
-38, -116, -33,
41, -118, 18,
-94, -45, -71,
-95, -83, -10,
-99, -50, 61,
42, -34, -114,
-38, -79, -91,
-94, -45, -71,
-38, -116, -33,
-38, -79, -91,
42, -34, -114,
94, -45, -71,
38, -79, -91,
-42, -34, -114,
95, -83, -10,
94, -45, -71,
99, 34, -71,
-41, -118, 18,
38, -116, -33,
95, -83, -10,
38, -79, -91,
38, -116, -33,
-41, -118, 18,
-60, 103, -41,
88, 89, 18,
64, -105, 28,
-87, -35, -85,
-60, 103, -41,
109, -56, 28,
87, -39, -83,
63, -26, -106,
64, -105, 28,
-87, -39, -83,
-91, 85, 18,
-77, -96, 31,
88, -33, -84,
97, -8, -81,
118, 25, 37,
85, 94, 3,
118, 25, 37,
-77, -96, 31,
63, -26, -106,
-63, -26, -106,
-92, 26, -82,
64, -105, 28,
63, -26, -106,
92, 26, -82,
-77, -96, 31,
64, -105, 28,
83, -87, 40,
-77, -96, 31,
-83, -87, 40,
-92, 26, -82,
97, -8, -81,
-63, -26, -106,
63, -26, -106,
109, -56, 28,
64, -105, 28,
-77, -96, 31,
50, 39, 109,
15, 43, 118,
58, -54, 98,
-93, -61, 59,
58, -54, 98,
65, 46, -98,
68, 106, 4,
-91, 19, -85,
65, 46, -98,
-69, 106, 4,
-48, 111, -35,
-65, 46, -98,
93, -61, 59,
91, 19, -85,
-65, 46, -98,
-50, 39, 109,
93, -61, 59,
-58, -54, 98,
-85, 57, -74,
-83, -29, 90,
-58, -54, 98,
65, 46, -98,
85, 57, -74,
-85, 57, -74,
-58, -54, 98,
-83, -29, 90,
83, -29, 90,
58, -54, 98,
83, -29, 90,
85, 57, -74,
-38, 103, 63,
28, 123, 2,
101, 20, -73,
38, 103, 63,
-38, 103, 63,
15, -34, -121,
-48, 111, -35,
48, 111, -35,
65, 46, -98,
58, -54, 98,
15, 43, 118,
-15, 43, 118,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:11 */
static s8 vtxnvgrp_frake_select_11[]={
-25, -123, -16,
-2, -125, -16,
-2, -126, -14,
-2, -126, -14,
21, -123, -19,
88, -77, 49,
22, -67, -105,
73, 14, -102,
-31, -79, -93,
-31, -79, -93,
-3, 44, -118,
-5, -75, -101,
-5, -75, -101,
-3, 44, -118,
20, -80, -95,
20, -80, -95,
-81, 17, -95,
-33, -66, -102,
-33, -66, -102,
-110, -27, -55,
-71, -99, -32,
22, -67, -105,
80, -88, 42,
65, -101, -38,
103, -31, -65,
12, -37, -120,
73, 14, -102,
73, 14, -102,
100, 17, -76,
-3, 44, -118,
-3, 44, -118,
-103, 19, -71,
-81, 17, -95,
-81, 17, -95,
-20, -36, -119,
-110, -27, -55,
-110, -27, -55,
-20, -36, -119,
-71, -99, -32,
-71, -99, -32,
-54, -61, -96,
-1, -93, -85,
-1, -93, -85,
45, -61, -101,
65, -101, -38,
65, -101, -38,
12, -37, -120,
103, -31, -65,
4, 100, 77,
-92, 71, 50,
-32, 105, 63,
98, 53, -58,
102, 64, -37,
124, -12, -20,
124, 9, 20,
86, -81, 44,
88, -77, 49,
88, -77, 49,
86, -81, 44,
-2, -126, -14,
-2, -126, -14,
-85, -78, 52,
-86, -74, 56,
-86, -74, 56,
-85, -78, 52,
-122, 14, 31,
-126, -7, -10,
-103, 68, -29,
-101, 57, -50,
-101, 57, -50,
-1, 106, -69,
-2, 94, -84,
-2, 94, -84,
-1, 106, -69,
98, 53, -58,
102, 64, -37,
97, 68, 43,
124, 9, 20,
124, 9, 20,
97, 68, 43,
106, 27, 62,
-100, 31, 70,
-92, 71, 50,
-122, 14, 31,
-122, 14, 31,
-92, 71, 50,
-103, 68, -29,
-103, 68, -29,
1, 126, -2,
-1, 106, -69,
-1, 106, -69,
1, 126, -2,
102, 64, -37,
63, 100, 43,
1, 126, -2,
4, 100, 77,
65, -101, -38,
103, -31, -65,
22, -67, -105,
-71, -99, -32,
-79, -86, 49,
-33, -66, -102,
-1, -93, -85,
65, -101, -38,
-71, -99, -32,
65, -101, -38,
0, -110, 62,
-71, -99, -32,
-25, -123, -16,
68, -105, -16,
-33, -66, -102,
-33, -66, -102,
-95, 37, -74,
-126, -7, -10,
-126, -7, -10,
-80, -96, 20,
-86, -74, 56,
-86, -74, 56,
68, -105, -16,
-25, -123, -16,
68, -105, -16,
-11, -57, -112,
70, 51, -92,
70, 51, -92,
-11, -57, -112,
-95, 37, -74,
-95, 37, -74,
-11, -57, -112,
-80, -96, 20,
-80, -96, 20,
-11, -57, -112,
68, -105, -16,
22, -67, -105,
-72, -103, -11,
21, -123, -19,
21, -123, -19,
-72, -103, -11,
88, -77, 49,
88, -77, 49,
78, -98, 13,
124, -12, -20,
124, -12, -20,
90, 34, -82,
22, -67, -105,
-76, 53, -86,
0, -57, -113,
-72, -103, -11,
-72, -103, -11,
0, -57, -113,
78, -98, 13,
78, -98, 13,
0, -57, -113,
90, 34, -82,
90, 34, -82,
0, -57, -113,
-76, 53, -86,
-31, -79, -93,
-65, -108, 4,
22, -67, -105,
22, -67, -105,
-65, -108, 4,
124, -12, -20,
124, -12, -20,
94, -83, -15,
98, 53, -58,
98, 53, -58,
-16, 66, -106,
-31, -79, -93,
-126, -12, 2,
-21, -55, -112,
-65, -108, 4,
-65, -108, 4,
-21, -55, -112,
94, -83, -15,
94, -83, -15,
-21, -55, -112,
-16, 66, -106,
-16, 66, -106,
-21, -55, -112,
-126, -12, 2,
-101, 57, -50,
-97, -80, -7,
-126, -7, -10,
-126, -7, -10,
62, -110, 0,
-33, -66, -102,
-33, -66, -102,
62, -110, 0,
20, -80, -95,
20, -80, -95,
10, 66, -107,
-101, 57, -50,
10, 66, -107,
10, -55, -113,
-97, -80, -7,
-97, -80, -7,
10, -55, -113,
62, -110, 0,
62, -110, 0,
10, -55, -113,
125, -16, -7,
125, -16, -7,
10, -55, -113,
10, 66, -107,
-5, -75, -101,
43, -112, 40,
-31, -79, -93,
-31, -79, -93,
43, -112, 40,
98, 53, -58,
98, 53, -58,
-54, 56, -99,
-2, 94, -84,
-2, 94, -84,
-54, 56, -99,
-5, -75, -101,
-108, -66, -8,
-12, -111, -59,
43, -112, 40,
43, -112, 40,
-12, -111, -59,
117, 10, -48,
117, 10, -48,
-12, -111, -59,
-54, 56, -99,
-54, 56, -99,
-12, -111, -59,
-108, -66, -8,
20, -80, -95,
-43, -110, 44,
-5, -75, -101,
-5, -75, -101,
48, 54, -103,
-2, 94, -84,
-2, 94, -84,
48, 54, -103,
-101, 57, -50,
-101, 57, -50,
-43, -110, 44,
20, -80, -95,
-43, -110, 44,
3, -111, -59,
104, -69, -17,
104, -69, -17,
3, -111, -59,
48, 54, -103,
48, 54, -103,
3, -111, -59,
-120, 13, -38,
-120, 13, -38,
3, -111, -59,
-43, -110, 44,
4, 25, 124,
5, 26, 124,
-100, 31, 70,
106, 27, 62,
5, 26, 124,
4, 25, 124,
80, -88, 42,
22, -67, -105,
21, -123, -19,
-79, -86, 49,
-25, -123, -16,
-33, -66, -102,
-79, -86, 49,
-2, -125, -16,
-25, -123, -16,
80, -88, 42,
21, -123, -19,
-2, -125, -16,
-79, -86, 49,
0, -110, 62,
-2, -125, -16,
106, 27, 62,
86, -81, 44,
124, 9, 20,
-122, 14, 31,
-85, -78, 52,
-100, 31, 70,
88, -77, 49,
124, -12, -20,
124, 9, 20,
-122, 14, 31,
-126, -7, -10,
-86, -74, 56,
-52, -9, 115,
-55, -72, 88,
6, -15, 125,
60, -74, 83,
2, -15, 126,
-2, -78, 100,
4, 100, 77,
5, 26, 124,
40, 103, 60,
4, 100, 77,
40, 103, 60,
97, 68, 43,
4, 100, 77,
97, 68, 43,
63, 100, 43,
-32, 105, 63,
5, 26, 124,
4, 100, 77,
4, 100, 77,
-57, 102, 48,
-92, 71, 50,
4, 100, 77,
1, 126, -2,
-57, 102, 48,
4, 25, 124,
18, -89, 88,
1, -108, 66,
1, -108, 66,
-60, -83, 73,
-85, -78, 52,
-85, -78, 52,
-75, 10, 101,
-100, 31, 70,
-100, 31, 70,
23, 3, 124,
4, 25, 124,
86, -81, 44,
63, -85, 69,
1, -108, 66,
1, -108, 66,
-14, -88, 89,
4, 25, 124,
4, 25, 124,
-13, 3, 126,
106, 27, 62,
106, 27, 62,
83, 8, 95,
86, -81, 44,
83, 8, 95,
63, -85, 69,
86, -81, 44,
-13, 3, 126,
83, 8, 95,
106, 27, 62,
-14, -88, 89,
-13, 3, 126,
4, 25, 124,
63, -85, 69,
-14, -88, 89,
1, -108, 66,
-100, 31, 70,
-75, 10, 101,
23, 3, 124,
-85, -78, 52,
-60, -83, 73,
-75, 10, 101,
1, -108, 66,
18, -89, 88,
-60, -83, 73,
4, 25, 124,
23, 3, 124,
18, -89, 88,
106, 27, 62,
40, 103, 60,
5, 26, 124,
5, 26, 124,
-32, 105, 63,
-100, 31, 70,
-101, 57, -50,
-120, 13, -38,
-43, -110, 44,
48, 54, -103,
-120, 13, -38,
-101, 57, -50,
-5, -75, -101,
104, -69, -17,
48, 54, -103,
-43, -110, 44,
104, -69, -17,
-5, -75, -101,
-54, 56, -99,
-108, -66, -8,
-5, -75, -101,
98, 53, -58,
117, 10, -48,
-54, 56, -99,
43, -112, 40,
117, 10, -48,
98, 53, -58,
-5, -75, -101,
-108, -66, -8,
43, -112, 40,
20, -80, -95,
125, -16, -7,
10, 66, -107,
62, -110, 0,
125, -16, -7,
20, -80, -95,
-126, -7, -10,
-97, -80, -7,
62, -110, 0,
-101, 57, -50,
10, 66, -107,
-97, -80, -7,
-16, 66, -106,
-126, -12, 2,
-31, -79, -93,
94, -83, -15,
-16, 66, -106,
98, 53, -58,
-65, -108, 4,
94, -83, -15,
124, -12, -20,
-31, -79, -93,
-126, -12, 2,
-65, -108, 4,
90, 34, -82,
-76, 53, -86,
22, -67, -105,
78, -98, 13,
90, 34, -82,
124, -12, -20,
-72, -103, -11,
78, -98, 13,
88, -77, 49,
22, -67, -105,
-76, 53, -86,
-72, -103, -11,
-86, -74, 56,
-80, -96, 20,
68, -105, -16,
-126, -7, -10,
-95, 37, -74,
-80, -96, 20,
-33, -66, -102,
70, 51, -92,
-95, 37, -74,
68, -105, -16,
70, 51, -92,
-33, -66, -102,
0, -110, 62,
-79, -86, 49,
-71, -99, -32,
1, 126, -2,
63, 100, 43,
102, 64, -37,
-103, 68, -29,
-57, 102, 48,
1, 126, -2,
-92, 71, 50,
-57, 102, 48,
-103, 68, -29,
-100, 31, 70,
-32, 105, 63,
-92, 71, 50,
97, 68, 43,
40, 103, 60,
106, 27, 62,
102, 64, -37,
63, 100, 43,
97, 68, 43,
-1, 106, -69,
102, 64, -37,
98, 53, -58,
-101, 57, -50,
-103, 68, -29,
-1, 106, -69,
-126, -7, -10,
-122, 14, 31,
-103, 68, -29,
-2, -126, -14,
1, -108, 66,
-85, -78, 52,
86, -81, 44,
1, -108, 66,
-2, -126, -14,
102, 64, -37,
124, 9, 20,
124, -12, -20,
12, -37, -120,
45, -61, -101,
-54, -61, -96,
45, -61, -101,
-1, -93, -85,
-54, -61, -96,
12, -37, -120,
-54, -61, -96,
-20, -36, -119,
65, -101, -38,
45, -61, -101,
12, -37, -120,
-20, -36, -119,
-54, -61, -96,
-71, -99, -32,
-81, 17, -95,
-103, 19, -71,
-20, -36, -119,
-3, 44, -118,
0, 46, -118,
-103, 19, -71,
100, 17, -76,
0, 46, -118,
-3, 44, -118,
12, -37, -120,
100, 17, -76,
73, 14, -102,
-81, 17, -95,
-110, -27, -55,
-33, -66, -102,
-3, 44, -118,
-81, 17, -95,
20, -80, -95,
-31, -79, -93,
73, 14, -102,
-3, 44, -118,
22, -67, -105,
103, -31, -65,
73, 14, -102,
-2, -126, -14,
-2, -125, -16,
21, -123, -19,
-2, -126, -14,
-86, -74, 56,
-25, -123, -16,
0, -110, 62,
80, -88, 42,
-2, -125, -16,
-14, -88, 89,
61, -11, 110,
-13, 3, 126,
-13, 3, 126,
-2, -78, 100,
83, 8, 95,
83, 8, 95,
-2, -78, 100,
63, -85, 69,
63, -85, 69,
61, -11, 110,
-14, -88, 89,
23, 3, 124,
-52, -9, 115,
18, -89, 88,
18, -89, 88,
-52, -9, 115,
-60, -83, 73,
-60, -83, 73,
8, -78, 99,
-75, 10, 101,
-75, 10, 101,
8, -78, 99,
23, 3, 124,
8, -78, 99,
-55, -72, 88,
23, 3, 124,
-60, -83, 73,
6, -15, 125,
8, -78, 99,
-52, -9, 115,
6, -15, 125,
-60, -83, 73,
23, 3, 124,
-55, -72, 88,
-52, -9, 115,
63, -85, 69,
2, -15, 126,
61, -11, 110,
-2, -78, 100,
2, -15, 126,
63, -85, 69,
-13, 3, 126,
60, -74, 83,
-2, -78, 100,
61, -11, 110,
60, -74, 83,
-13, 3, 126,
60, -74, 83,
61, -11, 110,
2, -15, 126,
-55, -72, 88,
8, -78, 99,
6, -15, 125,
65, -101, -38,
80, -88, 42,
0, -110, 62,
58, -53, 99,
-15, 44, 117,
-58, -53, 99,
93, 25, -82,
-93, 25, -82,
85, 56, -74,
15, 45, 117,
37, 104, 61,
-15, 44, 117,
-15, 44, 117,
-28, 123, 1,
-48, 111, -37,
-48, 111, -37,
28, 123, 1,
48, 111, -37,
48, 111, -37,
28, 123, 1,
15, 45, 117,
83, -28, 91,
93, 25, -82,
85, 56, -74,
-83, -28, 91,
83, -86, 41,
83, -28, 91,
-85, 56, -74,
-93, 25, -82,
-83, -28, 91,
-65, 45, -99,
-48, 111, -37,
65, 45, -99,
-93, 25, -82,
-83, -86, 41,
-83, -28, 91,
-83, -28, 91,
-83, -86, 41,
83, -86, 41,
83, -28, 91,
83, -86, 41,
93, 25, -82,
28, 123, 1,
-37, 104, 61,
15, 45, 117,
-48, 111, -37,
-28, 123, 1,
28, 123, 1,
-15, 44, 117,
37, 104, 61,
-28, 123, 1,
15, 45, 117,
-37, 104, 61,
37, 104, 61,
-93, 25, -82,
-85, 56, -74,
85, 56, -74,
37, 104, 61,
12, -37, -120,
-20, -36, -119,
-37, 104, 61,
100, 17, -76,
12, -37, -120,
28, 123, 1,
0, 46, -118,
100, 17, -76,
-28, 123, 1,
-103, 19, -71,
0, 46, -118,
37, 104, 61,
-20, -36, -119,
-103, 19, -71,
28, 123, 1,
-28, 123, 1,
0, 46, -118,
-28, 123, 1,
37, 104, 61,
-103, 19, -71,
58, -53, 99,
85, 56, -74,
65, 45, -99,
-58, -53, 99,
83, -28, 91,
58, -53, 99,
65, 45, -99,
-85, 56, -74,
-65, 45, -99,
-65, 45, -99,
-85, 56, -74,
-58, -53, 99,
-99, -49, 61,
93, -61, 60,
-50, 40, 109,
42, -35, -114,
-99, 33, -71,
91, 18, -86,
42, -118, 19,
42, -35, -114,
93, -61, 60,
-99, 33, -71,
-50, 40, 109,
-69, 106, 2,
-99, 33, -71,
-99, -49, 61,
-50, 40, 109,
42, -35, -114,
91, 18, -86,
93, -61, 60,
-99, 33, -71,
-69, 106, 2,
91, 18, -86,
-99, -49, 61,
42, -118, 19,
93, -61, 60,
-50, 40, 109,
-58, -53, 99,
-15, 44, 117,
93, -61, 60,
-65, 45, -99,
-58, -53, 99,
91, 18, -86,
-69, 106, 2,
-65, 45, -99,
-69, 106, 2,
-15, 44, 117,
-48, 111, -37,
50, 40, 109,
-93, -61, 60,
99, -49, 61,
-91, 18, -86,
99, 33, -71,
-42, -35, -114,
-93, -61, 60,
-42, -35, -114,
-42, -118, 19,
68, 106, 3,
50, 40, 109,
99, 33, -71,
50, 40, 109,
99, -49, 61,
99, 33, -71,
-93, -61, 60,
-91, 18, -86,
-42, -35, -114,
-91, 18, -86,
68, 106, 3,
99, 33, -71,
-93, -61, 60,
-42, -118, 19,
99, -49, 61,
50, 40, 109,
48, 111, -37,
15, 45, 117,
68, 106, 3,
65, 45, -99,
48, 111, -37,
-91, 18, -86,
-93, -61, 60,
65, 45, -99,
-93, -61, 60,
50, 40, 109,
58, -53, 99,
68, 106, 3,
48, 111, -37,
50, 40, 109,
-15, 44, 117,
-69, 106, 2,
-50, 40, 109,
110, -57, 26,
-75, -96, 32,
118, 24, 38,
97, -7, -81,
63, -26, -106,
-97, -8, -81,
-97, -8, -81,
118, 24, 38,
97, -7, -81,
-97, -8, -81,
110, -57, 26,
118, 24, 38,
-63, -26, -106,
-75, -96, 32,
-93, 25, -82,
-75, -96, 32,
83, -86, 41,
-83, -86, 41,
63, -106, 29,
93, 25, -82,
83, -86, 41,
63, -26, -106,
-93, 25, -82,
93, 25, -82,
-78, 7, 99,
73, 4, 103,
-91, 85, 19,
73, -103, 0,
-87, -38, -83,
88, -32, -84,
73, 4, 103,
73, -103, 0,
85, 94, 5,
-78, -99, -2,
-91, 85, 19,
-87, -38, -83,
-78, -99, -2,
-78, 7, 99,
-91, 85, 19,
73, -103, 0,
88, -32, -84,
85, 94, 5,
73, -103, 0,
-78, -99, -2,
-87, -38, -83,
73, 4, 103,
85, 94, 5,
-91, 85, 19,
-91, 85, 19,
85, 94, 5,
-75, -96, 32,
85, 94, 5,
88, -32, -84,
118, 24, 38,
88, -32, -84,
-63, -26, -106,
97, -7, -81,
-87, -38, -83,
-75, -96, 32,
-63, -26, -106,
88, 89, 19,
-73, 5, 103,
78, 7, 99,
-87, -33, -85,
87, -38, -83,
-73, -103, 0,
-61, 103, -39,
-73, -103, 0,
-73, 5, 103,
87, -38, -83,
88, 89, 19,
78, -99, -2,
88, 89, 19,
78, 7, 99,
78, -99, -2,
-61, 103, -39,
-87, -33, -85,
-73, -103, 0,
87, -38, -83,
78, -99, -2,
-73, -103, 0,
88, 89, 19,
-61, 103, -39,
-73, 5, 103,
88, 89, 19,
87, -38, -83,
63, -106, 29,
-87, -33, -85,
-97, -8, -81,
63, -26, -106,
-87, -33, -85,
110, -57, 26,
-97, -8, -81,
-61, 103, -39,
63, -106, 29,
110, -57, 26,
-42, -35, -114,
38, -80, -90,
-42, -118, 19,
-42, -118, 19,
95, -83, -9,
99, -49, 61,
99, -49, 61,
95, -83, -9,
99, 33, -71,
99, 33, -71,
94, -46, -71,
-42, -35, -114,
42, -118, 19,
-38, -116, -32,
42, -35, -114,
42, -35, -114,
-94, -46, -71,
-99, 33, -71,
-99, 33, -71,
-94, -46, -71,
-99, -49, 61,
-99, -49, 61,
-95, -83, -9,
42, -118, 19,
-75, -94, 37,
80, 4, 97,
38, -116, -32,
80, 4, 97,
94, -46, -71,
95, -83, -9,
81, 88, -40,
38, -80, -90,
94, -46, -71,
-75, -10, -101,
-75, -94, 37,
38, -80, -90,
-80, 4, 97,
-38, -116, -32,
-95, -83, -9,
75, -10, -101,
-94, -46, -71,
-38, -80, -90,
-81, 88, -40,
-80, 4, 97,
-94, -46, -71,
-38, -80, -90,
-38, -116, -32,
75, -10, -101,
-99, -38, 68,
71, -85, 60,
-57, -1, 113,
33, -26, -119,
-92, 51, -69,
81, 18, -95,
31, -121, 18,
33, -26, -119,
71, -85, 60,
-92, 51, -69,
-57, -1, 113,
-53, 107, -40,
-92, 51, -69,
-99, -38, 68,
-57, -1, 113,
33, -26, -119,
81, 18, -95,
71, -85, 60,
-92, 51, -69,
-53, 107, -40,
81, 18, -95,
-99, -38, 68,
31, -121, 18,
71, -85, 60,
33, -26, -119,
-72, -91, -49,
-92, 51, -69,
-92, 51, -69,
-72, -91, -49,
-99, -38, 68,
-99, -38, 68,
-72, -91, -49,
31, -121, 18,
31, -121, 18,
-72, -91, -49,
33, -26, -119,
81, 18, -95,
-81, 88, -40,
75, -10, -101,
-53, 107, -40,
-57, -1, 113,
-81, 88, -40,
-57, -1, 113,
71, -85, 60,
-80, 4, 97,
71, -85, 60,
81, 18, -95,
75, -94, 37,
73, -103, 0,
-26, -102, 70,
-78, -99, -2,
-78, -99, -2,
-26, -102, 70,
-78, 7, 99,
-78, 7, 99,
-33, -62, 105,
73, 4, 103,
73, 4, 103,
35, -58, 106,
73, -103, 0,
-73, 5, 103,
-35, -58, 106,
78, 7, 99,
78, 7, 99,
26, -102, 70,
78, -99, -2,
78, -99, -2,
26, -102, 70,
-73, -103, 0,
-73, -103, 0,
-35, -58, 106,
-73, 5, 103,
89, 13, 88,
71, 37, 98,
-89, 13, 88,
-82, 13, -95,
-113, -31, -46,
82, 13, -95,
-74, 39, 94,
-113, -31, -46,
-89, 13, 88,
112, -37, -44,
71, 37, 98,
82, 13, -95,
89, 13, 88,
50, 104, 51,
82, 13, -95,
82, 13, -95,
74, 31, -98,
-82, 13, -95,
-82, 13, -95,
-98, 71, 36,
-89, 13, 88,
-89, 13, 88,
-98, 71, 36,
89, 13, 88,
-98, 71, 36,
50, 104, 51,
89, 13, 88,
-82, 13, -95,
-89, 6, -89,
-98, 71, 36,
74, 31, -98,
-89, 6, -89,
-82, 13, -95,
50, 104, 51,
74, 31, -98,
82, 13, -95,
71, 37, 98,
89, 13, 88,
82, 13, -95,
-113, -31, -46,
-82, 13, -95,
-89, 13, 88,
-113, -31, -46,
112, -37, -44,
82, 13, -95,
71, 37, 98,
-74, 39, 94,
-89, 13, 88,
-113, -31, -46,
-35, -58, 106,
-27, -103, 68,
-74, 39, 94,
71, 37, 98,
-35, -58, 106,
71, 37, 98,
112, -37, -44,
33, -62, 105,
112, -37, -44,
-27, -103, 68,
26, -102, 70,
89, 13, 88,
-71, 37, 98,
-89, 13, 88,
-82, 13, -95,
113, -31, -46,
82, 13, -95,
89, 13, 88,
113, -31, -46,
74, 39, 94,
-82, 13, -95,
-71, 37, 98,
-112, -37, -44,
-82, 13, -95,
-50, 104, 51,
-89, 13, 88,
82, 13, -95,
-74, 31, -98,
-82, 13, -95,
89, 13, 88,
98, 71, 36,
82, 13, -95,
-89, 13, 88,
98, 71, 36,
89, 13, 88,
-89, 13, 88,
-50, 104, 51,
98, 71, 36,
98, 71, 36,
89, 6, -89,
82, 13, -95,
82, 13, -95,
89, 6, -89,
-74, 31, -98,
-82, 13, -95,
-74, 31, -98,
-50, 104, 51,
-82, 13, -95,
-89, 13, 88,
-71, 37, 98,
89, 13, 88,
82, 13, -95,
113, -31, -46,
-82, 13, -95,
-112, -37, -44,
113, -31, -46,
89, 13, 88,
74, 39, 94,
-71, 37, 98,
-71, 37, 98,
35, -58, 106,
-33, -62, 105,
74, 39, 94,
113, -31, -46,
35, -58, 106,
113, -31, -46,
-112, -37, -44,
27, -103, 68,
-112, -37, -44,
-33, -62, 105,
-26, -102, 70,
86, -75, -54,
-53, -84, -78,
89, 11, -89,
-65, 107, 17,
96, 82, -2,
-92, 78, -39,
99, -74, 26,
77, -65, 76,
-93, -84, -17,
77, -65, 76,
96, 82, -2,
62, 104, 37,
-93, -84, -17,
-100, -61, 46,
-92, 78, -39,
62, 104, 37,
-18, -2, 125,
77, -65, 76,
77, -65, 76,
-18, -2, 125,
-100, -61, 46,
-100, -61, 46,
-18, -2, 125,
-65, 107, 17,
-65, 107, 17,
-18, -2, 125,
62, 104, 37,
99, -74, 26,
86, -75, -54,
96, 82, -2,
-93, -84, -17,
-53, -84, -78,
99, -74, 26,
-92, 78, -39,
-57, 11, -112,
-93, -84, -17,
-57, 11, -112,
-53, -84, -78,
-93, -84, -17,
-53, -84, -78,
86, -75, -54,
99, -74, 26,
86, -75, -54,
89, 11, -89,
96, 82, -2,
-100, -61, 46,
-65, 107, 17,
-92, 78, -39,
77, -65, 76,
99, -74, 26,
96, 82, -2,
77, -65, 76,
-100, -61, 46,
-93, -84, -17,
-65, 107, 17,
62, 104, 37,
96, 82, -2,
-53, -84, -78,
-57, 11, -112,
89, 11, -89,
96, 82, -2,
89, 11, -89,
98, 71, 36,
89, 11, -89,
-57, 11, -112,
89, 6, -89,
-57, 11, -112,
-92, 78, -39,
-74, 31, -98,
-92, 78, -39,
96, 82, -2,
-50, 104, 51,
-89, 11, -89,
53, -84, -78,
-86, -75, -54,
92, 78, -39,
-96, 82, -2,
65, 107, 17,
93, -84, -17,
-77, -65, 76,
-99, -74, 26,
-62, 104, 37,
-96, 82, -2,
-77, -65, 76,
92, 78, -39,
100, -61, 46,
93, -84, -17,
-77, -65, 76,
18, -2, 125,
-62, 104, 37,
100, -61, 46,
18, -2, 125,
-77, -65, 76,
65, 107, 17,
18, -2, 125,
100, -61, 46,
-62, 104, 37,
18, -2, 125,
65, 107, 17,
-96, 82, -2,
-86, -75, -54,
-99, -74, 26,
-99, -74, 26,
53, -84, -78,
93, -84, -17,
93, -84, -17,
57, 11, -112,
92, 78, -39,
93, -84, -17,
53, -84, -78,
57, 11, -112,
-99, -74, 26,
-86, -75, -54,
53, -84, -78,
-96, 82, -2,
-89, 11, -89,
-86, -75, -54,
92, 78, -39,
65, 107, 17,
100, -61, 46,
-96, 82, -2,
-99, -74, 26,
-77, -65, 76,
93, -84, -17,
100, -61, 46,
-77, -65, 76,
-96, 82, -2,
-62, 104, 37,
65, 107, 17,
-89, 11, -89,
57, 11, -112,
53, -84, -78,
-96, 82, -2,
50, 104, 51,
-98, 71, 36,
92, 78, -39,
74, 31, -98,
50, 104, 51,
57, 11, -112,
-89, 6, -89,
74, 31, -98,
-89, 11, -89,
-98, 71, 36,
-89, 6, -89,
63, -26, -106,
87, -38, -83,
-87, -33, -85,
88, -32, -84,
-87, -38, -83,
-63, -26, -106,
81, 88, -40,
-81, 18, -95,
-75, -10, -101,
-75, -10, -101,
-71, -85, 60,
-75, -94, 37,
80, 4, 97,
53, 107, -40,
81, 88, -40,
57, -1, 113,
-71, -85, 60,
99, -38, 68,
-81, 18, -95,
92, 51, -69,
-33, -26, -119,
-71, -85, 60,
-33, -26, -119,
-31, -121, 18,
53, 107, -40,
57, -1, 113,
92, 51, -69,
57, -1, 113,
99, -38, 68,
92, 51, -69,
-71, -85, 60,
-81, 18, -95,
-33, -26, -119,
-81, 18, -95,
53, 107, -40,
92, 51, -69,
-71, -85, 60,
-31, -121, 18,
99, -38, 68,
92, 51, -69,
72, -91, -49,
-33, -26, -119,
99, -38, 68,
72, -91, -49,
92, 51, -69,
-31, -121, 18,
72, -91, -49,
99, -38, 68,
-33, -26, -119,
72, -91, -49,
-31, -121, 18,
-75, -94, 37,
-71, -85, 60,
80, 4, 97,
-71, -85, 60,
57, -1, 113,
80, 4, 97,
80, 4, 97,
57, -1, 113,
53, 107, -40,
-75, -10, -101,
-81, 18, -95,
-71, -85, 60,
81, 88, -40,
53, 107, -40,
-81, 18, -95,
-89, 11, -89,
-96, 82, -2,
-98, 71, 36,
57, 11, -112,
-89, 11, -89,
-89, 6, -89,
92, 78, -39,
57, 11, -112,
74, 31, -98,
-96, 82, -2,
92, 78, -39,
50, 104, 51,
96, 82, -2,
98, 71, 36,
-50, 104, 51,
-92, 78, -39,
-50, 104, 51,
-74, 31, -98,
-57, 11, -112,
-74, 31, -98,
89, 6, -89,
89, 11, -89,
89, 6, -89,
98, 71, 36,
-112, -37, -44,
-71, 37, 98,
-33, -62, 105,
-112, -37, -44,
-26, -102, 70,
27, -103, 68,
113, -31, -46,
27, -103, 68,
35, -58, 106,
-71, 37, 98,
74, 39, 94,
35, -58, 106,
112, -37, -44,
-113, -31, -46,
-27, -103, 68,
112, -37, -44,
26, -102, 70,
33, -62, 105,
71, 37, 98,
33, -62, 105,
-35, -58, 106,
-113, -31, -46,
-74, 39, 94,
-35, -58, 106,
-73, -103, 0,
-27, -103, 68,
-35, -58, 106,
26, -102, 70,
-27, -103, 68,
-73, -103, 0,
78, 7, 99,
33, -62, 105,
26, -102, 70,
-35, -58, 106,
33, -62, 105,
78, 7, 99,
35, -58, 106,
27, -103, 68,
73, -103, 0,
-33, -62, 105,
35, -58, 106,
73, 4, 103,
-26, -102, 70,
-33, -62, 105,
-78, 7, 99,
73, -103, 0,
27, -103, 68,
-26, -102, 70,
81, 18, -95,
75, -10, -101,
75, -94, 37,
71, -85, 60,
75, -94, 37,
-80, 4, 97,
-57, -1, 113,
-80, 4, 97,
-81, 88, -40,
81, 18, -95,
-53, 107, -40,
-81, 88, -40,
-38, -116, -32,
75, -94, 37,
75, -10, -101,
-80, 4, 97,
-95, -83, -9,
-94, -46, -71,
75, -10, -101,
-81, 88, -40,
-94, -46, -71,
-80, 4, 97,
75, -94, 37,
-38, -116, -32,
-75, -94, 37,
38, -116, -32,
38, -80, -90,
81, 88, -40,
-75, -10, -101,
38, -80, -90,
80, 4, 97,
81, 88, -40,
94, -46, -71,
80, 4, 97,
95, -83, -9,
38, -116, -32,
-95, -83, -9,
-38, -116, -32,
42, -118, 19,
-94, -46, -71,
-95, -83, -9,
-99, -49, 61,
42, -35, -114,
-38, -80, -90,
-94, -46, -71,
-38, -116, -32,
-38, -80, -90,
42, -35, -114,
94, -46, -71,
38, -80, -90,
-42, -35, -114,
95, -83, -9,
94, -46, -71,
99, 33, -71,
-42, -118, 19,
38, -116, -32,
95, -83, -9,
38, -80, -90,
38, -116, -32,
-42, -118, 19,
-61, 103, -39,
88, 89, 19,
63, -106, 29,
-87, -33, -85,
-61, 103, -39,
110, -57, 26,
87, -38, -83,
63, -26, -106,
63, -106, 29,
-87, -38, -83,
-91, 85, 19,
-75, -96, 32,
88, -32, -84,
97, -7, -81,
118, 24, 38,
85, 94, 5,
118, 24, 38,
-75, -96, 32,
63, -26, -106,
-63, -26, -106,
-93, 25, -82,
63, -106, 29,
63, -26, -106,
93, 25, -82,
-75, -96, 32,
63, -106, 29,
83, -86, 41,
-75, -96, 32,
-83, -86, 41,
-93, 25, -82,
97, -7, -81,
-63, -26, -106,
63, -26, -106,
110, -57, 26,
63, -106, 29,
-75, -96, 32,
50, 40, 109,
15, 45, 117,
58, -53, 99,
-93, -61, 60,
58, -53, 99,
65, 45, -99,
68, 106, 3,
-91, 18, -86,
65, 45, -99,
-69, 106, 2,
-48, 111, -37,
-65, 45, -99,
93, -61, 60,
91, 18, -86,
-65, 45, -99,
-50, 40, 109,
93, -61, 60,
-58, -53, 99,
-85, 56, -74,
-83, -28, 91,
-58, -53, 99,
65, 45, -99,
85, 56, -74,
-85, 56, -74,
-58, -53, 99,
-83, -28, 91,
83, -28, 91,
58, -53, 99,
83, -28, 91,
85, 56, -74,
-37, 104, 61,
28, 123, 1,
100, 17, -76,
37, 104, 61,
-37, 104, 61,
12, -37, -120,
-48, 111, -37,
48, 111, -37,
65, 45, -99,
58, -53, 99,
15, 45, 117,
-15, 44, 117,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:12 */
static s8 vtxnvgrp_frake_select_12[]={
-28, -123, -12,
-4, -126, -12,
-4, -126, -10,
-4, -126, -10,
19, -124, -16,
88, -77, 47,
17, -70, -104,
69, 9, -106,
-36, -81, -89,
-36, -81, -89,
-7, 41, -119,
-10, -78, -99,
-10, -78, -99,
-7, 41, -119,
15, -83, -94,
15, -83, -94,
-85, 17, -92,
-39, -68, -99,
-39, -68, -99,
-113, -26, -49,
-74, -99, -25,
17, -70, -104,
80, -88, 41,
62, -103, -38,
100, -35, -69,
9, -41, -119,
69, 9, -106,
69, 9, -106,
98, 14, -78,
-7, 41, -119,
-7, 41, -119,
-104, 19, -69,
-85, 17, -92,
-85, 17, -92,
-24, -38, -118,
-113, -26, -49,
-113, -26, -49,
-24, -38, -118,
-74, -99, -25,
-74, -99, -25,
-59, -64, -91,
-3, -99, -78,
-3, -99, -78,
42, -65, -100,
62, -103, -38,
62, -103, -38,
9, -41, -119,
100, -35, -69,
8, 102, 74,
-88, 74, 52,
-28, 107, 61,
97, 49, -64,
101, 61, -44,
123, -15, -25,
125, 8, 15,
87, -81, 43,
88, -77, 47,
88, -77, 47,
87, -81, 43,
-4, -126, -10,
-4, -126, -10,
-84, -75, 58,
-84, -71, 62,
-84, -71, 62,
-84, -75, 58,
-120, 17, 36,
-126, -5, -4,
-103, 68, -26,
-102, 57, -47,
-102, 57, -47,
-2, 104, -72,
-4, 91, -87,
-4, 91, -87,
-2, 104, -72,
97, 49, -64,
101, 61, -44,
100, 68, 37,
125, 8, 15,
125, 8, 15,
100, 68, 37,
109, 27, 58,
-96, 35, 74,
-88, 74, 52,
-120, 17, 36,
-120, 17, 36,
-88, 74, 52,
-103, 68, -26,
-103, 68, -26,
3, 126, -6,
-2, 104, -72,
-2, 104, -72,
3, 126, -6,
101, 61, -44,
67, 101, 37,
3, 126, -6,
8, 102, 74,
62, -103, -38,
100, -35, -69,
17, -70, -104,
-74, -99, -25,
-78, -83, 55,
-39, -68, -99,
-3, -99, -78,
62, -103, -38,
-74, -99, -25,
62, -103, -38,
2, -108, 66,
-74, -99, -25,
-28, -123, -12,
65, -107, -16,
-39, -68, -99,
-39, -68, -99,
-98, 36, -71,
-126, -5, -4,
-126, -5, -4,
-80, -94, 26,
-84, -71, 62,
-84, -71, 62,
65, -107, -16,
-28, -123, -12,
65, -107, -16,
-17, -60, -110,
67, 46, -97,
67, 46, -97,
-17, -60, -110,
-98, 36, -71,
-98, 36, -71,
-17, -60, -110,
-80, -94, 26,
-80, -94, 26,
-17, -60, -110,
65, -107, -16,
17, -70, -104,
-74, -102, -5,
19, -124, -16,
19, -124, -16,
-74, -102, -5,
88, -77, 47,
88, -77, 47,
77, -99, 13,
123, -15, -25,
123, -15, -25,
87, 29, -87,
17, -70, -104,
-78, 51, -85,
-5, -60, -111,
-74, -102, -5,
-74, -102, -5,
-5, -60, -111,
77, -99, 13,
77, -99, 13,
-5, -60, -111,
87, 29, -87,
87, 29, -87,
-5, -60, -111,
-78, 51, -85,
-36, -81, -89,
-66, -107, 10,
17, -70, -104,
17, -70, -104,
-66, -107, 10,
123, -15, -25,
123, -15, -25,
92, -85, -17,
97, 49, -64,
97, 49, -64,
-20, 63, -108,
-36, -81, -89,
-126, -9, 8,
-27, -58, -109,
-66, -107, 10,
-66, -107, 10,
-27, -58, -109,
92, -85, -17,
92, -85, -17,
-27, -58, -109,
-20, 63, -108,
-20, 63, -108,
-27, -58, -109,
-126, -9, 8,
-102, 57, -47,
-99, -79, -1,
-126, -5, -4,
-126, -5, -4,
60, -111, 0,
-39, -68, -99,
-39, -68, -99,
60, -111, 0,
15, -83, -94,
15, -83, -94,
6, 62, -110,
-102, 57, -47,
6, 62, -110,
4, -59, -112,
-99, -79, -1,
-99, -79, -1,
4, -59, -112,
60, -111, 0,
60, -111, 0,
4, -59, -112,
124, -19, -13,
124, -19, -13,
4, -59, -112,
6, 62, -110,
-10, -78, -99,
43, -111, 42,
-36, -81, -89,
-36, -81, -89,
43, -111, 42,
97, 49, -64,
97, 49, -64,
-57, 54, -99,
-4, 91, -87,
-4, 91, -87,
-57, 54, -99,
-10, -78, -99,
-109, -64, -2,
-16, -113, -54,
43, -111, 42,
43, -111, 42,
-16, -113, -54,
114, 6, -53,
114, 6, -53,
-16, -113, -54,
-57, 54, -99,
-57, 54, -99,
-16, -113, -54,
-109, -64, -2,
15, -83, -94,
-43, -108, 49,
-10, -78, -99,
-10, -78, -99,
44, 50, -107,
-4, 91, -87,
-4, 91, -87,
44, 50, -107,
-102, 57, -47,
-102, 57, -47,
-43, -108, 49,
15, -83, -94,
-43, -108, 49,
0, -113, -56,
102, -72, -20,
102, -72, -20,
0, -113, -56,
44, 50, -107,
44, 50, -107,
0, -113, -56,
-121, 14, -33,
-121, 14, -33,
0, -113, -56,
-43, -108, 49,
9, 29, 123,
10, 29, 122,
-96, 35, 74,
109, 27, 58,
10, 29, 122,
9, 29, 123,
80, -88, 41,
17, -70, -104,
19, -124, -16,
-78, -83, 55,
-28, -123, -12,
-39, -68, -99,
-78, -83, 55,
-4, -126, -12,
-28, -123, -12,
80, -88, 41,
19, -124, -16,
-4, -126, -12,
-78, -83, 55,
2, -108, 66,
-4, -126, -12,
109, 27, 58,
87, -81, 43,
125, 8, 15,
-120, 17, 36,
-84, -75, 58,
-96, 35, 74,
88, -77, 47,
123, -15, -25,
125, 8, 15,
-120, 17, 36,
-126, -5, -4,
-84, -71, 62,
-48, -4, 117,
-52, -68, 92,
11, -11, 125,
62, -72, 83,
7, -11, 126,
0, -74, 102,
8, 102, 74,
10, 29, 122,
44, 105, 55,
8, 102, 74,
44, 105, 55,
100, 68, 37,
8, 102, 74,
100, 68, 37,
67, 101, 37,
-28, 107, 61,
10, 29, 122,
8, 102, 74,
8, 102, 74,
-53, 105, 47,
-88, 74, 52,
8, 102, 74,
3, 126, -6,
-53, 105, 47,
9, 29, 123,
20, -86, 90,
3, -106, 69,
3, -106, 69,
-58, -80, 78,
-84, -75, 58,
-84, -75, 58,
-70, 14, 104,
-96, 35, 74,
-96, 35, 74,
28, 6, 123,
9, 29, 123,
87, -81, 43,
64, -84, 69,
3, -106, 69,
3, -106, 69,
-11, -85, 92,
9, 29, 123,
9, 29, 123,
-7, 7, 126,
109, 27, 58,
109, 27, 58,
87, 9, 91,
87, -81, 43,
87, 9, 91,
64, -84, 69,
87, -81, 43,
-7, 7, 126,
87, 9, 91,
109, 27, 58,
-11, -85, 92,
-7, 7, 126,
9, 29, 123,
64, -84, 69,
-11, -85, 92,
3, -106, 69,
-96, 35, 74,
-70, 14, 104,
28, 6, 123,
-84, -75, 58,
-58, -80, 78,
-70, 14, 104,
3, -106, 69,
20, -86, 90,
-58, -80, 78,
9, 29, 123,
28, 6, 123,
20, -86, 90,
109, 27, 58,
44, 105, 55,
10, 29, 122,
10, 29, 122,
-28, 107, 61,
-96, 35, 74,
-102, 57, -47,
-121, 14, -33,
-43, -108, 49,
44, 50, -107,
-121, 14, -33,
-102, 57, -47,
-10, -78, -99,
102, -72, -20,
44, 50, -107,
-43, -108, 49,
102, -72, -20,
-10, -78, -99,
-57, 54, -99,
-109, -64, -2,
-10, -78, -99,
97, 49, -64,
114, 6, -53,
-57, 54, -99,
43, -111, 42,
114, 6, -53,
97, 49, -64,
-10, -78, -99,
-109, -64, -2,
43, -111, 42,
15, -83, -94,
124, -19, -13,
6, 62, -110,
60, -111, 0,
124, -19, -13,
15, -83, -94,
-126, -5, -4,
-99, -79, -1,
60, -111, 0,
-102, 57, -47,
6, 62, -110,
-99, -79, -1,
-20, 63, -108,
-126, -9, 8,
-36, -81, -89,
92, -85, -17,
-20, 63, -108,
97, 49, -64,
-66, -107, 10,
92, -85, -17,
123, -15, -25,
-36, -81, -89,
-126, -9, 8,
-66, -107, 10,
87, 29, -87,
-78, 51, -85,
17, -70, -104,
77, -99, 13,
87, 29, -87,
123, -15, -25,
-74, -102, -5,
77, -99, 13,
88, -77, 47,
17, -70, -104,
-78, 51, -85,
-74, -102, -5,
-84, -71, 62,
-80, -94, 26,
65, -107, -16,
-126, -5, -4,
-98, 36, -71,
-80, -94, 26,
-39, -68, -99,
67, 46, -97,
-98, 36, -71,
65, -107, -16,
67, 46, -97,
-39, -68, -99,
2, -108, 66,
-78, -83, 55,
-74, -99, -25,
3, 126, -6,
67, 101, 37,
101, 61, -44,
-103, 68, -26,
-53, 105, 47,
3, 126, -6,
-88, 74, 52,
-53, 105, 47,
-103, 68, -26,
-96, 35, 74,
-28, 107, 61,
-88, 74, 52,
100, 68, 37,
44, 105, 55,
109, 27, 58,
101, 61, -44,
67, 101, 37,
100, 68, 37,
-2, 104, -72,
101, 61, -44,
97, 49, -64,
-102, 57, -47,
-103, 68, -26,
-2, 104, -72,
-126, -5, -4,
-120, 17, 36,
-103, 68, -26,
-4, -126, -10,
3, -106, 69,
-84, -75, 58,
87, -81, 43,
3, -106, 69,
-4, -126, -10,
101, 61, -44,
125, 8, 15,
123, -15, -25,
9, -41, -119,
42, -65, -100,
-59, -64, -91,
42, -65, -100,
-3, -99, -78,
-59, -64, -91,
9, -41, -119,
-59, -64, -91,
-24, -38, -118,
62, -103, -38,
42, -65, -100,
9, -41, -119,
-24, -38, -118,
-59, -64, -91,
-74, -99, -25,
-85, 17, -92,
-104, 19, -69,
-24, -38, -118,
-7, 41, -119,
0, 43, -119,
-104, 19, -69,
98, 14, -78,
0, 43, -119,
-7, 41, -119,
9, -41, -119,
98, 14, -78,
69, 9, -106,
-85, 17, -92,
-113, -26, -49,
-39, -68, -99,
-7, 41, -119,
-85, 17, -92,
15, -83, -94,
-36, -81, -89,
69, 9, -106,
-7, 41, -119,
17, -70, -104,
100, -35, -69,
69, 9, -106,
-4, -126, -10,
-4, -126, -12,
19, -124, -16,
-4, -126, -10,
-84, -71, 62,
-28, -123, -12,
2, -108, 66,
80, -88, 41,
-4, -126, -12,
-11, -85, 92,
65, -8, 108,
-7, 7, 126,
-7, 7, 126,
0, -74, 102,
87, 9, 91,
87, 9, 91,
0, -74, 102,
64, -84, 69,
64, -84, 69,
65, -8, 108,
-11, -85, 92,
28, 6, 123,
-48, -4, 117,
20, -86, 90,
20, -86, 90,
-48, -4, 117,
-58, -80, 78,
-58, -80, 78,
11, -74, 101,
-70, 14, 104,
-70, 14, 104,
11, -74, 101,
28, 6, 123,
11, -74, 101,
-52, -68, 92,
28, 6, 123,
-58, -80, 78,
11, -11, 125,
11, -74, 101,
-48, -4, 117,
11, -11, 125,
-58, -80, 78,
28, 6, 123,
-52, -68, 92,
-48, -4, 117,
64, -84, 69,
7, -11, 126,
65, -8, 108,
0, -74, 102,
7, -11, 126,
64, -84, 69,
-7, 7, 126,
62, -72, 83,
0, -74, 102,
65, -8, 108,
62, -72, 83,
-7, 7, 126,
62, -72, 83,
65, -8, 108,
7, -11, 126,
-52, -68, 92,
11, -74, 101,
11, -11, 125,
62, -103, -38,
80, -88, 41,
2, -108, 66,
58, -52, 99,
-15, 46, 117,
-58, -52, 99,
93, 24, -82,
-93, 24, -82,
85, 55, -75,
15, 46, 117,
36, 106, 59,
-15, 46, 117,
-15, 46, 117,
-28, 123, 0,
-48, 110, -38,
-48, 110, -38,
28, 123, 0,
48, 110, -38,
48, 110, -38,
28, 123, 0,
15, 46, 117,
83, -27, 91,
93, 24, -82,
85, 55, -75,
-83, -27, 91,
83, -86, 42,
83, -27, 91,
-85, 55, -75,
-93, 24, -82,
-83, -27, 91,
-65, 44, -99,
-48, 110, -38,
65, 44, -99,
-93, 24, -82,
-83, -86, 42,
-83, -27, 91,
-83, -27, 91,
-83, -86, 42,
83, -86, 42,
83, -27, 91,
83, -86, 42,
93, 24, -82,
28, 123, 0,
-36, 106, 59,
15, 46, 117,
-48, 110, -38,
-28, 123, 0,
28, 123, 0,
-15, 46, 117,
36, 106, 59,
-28, 123, 0,
15, 46, 117,
-36, 106, 59,
36, 106, 59,
-93, 24, -82,
-85, 55, -75,
85, 55, -75,
36, 106, 59,
9, -41, -119,
-24, -38, -118,
-36, 106, 59,
98, 14, -78,
9, -41, -119,
28, 123, 0,
0, 43, -119,
98, 14, -78,
-28, 123, 0,
-104, 19, -69,
0, 43, -119,
36, 106, 59,
-24, -38, -118,
-104, 19, -69,
28, 123, 0,
-28, 123, 0,
0, 43, -119,
-28, 123, 0,
36, 106, 59,
-104, 19, -69,
58, -52, 99,
85, 55, -75,
65, 44, -99,
-58, -52, 99,
83, -27, 91,
58, -52, 99,
65, 44, -99,
-85, 55, -75,
-65, 44, -99,
-65, 44, -99,
-85, 55, -75,
-58, -52, 99,
-99, -48, 62,
93, -60, 60,
-50, 41, 108,
42, -37, -113,
-99, 32, -72,
91, 17, -86,
42, -117, 21,
42, -37, -113,
93, -60, 60,
-99, 32, -72,
-50, 41, 108,
-68, 106, 1,
-99, 32, -72,
-99, -48, 62,
-50, 41, 108,
42, -37, -113,
91, 17, -86,
93, -60, 60,
-99, 32, -72,
-68, 106, 1,
91, 17, -86,
-99, -48, 62,
42, -117, 21,
93, -60, 60,
-50, 41, 108,
-58, -52, 99,
-15, 46, 117,
93, -60, 60,
-65, 44, -99,
-58, -52, 99,
91, 17, -86,
-68, 106, 1,
-65, 44, -99,
-68, 106, 1,
-15, 46, 117,
-48, 110, -38,
50, 41, 108,
-93, -60, 60,
99, -48, 62,
-91, 17, -86,
99, 32, -72,
-42, -37, -113,
-93, -60, 60,
-42, -37, -113,
-42, -117, 21,
68, 106, 1,
50, 41, 108,
99, 32, -72,
50, 41, 108,
99, -48, 62,
99, 32, -72,
-93, -60, 60,
-91, 17, -86,
-42, -37, -113,
-91, 17, -86,
68, 106, 1,
99, 32, -72,
-93, -60, 60,
-42, -117, 21,
99, -48, 62,
50, 41, 108,
48, 110, -38,
15, 46, 117,
68, 106, 1,
65, 44, -99,
48, 110, -38,
-91, 17, -86,
-93, -60, 60,
65, 44, -99,
-93, -60, 60,
50, 41, 108,
58, -52, 99,
68, 106, 1,
48, 110, -38,
50, 41, 108,
-15, 46, 117,
-68, 106, 1,
-50, 41, 108,
110, -56, 24,
-74, -97, 34,
118, 24, 38,
97, -7, -81,
63, -26, -106,
-97, -7, -81,
-97, -7, -81,
118, 24, 38,
97, -7, -81,
-97, -7, -81,
110, -56, 24,
118, 24, 38,
-63, -26, -106,
-74, -97, 34,
-93, 24, -82,
-74, -97, 34,
83, -86, 42,
-83, -86, 42,
62, -106, 30,
93, 24, -82,
83, -86, 42,
63, -26, -106,
-93, 24, -82,
93, 24, -82,
-78, 5, 99,
73, 2, 103,
-91, 85, 21,
73, -103, -2,
-87, -36, -84,
88, -30, -85,
73, 2, 103,
73, -103, -2,
85, 94, 6,
-78, -99, -4,
-91, 85, 21,
-87, -36, -84,
-78, -99, -4,
-78, 5, 99,
-91, 85, 21,
73, -103, -2,
88, -30, -85,
85, 94, 6,
73, -103, -2,
-78, -99, -4,
-87, -36, -84,
73, 2, 103,
85, 94, 6,
-91, 85, 21,
-91, 85, 21,
85, 94, 6,
-74, -97, 34,
85, 94, 6,
88, -30, -85,
118, 24, 38,
88, -30, -85,
-63, -26, -106,
97, -7, -81,
-87, -36, -84,
-74, -97, 34,
-63, -26, -106,
88, 88, 21,
-73, 4, 103,
78, 5, 99,
-88, -31, -85,
87, -36, -84,
-73, -103, -1,
-62, 104, -37,
-73, -103, -1,
-73, 4, 103,
87, -36, -84,
88, 88, 21,
78, -99, -4,
88, 88, 21,
78, 5, 99,
78, -99, -4,
-62, 104, -37,
-88, -31, -85,
-73, -103, -1,
87, -36, -84,
78, -99, -4,
-73, -103, -1,
88, 88, 21,
-62, 104, -37,
-73, 4, 103,
88, 88, 21,
87, -36, -84,
62, -106, 30,
-88, -31, -85,
-97, -7, -81,
63, -26, -106,
-88, -31, -85,
110, -56, 24,
-97, -7, -81,
-62, 104, -37,
62, -106, 30,
110, -56, 24,
-42, -37, -113,
38, -81, -89,
-42, -117, 21,
-42, -117, 21,
94, -83, -8,
99, -48, 62,
99, -48, 62,
94, -83, -8,
99, 32, -72,
99, 32, -72,
94, -47, -70,
-42, -37, -113,
42, -117, 21,
-38, -116, -30,
42, -37, -113,
42, -37, -113,
-94, -47, -70,
-99, 32, -72,
-99, 32, -72,
-94, -47, -70,
-99, -48, 62,
-99, -48, 62,
-94, -83, -8,
42, -117, 21,
-75, -94, 38,
80, 5, 97,
38, -116, -30,
80, 5, 97,
94, -47, -70,
94, -83, -8,
81, 88, -41,
38, -81, -89,
94, -47, -70,
-75, -11, -101,
-75, -94, 38,
38, -81, -89,
-80, 5, 97,
-38, -116, -30,
-94, -83, -8,
75, -11, -101,
-94, -47, -70,
-38, -81, -89,
-81, 88, -41,
-80, 5, 97,
-94, -47, -70,
-38, -81, -89,
-38, -116, -30,
75, -11, -101,
-99, -37, 69,
71, -84, 61,
-57, 0, 113,
33, -28, -119,
-92, 50, -70,
81, 17, -95,
31, -121, 19,
33, -28, -119,
71, -84, 61,
-92, 50, -70,
-57, 0, 113,
-53, 107, -41,
-92, 50, -70,
-99, -37, 69,
-57, 0, 113,
33, -28, -119,
81, 17, -95,
71, -84, 61,
-92, 50, -70,
-53, 107, -41,
81, 17, -95,
-99, -37, 69,
31, -121, 19,
71, -84, 61,
33, -28, -119,
-72, -92, -48,
-92, 50, -70,
-92, 50, -70,
-72, -92, -48,
-99, -37, 69,
-99, -37, 69,
-72, -92, -48,
31, -121, 19,
31, -121, 19,
-72, -92, -48,
33, -28, -119,
81, 17, -95,
-81, 88, -41,
75, -11, -101,
-53, 107, -41,
-57, 0, 113,
-81, 88, -41,
-57, 0, 113,
71, -84, 61,
-80, 5, 97,
71, -84, 61,
81, 17, -95,
75, -94, 38,
73, -103, -2,
-26, -103, 68,
-78, -99, -4,
-78, -99, -4,
-26, -103, 68,
-78, 5, 99,
-78, 5, 99,
-33, -64, 104,
73, 2, 103,
73, 2, 103,
35, -60, 105,
73, -103, -2,
-73, 4, 103,
-35, -60, 105,
78, 5, 99,
78, 5, 99,
26, -103, 68,
78, -99, -4,
78, -99, -4,
26, -103, 68,
-73, -103, -1,
-73, -103, -1,
-35, -60, 105,
-73, 4, 103,
89, 17, 88,
72, 38, 97,
-89, 17, 88,
-84, 1, -95,
-109, -39, -50,
84, 1, -95,
-75, 40, 93,
-109, -39, -50,
-89, 17, 88,
108, -45, -48,
72, 38, 97,
84, 1, -95,
89, 17, 88,
50, 106, 46,
84, 1, -95,
84, 1, -95,
73, 27, -99,
-84, 1, -95,
-84, 1, -95,
-98, 73, 33,
-89, 17, 88,
-89, 17, 88,
-98, 73, 33,
89, 17, 88,
-98, 73, 33,
50, 106, 46,
89, 17, 88,
-84, 1, -95,
-89, 2, -89,
-98, 73, 33,
73, 27, -99,
-89, 2, -89,
-84, 1, -95,
50, 106, 46,
73, 27, -99,
84, 1, -95,
72, 38, 97,
89, 17, 88,
84, 1, -95,
-109, -39, -50,
-84, 1, -95,
-89, 17, 88,
-109, -39, -50,
108, -45, -48,
84, 1, -95,
72, 38, 97,
-75, 40, 93,
-89, 17, 88,
-109, -39, -50,
-35, -60, 105,
-27, -104, 66,
-75, 40, 93,
72, 38, 97,
-35, -60, 105,
72, 38, 97,
108, -45, -48,
33, -64, 104,
108, -45, -48,
-27, -104, 66,
26, -103, 68,
89, 17, 88,
-72, 38, 97,
-89, 17, 88,
-84, 1, -95,
109, -39, -50,
84, 1, -95,
89, 17, 88,
109, -39, -50,
75, 40, 93,
-84, 1, -95,
-72, 38, 97,
-108, -45, -48,
-84, 1, -95,
-50, 106, 46,
-89, 17, 88,
84, 1, -95,
-73, 27, -99,
-84, 1, -95,
89, 17, 88,
98, 73, 33,
84, 1, -95,
-89, 17, 88,
98, 73, 33,
89, 17, 88,
-89, 17, 88,
-50, 106, 46,
98, 73, 33,
98, 73, 33,
89, 2, -89,
84, 1, -95,
84, 1, -95,
89, 2, -89,
-73, 27, -99,
-84, 1, -95,
-73, 27, -99,
-50, 106, 46,
-84, 1, -95,
-89, 17, 88,
-72, 38, 97,
89, 17, 88,
84, 1, -95,
109, -39, -50,
-84, 1, -95,
-108, -45, -48,
109, -39, -50,
89, 17, 88,
75, 40, 93,
-72, 38, 97,
-72, 38, 97,
35, -60, 105,
-33, -64, 104,
75, 40, 93,
109, -39, -50,
35, -60, 105,
109, -39, -50,
-108, -45, -48,
27, -104, 66,
-108, -45, -48,
-33, -64, 104,
-26, -103, 68,
86, -77, -50,
-53, -87, -74,
89, 8, -89,
-65, 108, 12,
95, 82, -6,
-91, 76, -43,
99, -73, 30,
77, -61, 79,
-93, -84, -13,
77, -61, 79,
95, 82, -6,
62, 105, 32,
-93, -84, -13,
-100, -59, 48,
-91, 76, -43,
62, 105, 32,
-18, 3, 125,
77, -61, 79,
77, -61, 79,
-18, 3, 125,
-100, -59, 48,
-100, -59, 48,
-18, 3, 125,
-65, 108, 12,
-65, 108, 12,
-18, 3, 125,
62, 105, 32,
99, -73, 30,
86, -77, -50,
95, 82, -6,
-93, -84, -13,
-53, -87, -74,
99, -73, 30,
-91, 76, -43,
-57, 7, -113,
-93, -84, -13,
-57, 7, -113,
-53, -87, -74,
-93, -84, -13,
-53, -87, -74,
86, -77, -50,
99, -73, 30,
86, -77, -50,
89, 8, -89,
95, 82, -6,
-100, -59, 48,
-65, 108, 12,
-91, 76, -43,
77, -61, 79,
99, -73, 30,
95, 82, -6,
77, -61, 79,
-100, -59, 48,
-93, -84, -13,
-65, 108, 12,
62, 105, 32,
95, 82, -6,
-53, -87, -74,
-57, 7, -113,
89, 8, -89,
95, 82, -6,
89, 8, -89,
98, 73, 33,
89, 8, -89,
-57, 7, -113,
89, 2, -89,
-57, 7, -113,
-91, 76, -43,
-73, 27, -99,
-91, 76, -43,
95, 82, -6,
-50, 106, 46,
-89, 8, -89,
53, -87, -74,
-86, -77, -50,
91, 76, -43,
-95, 82, -6,
65, 108, 12,
93, -84, -13,
-77, -61, 79,
-99, -73, 30,
-62, 105, 32,
-95, 82, -6,
-77, -61, 79,
91, 76, -43,
100, -59, 48,
93, -84, -13,
-77, -61, 79,
18, 3, 125,
-62, 105, 32,
100, -59, 48,
18, 3, 125,
-77, -61, 79,
65, 108, 12,
18, 3, 125,
100, -59, 48,
-62, 105, 32,
18, 3, 125,
65, 108, 12,
-95, 82, -6,
-86, -77, -50,
-99, -73, 30,
-99, -73, 30,
53, -87, -74,
93, -84, -13,
93, -84, -13,
57, 7, -113,
91, 76, -43,
93, -84, -13,
53, -87, -74,
57, 7, -113,
-99, -73, 30,
-86, -77, -50,
53, -87, -74,
-95, 82, -6,
-89, 8, -89,
-86, -77, -50,
91, 76, -43,
65, 108, 12,
100, -59, 48,
-95, 82, -6,
-99, -73, 30,
-77, -61, 79,
93, -84, -13,
100, -59, 48,
-77, -61, 79,
-95, 82, -6,
-62, 105, 32,
65, 108, 12,
-89, 8, -89,
57, 7, -113,
53, -87, -74,
-95, 82, -6,
50, 106, 46,
-98, 73, 33,
91, 76, -43,
73, 27, -99,
50, 106, 46,
57, 7, -113,
-89, 2, -89,
73, 27, -99,
-89, 8, -89,
-98, 73, 33,
-89, 2, -89,
63, -26, -106,
87, -36, -84,
-88, -31, -85,
88, -30, -85,
-87, -36, -84,
-63, -26, -106,
81, 88, -41,
-81, 17, -95,
-75, -11, -101,
-75, -11, -101,
-71, -84, 61,
-75, -94, 38,
80, 5, 97,
53, 107, -41,
81, 88, -41,
57, 0, 113,
-71, -84, 61,
99, -37, 69,
-81, 17, -95,
92, 50, -70,
-33, -28, -119,
-71, -84, 61,
-33, -28, -119,
-31, -121, 19,
53, 107, -41,
57, 0, 113,
92, 50, -70,
57, 0, 113,
99, -37, 69,
92, 50, -70,
-71, -84, 61,
-81, 17, -95,
-33, -28, -119,
-81, 17, -95,
53, 107, -41,
92, 50, -70,
-71, -84, 61,
-31, -121, 19,
99, -37, 69,
92, 50, -70,
72, -92, -48,
-33, -28, -119,
99, -37, 69,
72, -92, -48,
92, 50, -70,
-31, -121, 19,
72, -92, -48,
99, -37, 69,
-33, -28, -119,
72, -92, -48,
-31, -121, 19,
-75, -94, 38,
-71, -84, 61,
80, 5, 97,
-71, -84, 61,
57, 0, 113,
80, 5, 97,
80, 5, 97,
57, 0, 113,
53, 107, -41,
-75, -11, -101,
-81, 17, -95,
-71, -84, 61,
81, 88, -41,
53, 107, -41,
-81, 17, -95,
-89, 8, -89,
-95, 82, -6,
-98, 73, 33,
57, 7, -113,
-89, 8, -89,
-89, 2, -89,
91, 76, -43,
57, 7, -113,
73, 27, -99,
-95, 82, -6,
91, 76, -43,
50, 106, 46,
95, 82, -6,
98, 73, 33,
-50, 106, 46,
-91, 76, -43,
-50, 106, 46,
-73, 27, -99,
-57, 7, -113,
-73, 27, -99,
89, 2, -89,
89, 8, -89,
89, 2, -89,
98, 73, 33,
-108, -45, -48,
-72, 38, 97,
-33, -64, 104,
-108, -45, -48,
-26, -103, 68,
27, -104, 66,
109, -39, -50,
27, -104, 66,
35, -60, 105,
-72, 38, 97,
75, 40, 93,
35, -60, 105,
108, -45, -48,
-109, -39, -50,
-27, -104, 66,
108, -45, -48,
26, -103, 68,
33, -64, 104,
72, 38, 97,
33, -64, 104,
-35, -60, 105,
-109, -39, -50,
-75, 40, 93,
-35, -60, 105,
-73, -103, -1,
-27, -104, 66,
-35, -60, 105,
26, -103, 68,
-27, -104, 66,
-73, -103, -1,
78, 5, 99,
33, -64, 104,
26, -103, 68,
-35, -60, 105,
33, -64, 104,
78, 5, 99,
35, -60, 105,
27, -104, 66,
73, -103, -2,
-33, -64, 104,
35, -60, 105,
73, 2, 103,
-26, -103, 68,
-33, -64, 104,
-78, 5, 99,
73, -103, -2,
27, -104, 66,
-26, -103, 68,
81, 17, -95,
75, -11, -101,
75, -94, 38,
71, -84, 61,
75, -94, 38,
-80, 5, 97,
-57, 0, 113,
-80, 5, 97,
-81, 88, -41,
81, 17, -95,
-53, 107, -41,
-81, 88, -41,
-38, -116, -30,
75, -94, 38,
75, -11, -101,
-80, 5, 97,
-94, -83, -8,
-94, -47, -70,
75, -11, -101,
-81, 88, -41,
-94, -47, -70,
-80, 5, 97,
75, -94, 38,
-38, -116, -30,
-75, -94, 38,
38, -116, -30,
38, -81, -89,
81, 88, -41,
-75, -11, -101,
38, -81, -89,
80, 5, 97,
81, 88, -41,
94, -47, -70,
80, 5, 97,
94, -83, -8,
38, -116, -30,
-94, -83, -8,
-38, -116, -30,
42, -117, 21,
-94, -47, -70,
-94, -83, -8,
-99, -48, 62,
42, -37, -113,
-38, -81, -89,
-94, -47, -70,
-38, -116, -30,
-38, -81, -89,
42, -37, -113,
94, -47, -70,
38, -81, -89,
-42, -37, -113,
94, -83, -8,
94, -47, -70,
99, 32, -72,
-42, -117, 21,
38, -116, -30,
94, -83, -8,
38, -81, -89,
38, -116, -30,
-42, -117, 21,
-62, 104, -37,
88, 88, 21,
62, -106, 30,
-88, -31, -85,
-62, 104, -37,
110, -56, 24,
87, -36, -84,
63, -26, -106,
62, -106, 30,
-87, -36, -84,
-91, 85, 21,
-74, -97, 34,
88, -30, -85,
97, -7, -81,
118, 24, 38,
85, 94, 6,
118, 24, 38,
-74, -97, 34,
63, -26, -106,
-63, -26, -106,
-93, 24, -82,
62, -106, 30,
63, -26, -106,
93, 24, -82,
-74, -97, 34,
62, -106, 30,
83, -86, 42,
-74, -97, 34,
-83, -86, 42,
-93, 24, -82,
97, -7, -81,
-63, -26, -106,
63, -26, -106,
110, -56, 24,
62, -106, 30,
-74, -97, 34,
50, 41, 108,
15, 46, 117,
58, -52, 99,
-93, -60, 60,
58, -52, 99,
65, 44, -99,
68, 106, 1,
-91, 17, -86,
65, 44, -99,
-68, 106, 1,
-48, 110, -38,
-65, 44, -99,
93, -60, 60,
91, 17, -86,
-65, 44, -99,
-50, 41, 108,
93, -60, 60,
-58, -52, 99,
-85, 55, -75,
-83, -27, 91,
-58, -52, 99,
65, 44, -99,
85, 55, -75,
-85, 55, -75,
-58, -52, 99,
-83, -27, 91,
83, -27, 91,
58, -52, 99,
83, -27, 91,
85, 55, -75,
-36, 106, 59,
28, 123, 0,
98, 14, -78,
36, 106, 59,
-36, 106, 59,
9, -41, -119,
-48, 110, -38,
48, 110, -38,
65, 44, -99,
58, -52, 99,
15, 46, 117,
-15, 46, 117,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:13 */
static s8 vtxnvgrp_frake_select_13[]={
-30, -123, -7,
-5, -126, -7,
-6, -126, -6,
-6, -126, -6,
17, -124, -14,
89, -76, 46,
12, -73, -102,
64, 4, -109,
-42, -83, -85,
-42, -83, -85,
-12, 37, -120,
-15, -81, -96,
-15, -81, -96,
-12, 37, -120,
10, -85, -92,
10, -85, -92,
-89, 16, -88,
-44, -71, -95,
-44, -71, -95,
-117, -25, -42,
-76, -99, -18,
12, -73, -102,
80, -88, 41,
58, -105, -38,
96, -39, -72,
5, -45, -118,
64, 4, -109,
64, 4, -109,
96, 11, -81,
-12, 37, -120,
-12, 37, -120,
-106, 19, -66,
-89, 16, -88,
-89, 16, -88,
-29, -40, -116,
-117, -25, -42,
-117, -25, -42,
-29, -40, -116,
-76, -99, -18,
-76, -99, -18,
-64, -67, -86,
-4, -104, -71,
-4, -104, -71,
38, -69, -99,
58, -105, -38,
58, -105, -38,
5, -45, -118,
96, -39, -72,
12, 104, 71,
-84, 77, 54,
-23, 109, 59,
94, 45, -70,
101, 58, -50,
121, -19, -30,
126, 6, 9,
87, -81, 41,
89, -76, 46,
89, -76, 46,
87, -81, 41,
-6, -126, -6,
-6, -126, -6,
-82, -71, 64,
-82, -67, 68,
-82, -67, 68,
-82, -71, 64,
-118, 21, 40,
-126, -3, 0,
-103, 69, -24,
-103, 57, -44,
-103, 57, -44,
-4, 101, -75,
-7, 88, -90,
-7, 88, -90,
-4, 101, -75,
94, 45, -70,
101, 58, -50,
102, 67, 31,
126, 6, 9,
126, 6, 9,
102, 67, 31,
112, 26, 53,
-92, 39, 77,
-84, 77, 54,
-118, 21, 40,
-118, 21, 40,
-84, 77, 54,
-103, 69, -24,
-103, 69, -24,
4, 126, -9,
-4, 101, -75,
-4, 101, -75,
4, 126, -9,
101, 58, -50,
70, 101, 31,
4, 126, -9,
12, 104, 71,
58, -105, -38,
96, -39, -72,
12, -73, -102,
-76, -99, -18,
-77, -80, 61,
-44, -71, -95,
-4, -104, -71,
58, -105, -38,
-76, -99, -18,
58, -105, -38,
3, -106, 69,
-76, -99, -18,
-30, -123, -7,
63, -109, -16,
-44, -71, -95,
-44, -71, -95,
-100, 36, -68,
-126, -3, 0,
-126, -3, 0,
-80, -92, 32,
-82, -67, 68,
-82, -67, 68,
63, -109, -16,
-30, -123, -7,
63, -109, -16,
-23, -63, -107,
63, 41, -102,
63, 41, -102,
-23, -63, -107,
-100, 36, -68,
-100, 36, -68,
-23, -63, -107,
-80, -92, 32,
-80, -92, 32,
-23, -63, -107,
63, -109, -16,
12, -73, -102,
-75, -101, 0,
17, -124, -14,
17, -124, -14,
-75, -101, 0,
89, -76, 46,
89, -76, 46,
76, -100, 12,
121, -19, -30,
121, -19, -30,
83, 24, -92,
12, -73, -102,
-81, 50, -83,
-11, -64, -108,
-75, -101, 0,
-75, -101, 0,
-11, -64, -108,
76, -100, 12,
76, -100, 12,
-11, -64, -108,
83, 24, -92,
83, 24, -92,
-11, -64, -108,
-81, 50, -83,
-42, -83, -85,
-67, -106, 16,
12, -73, -102,
12, -73, -102,
-67, -106, 16,
121, -19, -30,
121, -19, -30,
89, -87, -19,
94, 45, -70,
94, 45, -70,
-23, 60, -109,
-42, -83, -85,
-126, -6, 13,
-34, -61, -106,
-67, -106, 16,
-67, -106, 16,
-34, -61, -106,
89, -87, -19,
89, -87, -19,
-34, -61, -106,
-23, 60, -109,
-23, 60, -109,
-34, -61, -106,
-126, -6, 13,
-103, 57, -44,
-100, -77, 4,
-126, -3, 0,
-126, -3, 0,
58, -112, 0,
-44, -71, -95,
-44, -71, -95,
58, -112, 0,
10, -85, -92,
10, -85, -92,
2, 58, -112,
-103, 57, -44,
2, 58, -112,
-1, -62, -110,
-100, -77, 4,
-100, -77, 4,
-1, -62, -110,
58, -112, 0,
58, -112, 0,
-1, -62, -110,
123, -22, -18,
123, -22, -18,
-1, -62, -110,
2, 58, -112,
-15, -81, -96,
43, -111, 43,
-42, -83, -85,
-42, -83, -85,
43, -111, 43,
94, 45, -70,
94, 45, -70,
-60, 51, -98,
-7, 88, -90,
-7, 88, -90,
-60, 51, -98,
-15, -81, -96,
-110, -62, 4,
-20, -115, -49,
43, -111, 43,
43, -111, 43,
-20, -115, -49,
112, 3, -58,
112, 3, -58,
-20, -115, -49,
-60, 51, -98,
-60, 51, -98,
-20, -115, -49,
-110, -62, 4,
10, -85, -92,
-42, -106, 54,
-15, -81, -96,
-15, -81, -96,
39, 46, -111,
-7, 88, -90,
-7, 88, -90,
39, 46, -111,
-103, 57, -44,
-103, 57, -44,
-42, -106, 54,
10, -85, -92,
-42, -106, 54,
-4, -115, -52,
100, -74, -22,
100, -74, -22,
-4, -115, -52,
39, 46, -111,
39, 46, -111,
-4, -115, -52,
-122, 15, -29,
-122, 15, -29,
-4, -115, -52,
-42, -106, 54,
15, 33, 121,
15, 33, 121,
-92, 39, 77,
112, 26, 53,
15, 33, 121,
15, 33, 121,
80, -88, 41,
12, -73, -102,
17, -124, -14,
-77, -80, 61,
-30, -123, -7,
-44, -71, -95,
-77, -80, 61,
-5, -126, -7,
-30, -123, -7,
80, -88, 41,
17, -124, -14,
-5, -126, -7,
-77, -80, 61,
3, -106, 69,
-5, -126, -7,
112, 26, 53,
87, -81, 41,
126, 6, 9,
-118, 21, 40,
-82, -71, 64,
-92, 39, 77,
89, -76, 46,
121, -19, -30,
126, 6, 9,
-118, 21, 40,
-126, -3, 0,
-82, -67, 68,
-42, 0, 119,
-49, -64, 97,
16, -7, 125,
64, -71, 82,
12, -7, 126,
4, -71, 105,
12, 104, 71,
15, 33, 121,
48, 105, 50,
12, 104, 71,
48, 105, 50,
102, 67, 31,
12, 104, 71,
102, 67, 31,
70, 101, 31,
-23, 109, 59,
15, 33, 121,
12, 104, 71,
12, 104, 71,
-49, 107, 46,
-84, 77, 54,
12, 104, 71,
4, 126, -9,
-49, 107, 46,
15, 33, 121,
23, -84, 92,
5, -103, 73,
5, -103, 73,
-56, -77, 83,
-82, -71, 64,
-82, -71, 64,
-66, 18, 106,
-92, 39, 77,
-92, 39, 77,
34, 10, 121,
15, 33, 121,
87, -81, 41,
66, -83, 68,
5, -103, 73,
5, -103, 73,
-9, -82, 95,
15, 33, 121,
15, 33, 121,
-2, 11, 126,
112, 26, 53,
112, 26, 53,
91, 10, 87,
87, -81, 41,
91, 10, 87,
66, -83, 68,
87, -81, 41,
-2, 11, 126,
91, 10, 87,
112, 26, 53,
-9, -82, 95,
-2, 11, 126,
15, 33, 121,
66, -83, 68,
-9, -82, 95,
5, -103, 73,
-92, 39, 77,
-66, 18, 106,
34, 10, 121,
-82, -71, 64,
-56, -77, 83,
-66, 18, 106,
5, -103, 73,
23, -84, 92,
-56, -77, 83,
15, 33, 121,
34, 10, 121,
23, -84, 92,
112, 26, 53,
48, 105, 50,
15, 33, 121,
15, 33, 121,
-23, 109, 59,
-92, 39, 77,
-103, 57, -44,
-122, 15, -29,
-42, -106, 54,
39, 46, -111,
-122, 15, -29,
-103, 57, -44,
-15, -81, -96,
100, -74, -22,
39, 46, -111,
-42, -106, 54,
100, -74, -22,
-15, -81, -96,
-60, 51, -98,
-110, -62, 4,
-15, -81, -96,
94, 45, -70,
112, 3, -58,
-60, 51, -98,
43, -111, 43,
112, 3, -58,
94, 45, -70,
-15, -81, -96,
-110, -62, 4,
43, -111, 43,
10, -85, -92,
123, -22, -18,
2, 58, -112,
58, -112, 0,
123, -22, -18,
10, -85, -92,
-126, -3, 0,
-100, -77, 4,
58, -112, 0,
-103, 57, -44,
2, 58, -112,
-100, -77, 4,
-23, 60, -109,
-126, -6, 13,
-42, -83, -85,
89, -87, -19,
-23, 60, -109,
94, 45, -70,
-67, -106, 16,
89, -87, -19,
121, -19, -30,
-42, -83, -85,
-126, -6, 13,
-67, -106, 16,
83, 24, -92,
-81, 50, -83,
12, -73, -102,
76, -100, 12,
83, 24, -92,
121, -19, -30,
-75, -101, 0,
76, -100, 12,
89, -76, 46,
12, -73, -102,
-81, 50, -83,
-75, -101, 0,
-82, -67, 68,
-80, -92, 32,
63, -109, -16,
-126, -3, 0,
-100, 36, -68,
-80, -92, 32,
-44, -71, -95,
63, 41, -102,
-100, 36, -68,
63, -109, -16,
63, 41, -102,
-44, -71, -95,
3, -106, 69,
-77, -80, 61,
-76, -99, -18,
4, 126, -9,
70, 101, 31,
101, 58, -50,
-103, 69, -24,
-49, 107, 46,
4, 126, -9,
-84, 77, 54,
-49, 107, 46,
-103, 69, -24,
-92, 39, 77,
-23, 109, 59,
-84, 77, 54,
102, 67, 31,
48, 105, 50,
112, 26, 53,
101, 58, -50,
70, 101, 31,
102, 67, 31,
-4, 101, -75,
101, 58, -50,
94, 45, -70,
-103, 57, -44,
-103, 69, -24,
-4, 101, -75,
-126, -3, 0,
-118, 21, 40,
-103, 69, -24,
-6, -126, -6,
5, -103, 73,
-82, -71, 64,
87, -81, 41,
5, -103, 73,
-6, -126, -6,
101, 58, -50,
126, 6, 9,
121, -19, -30,
5, -45, -118,
38, -69, -99,
-64, -67, -86,
38, -69, -99,
-4, -104, -71,
-64, -67, -86,
5, -45, -118,
-64, -67, -86,
-29, -40, -116,
58, -105, -38,
38, -69, -99,
5, -45, -118,
-29, -40, -116,
-64, -67, -86,
-76, -99, -18,
-89, 16, -88,
-106, 19, -66,
-29, -40, -116,
-12, 37, -120,
-1, 40, -120,
-106, 19, -66,
96, 11, -81,
-1, 40, -120,
-12, 37, -120,
5, -45, -118,
96, 11, -81,
64, 4, -109,
-89, 16, -88,
-117, -25, -42,
-44, -71, -95,
-12, 37, -120,
-89, 16, -88,
10, -85, -92,
-42, -83, -85,
64, 4, -109,
-12, 37, -120,
12, -73, -102,
96, -39, -72,
64, 4, -109,
-6, -126, -6,
-5, -126, -7,
17, -124, -14,
-6, -126, -6,
-82, -67, 68,
-30, -123, -7,
3, -106, 69,
80, -88, 41,
-5, -126, -7,
-9, -82, 95,
69, -6, 105,
-2, 11, 126,
-2, 11, 126,
4, -71, 105,
91, 10, 87,
91, 10, 87,
4, -71, 105,
66, -83, 68,
66, -83, 68,
69, -6, 105,
-9, -82, 95,
34, 10, 121,
-42, 0, 119,
23, -84, 92,
23, -84, 92,
-42, 0, 119,
-56, -77, 83,
-56, -77, 83,
14, -71, 103,
-66, 18, 106,
-66, 18, 106,
14, -71, 103,
34, 10, 121,
14, -71, 103,
-49, -64, 97,
34, 10, 121,
-56, -77, 83,
16, -7, 125,
14, -71, 103,
-42, 0, 119,
16, -7, 125,
-56, -77, 83,
34, 10, 121,
-49, -64, 97,
-42, 0, 119,
66, -83, 68,
12, -7, 126,
69, -6, 105,
4, -71, 105,
12, -7, 126,
66, -83, 68,
-2, 11, 126,
64, -71, 82,
4, -71, 105,
69, -6, 105,
64, -71, 82,
-2, 11, 126,
64, -71, 82,
69, -6, 105,
12, -7, 126,
-49, -64, 97,
14, -71, 103,
16, -7, 125,
58, -105, -38,
80, -88, 41,
3, -106, 69,
58, -50, 100,
-15, 47, 116,
-58, -50, 100,
93, 23, -82,
-93, 23, -82,
85, 54, -75,
15, 47, 116,
34, 107, 57,
-15, 47, 116,
-15, 47, 116,
-28, 123, -2,
-48, 110, -39,
-48, 110, -39,
28, 123, -2,
48, 110, -39,
48, 110, -39,
28, 123, -2,
15, 47, 116,
83, -26, 92,
93, 23, -82,
85, 54, -75,
-83, -26, 92,
83, -85, 43,
83, -26, 92,
-85, 54, -75,
-93, 23, -82,
-83, -26, 92,
-65, 42, -100,
-48, 110, -39,
65, 42, -100,
-93, 23, -82,
-83, -85, 43,
-83, -26, 92,
-83, -26, 92,
-83, -85, 43,
83, -85, 43,
83, -26, 92,
83, -85, 43,
93, 23, -82,
28, 123, -2,
-34, 107, 57,
15, 47, 116,
-48, 110, -39,
-28, 123, -2,
28, 123, -2,
-15, 47, 116,
34, 107, 57,
-28, 123, -2,
15, 47, 116,
-34, 107, 57,
34, 107, 57,
-93, 23, -82,
-85, 54, -75,
85, 54, -75,
34, 107, 57,
5, -45, -118,
-29, -40, -116,
-34, 107, 57,
96, 11, -81,
5, -45, -118,
28, 123, -2,
-1, 40, -120,
96, 11, -81,
-28, 123, -2,
-106, 19, -66,
-1, 40, -120,
34, 107, 57,
-29, -40, -116,
-106, 19, -66,
28, 123, -2,
-28, 123, -2,
-1, 40, -120,
-28, 123, -2,
34, 107, 57,
-106, 19, -66,
58, -50, 100,
85, 54, -75,
65, 42, -100,
-58, -50, 100,
83, -26, 92,
58, -50, 100,
65, 42, -100,
-85, 54, -75,
-65, 42, -100,
-65, 42, -100,
-85, 54, -75,
-58, -50, 100,
-99, -47, 63,
93, -60, 61,
-50, 43, 108,
42, -38, -113,
-99, 31, -72,
91, 15, -86,
42, -117, 22,
42, -38, -113,
93, -60, 61,
-99, 31, -72,
-50, 43, 108,
-68, 106, 0,
-99, 31, -72,
-99, -47, 63,
-50, 43, 108,
42, -38, -113,
91, 15, -86,
93, -60, 61,
-99, 31, -72,
-68, 106, 0,
91, 15, -86,
-99, -47, 63,
42, -117, 22,
93, -60, 61,
-50, 43, 108,
-58, -50, 100,
-15, 47, 116,
93, -60, 61,
-65, 42, -100,
-58, -50, 100,
91, 15, -86,
-68, 106, 0,
-65, 42, -100,
-68, 106, 0,
-15, 47, 116,
-48, 110, -39,
50, 43, 108,
-93, -60, 61,
99, -47, 63,
-91, 15, -86,
99, 31, -72,
-42, -38, -113,
-93, -60, 61,
-42, -38, -113,
-42, -117, 22,
68, 106, 0,
50, 43, 108,
99, 31, -72,
50, 43, 108,
99, -47, 63,
99, 31, -72,
-93, -60, 61,
-91, 15, -86,
-42, -38, -113,
-91, 15, -86,
68, 106, 0,
99, 31, -72,
-93, -60, 61,
-42, -117, 22,
99, -47, 63,
50, 43, 108,
48, 110, -39,
15, 47, 116,
68, 106, 0,
65, 42, -100,
48, 110, -39,
-91, 15, -86,
-93, -60, 61,
65, 42, -100,
-93, -60, 61,
50, 43, 108,
58, -50, 100,
68, 106, 0,
48, 110, -39,
50, 43, 108,
-15, 47, 116,
-68, 106, 0,
-50, 43, 108,
111, -56, 22,
-72, -97, 35,
118, 23, 39,
97, -7, -81,
63, -26, -106,
-97, -7, -81,
-97, -7, -81,
118, 23, 39,
97, -7, -81,
-97, -7, -81,
111, -56, 22,
118, 23, 39,
-63, -26, -106,
-72, -97, 35,
-93, 23, -82,
-72, -97, 35,
83, -85, 43,
-83, -85, 43,
61, -106, 31,
93, 23, -82,
83, -85, 43,
63, -26, -106,
-93, 23, -82,
93, 23, -82,
-78, 4, 99,
73, 1, 103,
-91, 84, 22,
73, -103, -3,
-87, -35, -84,
89, -29, -85,
73, 1, 103,
73, -103, -3,
84, 94, 8,
-78, -99, -6,
-91, 84, 22,
-87, -35, -84,
-78, -99, -6,
-78, 4, 99,
-91, 84, 22,
73, -103, -3,
89, -29, -85,
84, 94, 8,
73, -103, -3,
-78, -99, -6,
-87, -35, -84,
73, 1, 103,
84, 94, 8,
-91, 84, 22,
-91, 84, 22,
84, 94, 8,
-72, -97, 35,
84, 94, 8,
89, -29, -85,
118, 23, 39,
89, -29, -85,
-63, -26, -106,
97, -7, -81,
-87, -35, -84,
-72, -97, 35,
-63, -26, -106,
88, 88, 22,
-73, 2, 103,
78, 4, 99,
-88, -30, -86,
87, -35, -84,
-73, -103, -3,
-62, 104, -34,
-73, -103, -3,
-73, 2, 103,
87, -35, -84,
88, 88, 22,
78, -99, -6,
88, 88, 22,
78, 4, 99,
78, -99, -6,
-62, 104, -34,
-88, -30, -86,
-73, -103, -3,
87, -35, -84,
78, -99, -6,
-73, -103, -3,
88, 88, 22,
-62, 104, -34,
-73, 2, 103,
88, 88, 22,
87, -35, -84,
61, -106, 31,
-88, -30, -86,
-97, -7, -81,
63, -26, -106,
-88, -30, -86,
111, -56, 22,
-97, -7, -81,
-62, 104, -34,
61, -106, 31,
111, -56, 22,
-42, -38, -113,
38, -82, -88,
-42, -117, 22,
-42, -117, 22,
94, -84, -7,
99, -47, 63,
99, -47, 63,
94, -84, -7,
99, 31, -72,
99, 31, -72,
94, -48, -70,
-42, -38, -113,
42, -117, 22,
-38, -117, -29,
42, -38, -113,
42, -38, -113,
-94, -48, -70,
-99, 31, -72,
-99, 31, -72,
-94, -48, -70,
-99, -47, 63,
-99, -47, 63,
-94, -84, -7,
42, -117, 22,
-75, -94, 39,
80, 6, 97,
38, -117, -29,
80, 6, 97,
94, -48, -70,
94, -84, -7,
81, 88, -42,
38, -82, -88,
94, -48, -70,
-75, -12, -101,
-75, -94, 39,
38, -82, -88,
-80, 6, 97,
-38, -117, -29,
-94, -84, -7,
75, -12, -101,
-94, -48, -70,
-38, -82, -88,
-81, 88, -42,
-80, 6, 97,
-94, -48, -70,
-38, -82, -88,
-38, -117, -29,
75, -12, -101,
-99, -36, 69,
71, -83, 62,
-57, 1, 113,
33, -29, -118,
-92, 49, -71,
81, 16, -96,
31, -121, 21,
33, -29, -118,
71, -83, 62,
-92, 49, -71,
-57, 1, 113,
-53, 106, -43,
-92, 49, -71,
-99, -36, 69,
-57, 1, 113,
33, -29, -118,
81, 16, -96,
71, -83, 62,
-92, 49, -71,
-53, 106, -43,
81, 16, -96,
-99, -36, 69,
31, -121, 21,
71, -83, 62,
33, -29, -118,
-72, -93, -47,
-92, 49, -71,
-92, 49, -71,
-72, -93, -47,
-99, -36, 69,
-99, -36, 69,
-72, -93, -47,
31, -121, 21,
31, -121, 21,
-72, -93, -47,
33, -29, -118,
81, 16, -96,
-81, 88, -42,
75, -12, -101,
-53, 106, -43,
-57, 1, 113,
-81, 88, -42,
-57, 1, 113,
71, -83, 62,
-80, 6, 97,
71, -83, 62,
81, 16, -96,
75, -94, 39,
73, -103, -3,
-26, -104, 67,
-78, -99, -6,
-78, -99, -6,
-26, -104, 67,
-78, 4, 99,
-78, 4, 99,
-33, -65, 103,
73, 1, 103,
73, 1, 103,
35, -62, 104,
73, -103, -3,
-73, 2, 103,
-35, -62, 104,
78, 4, 99,
78, 4, 99,
26, -104, 67,
78, -99, -6,
78, -99, -6,
26, -104, 67,
-73, -103, -3,
-73, -103, -3,
-35, -62, 104,
-73, 2, 103,
89, 21, 87,
73, 39, 96,
-89, 21, 87,
-85, -8, -93,
-105, -46, -52,
85, -8, -93,
-76, 41, 92,
-105, -46, -52,
-89, 21, 87,
104, -52, -50,
73, 39, 96,
85, -8, -93,
89, 21, 87,
50, 109, 41,
85, -8, -93,
85, -8, -93,
73, 22, -100,
-85, -8, -93,
-85, -8, -93,
-98, 75, 29,
-89, 21, 87,
-89, 21, 87,
-98, 75, 29,
89, 21, 87,
-98, 75, 29,
50, 109, 41,
89, 21, 87,
-85, -8, -93,
-89, -1, -89,
-98, 75, 29,
73, 22, -100,
-89, -1, -89,
-85, -8, -93,
50, 109, 41,
73, 22, -100,
85, -8, -93,
73, 39, 96,
89, 21, 87,
85, -8, -93,
-105, -46, -52,
-85, -8, -93,
-89, 21, 87,
-105, -46, -52,
104, -52, -50,
85, -8, -93,
73, 39, 96,
-76, 41, 92,
-89, 21, 87,
-105, -46, -52,
-35, -62, 104,
-27, -105, 64,
-76, 41, 92,
73, 39, 96,
-35, -62, 104,
73, 39, 96,
104, -52, -50,
33, -65, 103,
104, -52, -50,
-27, -105, 64,
26, -104, 67,
89, 21, 87,
-73, 39, 96,
-89, 21, 87,
-85, -8, -93,
105, -46, -52,
85, -8, -93,
89, 21, 87,
105, -46, -52,
76, 41, 92,
-85, -8, -93,
-73, 39, 96,
-104, -52, -50,
-85, -8, -93,
-50, 109, 41,
-89, 21, 87,
85, -8, -93,
-73, 22, -100,
-85, -8, -93,
89, 21, 87,
98, 75, 29,
85, -8, -93,
-89, 21, 87,
98, 75, 29,
89, 21, 87,
-89, 21, 87,
-50, 109, 41,
98, 75, 29,
98, 75, 29,
89, -1, -89,
85, -8, -93,
85, -8, -93,
89, -1, -89,
-73, 22, -100,
-85, -8, -93,
-73, 22, -100,
-50, 109, 41,
-85, -8, -93,
-89, 21, 87,
-73, 39, 96,
89, 21, 87,
85, -8, -93,
105, -46, -52,
-85, -8, -93,
-104, -52, -50,
105, -46, -52,
89, 21, 87,
76, 41, 92,
-73, 39, 96,
-73, 39, 96,
35, -62, 104,
-33, -65, 103,
76, 41, 92,
105, -46, -52,
35, -62, 104,
105, -46, -52,
-104, -52, -50,
27, -105, 64,
-104, -52, -50,
-33, -65, 103,
-26, -104, 67,
86, -79, -47,
-53, -90, -70,
89, 4, -90,
-65, 108, 7,
95, 82, -10,
-91, 74, -46,
99, -71, 33,
77, -57, 82,
-93, -85, -10,
77, -57, 82,
95, 82, -10,
61, 107, 28,
-93, -85, -10,
-101, -56, 51,
-91, 74, -46,
61, 107, 28,
-18, 9, 125,
77, -57, 82,
77, -57, 82,
-18, 9, 125,
-101, -56, 51,
-101, -56, 51,
-18, 9, 125,
-65, 108, 7,
-65, 108, 7,
-18, 9, 125,
61, 107, 28,
99, -71, 33,
86, -79, -47,
95, 82, -10,
-93, -85, -10,
-53, -90, -70,
99, -71, 33,
-91, 74, -46,
-57, 2, -113,
-93, -85, -10,
-57, 2, -113,
-53, -90, -70,
-93, -85, -10,
-53, -90, -70,
86, -79, -47,
99, -71, 33,
86, -79, -47,
89, 4, -90,
95, 82, -10,
-101, -56, 51,
-65, 108, 7,
-91, 74, -46,
77, -57, 82,
99, -71, 33,
95, 82, -10,
77, -57, 82,
-101, -56, 51,
-93, -85, -10,
-65, 108, 7,
61, 107, 28,
95, 82, -10,
-53, -90, -70,
-57, 2, -113,
89, 4, -90,
95, 82, -10,
89, 4, -90,
98, 75, 29,
89, 4, -90,
-57, 2, -113,
89, -1, -89,
-57, 2, -113,
-91, 74, -46,
-73, 22, -100,
-91, 74, -46,
95, 82, -10,
-50, 109, 41,
-89, 4, -90,
53, -90, -70,
-86, -79, -47,
91, 74, -46,
-95, 82, -10,
65, 108, 7,
93, -85, -10,
-77, -57, 82,
-99, -71, 33,
-61, 107, 28,
-95, 82, -10,
-77, -57, 82,
91, 74, -46,
101, -56, 51,
93, -85, -10,
-77, -57, 82,
18, 9, 125,
-61, 107, 28,
101, -56, 51,
18, 9, 125,
-77, -57, 82,
65, 108, 7,
18, 9, 125,
101, -56, 51,
-61, 107, 28,
18, 9, 125,
65, 108, 7,
-95, 82, -10,
-86, -79, -47,
-99, -71, 33,
-99, -71, 33,
53, -90, -70,
93, -85, -10,
93, -85, -10,
57, 2, -113,
91, 74, -46,
93, -85, -10,
53, -90, -70,
57, 2, -113,
-99, -71, 33,
-86, -79, -47,
53, -90, -70,
-95, 82, -10,
-89, 4, -90,
-86, -79, -47,
91, 74, -46,
65, 108, 7,
101, -56, 51,
-95, 82, -10,
-99, -71, 33,
-77, -57, 82,
93, -85, -10,
101, -56, 51,
-77, -57, 82,
-95, 82, -10,
-61, 107, 28,
65, 108, 7,
-89, 4, -90,
57, 2, -113,
53, -90, -70,
-95, 82, -10,
50, 109, 41,
-98, 75, 29,
91, 74, -46,
73, 22, -100,
50, 109, 41,
57, 2, -113,
-89, -1, -89,
73, 22, -100,
-89, 4, -90,
-98, 75, 29,
-89, -1, -89,
63, -26, -106,
87, -35, -84,
-88, -30, -86,
89, -29, -85,
-87, -35, -84,
-63, -26, -106,
81, 88, -42,
-81, 16, -96,
-75, -12, -101,
-75, -12, -101,
-71, -83, 62,
-75, -94, 39,
80, 6, 97,
53, 106, -43,
81, 88, -42,
57, 1, 113,
-71, -83, 62,
99, -36, 69,
-81, 16, -96,
92, 49, -71,
-33, -29, -118,
-71, -83, 62,
-33, -29, -118,
-31, -121, 21,
53, 106, -43,
57, 1, 113,
92, 49, -71,
57, 1, 113,
99, -36, 69,
92, 49, -71,
-71, -83, 62,
-81, 16, -96,
-33, -29, -118,
-81, 16, -96,
53, 106, -43,
92, 49, -71,
-71, -83, 62,
-31, -121, 21,
99, -36, 69,
92, 49, -71,
72, -93, -47,
-33, -29, -118,
99, -36, 69,
72, -93, -47,
92, 49, -71,
-31, -121, 21,
72, -93, -47,
99, -36, 69,
-33, -29, -118,
72, -93, -47,
-31, -121, 21,
-75, -94, 39,
-71, -83, 62,
80, 6, 97,
-71, -83, 62,
57, 1, 113,
80, 6, 97,
80, 6, 97,
57, 1, 113,
53, 106, -43,
-75, -12, -101,
-81, 16, -96,
-71, -83, 62,
81, 88, -42,
53, 106, -43,
-81, 16, -96,
-89, 4, -90,
-95, 82, -10,
-98, 75, 29,
57, 2, -113,
-89, 4, -90,
-89, -1, -89,
91, 74, -46,
57, 2, -113,
73, 22, -100,
-95, 82, -10,
91, 74, -46,
50, 109, 41,
95, 82, -10,
98, 75, 29,
-50, 109, 41,
-91, 74, -46,
-50, 109, 41,
-73, 22, -100,
-57, 2, -113,
-73, 22, -100,
89, -1, -89,
89, 4, -90,
89, -1, -89,
98, 75, 29,
-104, -52, -50,
-73, 39, 96,
-33, -65, 103,
-104, -52, -50,
-26, -104, 67,
27, -105, 64,
105, -46, -52,
27, -105, 64,
35, -62, 104,
-73, 39, 96,
76, 41, 92,
35, -62, 104,
104, -52, -50,
-105, -46, -52,
-27, -105, 64,
104, -52, -50,
26, -104, 67,
33, -65, 103,
73, 39, 96,
33, -65, 103,
-35, -62, 104,
-105, -46, -52,
-76, 41, 92,
-35, -62, 104,
-73, -103, -3,
-27, -105, 64,
-35, -62, 104,
26, -104, 67,
-27, -105, 64,
-73, -103, -3,
78, 4, 99,
33, -65, 103,
26, -104, 67,
-35, -62, 104,
33, -65, 103,
78, 4, 99,
35, -62, 104,
27, -105, 64,
73, -103, -3,
-33, -65, 103,
35, -62, 104,
73, 1, 103,
-26, -104, 67,
-33, -65, 103,
-78, 4, 99,
73, -103, -3,
27, -105, 64,
-26, -104, 67,
81, 16, -96,
75, -12, -101,
75, -94, 39,
71, -83, 62,
75, -94, 39,
-80, 6, 97,
-57, 1, 113,
-80, 6, 97,
-81, 88, -42,
81, 16, -96,
-53, 106, -43,
-81, 88, -42,
-38, -117, -29,
75, -94, 39,
75, -12, -101,
-80, 6, 97,
-94, -84, -7,
-94, -48, -70,
75, -12, -101,
-81, 88, -42,
-94, -48, -70,
-80, 6, 97,
75, -94, 39,
-38, -117, -29,
-75, -94, 39,
38, -117, -29,
38, -82, -88,
81, 88, -42,
-75, -12, -101,
38, -82, -88,
80, 6, 97,
81, 88, -42,
94, -48, -70,
80, 6, 97,
94, -84, -7,
38, -117, -29,
-94, -84, -7,
-38, -117, -29,
42, -117, 22,
-94, -48, -70,
-94, -84, -7,
-99, -47, 63,
42, -38, -113,
-38, -82, -88,
-94, -48, -70,
-38, -117, -29,
-38, -82, -88,
42, -38, -113,
94, -48, -70,
38, -82, -88,
-42, -38, -113,
94, -84, -7,
94, -48, -70,
99, 31, -72,
-42, -117, 22,
38, -117, -29,
94, -84, -7,
38, -82, -88,
38, -117, -29,
-42, -117, 22,
-62, 104, -34,
88, 88, 22,
61, -106, 31,
-88, -30, -86,
-62, 104, -34,
111, -56, 22,
87, -35, -84,
63, -26, -106,
61, -106, 31,
-87, -35, -84,
-91, 84, 22,
-72, -97, 35,
89, -29, -85,
97, -7, -81,
118, 23, 39,
84, 94, 8,
118, 23, 39,
-72, -97, 35,
63, -26, -106,
-63, -26, -106,
-93, 23, -82,
61, -106, 31,
63, -26, -106,
93, 23, -82,
-72, -97, 35,
61, -106, 31,
83, -85, 43,
-72, -97, 35,
-83, -85, 43,
-93, 23, -82,
97, -7, -81,
-63, -26, -106,
63, -26, -106,
111, -56, 22,
61, -106, 31,
-72, -97, 35,
50, 43, 108,
15, 47, 116,
58, -50, 100,
-93, -60, 61,
58, -50, 100,
65, 42, -100,
68, 106, 0,
-91, 15, -86,
65, 42, -100,
-68, 106, 0,
-48, 110, -39,
-65, 42, -100,
93, -60, 61,
91, 15, -86,
-65, 42, -100,
-50, 43, 108,
93, -60, 61,
-58, -50, 100,
-85, 54, -75,
-83, -26, 92,
-58, -50, 100,
65, 42, -100,
85, 54, -75,
-85, 54, -75,
-58, -50, 100,
-83, -26, 92,
83, -26, 92,
58, -50, 100,
83, -26, 92,
85, 54, -75,
-34, 107, 57,
28, 123, -2,
96, 11, -81,
34, 107, 57,
-34, 107, 57,
5, -45, -118,
-48, 110, -39,
48, 110, -39,
65, 42, -100,
58, -50, 100,
15, 47, 116,
-15, 47, 116,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:14 */
static s8 vtxnvgrp_frake_select_14[]={
-31, -122, -2,
-7, -126, -3,
-7, -126, -2,
-7, -126, -2,
15, -125, -11,
90, -77, 44,
6, -76, -101,
59, 0, -112,
-48, -85, -80,
-48, -85, -80,
-16, 34, -121,
-20, -84, -92,
-20, -84, -92,
-16, 34, -121,
4, -88, -90,
4, -88, -90,
-93, 16, -84,
-50, -73, -90,
-50, -73, -90,
-119, -23, -35,
-78, -98, -11,
6, -76, -101,
81, -88, 40,
55, -107, -38,
92, -44, -75,
2, -49, -117,
59, 0, -112,
59, 0, -112,
95, 7, -83,
-16, 34, -121,
-16, 34, -121,
-107, 19, -64,
-93, 16, -84,
-93, 16, -84,
-34, -42, -114,
-119, -23, -35,
-119, -23, -35,
-34, -42, -114,
-78, -98, -11,
-78, -98, -11,
-68, -69, -80,
-6, -109, -64,
-6, -109, -64,
34, -73, -97,
55, -107, -38,
55, -107, -38,
2, -49, -117,
92, -44, -75,
17, 105, 68,
-81, 80, 55,
-19, 112, 56,
92, 40, -77,
99, 54, -56,
119, -22, -34,
126, 3, 3,
88, -81, 40,
90, -77, 44,
90, -77, 44,
88, -81, 40,
-7, -126, -2,
-7, -126, -2,
-80, -67, 70,
-80, -63, 74,
-80, -63, 74,
-80, -67, 70,
-115, 25, 45,
-126, 0, 6,
-103, 71, -21,
-104, 58, -41,
-104, 58, -41,
-6, 99, -78,
-10, 85, -93,
-10, 85, -93,
-6, 99, -78,
92, 40, -77,
99, 54, -56,
105, 66, 25,
126, 3, 3,
126, 3, 3,
105, 66, 25,
114, 25, 47,
-88, 44, 80,
-81, 80, 55,
-115, 25, 45,
-115, 25, 45,
-81, 80, 55,
-103, 71, -21,
-103, 71, -21,
5, 126, -13,
-6, 99, -78,
-6, 99, -78,
5, 126, -13,
99, 54, -56,
72, 100, 25,
5, 126, -13,
17, 105, 68,
55, -107, -38,
92, -44, -75,
6, -76, -101,
-78, -98, -11,
-75, -76, 67,
-50, -73, -90,
-6, -109, -64,
55, -107, -38,
-78, -98, -11,
55, -107, -38,
5, -104, 72,
-78, -98, -11,
-31, -122, -2,
60, -110, -15,
-50, -73, -90,
-50, -73, -90,
-102, 35, -65,
-126, 0, 6,
-126, 0, 6,
-80, -89, 39,
-80, -63, 74,
-80, -63, 74,
60, -110, -15,
-31, -122, -2,
60, -110, -15,
-30, -66, -103,
59, 36, -106,
59, 36, -106,
-30, -66, -103,
-102, 35, -65,
-102, 35, -65,
-30, -66, -103,
-80, -89, 39,
-80, -89, 39,
-30, -66, -103,
60, -110, -15,
6, -76, -101,
-77, -100, 6,
15, -125, -11,
15, -125, -11,
-77, -100, 6,
90, -77, 44,
90, -77, 44,
75, -101, 11,
119, -22, -34,
119, -22, -34,
79, 19, -97,
6, -76, -101,
-84, 49, -81,
-18, -67, -106,
-77, -100, 6,
-77, -100, 6,
-18, -67, -106,
75, -101, 11,
75, -101, 11,
-18, -67, -106,
79, 19, -97,
79, 19, -97,
-18, -67, -106,
-84, 49, -81,
-48, -85, -80,
-68, -104, 22,
6, -76, -101,
6, -76, -101,
-68, -104, 22,
119, -22, -34,
119, -22, -34,
87, -89, -20,
92, 40, -77,
92, 40, -77,
-27, 56, -110,
-48, -85, -80,
-125, -2, 19,
-40, -63, -102,
-68, -104, 22,
-68, -104, 22,
-40, -63, -102,
87, -89, -20,
87, -89, -20,
-40, -63, -102,
-27, 56, -110,
-27, 56, -110,
-40, -63, -102,
-125, -2, 19,
-104, 58, -41,
-101, -76, 11,
-126, 0, 6,
-126, 0, 6,
56, -113, 0,
-50, -73, -90,
-50, -73, -90,
56, -113, 0,
4, -88, -90,
4, -88, -90,
-1, 54, -114,
-104, 58, -41,
-1, 54, -114,
-7, -65, -108,
-101, -76, 11,
-101, -76, 11,
-7, -65, -108,
56, -113, 0,
56, -113, 0,
-7, -65, -108,
122, -25, -22,
122, -25, -22,
-7, -65, -108,
-1, 54, -114,
-20, -84, -92,
43, -110, 44,
-48, -85, -80,
-48, -85, -80,
43, -110, 44,
92, 40, -77,
92, 40, -77,
-64, 49, -97,
-10, 85, -93,
-10, 85, -93,
-64, 49, -97,
-20, -84, -92,
-111, -60, 10,
-25, -116, -43,
43, -110, 44,
43, -110, 44,
-25, -116, -43,
109, 0, -64,
109, 0, -64,
-25, -116, -43,
-64, 49, -97,
-64, 49, -97,
-25, -116, -43,
-111, -60, 10,
4, -88, -90,
-42, -103, 60,
-20, -84, -92,
-20, -84, -92,
35, 42, -114,
-10, 85, -93,
-10, 85, -93,
35, 42, -114,
-104, 58, -41,
-104, 58, -41,
-42, -103, 60,
4, -88, -90,
-42, -103, 60,
-8, -117, -48,
97, -77, -24,
97, -77, -24,
-8, -117, -48,
35, 42, -114,
35, 42, -114,
-8, -117, -48,
-123, 16, -23,
-123, 16, -23,
-8, -117, -48,
-42, -103, 60,
20, 37, 119,
21, 37, 119,
-88, 44, 80,
114, 25, 47,
21, 37, 119,
20, 37, 119,
81, -88, 40,
6, -76, -101,
15, -125, -11,
-75, -76, 67,
-31, -122, -2,
-50, -73, -90,
-75, -76, 67,
-7, -126, -3,
-31, -122, -2,
81, -88, 40,
15, -125, -11,
-7, -126, -3,
-75, -76, 67,
5, -104, 72,
-7, -126, -3,
114, 25, 47,
88, -81, 40,
126, 3, 3,
-115, 25, 45,
-80, -67, 70,
-88, 44, 80,
90, -77, 44,
119, -22, -34,
126, 3, 3,
-115, 25, 45,
-126, 0, 6,
-80, -63, 74,
-37, 5, 121,
-45, -60, 101,
22, -2, 124,
67, -69, 82,
18, -3, 125,
8, -67, 107,
17, 105, 68,
21, 37, 119,
52, 106, 44,
17, 105, 68,
52, 106, 44,
105, 66, 25,
17, 105, 68,
105, 66, 25,
72, 100, 25,
-19, 112, 56,
21, 37, 119,
17, 105, 68,
17, 105, 68,
-45, 109, 44,
-81, 80, 55,
17, 105, 68,
5, 126, -13,
-45, 109, 44,
20, 37, 119,
25, -81, 93,
7, -101, 76,
7, -101, 76,
-53, -73, 88,
-80, -67, 70,
-80, -67, 70,
-61, 23, 108,
-88, 44, 80,
-88, 44, 80,
39, 13, 119,
20, 37, 119,
88, -81, 40,
68, -82, 68,
7, -101, 76,
7, -101, 76,
-6, -79, 98,
20, 37, 119,
20, 37, 119,
3, 15, 126,
114, 25, 47,
114, 25, 47,
95, 12, 82,
88, -81, 40,
95, 12, 82,
68, -82, 68,
88, -81, 40,
3, 15, 126,
95, 12, 82,
114, 25, 47,
-6, -79, 98,
3, 15, 126,
20, 37, 119,
68, -82, 68,
-6, -79, 98,
7, -101, 76,
-88, 44, 80,
-61, 23, 108,
39, 13, 119,
-80, -67, 70,
-53, -73, 88,
-61, 23, 108,
7, -101, 76,
25, -81, 93,
-53, -73, 88,
20, 37, 119,
39, 13, 119,
25, -81, 93,
114, 25, 47,
52, 106, 44,
21, 37, 119,
21, 37, 119,
-19, 112, 56,
-88, 44, 80,
-104, 58, -41,
-123, 16, -23,
-42, -103, 60,
35, 42, -114,
-123, 16, -23,
-104, 58, -41,
-20, -84, -92,
97, -77, -24,
35, 42, -114,
-42, -103, 60,
97, -77, -24,
-20, -84, -92,
-64, 49, -97,
-111, -60, 10,
-20, -84, -92,
92, 40, -77,
109, 0, -64,
-64, 49, -97,
43, -110, 44,
109, 0, -64,
92, 40, -77,
-20, -84, -92,
-111, -60, 10,
43, -110, 44,
4, -88, -90,
122, -25, -22,
-1, 54, -114,
56, -113, 0,
122, -25, -22,
4, -88, -90,
-126, 0, 6,
-101, -76, 11,
56, -113, 0,
-104, 58, -41,
-1, 54, -114,
-101, -76, 11,
-27, 56, -110,
-125, -2, 19,
-48, -85, -80,
87, -89, -20,
-27, 56, -110,
92, 40, -77,
-68, -104, 22,
87, -89, -20,
119, -22, -34,
-48, -85, -80,
-125, -2, 19,
-68, -104, 22,
79, 19, -97,
-84, 49, -81,
6, -76, -101,
75, -101, 11,
79, 19, -97,
119, -22, -34,
-77, -100, 6,
75, -101, 11,
90, -77, 44,
6, -76, -101,
-84, 49, -81,
-77, -100, 6,
-80, -63, 74,
-80, -89, 39,
60, -110, -15,
-126, 0, 6,
-102, 35, -65,
-80, -89, 39,
-50, -73, -90,
59, 36, -106,
-102, 35, -65,
60, -110, -15,
59, 36, -106,
-50, -73, -90,
5, -104, 72,
-75, -76, 67,
-78, -98, -11,
5, 126, -13,
72, 100, 25,
99, 54, -56,
-103, 71, -21,
-45, 109, 44,
5, 126, -13,
-81, 80, 55,
-45, 109, 44,
-103, 71, -21,
-88, 44, 80,
-19, 112, 56,
-81, 80, 55,
105, 66, 25,
52, 106, 44,
114, 25, 47,
99, 54, -56,
72, 100, 25,
105, 66, 25,
-6, 99, -78,
99, 54, -56,
92, 40, -77,
-104, 58, -41,
-103, 71, -21,
-6, 99, -78,
-126, 0, 6,
-115, 25, 45,
-103, 71, -21,
-7, -126, -2,
7, -101, 76,
-80, -67, 70,
88, -81, 40,
7, -101, 76,
-7, -126, -2,
99, 54, -56,
126, 3, 3,
119, -22, -34,
2, -49, -117,
34, -73, -97,
-68, -69, -80,
34, -73, -97,
-6, -109, -64,
-68, -69, -80,
2, -49, -117,
-68, -69, -80,
-34, -42, -114,
55, -107, -38,
34, -73, -97,
2, -49, -117,
-34, -42, -114,
-68, -69, -80,
-78, -98, -11,
-93, 16, -84,
-107, 19, -64,
-34, -42, -114,
-16, 34, -121,
-1, 38, -121,
-107, 19, -64,
95, 7, -83,
-1, 38, -121,
-16, 34, -121,
2, -49, -117,
95, 7, -83,
59, 0, -112,
-93, 16, -84,
-119, -23, -35,
-50, -73, -90,
-16, 34, -121,
-93, 16, -84,
4, -88, -90,
-48, -85, -80,
59, 0, -112,
-16, 34, -121,
6, -76, -101,
92, -44, -75,
59, 0, -112,
-7, -126, -2,
-7, -126, -3,
15, -125, -11,
-7, -126, -2,
-80, -63, 74,
-31, -122, -2,
5, -104, 72,
81, -88, 40,
-7, -126, -3,
-6, -79, 98,
74, -4, 102,
3, 15, 126,
3, 15, 126,
8, -67, 107,
95, 12, 82,
95, 12, 82,
8, -67, 107,
68, -82, 68,
68, -82, 68,
74, -4, 102,
-6, -79, 98,
39, 13, 119,
-37, 5, 121,
25, -81, 93,
25, -81, 93,
-37, 5, 121,
-53, -73, 88,
-53, -73, 88,
17, -68, 105,
-61, 23, 108,
-61, 23, 108,
17, -68, 105,
39, 13, 119,
17, -68, 105,
-45, -60, 101,
39, 13, 119,
-53, -73, 88,
22, -2, 124,
17, -68, 105,
-37, 5, 121,
22, -2, 124,
-53, -73, 88,
39, 13, 119,
-45, -60, 101,
-37, 5, 121,
68, -82, 68,
18, -3, 125,
74, -4, 102,
8, -67, 107,
18, -3, 125,
68, -82, 68,
3, 15, 126,
67, -69, 82,
8, -67, 107,
74, -4, 102,
67, -69, 82,
3, 15, 126,
67, -69, 82,
74, -4, 102,
18, -3, 125,
-45, -60, 101,
17, -68, 105,
22, -2, 124,
55, -107, -38,
81, -88, 40,
5, -104, 72,
58, -49, 100,
-14, 49, 116,
-58, -49, 100,
93, 22, -82,
-93, 22, -82,
85, 53, -76,
15, 49, 115,
33, 109, 55,
-14, 49, 116,
-14, 49, 116,
-28, 123, -3,
-48, 110, -41,
-48, 110, -41,
28, 123, -3,
48, 110, -41,
48, 110, -41,
28, 123, -3,
15, 49, 115,
83, -25, 92,
93, 22, -82,
85, 53, -76,
-83, -25, 92,
83, -85, 44,
83, -25, 92,
-85, 53, -76,
-93, 22, -82,
-83, -25, 92,
-65, 41, -100,
-48, 110, -41,
65, 41, -100,
-93, 22, -82,
-83, -85, 44,
-83, -25, 92,
-83, -25, 92,
-83, -85, 44,
83, -85, 44,
83, -25, 92,
83, -85, 44,
93, 22, -82,
28, 123, -3,
-33, 109, 55,
15, 49, 115,
-48, 110, -41,
-28, 123, -3,
28, 123, -3,
-14, 49, 116,
33, 109, 55,
-28, 123, -3,
15, 49, 115,
-33, 109, 55,
33, 109, 55,
-93, 22, -82,
-85, 53, -76,
85, 53, -76,
33, 109, 55,
2, -49, -117,
-34, -42, -114,
-33, 109, 55,
95, 7, -83,
2, -49, -117,
28, 123, -3,
-1, 38, -121,
95, 7, -83,
-28, 123, -3,
-107, 19, -64,
-1, 38, -121,
33, 109, 55,
-34, -42, -114,
-107, 19, -64,
28, 123, -3,
-28, 123, -3,
-1, 38, -121,
-28, 123, -3,
33, 109, 55,
-107, 19, -64,
58, -49, 100,
85, 53, -76,
65, 41, -100,
-58, -49, 100,
83, -25, 92,
58, -49, 100,
65, 41, -100,
-85, 53, -76,
-65, 41, -100,
-65, 41, -100,
-85, 53, -76,
-58, -49, 100,
-99, -47, 63,
93, -59, 62,
-50, 44, 107,
42, -39, -112,
-99, 30, -73,
91, 14, -86,
42, -117, 24,
42, -39, -112,
93, -59, 62,
-99, 30, -73,
-50, 44, 107,
-68, 106, -1,
-99, 30, -73,
-99, -47, 63,
-50, 44, 107,
42, -39, -112,
91, 14, -86,
93, -59, 62,
-99, 30, -73,
-68, 106, -1,
91, 14, -86,
-99, -47, 63,
42, -117, 24,
93, -59, 62,
-50, 44, 107,
-58, -49, 100,
-14, 49, 116,
93, -59, 62,
-65, 41, -100,
-58, -49, 100,
91, 14, -86,
-68, 106, -1,
-65, 41, -100,
-68, 106, -1,
-14, 49, 116,
-48, 110, -41,
50, 44, 107,
-93, -59, 62,
99, -47, 63,
-91, 14, -86,
99, 30, -73,
-42, -39, -112,
-93, -59, 62,
-42, -39, -112,
-42, -117, 24,
68, 106, 0,
50, 44, 107,
99, 30, -73,
50, 44, 107,
99, -47, 63,
99, 30, -73,
-93, -59, 62,
-91, 14, -86,
-42, -39, -112,
-91, 14, -86,
68, 106, 0,
99, 30, -73,
-93, -59, 62,
-42, -117, 24,
99, -47, 63,
50, 44, 107,
48, 110, -41,
15, 49, 115,
68, 106, 0,
65, 41, -100,
48, 110, -41,
-91, 14, -86,
-93, -59, 62,
65, 41, -100,
-93, -59, 62,
50, 44, 107,
58, -49, 100,
68, 106, 0,
48, 110, -41,
50, 44, 107,
-14, 49, 116,
-68, 106, -1,
-50, 44, 107,
111, -56, 20,
-71, -98, 36,
118, 23, 39,
97, -6, -81,
62, -26, -107,
-97, -7, -81,
-97, -7, -81,
118, 23, 39,
97, -6, -81,
-97, -7, -81,
111, -56, 20,
118, 23, 39,
-62, -26, -107,
-71, -98, 36,
-93, 22, -82,
-71, -98, 36,
83, -85, 44,
-83, -85, 44,
60, -107, 32,
93, 22, -82,
83, -85, 44,
62, -26, -107,
-93, 22, -82,
93, 22, -82,
-78, 2, 99,
73, 0, 103,
-91, 84, 23,
73, -103, -5,
-88, -34, -84,
89, -27, -85,
73, 0, 103,
73, -103, -5,
84, 93, 10,
-78, -99, -8,
-91, 84, 23,
-88, -34, -84,
-78, -99, -8,
-78, 2, 99,
-91, 84, 23,
73, -103, -5,
89, -27, -85,
84, 93, 10,
73, -103, -5,
-78, -99, -8,
-88, -34, -84,
73, 0, 103,
84, 93, 10,
-91, 84, 23,
-91, 84, 23,
84, 93, 10,
-71, -98, 36,
84, 93, 10,
89, -27, -85,
118, 23, 39,
89, -27, -85,
-62, -26, -107,
97, -6, -81,
-88, -34, -84,
-71, -98, 36,
-62, -26, -107,
88, 88, 24,
-73, 0, 103,
78, 2, 99,
-88, -28, -86,
88, -34, -84,
-73, -103, -5,
-63, 105, -32,
-73, -103, -5,
-73, 0, 103,
88, -34, -84,
88, 88, 24,
78, -99, -8,
88, 88, 24,
78, 2, 99,
78, -99, -8,
-63, 105, -32,
-88, -28, -86,
-73, -103, -5,
88, -34, -84,
78, -99, -8,
-73, -103, -5,
88, 88, 24,
-63, 105, -32,
-73, 0, 103,
88, 88, 24,
88, -34, -84,
60, -107, 32,
-88, -28, -86,
-97, -7, -81,
62, -26, -107,
-88, -28, -86,
111, -56, 20,
-97, -7, -81,
-63, 105, -32,
60, -107, 32,
111, -56, 20,
-42, -39, -112,
38, -84, -87,
-42, -117, 24,
-42, -117, 24,
94, -84, -6,
99, -47, 63,
99, -47, 63,
94, -84, -6,
99, 30, -73,
99, 30, -73,
94, -49, -69,
-42, -39, -112,
42, -117, 24,
-38, -117, -27,
42, -39, -112,
42, -39, -112,
-94, -49, -69,
-99, 30, -73,
-99, 30, -73,
-94, -49, -69,
-99, -47, 63,
-99, -47, 63,
-94, -84, -6,
42, -117, 24,
-75, -93, 40,
80, 8, 97,
38, -117, -27,
80, 8, 97,
94, -49, -69,
94, -84, -6,
80, 87, -43,
38, -84, -87,
94, -49, -69,
-75, -13, -101,
-75, -93, 40,
38, -84, -87,
-80, 8, 97,
-38, -117, -27,
-94, -84, -6,
75, -13, -101,
-94, -49, -69,
-38, -84, -87,
-80, 87, -43,
-80, 8, 97,
-94, -49, -69,
-38, -84, -87,
-38, -117, -27,
75, -13, -101,
-99, -35, 70,
71, -83, 63,
-57, 2, 113,
33, -31, -118,
-92, 48, -71,
81, 15, -96,
31, -120, 22,
33, -31, -118,
71, -83, 63,
-92, 48, -71,
-57, 2, 113,
-53, 106, -44,
-92, 48, -71,
-99, -35, 70,
-57, 2, 113,
33, -31, -118,
81, 15, -96,
71, -83, 63,
-92, 48, -71,
-53, 106, -44,
81, 15, -96,
-99, -35, 70,
31, -120, 22,
71, -83, 63,
33, -31, -118,
-72, -93, -45,
-92, 48, -71,
-92, 48, -71,
-72, -93, -45,
-99, -35, 70,
-99, -35, 70,
-72, -93, -45,
31, -120, 22,
31, -120, 22,
-72, -93, -45,
33, -31, -118,
81, 15, -96,
-80, 87, -43,
75, -13, -101,
-53, 106, -44,
-57, 2, 113,
-80, 87, -43,
-57, 2, 113,
71, -83, 63,
-80, 8, 97,
71, -83, 63,
81, 15, -96,
75, -93, 40,
73, -103, -5,
-26, -105, 65,
-78, -99, -8,
-78, -99, -8,
-26, -105, 65,
-78, 2, 99,
-78, 2, 99,
-33, -67, 102,
73, 0, 103,
73, 0, 103,
35, -64, 103,
73, -103, -5,
-73, 0, 103,
-35, -64, 103,
78, 2, 99,
78, 2, 99,
26, -105, 65,
78, -99, -8,
78, -99, -8,
26, -105, 65,
-73, -103, -5,
-73, -103, -5,
-35, -64, 103,
-73, 0, 103,
89, 25, 86,
74, 39, 95,
-89, 25, 86,
-87, -17, -90,
-102, -52, -53,
87, -17, -90,
-77, 41, 91,
-102, -52, -53,
-89, 25, 86,
100, -58, -51,
74, 39, 95,
87, -17, -90,
89, 25, 86,
49, 110, 36,
87, -17, -90,
87, -17, -90,
73, 18, -101,
-87, -17, -90,
-87, -17, -90,
-97, 76, 25,
-89, 25, 86,
-89, 25, 86,
-97, 76, 25,
89, 25, 86,
-97, 76, 25,
49, 110, 36,
89, 25, 86,
-87, -17, -90,
-89, -5, -89,
-97, 76, 25,
73, 18, -101,
-89, -5, -89,
-87, -17, -90,
49, 110, 36,
73, 18, -101,
87, -17, -90,
74, 39, 95,
89, 25, 86,
87, -17, -90,
-102, -52, -53,
-87, -17, -90,
-89, 25, 86,
-102, -52, -53,
100, -58, -51,
87, -17, -90,
74, 39, 95,
-77, 41, 91,
-89, 25, 86,
-102, -52, -53,
-35, -64, 103,
-27, -106, 62,
-77, 41, 91,
74, 39, 95,
-35, -64, 103,
74, 39, 95,
100, -58, -51,
33, -67, 102,
100, -58, -51,
-27, -106, 62,
26, -105, 65,
89, 25, 86,
-74, 39, 95,
-89, 25, 86,
-87, -17, -90,
102, -52, -53,
87, -17, -90,
89, 25, 86,
102, -52, -53,
77, 41, 91,
-87, -17, -90,
-74, 39, 95,
-100, -58, -51,
-87, -17, -90,
-49, 110, 36,
-89, 25, 86,
87, -17, -90,
-73, 18, -101,
-87, -17, -90,
89, 25, 86,
97, 76, 25,
87, -17, -90,
-89, 25, 86,
97, 76, 25,
89, 25, 86,
-89, 25, 86,
-49, 110, 36,
97, 76, 25,
97, 76, 25,
89, -5, -89,
87, -17, -90,
87, -17, -90,
89, -5, -89,
-73, 18, -101,
-87, -17, -90,
-73, 18, -101,
-49, 110, 36,
-87, -17, -90,
-89, 25, 86,
-74, 39, 95,
89, 25, 86,
87, -17, -90,
102, -52, -53,
-87, -17, -90,
-100, -58, -51,
102, -52, -53,
89, 25, 86,
77, 41, 91,
-74, 39, 95,
-74, 39, 95,
35, -64, 103,
-33, -67, 102,
77, 41, 91,
102, -52, -53,
35, -64, 103,
102, -52, -53,
-100, -58, -51,
27, -106, 62,
-100, -58, -51,
-33, -67, 102,
-26, -105, 65,
86, -81, -43,
-53, -93, -66,
89, 0, -90,
-65, 109, 2,
95, 82, -13,
-91, 72, -50,
99, -69, 37,
77, -53, 85,
-93, -85, -6,
77, -53, 85,
95, 82, -13,
61, 108, 23,
-93, -85, -6,
-101, -54, 54,
-91, 72, -50,
61, 108, 23,
-18, 14, 124,
77, -53, 85,
77, -53, 85,
-18, 14, 124,
-101, -54, 54,
-101, -54, 54,
-18, 14, 124,
-65, 109, 2,
-65, 109, 2,
-18, 14, 124,
61, 108, 23,
99, -69, 37,
86, -81, -43,
95, 82, -13,
-93, -85, -6,
-53, -93, -66,
99, -69, 37,
-91, 72, -50,
-56, -3, -113,
-93, -85, -6,
-56, -3, -113,
-53, -93, -66,
-93, -85, -6,
-53, -93, -66,
86, -81, -43,
99, -69, 37,
86, -81, -43,
89, 0, -90,
95, 82, -13,
-101, -54, 54,
-65, 109, 2,
-91, 72, -50,
77, -53, 85,
99, -69, 37,
95, 82, -13,
77, -53, 85,
-101, -54, 54,
-93, -85, -6,
-65, 109, 2,
61, 108, 23,
95, 82, -13,
-53, -93, -66,
-56, -3, -113,
89, 0, -90,
95, 82, -13,
89, 0, -90,
97, 76, 25,
89, 0, -90,
-56, -3, -113,
89, -5, -89,
-56, -3, -113,
-91, 72, -50,
-73, 18, -101,
-91, 72, -50,
95, 82, -13,
-49, 110, 36,
-89, 0, -90,
53, -93, -66,
-86, -81, -43,
91, 72, -50,
-95, 82, -13,
65, 109, 2,
93, -85, -6,
-77, -53, 85,
-99, -69, 37,
-61, 108, 23,
-95, 82, -13,
-77, -53, 85,
91, 72, -50,
101, -54, 54,
93, -85, -6,
-77, -53, 85,
18, 14, 124,
-61, 108, 23,
101, -54, 54,
18, 14, 124,
-77, -53, 85,
65, 109, 2,
18, 14, 124,
101, -54, 54,
-61, 108, 23,
18, 14, 124,
65, 109, 2,
-95, 82, -13,
-86, -81, -43,
-99, -69, 37,
-99, -69, 37,
53, -93, -66,
93, -85, -6,
93, -85, -6,
56, -3, -113,
91, 72, -50,
93, -85, -6,
53, -93, -66,
56, -3, -113,
-99, -69, 37,
-86, -81, -43,
53, -93, -66,
-95, 82, -13,
-89, 0, -90,
-86, -81, -43,
91, 72, -50,
65, 109, 2,
101, -54, 54,
-95, 82, -13,
-99, -69, 37,
-77, -53, 85,
93, -85, -6,
101, -54, 54,
-77, -53, 85,
-95, 82, -13,
-61, 108, 23,
65, 109, 2,
-89, 0, -90,
56, -3, -113,
53, -93, -66,
-95, 82, -13,
49, 110, 36,
-97, 76, 25,
91, 72, -50,
73, 18, -101,
49, 110, 36,
56, -3, -113,
-89, -5, -89,
73, 18, -101,
-89, 0, -90,
-97, 76, 25,
-89, -5, -89,
62, -26, -107,
88, -34, -84,
-88, -28, -86,
89, -27, -85,
-88, -34, -84,
-62, -26, -107,
80, 87, -43,
-81, 15, -96,
-75, -13, -101,
-75, -13, -101,
-71, -83, 63,
-75, -93, 40,
80, 8, 97,
53, 106, -44,
80, 87, -43,
57, 2, 113,
-71, -83, 63,
99, -35, 70,
-81, 15, -96,
92, 48, -71,
-33, -31, -118,
-71, -83, 63,
-33, -31, -118,
-31, -120, 22,
53, 106, -44,
57, 2, 113,
92, 48, -71,
57, 2, 113,
99, -35, 70,
92, 48, -71,
-71, -83, 63,
-81, 15, -96,
-33, -31, -118,
-81, 15, -96,
53, 106, -44,
92, 48, -71,
-71, -83, 63,
-31, -120, 22,
99, -35, 70,
92, 48, -71,
72, -93, -45,
-33, -31, -118,
99, -35, 70,
72, -93, -45,
92, 48, -71,
-31, -120, 22,
72, -93, -45,
99, -35, 70,
-33, -31, -118,
72, -93, -45,
-31, -120, 22,
-75, -93, 40,
-71, -83, 63,
80, 8, 97,
-71, -83, 63,
57, 2, 113,
80, 8, 97,
80, 8, 97,
57, 2, 113,
53, 106, -44,
-75, -13, -101,
-81, 15, -96,
-71, -83, 63,
80, 87, -43,
53, 106, -44,
-81, 15, -96,
-89, 0, -90,
-95, 82, -13,
-97, 76, 25,
56, -3, -113,
-89, 0, -90,
-89, -5, -89,
91, 72, -50,
56, -3, -113,
73, 18, -101,
-95, 82, -13,
91, 72, -50,
49, 110, 36,
95, 82, -13,
97, 76, 25,
-49, 110, 36,
-91, 72, -50,
-49, 110, 36,
-73, 18, -101,
-56, -3, -113,
-73, 18, -101,
89, -5, -89,
89, 0, -90,
89, -5, -89,
97, 76, 25,
-100, -58, -51,
-74, 39, 95,
-33, -67, 102,
-100, -58, -51,
-26, -105, 65,
27, -106, 62,
102, -52, -53,
27, -106, 62,
35, -64, 103,
-74, 39, 95,
77, 41, 91,
35, -64, 103,
100, -58, -51,
-102, -52, -53,
-27, -106, 62,
100, -58, -51,
26, -105, 65,
33, -67, 102,
74, 39, 95,
33, -67, 102,
-35, -64, 103,
-102, -52, -53,
-77, 41, 91,
-35, -64, 103,
-73, -103, -5,
-27, -106, 62,
-35, -64, 103,
26, -105, 65,
-27, -106, 62,
-73, -103, -5,
78, 2, 99,
33, -67, 102,
26, -105, 65,
-35, -64, 103,
33, -67, 102,
78, 2, 99,
35, -64, 103,
27, -106, 62,
73, -103, -5,
-33, -67, 102,
35, -64, 103,
73, 0, 103,
-26, -105, 65,
-33, -67, 102,
-78, 2, 99,
73, -103, -5,
27, -106, 62,
-26, -105, 65,
81, 15, -96,
75, -13, -101,
75, -93, 40,
71, -83, 63,
75, -93, 40,
-80, 8, 97,
-57, 2, 113,
-80, 8, 97,
-80, 87, -43,
81, 15, -96,
-53, 106, -44,
-80, 87, -43,
-38, -117, -27,
75, -93, 40,
75, -13, -101,
-80, 8, 97,
-94, -84, -6,
-94, -49, -69,
75, -13, -101,
-80, 87, -43,
-94, -49, -69,
-80, 8, 97,
75, -93, 40,
-38, -117, -27,
-75, -93, 40,
38, -117, -27,
38, -84, -87,
80, 87, -43,
-75, -13, -101,
38, -84, -87,
80, 8, 97,
80, 87, -43,
94, -49, -69,
80, 8, 97,
94, -84, -6,
38, -117, -27,
-94, -84, -6,
-38, -117, -27,
42, -117, 24,
-94, -49, -69,
-94, -84, -6,
-99, -47, 63,
42, -39, -112,
-38, -84, -87,
-94, -49, -69,
-38, -117, -27,
-38, -84, -87,
42, -39, -112,
94, -49, -69,
38, -84, -87,
-42, -39, -112,
94, -84, -6,
94, -49, -69,
99, 30, -73,
-42, -117, 24,
38, -117, -27,
94, -84, -6,
38, -84, -87,
38, -117, -27,
-42, -117, 24,
-63, 105, -32,
88, 88, 24,
60, -107, 32,
-88, -28, -86,
-63, 105, -32,
111, -56, 20,
88, -34, -84,
62, -26, -107,
60, -107, 32,
-88, -34, -84,
-91, 84, 23,
-71, -98, 36,
89, -27, -85,
97, -6, -81,
118, 23, 39,
84, 93, 10,
118, 23, 39,
-71, -98, 36,
62, -26, -107,
-62, -26, -107,
-93, 22, -82,
60, -107, 32,
62, -26, -107,
93, 22, -82,
-71, -98, 36,
60, -107, 32,
83, -85, 44,
-71, -98, 36,
-83, -85, 44,
-93, 22, -82,
97, -6, -81,
-62, -26, -107,
62, -26, -107,
111, -56, 20,
60, -107, 32,
-71, -98, 36,
50, 44, 107,
15, 49, 115,
58, -49, 100,
-93, -59, 62,
58, -49, 100,
65, 41, -100,
68, 106, 0,
-91, 14, -86,
65, 41, -100,
-68, 106, -1,
-48, 110, -41,
-65, 41, -100,
93, -59, 62,
91, 14, -86,
-65, 41, -100,
-50, 44, 107,
93, -59, 62,
-58, -49, 100,
-85, 53, -76,
-83, -25, 92,
-58, -49, 100,
65, 41, -100,
85, 53, -76,
-85, 53, -76,
-58, -49, 100,
-83, -25, 92,
83, -25, 92,
58, -49, 100,
83, -25, 92,
85, 53, -76,
-33, 109, 55,
28, 123, -3,
95, 7, -83,
33, 109, 55,
-33, 109, 55,
2, -49, -117,
-48, 110, -41,
48, 110, -41,
65, 41, -100,
58, -49, 100,
15, 49, 115,
-14, 49, 116,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:15 */
static s8 vtxnvgrp_frake_select_15[]={
-33, -122, 3,
-8, -126, 0,
-9, -126, 2,
-9, -126, 2,
14, -125, -9,
91, -77, 42,
0, -79, -99,
54, -5, -114,
-53, -86, -75,
-53, -86, -75,
-21, 31, -121,
-24, -86, -89,
-24, -86, -89,
-21, 31, -121,
-1, -90, -88,
-1, -90, -88,
-96, 17, -80,
-55, -75, -85,
-55, -75, -85,
-122, -21, -28,
-80, -97, -4,
0, -79, -99,
81, -89, 39,
51, -109, -37,
87, -48, -77,
0, -52, -115,
54, -5, -114,
54, -5, -114,
93, 4, -85,
-21, 31, -121,
-21, 31, -121,
-109, 19, -61,
-96, 17, -80,
-96, 17, -80,
-38, -44, -112,
-122, -21, -28,
-122, -21, -28,
-38, -44, -112,
-80, -97, -4,
-80, -97, -4,
-72, -71, -75,
-7, -113, -57,
-7, -113, -57,
30, -77, -96,
51, -109, -37,
51, -109, -37,
0, -52, -115,
87, -48, -77,
20, 107, 64,
-77, 83, 56,
-14, 114, 53,
89, 36, -82,
97, 50, -63,
117, -27, -39,
126, 0, -1,
88, -82, 38,
91, -77, 42,
91, -77, 42,
88, -82, 38,
-9, -126, 2,
-9, -126, 2,
-78, -63, 77,
-77, -59, 80,
-77, -59, 80,
-78, -63, 77,
-112, 29, 50,
-126, 2, 12,
-102, 72, -18,
-105, 59, -38,
-105, 59, -38,
-8, 96, -81,
-13, 82, -95,
-13, 82, -95,
-8, 96, -81,
89, 36, -82,
97, 50, -63,
107, 65, 18,
126, 0, -1,
126, 0, -1,
107, 65, 18,
117, 24, 42,
-83, 48, 82,
-77, 83, 56,
-112, 29, 50,
-112, 29, 50,
-77, 83, 56,
-102, 72, -18,
-102, 72, -18,
5, 125, -17,
-8, 96, -81,
-8, 96, -81,
5, 125, -17,
97, 50, -63,
75, 100, 18,
5, 125, -17,
20, 107, 64,
51, -109, -37,
87, -48, -77,
0, -79, -99,
-80, -97, -4,
-73, -73, 73,
-55, -75, -85,
-7, -113, -57,
51, -109, -37,
-80, -97, -4,
51, -109, -37,
8, -101, 75,
-80, -97, -4,
-33, -122, 3,
57, -112, -14,
-55, -75, -85,
-55, -75, -85,
-105, 35, -61,
-126, 2, 12,
-126, 2, 12,
-80, -87, 45,
-77, -59, 80,
-77, -59, 80,
57, -112, -14,
-33, -122, 3,
57, -112, -14,
-36, -69, -99,
54, 30, -110,
54, 30, -110,
-36, -69, -99,
-105, 35, -61,
-105, 35, -61,
-36, -69, -99,
-80, -87, 45,
-80, -87, 45,
-36, -69, -99,
57, -112, -14,
0, -79, -99,
-78, -99, 12,
14, -125, -9,
14, -125, -9,
-78, -99, 12,
91, -77, 42,
91, -77, 42,
74, -102, 11,
117, -27, -39,
117, -27, -39,
74, 14, -101,
0, -79, -99,
-86, 48, -79,
-24, -70, -102,
-78, -99, 12,
-78, -99, 12,
-24, -70, -102,
74, -102, 11,
74, -102, 11,
-24, -70, -102,
74, 14, -101,
74, 14, -101,
-24, -70, -102,
-86, 48, -79,
-53, -86, -75,
-69, -102, 28,
0, -79, -99,
0, -79, -99,
-69, -102, 28,
117, -27, -39,
117, -27, -39,
84, -92, -21,
89, 36, -82,
89, 36, -82,
-31, 53, -110,
-53, -86, -75,
-124, 1, 25,
-46, -66, -97,
-69, -102, 28,
-69, -102, 28,
-46, -66, -97,
84, -92, -21,
84, -92, -21,
-46, -66, -97,
-31, 53, -110,
-31, 53, -110,
-46, -66, -97,
-124, 1, 25,
-105, 59, -38,
-101, -73, 18,
-126, 2, 12,
-126, 2, 12,
55, -114, 1,
-55, -75, -85,
-55, -75, -85,
55, -114, 1,
-1, -90, -88,
-1, -90, -88,
-5, 50, -116,
-105, 59, -38,
-5, 50, -116,
-14, -68, -105,
-101, -73, 18,
-101, -73, 18,
-14, -68, -105,
55, -114, 1,
55, -114, 1,
-14, -68, -105,
120, -29, -27,
120, -29, -27,
-14, -68, -105,
-5, 50, -116,
-24, -86, -89,
44, -109, 46,
-53, -86, -75,
-53, -86, -75,
44, -109, 46,
89, 36, -82,
89, 36, -82,
-67, 47, -96,
-13, 82, -95,
-13, 82, -95,
-67, 47, -96,
-24, -86, -89,
-111, -57, 17,
-29, -117, -37,
44, -109, 46,
44, -109, 46,
-29, -117, -37,
106, -4, -69,
106, -4, -69,
-29, -117, -37,
-67, 47, -96,
-67, 47, -96,
-29, -117, -37,
-111, -57, 17,
-1, -90, -88,
-40, -100, 65,
-24, -86, -89,
-24, -86, -89,
30, 37, -117,
-13, 82, -95,
-13, 82, -95,
30, 37, -117,
-105, 59, -38,
-105, 59, -38,
-40, -100, 65,
-1, -90, -88,
-40, -100, 65,
-12, -118, -43,
94, -80, -26,
94, -80, -26,
-12, -118, -43,
30, 37, -117,
30, 37, -117,
-12, -118, -43,
-124, 17, -18,
-124, 17, -18,
-12, -118, -43,
-40, -100, 65,
25, 40, 117,
27, 40, 117,
-83, 48, 82,
117, 24, 42,
27, 40, 117,
25, 40, 117,
81, -89, 39,
0, -79, -99,
14, -125, -9,
-73, -73, 73,
-33, -122, 3,
-55, -75, -85,
-73, -73, 73,
-8, -126, 0,
-33, -122, 3,
81, -89, 39,
14, -125, -9,
-8, -126, 0,
-73, -73, 73,
8, -101, 75,
-8, -126, 0,
117, 24, 42,
88, -82, 38,
126, 0, -1,
-112, 29, 50,
-78, -63, 77,
-83, 48, 82,
91, -77, 42,
117, -27, -39,
126, 0, -1,
-112, 29, 50,
-126, 2, 12,
-77, -59, 80,
-31, 10, 122,
-41, -55, 106,
27, 0, 123,
69, -68, 81,
23, 0, 124,
12, -63, 109,
20, 107, 64,
27, 40, 117,
56, 106, 38,
20, 107, 64,
56, 106, 38,
107, 65, 18,
20, 107, 64,
107, 65, 18,
75, 100, 18,
-14, 114, 53,
27, 40, 117,
20, 107, 64,
20, 107, 64,
-42, 111, 43,
-77, 83, 56,
20, 107, 64,
5, 125, -17,
-42, 111, 43,
25, 40, 117,
28, -79, 95,
10, -98, 79,
10, -98, 79,
-51, -70, 92,
-78, -63, 77,
-78, -63, 77,
-55, 27, 110,
-83, 48, 82,
-83, 48, 82,
45, 16, 117,
25, 40, 117,
88, -82, 38,
69, -80, 68,
10, -98, 79,
10, -98, 79,
-2, -76, 101,
25, 40, 117,
25, 40, 117,
10, 19, 125,
117, 24, 42,
117, 24, 42,
99, 12, 77,
88, -82, 38,
99, 12, 77,
69, -80, 68,
88, -82, 38,
10, 19, 125,
99, 12, 77,
117, 24, 42,
-2, -76, 101,
10, 19, 125,
25, 40, 117,
69, -80, 68,
-2, -76, 101,
10, -98, 79,
-83, 48, 82,
-55, 27, 110,
45, 16, 117,
-78, -63, 77,
-51, -70, 92,
-55, 27, 110,
10, -98, 79,
28, -79, 95,
-51, -70, 92,
25, 40, 117,
45, 16, 117,
28, -79, 95,
117, 24, 42,
56, 106, 38,
27, 40, 117,
27, 40, 117,
-14, 114, 53,
-83, 48, 82,
-105, 59, -38,
-124, 17, -18,
-40, -100, 65,
30, 37, -117,
-124, 17, -18,
-105, 59, -38,
-24, -86, -89,
94, -80, -26,
30, 37, -117,
-40, -100, 65,
94, -80, -26,
-24, -86, -89,
-67, 47, -96,
-111, -57, 17,
-24, -86, -89,
89, 36, -82,
106, -4, -69,
-67, 47, -96,
44, -109, 46,
106, -4, -69,
89, 36, -82,
-24, -86, -89,
-111, -57, 17,
44, -109, 46,
-1, -90, -88,
120, -29, -27,
-5, 50, -116,
55, -114, 1,
120, -29, -27,
-1, -90, -88,
-126, 2, 12,
-101, -73, 18,
55, -114, 1,
-105, 59, -38,
-5, 50, -116,
-101, -73, 18,
-31, 53, -110,
-124, 1, 25,
-53, -86, -75,
84, -92, -21,
-31, 53, -110,
89, 36, -82,
-69, -102, 28,
84, -92, -21,
117, -27, -39,
-53, -86, -75,
-124, 1, 25,
-69, -102, 28,
74, 14, -101,
-86, 48, -79,
0, -79, -99,
74, -102, 11,
74, 14, -101,
117, -27, -39,
-78, -99, 12,
74, -102, 11,
91, -77, 42,
0, -79, -99,
-86, 48, -79,
-78, -99, 12,
-77, -59, 80,
-80, -87, 45,
57, -112, -14,
-126, 2, 12,
-105, 35, -61,
-80, -87, 45,
-55, -75, -85,
54, 30, -110,
-105, 35, -61,
57, -112, -14,
54, 30, -110,
-55, -75, -85,
8, -101, 75,
-73, -73, 73,
-80, -97, -4,
5, 125, -17,
75, 100, 18,
97, 50, -63,
-102, 72, -18,
-42, 111, 43,
5, 125, -17,
-77, 83, 56,
-42, 111, 43,
-102, 72, -18,
-83, 48, 82,
-14, 114, 53,
-77, 83, 56,
107, 65, 18,
56, 106, 38,
117, 24, 42,
97, 50, -63,
75, 100, 18,
107, 65, 18,
-8, 96, -81,
97, 50, -63,
89, 36, -82,
-105, 59, -38,
-102, 72, -18,
-8, 96, -81,
-126, 2, 12,
-112, 29, 50,
-102, 72, -18,
-9, -126, 2,
10, -98, 79,
-78, -63, 77,
88, -82, 38,
10, -98, 79,
-9, -126, 2,
97, 50, -63,
126, 0, -1,
117, -27, -39,
0, -52, -115,
30, -77, -96,
-72, -71, -75,
30, -77, -96,
-7, -113, -57,
-72, -71, -75,
0, -52, -115,
-72, -71, -75,
-38, -44, -112,
51, -109, -37,
30, -77, -96,
0, -52, -115,
-38, -44, -112,
-72, -71, -75,
-80, -97, -4,
-96, 17, -80,
-109, 19, -61,
-38, -44, -112,
-21, 31, -121,
-2, 35, -122,
-109, 19, -61,
93, 4, -85,
-2, 35, -122,
-21, 31, -121,
0, -52, -115,
93, 4, -85,
54, -5, -114,
-96, 17, -80,
-122, -21, -28,
-55, -75, -85,
-21, 31, -121,
-96, 17, -80,
-1, -90, -88,
-53, -86, -75,
54, -5, -114,
-21, 31, -121,
0, -79, -99,
87, -48, -77,
54, -5, -114,
-9, -126, 2,
-8, -126, 0,
14, -125, -9,
-9, -126, 2,
-77, -59, 80,
-33, -122, 3,
8, -101, 75,
81, -89, 39,
-8, -126, 0,
-2, -76, 101,
78, -2, 99,
10, 19, 125,
10, 19, 125,
12, -63, 109,
99, 12, 77,
99, 12, 77,
12, -63, 109,
69, -80, 68,
69, -80, 68,
78, -2, 99,
-2, -76, 101,
45, 16, 117,
-31, 10, 122,
28, -79, 95,
28, -79, 95,
-31, 10, 122,
-51, -70, 92,
-51, -70, 92,
21, -64, 106,
-55, 27, 110,
-55, 27, 110,
21, -64, 106,
45, 16, 117,
21, -64, 106,
-41, -55, 106,
45, 16, 117,
-51, -70, 92,
27, 0, 123,
21, -64, 106,
-31, 10, 122,
27, 0, 123,
-51, -70, 92,
45, 16, 117,
-41, -55, 106,
-31, 10, 122,
69, -80, 68,
23, 0, 124,
78, -2, 99,
12, -63, 109,
23, 0, 124,
69, -80, 68,
10, 19, 125,
69, -68, 81,
12, -63, 109,
78, -2, 99,
69, -68, 81,
10, 19, 125,
69, -68, 81,
78, -2, 99,
23, 0, 124,
-41, -55, 106,
21, -64, 106,
27, 0, 123,
51, -109, -37,
81, -89, 39,
8, -101, 75,
58, -48, 101,
-14, 50, 115,
-58, -48, 101,
93, 21, -83,
-93, 21, -83,
85, 53, -77,
15, 50, 115,
31, 110, 53,
-14, 50, 115,
-14, 50, 115,
-29, 123, -5,
-48, 109, -42,
-48, 109, -42,
29, 123, -5,
48, 109, -42,
48, 109, -42,
29, 123, -5,
15, 50, 115,
83, -24, 92,
93, 21, -83,
85, 53, -77,
-83, -24, 92,
83, -84, 45,
83, -24, 92,
-85, 53, -77,
-93, 21, -83,
-83, -24, 92,
-65, 40, -101,
-48, 109, -42,
65, 40, -101,
-93, 21, -83,
-83, -84, 45,
-83, -24, 92,
-83, -24, 92,
-83, -84, 45,
83, -84, 45,
83, -24, 92,
83, -84, 45,
93, 21, -83,
29, 123, -5,
-31, 110, 53,
15, 50, 115,
-48, 109, -42,
-29, 123, -5,
29, 123, -5,
-14, 50, 115,
31, 110, 53,
-29, 123, -5,
15, 50, 115,
-31, 110, 53,
31, 110, 53,
-93, 21, -83,
-85, 53, -77,
85, 53, -77,
31, 110, 53,
0, -52, -115,
-38, -44, -112,
-31, 110, 53,
93, 4, -85,
0, -52, -115,
29, 123, -5,
-2, 35, -122,
93, 4, -85,
-29, 123, -5,
-109, 19, -61,
-2, 35, -122,
31, 110, 53,
-38, -44, -112,
-109, 19, -61,
29, 123, -5,
-29, 123, -5,
-2, 35, -122,
-29, 123, -5,
31, 110, 53,
-109, 19, -61,
58, -48, 101,
85, 53, -77,
65, 40, -101,
-58, -48, 101,
83, -24, 92,
58, -48, 101,
65, 40, -101,
-85, 53, -77,
-65, 40, -101,
-65, 40, -101,
-85, 53, -77,
-58, -48, 101,
-99, -46, 64,
93, -58, 62,
-50, 45, 107,
42, -41, -112,
-99, 29, -73,
91, 13, -87,
42, -116, 25,
42, -41, -112,
93, -58, 62,
-99, 29, -73,
-50, 45, 107,
-68, 106, -2,
-99, 29, -73,
-99, -46, 64,
-50, 45, 107,
42, -41, -112,
91, 13, -87,
93, -58, 62,
-99, 29, -73,
-68, 106, -2,
91, 13, -87,
-99, -46, 64,
42, -116, 25,
93, -58, 62,
-50, 45, 107,
-58, -48, 101,
-14, 50, 115,
93, -58, 62,
-65, 40, -101,
-58, -48, 101,
91, 13, -87,
-68, 106, -2,
-65, 40, -101,
-68, 106, -2,
-14, 50, 115,
-48, 109, -42,
50, 45, 107,
-93, -58, 62,
99, -46, 64,
-91, 13, -87,
99, 29, -73,
-42, -41, -112,
-93, -58, 62,
-42, -41, -112,
-42, -116, 25,
68, 107, -2,
50, 45, 107,
99, 29, -73,
50, 45, 107,
99, -46, 64,
99, 29, -73,
-93, -58, 62,
-91, 13, -87,
-42, -41, -112,
-91, 13, -87,
68, 107, -2,
99, 29, -73,
-93, -58, 62,
-42, -116, 25,
99, -46, 64,
50, 45, 107,
48, 109, -42,
15, 50, 115,
68, 107, -2,
65, 40, -101,
48, 109, -42,
-91, 13, -87,
-93, -58, 62,
65, 40, -101,
-93, -58, 62,
50, 45, 107,
58, -48, 101,
68, 107, -2,
48, 109, -42,
50, 45, 107,
-14, 50, 115,
-68, 106, -2,
-50, 45, 107,
112, -56, 18,
-69, -98, 38,
118, 22, 39,
97, -6, -81,
62, -27, -107,
-97, -6, -81,
-97, -6, -81,
118, 22, 39,
97, -6, -81,
-97, -6, -81,
112, -56, 18,
118, 22, 39,
-62, -27, -107,
-69, -98, 38,
-93, 21, -83,
-69, -98, 38,
83, -84, 45,
-83, -84, 45,
59, -107, 33,
93, 21, -83,
83, -84, 45,
62, -27, -107,
-93, 21, -83,
93, 21, -83,
-78, 0, 99,
72, -2, 103,
-91, 84, 25,
73, -103, -7,
-88, -32, -85,
89, -26, -85,
72, -2, 103,
73, -103, -7,
84, 93, 11,
-78, -99, -10,
-91, 84, 25,
-88, -32, -85,
-78, -99, -10,
-78, 0, 99,
-91, 84, 25,
73, -103, -7,
89, -26, -85,
84, 93, 11,
73, -103, -7,
-78, -99, -10,
-88, -32, -85,
72, -2, 103,
84, 93, 11,
-91, 84, 25,
-91, 84, 25,
84, 93, 11,
-69, -98, 38,
84, 93, 11,
89, -26, -85,
118, 22, 39,
89, -26, -85,
-62, -27, -107,
97, -6, -81,
-88, -32, -85,
-69, -98, 38,
-62, -27, -107,
87, 87, 25,
-73, -1, 103,
78, 0, 99,
-88, -27, -86,
88, -32, -85,
-73, -103, -7,
-64, 105, -29,
-73, -103, -7,
-73, -1, 103,
88, -32, -85,
87, 87, 25,
78, -99, -10,
87, 87, 25,
78, 0, 99,
78, -99, -10,
-64, 105, -29,
-88, -27, -86,
-73, -103, -7,
88, -32, -85,
78, -99, -10,
-73, -103, -7,
87, 87, 25,
-64, 105, -29,
-73, -1, 103,
87, 87, 25,
88, -32, -85,
59, -107, 33,
-88, -27, -86,
-97, -6, -81,
62, -27, -107,
-88, -27, -86,
112, -56, 18,
-97, -6, -81,
-64, 105, -29,
59, -107, 33,
112, -56, 18,
-42, -41, -112,
38, -85, -85,
-42, -116, 25,
-42, -116, 25,
94, -84, -5,
99, -46, 64,
99, -46, 64,
94, -84, -5,
99, 29, -73,
99, 29, -73,
94, -50, -68,
-42, -41, -112,
42, -116, 25,
-38, -118, -26,
42, -41, -112,
42, -41, -112,
-94, -50, -68,
-99, 29, -73,
-99, 29, -73,
-94, -50, -68,
-99, -46, 64,
-99, -46, 64,
-94, -84, -5,
42, -116, 25,
-75, -93, 41,
80, 9, 97,
38, -118, -26,
80, 9, 97,
94, -50, -68,
94, -84, -5,
80, 87, -44,
38, -85, -85,
94, -50, -68,
-75, -15, -101,
-75, -93, 41,
38, -85, -85,
-80, 9, 97,
-38, -118, -26,
-94, -84, -5,
75, -15, -101,
-94, -50, -68,
-38, -85, -85,
-80, 87, -44,
-80, 9, 97,
-94, -50, -68,
-38, -85, -85,
-38, -118, -26,
75, -15, -101,
-99, -34, 70,
71, -82, 64,
-57, 4, 113,
33, -32, -117,
-92, 47, -72,
81, 14, -96,
31, -120, 23,
33, -32, -117,
71, -82, 64,
-92, 47, -72,
-57, 4, 113,
-53, 105, -45,
-92, 47, -72,
-99, -34, 70,
-57, 4, 113,
33, -32, -117,
81, 14, -96,
71, -82, 64,
-92, 47, -72,
-53, 105, -45,
81, 14, -96,
-99, -34, 70,
31, -120, 23,
71, -82, 64,
33, -32, -117,
-72, -94, -44,
-92, 47, -72,
-92, 47, -72,
-72, -94, -44,
-99, -34, 70,
-99, -34, 70,
-72, -94, -44,
31, -120, 23,
31, -120, 23,
-72, -94, -44,
33, -32, -117,
81, 14, -96,
-80, 87, -44,
75, -15, -101,
-53, 105, -45,
-57, 4, 113,
-80, 87, -44,
-57, 4, 113,
71, -82, 64,
-80, 9, 97,
71, -82, 64,
81, 14, -96,
75, -93, 41,
73, -103, -7,
-26, -106, 63,
-78, -99, -10,
-78, -99, -10,
-26, -106, 63,
-78, 0, 99,
-78, 0, 99,
-33, -69, 100,
72, -2, 103,
72, -2, 103,
35, -66, 102,
73, -103, -7,
-73, -1, 103,
-35, -66, 102,
78, 0, 99,
78, 0, 99,
26, -106, 63,
78, -99, -10,
78, -99, -10,
26, -106, 63,
-73, -103, -7,
-73, -103, -7,
-35, -66, 102,
-73, -1, 103,
89, 29, 84,
75, 40, 94,
-89, 29, 84,
-88, -25, -87,
-99, -57, -54,
88, -25, -87,
-78, 42, 90,
-99, -57, -54,
-89, 29, 84,
96, -63, -51,
75, 40, 94,
88, -25, -87,
89, 29, 84,
49, 112, 31,
88, -25, -87,
88, -25, -87,
73, 13, -102,
-88, -25, -87,
-88, -25, -87,
-97, 77, 22,
-89, 29, 84,
-89, 29, 84,
-97, 77, 22,
89, 29, 84,
-97, 77, 22,
49, 112, 31,
89, 29, 84,
-88, -25, -87,
-89, -9, -89,
-97, 77, 22,
73, 13, -102,
-89, -9, -89,
-88, -25, -87,
49, 112, 31,
73, 13, -102,
88, -25, -87,
75, 40, 94,
89, 29, 84,
88, -25, -87,
-99, -57, -54,
-88, -25, -87,
-89, 29, 84,
-99, -57, -54,
96, -63, -51,
88, -25, -87,
75, 40, 94,
-78, 42, 90,
-89, 29, 84,
-99, -57, -54,
-35, -66, 102,
-27, -108, 60,
-78, 42, 90,
75, 40, 94,
-35, -66, 102,
75, 40, 94,
96, -63, -51,
33, -69, 100,
96, -63, -51,
-27, -108, 60,
26, -106, 63,
89, 29, 84,
-75, 40, 94,
-89, 29, 84,
-88, -25, -87,
99, -57, -54,
88, -25, -87,
89, 29, 84,
99, -57, -54,
78, 42, 90,
-88, -25, -87,
-75, 40, 94,
-96, -63, -51,
-88, -25, -87,
-49, 112, 31,
-89, 29, 84,
88, -25, -87,
-73, 13, -102,
-88, -25, -87,
89, 29, 84,
97, 77, 22,
88, -25, -87,
-89, 29, 84,
97, 77, 22,
89, 29, 84,
-89, 29, 84,
-49, 112, 31,
97, 77, 22,
97, 77, 22,
89, -9, -89,
88, -25, -87,
88, -25, -87,
89, -9, -89,
-73, 13, -102,
-88, -25, -87,
-73, 13, -102,
-49, 112, 31,
-88, -25, -87,
-89, 29, 84,
-75, 40, 94,
89, 29, 84,
88, -25, -87,
99, -57, -54,
-88, -25, -87,
-96, -63, -51,
99, -57, -54,
89, 29, 84,
78, 42, 90,
-75, 40, 94,
-75, 40, 94,
35, -66, 102,
-33, -69, 100,
78, 42, 90,
99, -57, -54,
35, -66, 102,
99, -57, -54,
-96, -63, -51,
27, -108, 60,
-96, -63, -51,
-33, -69, 100,
-26, -106, 63,
86, -83, -39,
-53, -97, -61,
88, -3, -90,
-64, 109, -2,
95, 81, -17,
-91, 69, -54,
99, -67, 40,
77, -49, 87,
-93, -85, -2,
77, -49, 87,
95, 81, -17,
61, 109, 17,
-93, -85, -2,
-101, -51, 56,
-91, 69, -54,
61, 109, 17,
-18, 20, 123,
77, -49, 87,
77, -49, 87,
-18, 20, 123,
-101, -51, 56,
-101, -51, 56,
-18, 20, 123,
-64, 109, -2,
-64, 109, -2,
-18, 20, 123,
61, 109, 17,
99, -67, 40,
86, -83, -39,
95, 81, -17,
-93, -85, -2,
-53, -97, -61,
99, -67, 40,
-91, 69, -54,
-56, -8, -113,
-93, -85, -2,
-56, -8, -113,
-53, -97, -61,
-93, -85, -2,
-53, -97, -61,
86, -83, -39,
99, -67, 40,
86, -83, -39,
88, -3, -90,
95, 81, -17,
-101, -51, 56,
-64, 109, -2,
-91, 69, -54,
77, -49, 87,
99, -67, 40,
95, 81, -17,
77, -49, 87,
-101, -51, 56,
-93, -85, -2,
-64, 109, -2,
61, 109, 17,
95, 81, -17,
-53, -97, -61,
-56, -8, -113,
88, -3, -90,
95, 81, -17,
88, -3, -90,
97, 77, 22,
88, -3, -90,
-56, -8, -113,
89, -9, -89,
-56, -8, -113,
-91, 69, -54,
-73, 13, -102,
-91, 69, -54,
95, 81, -17,
-49, 112, 31,
-88, -3, -90,
53, -97, -61,
-86, -83, -39,
91, 69, -54,
-95, 81, -17,
64, 109, -2,
93, -85, -2,
-77, -49, 87,
-99, -67, 40,
-61, 109, 17,
-95, 81, -17,
-77, -49, 87,
91, 69, -54,
101, -51, 56,
93, -85, -2,
-77, -49, 87,
18, 20, 123,
-61, 109, 17,
101, -51, 56,
18, 20, 123,
-77, -49, 87,
64, 109, -2,
18, 20, 123,
101, -51, 56,
-61, 109, 17,
18, 20, 123,
64, 109, -2,
-95, 81, -17,
-86, -83, -39,
-99, -67, 40,
-99, -67, 40,
53, -97, -61,
93, -85, -2,
93, -85, -2,
56, -8, -113,
91, 69, -54,
93, -85, -2,
53, -97, -61,
56, -8, -113,
-99, -67, 40,
-86, -83, -39,
53, -97, -61,
-95, 81, -17,
-88, -3, -90,
-86, -83, -39,
91, 69, -54,
64, 109, -2,
101, -51, 56,
-95, 81, -17,
-99, -67, 40,
-77, -49, 87,
93, -85, -2,
101, -51, 56,
-77, -49, 87,
-95, 81, -17,
-61, 109, 17,
64, 109, -2,
-88, -3, -90,
56, -8, -113,
53, -97, -61,
-95, 81, -17,
49, 112, 31,
-97, 77, 22,
91, 69, -54,
73, 13, -102,
49, 112, 31,
56, -8, -113,
-89, -9, -89,
73, 13, -102,
-88, -3, -90,
-97, 77, 22,
-89, -9, -89,
62, -27, -107,
88, -32, -85,
-88, -27, -86,
89, -26, -85,
-88, -32, -85,
-62, -27, -107,
80, 87, -44,
-81, 14, -96,
-75, -15, -101,
-75, -15, -101,
-71, -82, 64,
-75, -93, 41,
80, 9, 97,
53, 105, -45,
80, 87, -44,
57, 4, 113,
-71, -82, 64,
99, -34, 70,
-81, 14, -96,
92, 47, -72,
-33, -32, -117,
-71, -82, 64,
-33, -32, -117,
-31, -120, 23,
53, 105, -45,
57, 4, 113,
92, 47, -72,
57, 4, 113,
99, -34, 70,
92, 47, -72,
-71, -82, 64,
-81, 14, -96,
-33, -32, -117,
-81, 14, -96,
53, 105, -45,
92, 47, -72,
-71, -82, 64,
-31, -120, 23,
99, -34, 70,
92, 47, -72,
72, -94, -44,
-33, -32, -117,
99, -34, 70,
72, -94, -44,
92, 47, -72,
-31, -120, 23,
72, -94, -44,
99, -34, 70,
-33, -32, -117,
72, -94, -44,
-31, -120, 23,
-75, -93, 41,
-71, -82, 64,
80, 9, 97,
-71, -82, 64,
57, 4, 113,
80, 9, 97,
80, 9, 97,
57, 4, 113,
53, 105, -45,
-75, -15, -101,
-81, 14, -96,
-71, -82, 64,
80, 87, -44,
53, 105, -45,
-81, 14, -96,
-88, -3, -90,
-95, 81, -17,
-97, 77, 22,
56, -8, -113,
-88, -3, -90,
-89, -9, -89,
91, 69, -54,
56, -8, -113,
73, 13, -102,
-95, 81, -17,
91, 69, -54,
49, 112, 31,
95, 81, -17,
97, 77, 22,
-49, 112, 31,
-91, 69, -54,
-49, 112, 31,
-73, 13, -102,
-56, -8, -113,
-73, 13, -102,
89, -9, -89,
88, -3, -90,
89, -9, -89,
97, 77, 22,
-96, -63, -51,
-75, 40, 94,
-33, -69, 100,
-96, -63, -51,
-26, -106, 63,
27, -108, 60,
99, -57, -54,
27, -108, 60,
35, -66, 102,
-75, 40, 94,
78, 42, 90,
35, -66, 102,
96, -63, -51,
-99, -57, -54,
-27, -108, 60,
96, -63, -51,
26, -106, 63,
33, -69, 100,
75, 40, 94,
33, -69, 100,
-35, -66, 102,
-99, -57, -54,
-78, 42, 90,
-35, -66, 102,
-73, -103, -7,
-27, -108, 60,
-35, -66, 102,
26, -106, 63,
-27, -108, 60,
-73, -103, -7,
78, 0, 99,
33, -69, 100,
26, -106, 63,
-35, -66, 102,
33, -69, 100,
78, 0, 99,
35, -66, 102,
27, -108, 60,
73, -103, -7,
-33, -69, 100,
35, -66, 102,
72, -2, 103,
-26, -106, 63,
-33, -69, 100,
-78, 0, 99,
73, -103, -7,
27, -108, 60,
-26, -106, 63,
81, 14, -96,
75, -15, -101,
75, -93, 41,
71, -82, 64,
75, -93, 41,
-80, 9, 97,
-57, 4, 113,
-80, 9, 97,
-80, 87, -44,
81, 14, -96,
-53, 105, -45,
-80, 87, -44,
-38, -118, -26,
75, -93, 41,
75, -15, -101,
-80, 9, 97,
-94, -84, -5,
-94, -50, -68,
75, -15, -101,
-80, 87, -44,
-94, -50, -68,
-80, 9, 97,
75, -93, 41,
-38, -118, -26,
-75, -93, 41,
38, -118, -26,
38, -85, -85,
80, 87, -44,
-75, -15, -101,
38, -85, -85,
80, 9, 97,
80, 87, -44,
94, -50, -68,
80, 9, 97,
94, -84, -5,
38, -118, -26,
-94, -84, -5,
-38, -118, -26,
42, -116, 25,
-94, -50, -68,
-94, -84, -5,
-99, -46, 64,
42, -41, -112,
-38, -85, -85,
-94, -50, -68,
-38, -118, -26,
-38, -85, -85,
42, -41, -112,
94, -50, -68,
38, -85, -85,
-42, -41, -112,
94, -84, -5,
94, -50, -68,
99, 29, -73,
-42, -116, 25,
38, -118, -26,
94, -84, -5,
38, -85, -85,
38, -118, -26,
-42, -116, 25,
-64, 105, -29,
87, 87, 25,
59, -107, 33,
-88, -27, -86,
-64, 105, -29,
112, -56, 18,
88, -32, -85,
62, -27, -107,
59, -107, 33,
-88, -32, -85,
-91, 84, 25,
-69, -98, 38,
89, -26, -85,
97, -6, -81,
118, 22, 39,
84, 93, 11,
118, 22, 39,
-69, -98, 38,
62, -27, -107,
-62, -27, -107,
-93, 21, -83,
59, -107, 33,
62, -27, -107,
93, 21, -83,
-69, -98, 38,
59, -107, 33,
83, -84, 45,
-69, -98, 38,
-83, -84, 45,
-93, 21, -83,
97, -6, -81,
-62, -27, -107,
62, -27, -107,
112, -56, 18,
59, -107, 33,
-69, -98, 38,
50, 45, 107,
15, 50, 115,
58, -48, 101,
-93, -58, 62,
58, -48, 101,
65, 40, -101,
68, 107, -2,
-91, 13, -87,
65, 40, -101,
-68, 106, -2,
-48, 109, -42,
-65, 40, -101,
93, -58, 62,
91, 13, -87,
-65, 40, -101,
-50, 45, 107,
93, -58, 62,
-58, -48, 101,
-85, 53, -77,
-83, -24, 92,
-58, -48, 101,
65, 40, -101,
85, 53, -77,
-85, 53, -77,
-58, -48, 101,
-83, -24, 92,
83, -24, 92,
58, -48, 101,
83, -24, 92,
85, 53, -77,
-31, 110, 53,
29, 123, -5,
93, 4, -85,
31, 110, 53,
-31, 110, 53,
0, -52, -115,
-48, 109, -42,
48, 109, -42,
65, 40, -101,
58, -48, 101,
15, 50, 115,
-14, 50, 115,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:16 */
static s8 vtxnvgrp_frake_select_16[]={
-33, -122, 8,
-9, -126, 5,
-10, -126, 6,
-10, -126, 6,
13, -126, -6,
92, -77, 40,
-5, -81, -97,
49, -10, -116,
-59, -88, -69,
-59, -88, -69,
-26, 28, -120,
-29, -89, -85,
-29, -89, -85,
-26, 28, -120,
-7, -93, -85,
-7, -93, -85,
-100, 17, -75,
-61, -76, -80,
-61, -76, -80,
-123, -18, -21,
-82, -96, 2,
-5, -81, -97,
81, -89, 38,
48, -111, -36,
83, -53, -79,
-3, -56, -113,
49, -10, -116,
49, -10, -116,
91, 0, -87,
-26, 28, -120,
-26, 28, -120,
-110, 19, -59,
-100, 17, -75,
-100, 17, -75,
-43, -45, -110,
-123, -18, -21,
-123, -18, -21,
-43, -45, -110,
-82, -96, 2,
-82, -96, 2,
-76, -73, -70,
-9, -116, -50,
-9, -116, -50,
26, -80, -94,
48, -111, -36,
48, -111, -36,
-3, -56, -113,
83, -53, -79,
24, 108, 60,
-73, 86, 56,
-10, 116, 50,
85, 30, -88,
95, 45, -69,
115, -31, -43,
126, -2, -7,
89, -82, 36,
92, -77, 40,
92, -77, 40,
89, -82, 36,
-10, -126, 6,
-10, -126, 6,
-75, -59, 83,
-74, -55, 86,
-74, -55, 86,
-75, -59, 83,
-109, 34, 54,
-125, 6, 17,
-101, 74, -16,
-106, 60, -35,
-106, 60, -35,
-11, 94, -84,
-17, 79, -97,
-17, 79, -97,
-11, 94, -84,
85, 30, -88,
95, 45, -69,
109, 63, 12,
126, -2, -7,
126, -2, -7,
109, 63, 12,
119, 22, 37,
-78, 53, 84,
-73, 86, 56,
-109, 34, 54,
-109, 34, 54,
-73, 86, 56,
-101, 74, -16,
-101, 74, -16,
6, 124, -21,
-11, 94, -84,
-11, 94, -84,
6, 124, -21,
95, 45, -69,
78, 99, 11,
6, 124, -21,
24, 108, 60,
48, -111, -36,
83, -53, -79,
-5, -81, -97,
-82, -96, 2,
-71, -69, 78,
-61, -76, -80,
-9, -116, -50,
48, -111, -36,
-82, -96, 2,
48, -111, -36,
10, -99, 78,
-82, -96, 2,
-33, -122, 8,
55, -113, -13,
-61, -76, -80,
-61, -76, -80,
-107, 36, -57,
-125, 6, 17,
-125, 6, 17,
-79, -84, 52,
-74, -55, 86,
-74, -55, 86,
55, -113, -13,
-33, -122, 8,
55, -113, -13,
-43, -72, -95,
49, 25, -114,
49, 25, -114,
-43, -72, -95,
-107, 36, -57,
-107, 36, -57,
-43, -72, -95,
-79, -84, 52,
-79, -84, 52,
-43, -72, -95,
55, -113, -13,
-5, -81, -97,
-79, -97, 19,
13, -126, -6,
13, -126, -6,
-79, -97, 19,
92, -77, 40,
92, -77, 40,
73, -103, 11,
115, -31, -43,
115, -31, -43,
69, 8, -105,
-5, -81, -97,
-89, 47, -76,
-31, -72, -99,
-79, -97, 19,
-79, -97, 19,
-31, -72, -99,
73, -103, 11,
73, -103, 11,
-31, -72, -99,
69, 8, -105,
69, 8, -105,
-31, -72, -99,
-89, 47, -76,
-59, -88, -69,
-69, -100, 34,
-5, -81, -97,
-5, -81, -97,
-69, -100, 34,
115, -31, -43,
115, -31, -43,
81, -94, -22,
85, 30, -88,
85, 30, -88,
-34, 50, -111,
-59, -88, -69,
-123, 5, 31,
-53, -68, -92,
-69, -100, 34,
-69, -100, 34,
-53, -68, -92,
81, -94, -22,
81, -94, -22,
-53, -68, -92,
-34, 50, -111,
-34, 50, -111,
-53, -68, -92,
-123, 5, 31,
-106, 60, -35,
-101, -71, 25,
-125, 6, 17,
-125, 6, 17,
53, -115, 2,
-61, -76, -80,
-61, -76, -80,
53, -115, 2,
-7, -93, -85,
-7, -93, -85,
-9, 46, -117,
-106, 60, -35,
-9, 46, -117,
-20, -71, -102,
-101, -71, 25,
-101, -71, 25,
-20, -71, -102,
53, -115, 2,
53, -115, 2,
-20, -71, -102,
118, -34, -32,
118, -34, -32,
-20, -71, -102,
-9, 46, -117,
-29, -89, -85,
44, -109, 47,
-59, -88, -69,
-59, -88, -69,
44, -109, 47,
85, 30, -88,
85, 30, -88,
-71, 45, -94,
-17, 79, -97,
-17, 79, -97,
-71, 45, -94,
-29, -89, -85,
-112, -54, 24,
-33, -118, -32,
44, -109, 47,
44, -109, 47,
-33, -118, -32,
102, -8, -74,
102, -8, -74,
-33, -118, -32,
-71, 45, -94,
-71, 45, -94,
-33, -118, -32,
-112, -54, 24,
-7, -93, -85,
-39, -97, 70,
-29, -89, -85,
-29, -89, -85,
25, 33, -119,
-17, 79, -97,
-17, 79, -97,
25, 33, -119,
-106, 60, -35,
-106, 60, -35,
-39, -97, 70,
-7, -93, -85,
-39, -97, 70,
-16, -119, -39,
91, -83, -28,
91, -83, -28,
-16, -119, -39,
25, 33, -119,
25, 33, -119,
-16, -119, -39,
-124, 19, -13,
-124, 19, -13,
-16, -119, -39,
-39, -97, 70,
30, 44, 115,
33, 43, 114,
-78, 53, 84,
119, 22, 37,
33, 43, 114,
30, 44, 115,
81, -89, 38,
-5, -81, -97,
13, -126, -6,
-71, -69, 78,
-33, -122, 8,
-61, -76, -80,
-71, -69, 78,
-9, -126, 5,
-33, -122, 8,
81, -89, 38,
13, -126, -6,
-9, -126, 5,
-71, -69, 78,
10, -99, 78,
-9, -126, 5,
119, 22, 37,
89, -82, 36,
126, -2, -7,
-109, 34, 54,
-75, -59, 83,
-78, 53, 84,
92, -77, 40,
115, -31, -43,
126, -2, -7,
-109, 34, 54,
-125, 6, 17,
-74, -55, 86,
-25, 15, 123,
-37, -51, 109,
33, 4, 122,
72, -66, 80,
29, 4, 123,
16, -60, 110,
24, 108, 60,
33, 43, 114,
60, 107, 32,
24, 108, 60,
60, 107, 32,
109, 63, 12,
24, 108, 60,
109, 63, 12,
78, 99, 11,
-10, 116, 50,
33, 43, 114,
24, 108, 60,
24, 108, 60,
-38, 113, 41,
-73, 86, 56,
24, 108, 60,
6, 124, -21,
-38, 113, 41,
30, 44, 115,
31, -76, 96,
13, -96, 81,
13, -96, 81,
-48, -66, 97,
-75, -59, 83,
-75, -59, 83,
-50, 31, 112,
-78, 53, 84,
-78, 53, 84,
51, 19, 114,
30, 44, 115,
89, -82, 36,
71, -79, 68,
13, -96, 81,
13, -96, 81,
0, -73, 103,
30, 44, 115,
30, 44, 115,
16, 22, 123,
119, 22, 37,
119, 22, 37,
103, 13, 72,
89, -82, 36,
103, 13, 72,
71, -79, 68,
89, -82, 36,
16, 22, 123,
103, 13, 72,
119, 22, 37,
0, -73, 103,
16, 22, 123,
30, 44, 115,
71, -79, 68,
0, -73, 103,
13, -96, 81,
-78, 53, 84,
-50, 31, 112,
51, 19, 114,
-75, -59, 83,
-48, -66, 97,
-50, 31, 112,
13, -96, 81,
31, -76, 96,
-48, -66, 97,
30, 44, 115,
51, 19, 114,
31, -76, 96,
119, 22, 37,
60, 107, 32,
33, 43, 114,
33, 43, 114,
-10, 116, 50,
-78, 53, 84,
-106, 60, -35,
-124, 19, -13,
-39, -97, 70,
25, 33, -119,
-124, 19, -13,
-106, 60, -35,
-29, -89, -85,
91, -83, -28,
25, 33, -119,
-39, -97, 70,
91, -83, -28,
-29, -89, -85,
-71, 45, -94,
-112, -54, 24,
-29, -89, -85,
85, 30, -88,
102, -8, -74,
-71, 45, -94,
44, -109, 47,
102, -8, -74,
85, 30, -88,
-29, -89, -85,
-112, -54, 24,
44, -109, 47,
-7, -93, -85,
118, -34, -32,
-9, 46, -117,
53, -115, 2,
118, -34, -32,
-7, -93, -85,
-125, 6, 17,
-101, -71, 25,
53, -115, 2,
-106, 60, -35,
-9, 46, -117,
-101, -71, 25,
-34, 50, -111,
-123, 5, 31,
-59, -88, -69,
81, -94, -22,
-34, 50, -111,
85, 30, -88,
-69, -100, 34,
81, -94, -22,
115, -31, -43,
-59, -88, -69,
-123, 5, 31,
-69, -100, 34,
69, 8, -105,
-89, 47, -76,
-5, -81, -97,
73, -103, 11,
69, 8, -105,
115, -31, -43,
-79, -97, 19,
73, -103, 11,
92, -77, 40,
-5, -81, -97,
-89, 47, -76,
-79, -97, 19,
-74, -55, 86,
-79, -84, 52,
55, -113, -13,
-125, 6, 17,
-107, 36, -57,
-79, -84, 52,
-61, -76, -80,
49, 25, -114,
-107, 36, -57,
55, -113, -13,
49, 25, -114,
-61, -76, -80,
10, -99, 78,
-71, -69, 78,
-82, -96, 2,
6, 124, -21,
78, 99, 11,
95, 45, -69,
-101, 74, -16,
-38, 113, 41,
6, 124, -21,
-73, 86, 56,
-38, 113, 41,
-101, 74, -16,
-78, 53, 84,
-10, 116, 50,
-73, 86, 56,
109, 63, 12,
60, 107, 32,
119, 22, 37,
95, 45, -69,
78, 99, 11,
109, 63, 12,
-11, 94, -84,
95, 45, -69,
85, 30, -88,
-106, 60, -35,
-101, 74, -16,
-11, 94, -84,
-125, 6, 17,
-109, 34, 54,
-101, 74, -16,
-10, -126, 6,
13, -96, 81,
-75, -59, 83,
89, -82, 36,
13, -96, 81,
-10, -126, 6,
95, 45, -69,
126, -2, -7,
115, -31, -43,
-3, -56, -113,
26, -80, -94,
-76, -73, -70,
26, -80, -94,
-9, -116, -50,
-76, -73, -70,
-3, -56, -113,
-76, -73, -70,
-43, -45, -110,
48, -111, -36,
26, -80, -94,
-3, -56, -113,
-43, -45, -110,
-76, -73, -70,
-82, -96, 2,
-100, 17, -75,
-110, 19, -59,
-43, -45, -110,
-26, 28, -120,
-2, 32, -122,
-110, 19, -59,
91, 0, -87,
-2, 32, -122,
-26, 28, -120,
-3, -56, -113,
91, 0, -87,
49, -10, -116,
-100, 17, -75,
-123, -18, -21,
-61, -76, -80,
-26, 28, -120,
-100, 17, -75,
-7, -93, -85,
-59, -88, -69,
49, -10, -116,
-26, 28, -120,
-5, -81, -97,
83, -53, -79,
49, -10, -116,
-10, -126, 6,
-9, -126, 5,
13, -126, -6,
-10, -126, 6,
-74, -55, 86,
-33, -122, 8,
10, -99, 78,
81, -89, 38,
-9, -126, 5,
0, -73, 103,
82, -1, 96,
16, 22, 123,
16, 22, 123,
16, -60, 110,
103, 13, 72,
103, 13, 72,
16, -60, 110,
71, -79, 68,
71, -79, 68,
82, -1, 96,
0, -73, 103,
51, 19, 114,
-25, 15, 123,
31, -76, 96,
31, -76, 96,
-25, 15, 123,
-48, -66, 97,
-48, -66, 97,
25, -61, 107,
-50, 31, 112,
-50, 31, 112,
25, -61, 107,
51, 19, 114,
25, -61, 107,
-37, -51, 109,
51, 19, 114,
-48, -66, 97,
33, 4, 122,
25, -61, 107,
-25, 15, 123,
33, 4, 122,
-48, -66, 97,
51, 19, 114,
-37, -51, 109,
-25, 15, 123,
71, -79, 68,
29, 4, 123,
82, -1, 96,
16, -60, 110,
29, 4, 123,
71, -79, 68,
16, 22, 123,
72, -66, 80,
16, -60, 110,
82, -1, 96,
72, -66, 80,
16, 22, 123,
72, -66, 80,
82, -1, 96,
29, 4, 123,
-37, -51, 109,
25, -61, 107,
33, 4, 122,
48, -111, -36,
81, -89, 38,
10, -99, 78,
58, -47, 102,
-14, 52, 114,
-58, -47, 102,
93, 20, -83,
-93, 20, -83,
85, 52, -77,
15, 52, 114,
30, 112, 50,
-14, 52, 114,
-14, 52, 114,
-29, 123, -7,
-48, 109, -43,
-48, 109, -43,
29, 123, -7,
48, 109, -43,
48, 109, -43,
29, 123, -7,
15, 52, 114,
83, -23, 92,
93, 20, -83,
85, 52, -77,
-83, -23, 92,
83, -83, 46,
83, -23, 92,
-85, 52, -77,
-93, 20, -83,
-83, -23, 92,
-65, 39, -101,
-48, 109, -43,
65, 39, -101,
-93, 20, -83,
-83, -83, 46,
-83, -23, 92,
-83, -23, 92,
-83, -83, 46,
83, -83, 46,
83, -23, 92,
83, -83, 46,
93, 20, -83,
29, 123, -7,
-30, 112, 50,
15, 52, 114,
-48, 109, -43,
-29, 123, -7,
29, 123, -7,
-14, 52, 114,
30, 112, 50,
-29, 123, -7,
15, 52, 114,
-30, 112, 50,
30, 112, 50,
-93, 20, -83,
-85, 52, -77,
85, 52, -77,
30, 112, 50,
-3, -56, -113,
-43, -45, -110,
-30, 112, 50,
91, 0, -87,
-3, -56, -113,
29, 123, -7,
-2, 32, -122,
91, 0, -87,
-29, 123, -7,
-110, 19, -59,
-2, 32, -122,
30, 112, 50,
-43, -45, -110,
-110, 19, -59,
29, 123, -7,
-29, 123, -7,
-2, 32, -122,
-29, 123, -7,
30, 112, 50,
-110, 19, -59,
58, -47, 102,
85, 52, -77,
65, 39, -101,
-58, -47, 102,
83, -23, 92,
58, -47, 102,
65, 39, -101,
-85, 52, -77,
-65, 39, -101,
-65, 39, -101,
-85, 52, -77,
-58, -47, 102,
-99, -45, 64,
93, -58, 63,
-50, 47, 106,
42, -42, -111,
-99, 28, -73,
91, 12, -87,
42, -116, 27,
42, -42, -111,
93, -58, 63,
-99, 28, -73,
-50, 47, 106,
-68, 106, -3,
-99, 28, -73,
-99, -45, 64,
-50, 47, 106,
42, -42, -111,
91, 12, -87,
93, -58, 63,
-99, 28, -73,
-68, 106, -3,
91, 12, -87,
-99, -45, 64,
42, -116, 27,
93, -58, 63,
-50, 47, 106,
-58, -47, 102,
-14, 52, 114,
93, -58, 63,
-65, 39, -101,
-58, -47, 102,
91, 12, -87,
-68, 106, -3,
-65, 39, -101,
-68, 106, -3,
-14, 52, 114,
-48, 109, -43,
50, 47, 106,
-93, -58, 63,
99, -45, 64,
-91, 12, -87,
99, 28, -73,
-42, -42, -111,
-93, -58, 63,
-42, -42, -111,
-42, -116, 27,
68, 107, -3,
50, 47, 106,
99, 28, -73,
50, 47, 106,
99, -45, 64,
99, 28, -73,
-93, -58, 63,
-91, 12, -87,
-42, -42, -111,
-91, 12, -87,
68, 107, -3,
99, 28, -73,
-93, -58, 63,
-42, -116, 27,
99, -45, 64,
50, 47, 106,
48, 109, -43,
15, 52, 114,
68, 107, -3,
65, 39, -101,
48, 109, -43,
-91, 12, -87,
-93, -58, 63,
65, 39, -101,
-93, -58, 63,
50, 47, 106,
58, -47, 102,
68, 107, -3,
48, 109, -43,
50, 47, 106,
-14, 52, 114,
-68, 106, -3,
-50, 47, 106,
112, -55, 16,
-68, -99, 39,
118, 22, 40,
97, -6, -81,
62, -27, -107,
-97, -6, -81,
-97, -6, -81,
118, 22, 40,
97, -6, -81,
-97, -6, -81,
112, -55, 16,
118, 22, 40,
-62, -27, -107,
-68, -99, 39,
-93, 20, -83,
-68, -99, 39,
83, -83, 46,
-83, -83, 46,
57, -107, 34,
93, 20, -83,
83, -83, 46,
62, -27, -107,
-93, 20, -83,
93, 20, -83,
-78, -1, 99,
72, -4, 103,
-91, 84, 26,
73, -103, -9,
-88, -31, -85,
89, -24, -86,
72, -4, 103,
73, -103, -9,
84, 93, 13,
-78, -99, -11,
-91, 84, 26,
-88, -31, -85,
-78, -99, -11,
-78, -1, 99,
-91, 84, 26,
73, -103, -9,
89, -24, -86,
84, 93, 13,
73, -103, -9,
-78, -99, -11,
-88, -31, -85,
72, -4, 103,
84, 93, 13,
-91, 84, 26,
-91, 84, 26,
84, 93, 13,
-68, -99, 39,
84, 93, 13,
89, -24, -86,
118, 22, 40,
89, -24, -86,
-62, -27, -107,
97, -6, -81,
-88, -31, -85,
-68, -99, 39,
-62, -27, -107,
87, 87, 27,
-73, -3, 103,
78, -1, 99,
-89, -25, -86,
88, -31, -85,
-73, -103, -9,
-65, 105, -27,
-73, -103, -9,
-73, -3, 103,
88, -31, -85,
87, 87, 27,
78, -99, -11,
87, 87, 27,
78, -1, 99,
78, -99, -11,
-65, 105, -27,
-89, -25, -86,
-73, -103, -9,
88, -31, -85,
78, -99, -11,
-73, -103, -9,
87, 87, 27,
-65, 105, -27,
-73, -3, 103,
87, 87, 27,
88, -31, -85,
57, -107, 34,
-89, -25, -86,
-97, -6, -81,
62, -27, -107,
-89, -25, -86,
112, -55, 16,
-97, -6, -81,
-65, 105, -27,
57, -107, 34,
112, -55, 16,
-42, -42, -111,
38, -86, -84,
-42, -116, 27,
-42, -116, 27,
94, -84, -4,
99, -45, 64,
99, -45, 64,
94, -84, -4,
99, 28, -73,
99, 28, -73,
94, -51, -68,
-42, -42, -111,
42, -116, 27,
-38, -118, -25,
42, -42, -111,
42, -42, -111,
-94, -51, -68,
-99, 28, -73,
-99, 28, -73,
-94, -51, -68,
-99, -45, 64,
-99, -45, 64,
-94, -84, -4,
42, -116, 27,
-75, -92, 42,
80, 10, 97,
38, -118, -25,
80, 10, 97,
94, -51, -68,
94, -84, -4,
80, 86, -45,
38, -86, -84,
94, -51, -68,
-75, -16, -101,
-75, -92, 42,
38, -86, -84,
-80, 10, 97,
-38, -118, -25,
-94, -84, -4,
75, -16, -101,
-94, -51, -68,
-38, -86, -84,
-80, 86, -45,
-80, 10, 97,
-94, -51, -68,
-38, -86, -84,
-38, -118, -25,
75, -16, -101,
-99, -33, 71,
71, -81, 65,
-57, 5, 112,
33, -33, -117,
-92, 47, -73,
81, 12, -96,
31, -120, 25,
33, -33, -117,
71, -81, 65,
-92, 47, -73,
-57, 5, 112,
-53, 105, -46,
-92, 47, -73,
-99, -33, 71,
-57, 5, 112,
33, -33, -117,
81, 12, -96,
71, -81, 65,
-92, 47, -73,
-53, 105, -46,
81, 12, -96,
-99, -33, 71,
31, -120, 25,
71, -81, 65,
33, -33, -117,
-72, -94, -43,
-92, 47, -73,
-92, 47, -73,
-72, -94, -43,
-99, -33, 71,
-99, -33, 71,
-72, -94, -43,
31, -120, 25,
31, -120, 25,
-72, -94, -43,
33, -33, -117,
81, 12, -96,
-80, 86, -45,
75, -16, -101,
-53, 105, -46,
-57, 5, 112,
-80, 86, -45,
-57, 5, 112,
71, -81, 65,
-80, 10, 97,
71, -81, 65,
81, 12, -96,
75, -92, 42,
73, -103, -9,
-26, -108, 61,
-78, -99, -11,
-78, -99, -11,
-26, -108, 61,
-78, -1, 99,
-78, -1, 99,
-33, -71, 99,
72, -4, 103,
72, -4, 103,
35, -68, 100,
73, -103, -9,
-73, -3, 103,
-35, -68, 100,
78, -1, 99,
78, -1, 99,
26, -108, 61,
78, -99, -11,
78, -99, -11,
26, -108, 61,
-73, -103, -9,
-73, -103, -9,
-35, -68, 100,
-73, -3, 103,
89, 33, 83,
76, 41, 92,
-89, 33, 83,
-88, -31, -84,
-96, -62, -54,
88, -31, -84,
-79, 43, 89,
-96, -62, -54,
-89, 33, 83,
94, -67, -51,
76, 41, 92,
88, -31, -84,
89, 33, 83,
49, 114, 25,
88, -31, -84,
88, -31, -84,
73, 8, -103,
-88, -31, -84,
-88, -31, -84,
-97, 78, 18,
-89, 33, 83,
-89, 33, 83,
-97, 78, 18,
89, 33, 83,
-97, 78, 18,
49, 114, 25,
89, 33, 83,
-88, -31, -84,
-89, -13, -89,
-97, 78, 18,
73, 8, -103,
-89, -13, -89,
-88, -31, -84,
49, 114, 25,
73, 8, -103,
88, -31, -84,
76, 41, 92,
89, 33, 83,
88, -31, -84,
-96, -62, -54,
-88, -31, -84,
-89, 33, 83,
-96, -62, -54,
94, -67, -51,
88, -31, -84,
76, 41, 92,
-79, 43, 89,
-89, 33, 83,
-96, -62, -54,
-35, -68, 100,
-27, -109, 58,
-79, 43, 89,
76, 41, 92,
-35, -68, 100,
76, 41, 92,
94, -67, -51,
33, -71, 99,
94, -67, -51,
-27, -109, 58,
26, -108, 61,
89, 33, 83,
-76, 41, 92,
-89, 33, 83,
-88, -31, -84,
96, -62, -54,
88, -31, -84,
89, 33, 83,
96, -62, -54,
79, 43, 89,
-88, -31, -84,
-76, 41, 92,
-94, -67, -51,
-88, -31, -84,
-49, 114, 25,
-89, 33, 83,
88, -31, -84,
-73, 8, -103,
-88, -31, -84,
89, 33, 83,
97, 78, 18,
88, -31, -84,
-89, 33, 83,
97, 78, 18,
89, 33, 83,
-89, 33, 83,
-49, 114, 25,
97, 78, 18,
97, 78, 18,
89, -13, -89,
88, -31, -84,
88, -31, -84,
89, -13, -89,
-73, 8, -103,
-88, -31, -84,
-73, 8, -103,
-49, 114, 25,
-88, -31, -84,
-89, 33, 83,
-76, 41, 92,
89, 33, 83,
88, -31, -84,
96, -62, -54,
-88, -31, -84,
-94, -67, -51,
96, -62, -54,
89, 33, 83,
79, 43, 89,
-76, 41, 92,
-76, 41, 92,
35, -68, 100,
-33, -71, 99,
79, 43, 89,
96, -62, -54,
35, -68, 100,
96, -62, -54,
-94, -67, -51,
27, -109, 58,
-94, -67, -51,
-33, -71, 99,
-26, -108, 61,
86, -85, -35,
-53, -99, -57,
88, -8, -90,
-64, 108, -7,
95, 80, -21,
-91, 66, -57,
99, -65, 43,
77, -45, 90,
-93, -85, 1,
77, -45, 90,
95, 80, -21,
61, 110, 12,
-93, -85, 1,
-101, -48, 59,
-91, 66, -57,
61, 110, 12,
-18, 26, 122,
77, -45, 90,
77, -45, 90,
-18, 26, 122,
-101, -48, 59,
-101, -48, 59,
-18, 26, 122,
-64, 108, -7,
-64, 108, -7,
-18, 26, 122,
61, 110, 12,
99, -65, 43,
86, -85, -35,
95, 80, -21,
-93, -85, 1,
-53, -99, -57,
99, -65, 43,
-91, 66, -57,
-56, -13, -112,
-93, -85, 1,
-56, -13, -112,
-53, -99, -57,
-93, -85, 1,
-53, -99, -57,
86, -85, -35,
99, -65, 43,
86, -85, -35,
88, -8, -90,
95, 80, -21,
-101, -48, 59,
-64, 108, -7,
-91, 66, -57,
77, -45, 90,
99, -65, 43,
95, 80, -21,
77, -45, 90,
-101, -48, 59,
-93, -85, 1,
-64, 108, -7,
61, 110, 12,
95, 80, -21,
-53, -99, -57,
-56, -13, -112,
88, -8, -90,
95, 80, -21,
88, -8, -90,
97, 78, 18,
88, -8, -90,
-56, -13, -112,
89, -13, -89,
-56, -13, -112,
-91, 66, -57,
-73, 8, -103,
-91, 66, -57,
95, 80, -21,
-49, 114, 25,
-88, -8, -90,
53, -99, -57,
-86, -85, -35,
91, 66, -57,
-95, 80, -21,
64, 108, -7,
93, -85, 1,
-77, -45, 90,
-99, -65, 43,
-61, 110, 12,
-95, 80, -21,
-77, -45, 90,
91, 66, -57,
101, -48, 59,
93, -85, 1,
-77, -45, 90,
18, 26, 122,
-61, 110, 12,
101, -48, 59,
18, 26, 122,
-77, -45, 90,
64, 108, -7,
18, 26, 122,
101, -48, 59,
-61, 110, 12,
18, 26, 122,
64, 108, -7,
-95, 80, -21,
-86, -85, -35,
-99, -65, 43,
-99, -65, 43,
53, -99, -57,
93, -85, 1,
93, -85, 1,
56, -13, -112,
91, 66, -57,
93, -85, 1,
53, -99, -57,
56, -13, -112,
-99, -65, 43,
-86, -85, -35,
53, -99, -57,
-95, 80, -21,
-88, -8, -90,
-86, -85, -35,
91, 66, -57,
64, 108, -7,
101, -48, 59,
-95, 80, -21,
-99, -65, 43,
-77, -45, 90,
93, -85, 1,
101, -48, 59,
-77, -45, 90,
-95, 80, -21,
-61, 110, 12,
64, 108, -7,
-88, -8, -90,
56, -13, -112,
53, -99, -57,
-95, 80, -21,
49, 114, 25,
-97, 78, 18,
91, 66, -57,
73, 8, -103,
49, 114, 25,
56, -13, -112,
-89, -13, -89,
73, 8, -103,
-88, -8, -90,
-97, 78, 18,
-89, -13, -89,
62, -27, -107,
88, -31, -85,
-89, -25, -86,
89, -24, -86,
-88, -31, -85,
-62, -27, -107,
80, 86, -45,
-81, 12, -96,
-75, -16, -101,
-75, -16, -101,
-71, -81, 65,
-75, -92, 42,
80, 10, 97,
53, 105, -46,
80, 86, -45,
57, 5, 112,
-71, -81, 65,
99, -33, 71,
-81, 12, -96,
92, 47, -73,
-33, -33, -117,
-71, -81, 65,
-33, -33, -117,
-31, -120, 25,
53, 105, -46,
57, 5, 112,
92, 47, -73,
57, 5, 112,
99, -33, 71,
92, 47, -73,
-71, -81, 65,
-81, 12, -96,
-33, -33, -117,
-81, 12, -96,
53, 105, -46,
92, 47, -73,
-71, -81, 65,
-31, -120, 25,
99, -33, 71,
92, 47, -73,
72, -94, -43,
-33, -33, -117,
99, -33, 71,
72, -94, -43,
92, 47, -73,
-31, -120, 25,
72, -94, -43,
99, -33, 71,
-33, -33, -117,
72, -94, -43,
-31, -120, 25,
-75, -92, 42,
-71, -81, 65,
80, 10, 97,
-71, -81, 65,
57, 5, 112,
80, 10, 97,
80, 10, 97,
57, 5, 112,
53, 105, -46,
-75, -16, -101,
-81, 12, -96,
-71, -81, 65,
80, 86, -45,
53, 105, -46,
-81, 12, -96,
-88, -8, -90,
-95, 80, -21,
-97, 78, 18,
56, -13, -112,
-88, -8, -90,
-89, -13, -89,
91, 66, -57,
56, -13, -112,
73, 8, -103,
-95, 80, -21,
91, 66, -57,
49, 114, 25,
95, 80, -21,
97, 78, 18,
-49, 114, 25,
-91, 66, -57,
-49, 114, 25,
-73, 8, -103,
-56, -13, -112,
-73, 8, -103,
89, -13, -89,
88, -8, -90,
89, -13, -89,
97, 78, 18,
-94, -67, -51,
-76, 41, 92,
-33, -71, 99,
-94, -67, -51,
-26, -108, 61,
27, -109, 58,
96, -62, -54,
27, -109, 58,
35, -68, 100,
-76, 41, 92,
79, 43, 89,
35, -68, 100,
94, -67, -51,
-96, -62, -54,
-27, -109, 58,
94, -67, -51,
26, -108, 61,
33, -71, 99,
76, 41, 92,
33, -71, 99,
-35, -68, 100,
-96, -62, -54,
-79, 43, 89,
-35, -68, 100,
-73, -103, -9,
-27, -109, 58,
-35, -68, 100,
26, -108, 61,
-27, -109, 58,
-73, -103, -9,
78, -1, 99,
33, -71, 99,
26, -108, 61,
-35, -68, 100,
33, -71, 99,
78, -1, 99,
35, -68, 100,
27, -109, 58,
73, -103, -9,
-33, -71, 99,
35, -68, 100,
72, -4, 103,
-26, -108, 61,
-33, -71, 99,
-78, -1, 99,
73, -103, -9,
27, -109, 58,
-26, -108, 61,
81, 12, -96,
75, -16, -101,
75, -92, 42,
71, -81, 65,
75, -92, 42,
-80, 10, 97,
-57, 5, 112,
-80, 10, 97,
-80, 86, -45,
81, 12, -96,
-53, 105, -46,
-80, 86, -45,
-38, -118, -25,
75, -92, 42,
75, -16, -101,
-80, 10, 97,
-94, -84, -4,
-94, -51, -68,
75, -16, -101,
-80, 86, -45,
-94, -51, -68,
-80, 10, 97,
75, -92, 42,
-38, -118, -25,
-75, -92, 42,
38, -118, -25,
38, -86, -84,
80, 86, -45,
-75, -16, -101,
38, -86, -84,
80, 10, 97,
80, 86, -45,
94, -51, -68,
80, 10, 97,
94, -84, -4,
38, -118, -25,
-94, -84, -4,
-38, -118, -25,
42, -116, 27,
-94, -51, -68,
-94, -84, -4,
-99, -45, 64,
42, -42, -111,
-38, -86, -84,
-94, -51, -68,
-38, -118, -25,
-38, -86, -84,
42, -42, -111,
94, -51, -68,
38, -86, -84,
-42, -42, -111,
94, -84, -4,
94, -51, -68,
99, 28, -73,
-42, -116, 27,
38, -118, -25,
94, -84, -4,
38, -86, -84,
38, -118, -25,
-42, -116, 27,
-65, 105, -27,
87, 87, 27,
57, -107, 34,
-89, -25, -86,
-65, 105, -27,
112, -55, 16,
88, -31, -85,
62, -27, -107,
57, -107, 34,
-88, -31, -85,
-91, 84, 26,
-68, -99, 39,
89, -24, -86,
97, -6, -81,
118, 22, 40,
84, 93, 13,
118, 22, 40,
-68, -99, 39,
62, -27, -107,
-62, -27, -107,
-93, 20, -83,
57, -107, 34,
62, -27, -107,
93, 20, -83,
-68, -99, 39,
57, -107, 34,
83, -83, 46,
-68, -99, 39,
-83, -83, 46,
-93, 20, -83,
97, -6, -81,
-62, -27, -107,
62, -27, -107,
112, -55, 16,
57, -107, 34,
-68, -99, 39,
50, 47, 106,
15, 52, 114,
58, -47, 102,
-93, -58, 63,
58, -47, 102,
65, 39, -101,
68, 107, -3,
-91, 12, -87,
65, 39, -101,
-68, 106, -3,
-48, 109, -43,
-65, 39, -101,
93, -58, 63,
91, 12, -87,
-65, 39, -101,
-50, 47, 106,
93, -58, 63,
-58, -47, 102,
-85, 52, -77,
-83, -23, 92,
-58, -47, 102,
65, 39, -101,
85, 52, -77,
-85, 52, -77,
-58, -47, 102,
-83, -23, 92,
83, -23, 92,
58, -47, 102,
83, -23, 92,
85, 52, -77,
-30, 112, 50,
29, 123, -7,
91, 0, -87,
30, 112, 50,
-30, 112, 50,
-3, -56, -113,
-48, 109, -43,
48, 109, -43,
65, 39, -101,
58, -47, 102,
15, 52, 114,
-14, 52, 114,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:17 */
static s8 vtxnvgrp_frake_select_17[]={
-34, -121, 13,
-9, -126, 9,
-10, -126, 10,
-10, -126, 10,
11, -126, -3,
92, -78, 38,
-11, -84, -94,
43, -15, -118,
-64, -89, -63,
-64, -89, -63,
-31, 25, -120,
-34, -91, -81,
-34, -91, -81,
-31, 25, -120,
-13, -95, -82,
-13, -95, -82,
-103, 19, -70,
-66, -78, -75,
-66, -78, -75,
-125, -15, -14,
-83, -94, 9,
-11, -84, -94,
81, -89, 37,
44, -113, -34,
78, -57, -81,
-6, -60, -111,
43, -15, -118,
43, -15, -118,
89, -2, -89,
-31, 25, -120,
-31, 25, -120,
-111, 20, -56,
-103, 19, -70,
-103, 19, -70,
-47, -47, -107,
-125, -15, -14,
-125, -15, -14,
-47, -47, -107,
-83, -94, 9,
-83, -94, 9,
-79, -75, -65,
-10, -118, -44,
-10, -118, -44,
22, -84, -91,
44, -113, -34,
44, -113, -34,
-6, -60, -111,
78, -57, -81,
28, 110, 56,
-69, 90, 56,
-5, 117, 47,
81, 25, -93,
93, 41, -75,
112, -36, -47,
126, -6, -13,
89, -83, 34,
92, -78, 38,
92, -78, 38,
89, -83, 34,
-10, -126, 10,
-10, -126, 10,
-72, -54, 89,
-70, -50, 92,
-70, -50, 92,
-72, -54, 89,
-105, 39, 57,
-124, 10, 22,
-100, 75, -13,
-106, 61, -32,
-106, 61, -32,
-14, 91, -86,
-21, 76, -99,
-21, 76, -99,
-14, 91, -86,
81, 25, -93,
93, 41, -75,
111, 61, 5,
126, -6, -13,
126, -6, -13,
111, 61, 5,
121, 20, 31,
-73, 58, 85,
-69, 90, 56,
-105, 39, 57,
-105, 39, 57,
-69, 90, 56,
-100, 75, -13,
-100, 75, -13,
6, 124, -25,
-14, 91, -86,
-14, 91, -86,
6, 124, -25,
93, 41, -75,
80, 98, 5,
6, 124, -25,
28, 110, 56,
44, -113, -34,
78, -57, -81,
-11, -84, -94,
-83, -94, 9,
-68, -65, 84,
-66, -78, -75,
-10, -118, -44,
44, -113, -34,
-83, -94, 9,
44, -113, -34,
13, -97, 80,
-83, -94, 9,
-34, -121, 13,
52, -114, -11,
-66, -78, -75,
-66, -78, -75,
-109, 37, -53,
-124, 10, 22,
-124, 10, 22,
-78, -80, 59,
-70, -50, 92,
-70, -50, 92,
52, -114, -11,
-34, -121, 13,
52, -114, -11,
-49, -74, -90,
44, 20, -117,
44, 20, -117,
-49, -74, -90,
-109, 37, -53,
-109, 37, -53,
-49, -74, -90,
-78, -80, 59,
-78, -80, 59,
-49, -74, -90,
52, -114, -11,
-11, -84, -94,
-80, -95, 25,
11, -126, -3,
11, -126, -3,
-80, -95, 25,
92, -78, 38,
92, -78, 38,
71, -104, 11,
112, -36, -47,
112, -36, -47,
64, 3, -109,
-11, -84, -94,
-92, 47, -73,
-37, -75, -95,
-80, -95, 25,
-80, -95, 25,
-37, -75, -95,
71, -104, 11,
71, -104, 11,
-37, -75, -95,
64, 3, -109,
64, 3, -109,
-37, -75, -95,
-92, 47, -73,
-64, -89, -63,
-69, -98, 41,
-11, -84, -94,
-11, -84, -94,
-69, -98, 41,
112, -36, -47,
112, -36, -47,
79, -96, -23,
81, 25, -93,
81, 25, -93,
-38, 47, -111,
-64, -89, -63,
-121, 10, 36,
-59, -70, -87,
-69, -98, 41,
-69, -98, 41,
-59, -70, -87,
79, -96, -23,
79, -96, -23,
-59, -70, -87,
-38, 47, -111,
-38, 47, -111,
-59, -70, -87,
-121, 10, 36,
-106, 61, -32,
-101, -68, 32,
-124, 10, 22,
-124, 10, 22,
51, -116, 4,
-66, -78, -75,
-66, -78, -75,
51, -116, 4,
-13, -95, -82,
-13, -95, -82,
-13, 42, -118,
-106, 61, -32,
-13, 42, -118,
-27, -73, -99,
-101, -68, 32,
-101, -68, 32,
-27, -73, -99,
51, -116, 4,
51, -116, 4,
-27, -73, -99,
115, -38, -36,
115, -38, -36,
-27, -73, -99,
-13, 42, -118,
-34, -91, -81,
44, -108, 48,
-64, -89, -63,
-64, -89, -63,
44, -108, 48,
81, 25, -93,
81, 25, -93,
-74, 44, -92,
-21, 76, -99,
-21, 76, -99,
-74, 44, -92,
-34, -91, -81,
-112, -50, 31,
-36, -118, -26,
44, -108, 48,
44, -108, 48,
-36, -118, -26,
98, -13, -78,
98, -13, -78,
-36, -118, -26,
-74, 44, -92,
-74, 44, -92,
-36, -118, -26,
-112, -50, 31,
-13, -95, -82,
-37, -94, 76,
-34, -91, -81,
-34, -91, -81,
20, 28, -122,
-21, 76, -99,
-21, 76, -99,
20, 28, -122,
-106, 61, -32,
-106, 61, -32,
-37, -94, 76,
-13, -95, -82,
-37, -94, 76,
-20, -120, -35,
88, -86, -29,
88, -86, -29,
-20, -120, -35,
20, 28, -122,
20, 28, -122,
-20, -120, -35,
-124, 21, -7,
-124, 21, -7,
-20, -120, -35,
-37, -94, 76,
35, 47, 112,
38, 46, 111,
-73, 58, 85,
121, 20, 31,
38, 46, 111,
35, 47, 112,
81, -89, 37,
-11, -84, -94,
11, -126, -3,
-68, -65, 84,
-34, -121, 13,
-66, -78, -75,
-68, -65, 84,
-9, -126, 9,
-34, -121, 13,
81, -89, 37,
11, -126, -3,
-9, -126, 9,
-68, -65, 84,
13, -97, 80,
-9, -126, 9,
121, 20, 31,
89, -83, 34,
126, -6, -13,
-105, 39, 57,
-72, -54, 89,
-73, 58, 85,
92, -78, 38,
112, -36, -47,
126, -6, -13,
-105, 39, 57,
-124, 10, 22,
-70, -50, 92,
-19, 19, 123,
-32, -46, 113,
39, 7, 120,
74, -65, 78,
35, 7, 121,
21, -57, 111,
28, 110, 56,
38, 46, 111,
63, 106, 25,
28, 110, 56,
63, 106, 25,
111, 61, 5,
28, 110, 56,
111, 61, 5,
80, 98, 5,
-5, 117, 47,
38, 46, 111,
28, 110, 56,
28, 110, 56,
-34, 115, 39,
-69, 90, 56,
28, 110, 56,
6, 124, -25,
-34, 115, 39,
35, 47, 112,
34, -73, 97,
17, -93, 83,
17, -93, 83,
-44, -62, 101,
-72, -54, 89,
-72, -54, 89,
-44, 36, 113,
-73, 58, 85,
-73, 58, 85,
56, 22, 111,
35, 47, 112,
89, -83, 34,
73, -78, 67,
17, -93, 83,
17, -93, 83,
3, -70, 105,
35, 47, 112,
35, 47, 112,
22, 25, 122,
121, 20, 31,
121, 20, 31,
106, 14, 67,
89, -83, 34,
106, 14, 67,
73, -78, 67,
89, -83, 34,
22, 25, 122,
106, 14, 67,
121, 20, 31,
3, -70, 105,
22, 25, 122,
35, 47, 112,
73, -78, 67,
3, -70, 105,
17, -93, 83,
-73, 58, 85,
-44, 36, 113,
56, 22, 111,
-72, -54, 89,
-44, -62, 101,
-44, 36, 113,
17, -93, 83,
34, -73, 97,
-44, -62, 101,
35, 47, 112,
56, 22, 111,
34, -73, 97,
121, 20, 31,
63, 106, 25,
38, 46, 111,
38, 46, 111,
-5, 117, 47,
-73, 58, 85,
-106, 61, -32,
-124, 21, -7,
-37, -94, 76,
20, 28, -122,
-124, 21, -7,
-106, 61, -32,
-34, -91, -81,
88, -86, -29,
20, 28, -122,
-37, -94, 76,
88, -86, -29,
-34, -91, -81,
-74, 44, -92,
-112, -50, 31,
-34, -91, -81,
81, 25, -93,
98, -13, -78,
-74, 44, -92,
44, -108, 48,
98, -13, -78,
81, 25, -93,
-34, -91, -81,
-112, -50, 31,
44, -108, 48,
-13, -95, -82,
115, -38, -36,
-13, 42, -118,
51, -116, 4,
115, -38, -36,
-13, -95, -82,
-124, 10, 22,
-101, -68, 32,
51, -116, 4,
-106, 61, -32,
-13, 42, -118,
-101, -68, 32,
-38, 47, -111,
-121, 10, 36,
-64, -89, -63,
79, -96, -23,
-38, 47, -111,
81, 25, -93,
-69, -98, 41,
79, -96, -23,
112, -36, -47,
-64, -89, -63,
-121, 10, 36,
-69, -98, 41,
64, 3, -109,
-92, 47, -73,
-11, -84, -94,
71, -104, 11,
64, 3, -109,
112, -36, -47,
-80, -95, 25,
71, -104, 11,
92, -78, 38,
-11, -84, -94,
-92, 47, -73,
-80, -95, 25,
-70, -50, 92,
-78, -80, 59,
52, -114, -11,
-124, 10, 22,
-109, 37, -53,
-78, -80, 59,
-66, -78, -75,
44, 20, -117,
-109, 37, -53,
52, -114, -11,
44, 20, -117,
-66, -78, -75,
13, -97, 80,
-68, -65, 84,
-83, -94, 9,
6, 124, -25,
80, 98, 5,
93, 41, -75,
-100, 75, -13,
-34, 115, 39,
6, 124, -25,
-69, 90, 56,
-34, 115, 39,
-100, 75, -13,
-73, 58, 85,
-5, 117, 47,
-69, 90, 56,
111, 61, 5,
63, 106, 25,
121, 20, 31,
93, 41, -75,
80, 98, 5,
111, 61, 5,
-14, 91, -86,
93, 41, -75,
81, 25, -93,
-106, 61, -32,
-100, 75, -13,
-14, 91, -86,
-124, 10, 22,
-105, 39, 57,
-100, 75, -13,
-10, -126, 10,
17, -93, 83,
-72, -54, 89,
89, -83, 34,
17, -93, 83,
-10, -126, 10,
93, 41, -75,
126, -6, -13,
112, -36, -47,
-6, -60, -111,
22, -84, -91,
-79, -75, -65,
22, -84, -91,
-10, -118, -44,
-79, -75, -65,
-6, -60, -111,
-79, -75, -65,
-47, -47, -107,
44, -113, -34,
22, -84, -91,
-6, -60, -111,
-47, -47, -107,
-79, -75, -65,
-83, -94, 9,
-103, 19, -70,
-111, 20, -56,
-47, -47, -107,
-31, 25, -120,
-2, 29, -123,
-111, 20, -56,
89, -2, -89,
-2, 29, -123,
-31, 25, -120,
-6, -60, -111,
89, -2, -89,
43, -15, -118,
-103, 19, -70,
-125, -15, -14,
-66, -78, -75,
-31, 25, -120,
-103, 19, -70,
-13, -95, -82,
-64, -89, -63,
43, -15, -118,
-31, 25, -120,
-11, -84, -94,
78, -57, -81,
43, -15, -118,
-10, -126, 10,
-9, -126, 9,
11, -126, -3,
-10, -126, 10,
-70, -50, 92,
-34, -121, 13,
13, -97, 80,
81, -89, 37,
-9, -126, 9,
3, -70, 105,
86, 0, 92,
22, 25, 122,
22, 25, 122,
21, -57, 111,
106, 14, 67,
106, 14, 67,
21, -57, 111,
73, -78, 67,
73, -78, 67,
86, 0, 92,
3, -70, 105,
56, 22, 111,
-19, 19, 123,
34, -73, 97,
34, -73, 97,
-19, 19, 123,
-44, -62, 101,
-44, -62, 101,
30, -58, 108,
-44, 36, 113,
-44, 36, 113,
30, -58, 108,
56, 22, 111,
30, -58, 108,
-32, -46, 113,
56, 22, 111,
-44, -62, 101,
39, 7, 120,
30, -58, 108,
-19, 19, 123,
39, 7, 120,
-44, -62, 101,
56, 22, 111,
-32, -46, 113,
-19, 19, 123,
73, -78, 67,
35, 7, 121,
86, 0, 92,
21, -57, 111,
35, 7, 121,
73, -78, 67,
22, 25, 122,
74, -65, 78,
21, -57, 111,
86, 0, 92,
74, -65, 78,
22, 25, 122,
74, -65, 78,
86, 0, 92,
35, 7, 121,
-32, -46, 113,
30, -58, 108,
39, 7, 120,
44, -113, -34,
81, -89, 37,
13, -97, 80,
58, -45, 102,
-14, 53, 114,
-58, -45, 102,
93, 19, -83,
-93, 19, -83,
85, 51, -78,
15, 53, 114,
28, 113, 48,
-14, 53, 114,
-14, 53, 114,
-29, 123, -9,
-48, 108, -45,
-48, 108, -45,
29, 123, -9,
48, 108, -45,
48, 108, -45,
29, 123, -9,
15, 53, 114,
83, -22, 93,
93, 19, -83,
85, 51, -78,
-83, -22, 93,
83, -83, 47,
83, -22, 93,
-85, 51, -78,
-93, 19, -83,
-83, -22, 93,
-65, 38, -101,
-48, 108, -45,
65, 38, -101,
-93, 19, -83,
-83, -83, 47,
-83, -22, 93,
-83, -22, 93,
-83, -83, 47,
83, -83, 47,
83, -22, 93,
83, -83, 47,
93, 19, -83,
29, 123, -9,
-28, 113, 48,
15, 53, 114,
-48, 108, -45,
-29, 123, -9,
29, 123, -9,
-14, 53, 114,
28, 113, 48,
-29, 123, -9,
15, 53, 114,
-28, 113, 48,
28, 113, 48,
-93, 19, -83,
-85, 51, -78,
85, 51, -78,
28, 113, 48,
-6, -60, -111,
-47, -47, -107,
-28, 113, 48,
89, -2, -89,
-6, -60, -111,
29, 123, -9,
-2, 29, -123,
89, -2, -89,
-29, 123, -9,
-111, 20, -56,
-2, 29, -123,
28, 113, 48,
-47, -47, -107,
-111, 20, -56,
29, 123, -9,
-29, 123, -9,
-2, 29, -123,
-29, 123, -9,
28, 113, 48,
-111, 20, -56,
58, -45, 102,
85, 51, -78,
65, 38, -101,
-58, -45, 102,
83, -22, 93,
58, -45, 102,
65, 38, -101,
-85, 51, -78,
-65, 38, -101,
-65, 38, -101,
-85, 51, -78,
-58, -45, 102,
-99, -44, 65,
93, -57, 64,
-50, 48, 106,
42, -43, -111,
-99, 27, -74,
91, 11, -87,
42, -116, 28,
42, -43, -111,
93, -57, 64,
-99, 27, -74,
-50, 48, 106,
-68, 106, -5,
-99, 27, -74,
-99, -44, 65,
-50, 48, 106,
42, -43, -111,
91, 11, -87,
93, -57, 64,
-99, 27, -74,
-68, 106, -5,
91, 11, -87,
-99, -44, 65,
42, -116, 28,
93, -57, 64,
-50, 48, 106,
-58, -45, 102,
-14, 53, 114,
93, -57, 64,
-65, 38, -101,
-58, -45, 102,
91, 11, -87,
-68, 106, -5,
-65, 38, -101,
-68, 106, -5,
-14, 53, 114,
-48, 108, -45,
50, 48, 105,
-93, -57, 64,
99, -44, 65,
-91, 11, -87,
99, 27, -74,
-42, -43, -111,
-93, -57, 64,
-42, -43, -111,
-42, -116, 28,
68, 107, -4,
50, 48, 105,
99, 27, -74,
50, 48, 105,
99, -44, 65,
99, 27, -74,
-93, -57, 64,
-91, 11, -87,
-42, -43, -111,
-91, 11, -87,
68, 107, -4,
99, 27, -74,
-93, -57, 64,
-42, -116, 28,
99, -44, 65,
50, 48, 105,
48, 108, -45,
15, 53, 114,
68, 107, -4,
65, 38, -101,
48, 108, -45,
-91, 11, -87,
-93, -57, 64,
65, 38, -101,
-93, -57, 64,
50, 48, 105,
58, -45, 102,
68, 107, -4,
48, 108, -45,
50, 48, 105,
-14, 53, 114,
-68, 106, -5,
-50, 48, 106,
113, -54, 14,
-67, -99, 40,
118, 21, 40,
97, -5, -81,
62, -27, -107,
-97, -6, -81,
-97, -6, -81,
118, 21, 40,
97, -5, -81,
-97, -6, -81,
113, -54, 14,
118, 21, 40,
-62, -27, -107,
-67, -99, 40,
-93, 19, -83,
-67, -99, 40,
83, -83, 47,
-83, -83, 47,
56, -107, 35,
93, 19, -83,
83, -83, 47,
62, -27, -107,
-93, 19, -83,
93, 19, -83,
-78, -3, 99,
72, -6, 103,
-91, 83, 28,
73, -103, -11,
-88, -29, -85,
90, -23, -86,
72, -6, 103,
73, -103, -11,
84, 93, 15,
-78, -98, -13,
-91, 83, 28,
-88, -29, -85,
-78, -98, -13,
-78, -3, 99,
-91, 83, 28,
73, -103, -11,
90, -23, -86,
84, 93, 15,
73, -103, -11,
-78, -98, -13,
-88, -29, -85,
72, -6, 103,
84, 93, 15,
-91, 83, 28,
-91, 83, 28,
84, 93, 15,
-67, -99, 40,
84, 93, 15,
90, -23, -86,
118, 21, 40,
90, -23, -86,
-62, -27, -107,
97, -5, -81,
-88, -29, -85,
-67, -99, 40,
-62, -27, -107,
87, 87, 28,
-73, -4, 103,
78, -3, 99,
-89, -23, -87,
88, -29, -85,
-73, -103, -11,
-65, 105, -24,
-73, -103, -11,
-73, -4, 103,
88, -29, -85,
87, 87, 28,
78, -98, -13,
87, 87, 28,
78, -3, 99,
78, -98, -13,
-65, 105, -24,
-89, -23, -87,
-73, -103, -11,
88, -29, -85,
78, -98, -13,
-73, -103, -11,
87, 87, 28,
-65, 105, -24,
-73, -4, 103,
87, 87, 28,
88, -29, -85,
56, -107, 35,
-89, -23, -87,
-97, -6, -81,
62, -27, -107,
-89, -23, -87,
113, -54, 14,
-97, -6, -81,
-65, 105, -24,
56, -107, 35,
113, -54, 14,
-42, -43, -111,
38, -87, -83,
-42, -116, 28,
-42, -116, 28,
94, -84, -3,
99, -44, 65,
99, -44, 65,
94, -84, -3,
99, 27, -74,
99, 27, -74,
94, -51, -67,
-42, -43, -111,
42, -116, 28,
-38, -118, -23,
42, -43, -111,
42, -43, -111,
-94, -51, -67,
-99, 27, -74,
-99, 27, -74,
-94, -51, -67,
-99, -44, 65,
-99, -44, 65,
-94, -84, -3,
42, -116, 28,
-75, -92, 43,
80, 11, 97,
38, -118, -23,
80, 11, 97,
94, -51, -67,
94, -84, -3,
80, 86, -46,
38, -87, -83,
94, -51, -67,
-75, -17, -100,
-75, -92, 43,
38, -87, -83,
-80, 11, 97,
-38, -118, -23,
-94, -84, -3,
75, -17, -100,
-94, -51, -67,
-38, -87, -83,
-80, 86, -46,
-80, 11, 97,
-94, -51, -67,
-38, -87, -83,
-38, -118, -23,
75, -17, -100,
-99, -32, 71,
71, -80, 66,
-57, 6, 112,
33, -35, -117,
-92, 46, -73,
81, 11, -96,
31, -120, 26,
33, -35, -117,
71, -80, 66,
-92, 46, -73,
-57, 6, 112,
-53, 104, -47,
-92, 46, -73,
-99, -32, 71,
-57, 6, 112,
33, -35, -117,
81, 11, -96,
71, -80, 66,
-92, 46, -73,
-53, 104, -47,
81, 11, -96,
-99, -32, 71,
31, -120, 26,
71, -80, 66,
33, -35, -117,
-72, -95, -42,
-92, 46, -73,
-92, 46, -73,
-72, -95, -42,
-99, -32, 71,
-99, -32, 71,
-72, -95, -42,
31, -120, 26,
31, -120, 26,
-72, -95, -42,
33, -35, -117,
81, 11, -96,
-80, 86, -46,
75, -17, -100,
-53, 104, -47,
-57, 6, 112,
-80, 86, -46,
-57, 6, 112,
71, -80, 66,
-80, 11, 97,
71, -80, 66,
81, 11, -96,
75, -92, 43,
73, -103, -11,
-26, -109, 59,
-78, -98, -13,
-78, -98, -13,
-26, -109, 59,
-78, -3, 99,
-78, -3, 99,
-33, -73, 97,
72, -6, 103,
72, -6, 103,
35, -70, 99,
73, -103, -11,
-73, -4, 103,
-35, -70, 99,
78, -3, 99,
78, -3, 99,
26, -109, 59,
78, -98, -13,
78, -98, -13,
26, -109, 59,
-73, -103, -11,
-73, -103, -11,
-35, -70, 99,
-73, -4, 103,
89, 37, 81,
77, 41, 91,
-89, 37, 81,
-89, -36, -82,
-94, -65, -53,
89, -36, -82,
-80, 44, 87,
-94, -65, -53,
-89, 37, 81,
91, -70, -51,
77, 41, 91,
89, -36, -82,
89, 37, 81,
49, 115, 20,
89, -36, -82,
89, -36, -82,
73, 3, -103,
-89, -36, -82,
-89, -36, -82,
-97, 79, 14,
-89, 37, 81,
-89, 37, 81,
-97, 79, 14,
89, 37, 81,
-97, 79, 14,
49, 115, 20,
89, 37, 81,
-89, -36, -82,
-89, -17, -88,
-97, 79, 14,
73, 3, -103,
-89, -17, -88,
-89, -36, -82,
49, 115, 20,
73, 3, -103,
89, -36, -82,
77, 41, 91,
89, 37, 81,
89, -36, -82,
-94, -65, -53,
-89, -36, -82,
-89, 37, 81,
-94, -65, -53,
91, -70, -51,
89, -36, -82,
77, 41, 91,
-80, 44, 87,
-89, 37, 81,
-94, -65, -53,
-35, -70, 99,
-27, -110, 56,
-80, 44, 87,
77, 41, 91,
-35, -70, 99,
77, 41, 91,
91, -70, -51,
33, -73, 97,
91, -70, -51,
-27, -110, 56,
26, -109, 59,
89, 37, 81,
-77, 41, 91,
-89, 37, 81,
-89, -36, -82,
94, -65, -53,
89, -36, -82,
89, 37, 81,
94, -65, -53,
80, 44, 87,
-89, -36, -82,
-77, 41, 91,
-91, -70, -51,
-89, -36, -82,
-49, 115, 20,
-89, 37, 81,
89, -36, -82,
-73, 3, -103,
-89, -36, -82,
89, 37, 81,
97, 79, 14,
89, -36, -82,
-89, 37, 81,
97, 79, 14,
89, 37, 81,
-89, 37, 81,
-49, 115, 20,
97, 79, 14,
97, 79, 14,
89, -17, -88,
89, -36, -82,
89, -36, -82,
89, -17, -88,
-73, 3, -103,
-89, -36, -82,
-73, 3, -103,
-49, 115, 20,
-89, -36, -82,
-89, 37, 81,
-77, 41, 91,
89, 37, 81,
89, -36, -82,
94, -65, -53,
-89, -36, -82,
-91, -70, -51,
94, -65, -53,
89, 37, 81,
80, 44, 87,
-77, 41, 91,
-77, 41, 91,
35, -70, 99,
-33, -73, 97,
80, 44, 87,
94, -65, -53,
35, -70, 99,
94, -65, -53,
-91, -70, -51,
27, -110, 56,
-91, -70, -51,
-33, -73, 97,
-26, -109, 59,
86, -87, -31,
-53, -102, -52,
88, -12, -89,
-64, 108, -12,
95, 79, -25,
-91, 64, -60,
99, -63, 46,
77, -40, 92,
-93, -85, 5,
77, -40, 92,
95, 79, -25,
61, 110, 7,
-93, -85, 5,
-101, -45, 61,
-91, 64, -60,
61, 110, 7,
-18, 32, 121,
77, -40, 92,
77, -40, 92,
-18, 32, 121,
-101, -45, 61,
-101, -45, 61,
-18, 32, 121,
-64, 108, -12,
-64, 108, -12,
-18, 32, 121,
61, 110, 7,
99, -63, 46,
86, -87, -31,
95, 79, -25,
-93, -85, 5,
-53, -102, -52,
99, -63, 46,
-91, 64, -60,
-56, -19, -112,
-93, -85, 5,
-56, -19, -112,
-53, -102, -52,
-93, -85, 5,
-53, -102, -52,
86, -87, -31,
99, -63, 46,
86, -87, -31,
88, -12, -89,
95, 79, -25,
-101, -45, 61,
-64, 108, -12,
-91, 64, -60,
77, -40, 92,
99, -63, 46,
95, 79, -25,
77, -40, 92,
-101, -45, 61,
-93, -85, 5,
-64, 108, -12,
61, 110, 7,
95, 79, -25,
-53, -102, -52,
-56, -19, -112,
88, -12, -89,
95, 79, -25,
88, -12, -89,
97, 79, 14,
88, -12, -89,
-56, -19, -112,
89, -17, -88,
-56, -19, -112,
-91, 64, -60,
-73, 3, -103,
-91, 64, -60,
95, 79, -25,
-49, 115, 20,
-88, -12, -89,
53, -102, -52,
-86, -87, -31,
91, 64, -60,
-95, 79, -25,
64, 108, -12,
93, -85, 5,
-77, -40, 92,
-99, -63, 46,
-61, 110, 7,
-95, 79, -25,
-77, -40, 92,
91, 64, -60,
101, -45, 61,
93, -85, 5,
-77, -40, 92,
18, 32, 121,
-61, 110, 7,
101, -45, 61,
18, 32, 121,
-77, -40, 92,
64, 108, -12,
18, 32, 121,
101, -45, 61,
-61, 110, 7,
18, 32, 121,
64, 108, -12,
-95, 79, -25,
-86, -87, -31,
-99, -63, 46,
-99, -63, 46,
53, -102, -52,
93, -85, 5,
93, -85, 5,
56, -19, -112,
91, 64, -60,
93, -85, 5,
53, -102, -52,
56, -19, -112,
-99, -63, 46,
-86, -87, -31,
53, -102, -52,
-95, 79, -25,
-88, -12, -89,
-86, -87, -31,
91, 64, -60,
64, 108, -12,
101, -45, 61,
-95, 79, -25,
-99, -63, 46,
-77, -40, 92,
93, -85, 5,
101, -45, 61,
-77, -40, 92,
-95, 79, -25,
-61, 110, 7,
64, 108, -12,
-88, -12, -89,
56, -19, -112,
53, -102, -52,
-95, 79, -25,
49, 115, 20,
-97, 79, 14,
91, 64, -60,
73, 3, -103,
49, 115, 20,
56, -19, -112,
-89, -17, -88,
73, 3, -103,
-88, -12, -89,
-97, 79, 14,
-89, -17, -88,
62, -27, -107,
88, -29, -85,
-89, -23, -87,
90, -23, -86,
-88, -29, -85,
-62, -27, -107,
80, 86, -46,
-81, 11, -96,
-75, -17, -100,
-75, -17, -100,
-71, -80, 66,
-75, -92, 43,
80, 11, 97,
53, 104, -47,
80, 86, -46,
57, 6, 112,
-71, -80, 66,
99, -32, 71,
-81, 11, -96,
92, 46, -73,
-33, -35, -117,
-71, -80, 66,
-33, -35, -117,
-31, -120, 26,
53, 104, -47,
57, 6, 112,
92, 46, -73,
57, 6, 112,
99, -32, 71,
92, 46, -73,
-71, -80, 66,
-81, 11, -96,
-33, -35, -117,
-81, 11, -96,
53, 104, -47,
92, 46, -73,
-71, -80, 66,
-31, -120, 26,
99, -32, 71,
92, 46, -73,
72, -95, -42,
-33, -35, -117,
99, -32, 71,
72, -95, -42,
92, 46, -73,
-31, -120, 26,
72, -95, -42,
99, -32, 71,
-33, -35, -117,
72, -95, -42,
-31, -120, 26,
-75, -92, 43,
-71, -80, 66,
80, 11, 97,
-71, -80, 66,
57, 6, 112,
80, 11, 97,
80, 11, 97,
57, 6, 112,
53, 104, -47,
-75, -17, -100,
-81, 11, -96,
-71, -80, 66,
80, 86, -46,
53, 104, -47,
-81, 11, -96,
-88, -12, -89,
-95, 79, -25,
-97, 79, 14,
56, -19, -112,
-88, -12, -89,
-89, -17, -88,
91, 64, -60,
56, -19, -112,
73, 3, -103,
-95, 79, -25,
91, 64, -60,
49, 115, 20,
95, 79, -25,
97, 79, 14,
-49, 115, 20,
-91, 64, -60,
-49, 115, 20,
-73, 3, -103,
-56, -19, -112,
-73, 3, -103,
89, -17, -88,
88, -12, -89,
89, -17, -88,
97, 79, 14,
-91, -70, -51,
-77, 41, 91,
-33, -73, 97,
-91, -70, -51,
-26, -109, 59,
27, -110, 56,
94, -65, -53,
27, -110, 56,
35, -70, 99,
-77, 41, 91,
80, 44, 87,
35, -70, 99,
91, -70, -51,
-94, -65, -53,
-27, -110, 56,
91, -70, -51,
26, -109, 59,
33, -73, 97,
77, 41, 91,
33, -73, 97,
-35, -70, 99,
-94, -65, -53,
-80, 44, 87,
-35, -70, 99,
-73, -103, -11,
-27, -110, 56,
-35, -70, 99,
26, -109, 59,
-27, -110, 56,
-73, -103, -11,
78, -3, 99,
33, -73, 97,
26, -109, 59,
-35, -70, 99,
33, -73, 97,
78, -3, 99,
35, -70, 99,
27, -110, 56,
73, -103, -11,
-33, -73, 97,
35, -70, 99,
72, -6, 103,
-26, -109, 59,
-33, -73, 97,
-78, -3, 99,
73, -103, -11,
27, -110, 56,
-26, -109, 59,
81, 11, -96,
75, -17, -100,
75, -92, 43,
71, -80, 66,
75, -92, 43,
-80, 11, 97,
-57, 6, 112,
-80, 11, 97,
-80, 86, -46,
81, 11, -96,
-53, 104, -47,
-80, 86, -46,
-38, -118, -23,
75, -92, 43,
75, -17, -100,
-80, 11, 97,
-94, -84, -3,
-94, -51, -67,
75, -17, -100,
-80, 86, -46,
-94, -51, -67,
-80, 11, 97,
75, -92, 43,
-38, -118, -23,
-75, -92, 43,
38, -118, -23,
38, -87, -83,
80, 86, -46,
-75, -17, -100,
38, -87, -83,
80, 11, 97,
80, 86, -46,
94, -51, -67,
80, 11, 97,
94, -84, -3,
38, -118, -23,
-94, -84, -3,
-38, -118, -23,
42, -116, 28,
-94, -51, -67,
-94, -84, -3,
-99, -44, 65,
42, -43, -111,
-38, -87, -83,
-94, -51, -67,
-38, -118, -23,
-38, -87, -83,
42, -43, -111,
94, -51, -67,
38, -87, -83,
-42, -43, -111,
94, -84, -3,
94, -51, -67,
99, 27, -74,
-42, -116, 28,
38, -118, -23,
94, -84, -3,
38, -87, -83,
38, -118, -23,
-42, -116, 28,
-65, 105, -24,
87, 87, 28,
56, -107, 35,
-89, -23, -87,
-65, 105, -24,
113, -54, 14,
88, -29, -85,
62, -27, -107,
56, -107, 35,
-88, -29, -85,
-91, 83, 28,
-67, -99, 40,
90, -23, -86,
97, -5, -81,
118, 21, 40,
84, 93, 15,
118, 21, 40,
-67, -99, 40,
62, -27, -107,
-62, -27, -107,
-93, 19, -83,
56, -107, 35,
62, -27, -107,
93, 19, -83,
-67, -99, 40,
56, -107, 35,
83, -83, 47,
-67, -99, 40,
-83, -83, 47,
-93, 19, -83,
97, -5, -81,
-62, -27, -107,
62, -27, -107,
113, -54, 14,
56, -107, 35,
-67, -99, 40,
50, 48, 105,
15, 53, 114,
58, -45, 102,
-93, -57, 64,
58, -45, 102,
65, 38, -101,
68, 107, -4,
-91, 11, -87,
65, 38, -101,
-68, 106, -5,
-48, 108, -45,
-65, 38, -101,
93, -57, 64,
91, 11, -87,
-65, 38, -101,
-50, 48, 106,
93, -57, 64,
-58, -45, 102,
-85, 51, -78,
-83, -22, 93,
-58, -45, 102,
65, 38, -101,
85, 51, -78,
-85, 51, -78,
-58, -45, 102,
-83, -22, 93,
83, -22, 93,
58, -45, 102,
83, -22, 93,
85, 51, -78,
-28, 113, 48,
29, 123, -9,
89, -2, -89,
28, 113, 48,
-28, 113, 48,
-6, -60, -111,
-48, 108, -45,
48, 108, -45,
65, 38, -101,
58, -45, 102,
15, 53, 114,
-14, 53, 114,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:18 */
static s8 vtxnvgrp_frake_select_18[]={
-33, -120, 19,
-10, -125, 13,
-11, -125, 14,
-11, -125, 14,
10, -126, -1,
92, -78, 36,
-17, -86, -91,
37, -20, -119,
-69, -89, -57,
-69, -89, -57,
-36, 22, -119,
-38, -93, -77,
-38, -93, -77,
-36, 22, -119,
-20, -96, -79,
-20, -96, -79,
-106, 20, -66,
-70, -79, -69,
-70, -79, -69,
-126, -11, -7,
-84, -93, 17,
-17, -86, -91,
81, -89, 37,
41, -115, -33,
73, -62, -82,
-9, -63, -109,
37, -20, -119,
37, -20, -119,
88, -6, -91,
-36, 22, -119,
-36, 22, -119,
-112, 20, -54,
-106, 20, -66,
-106, 20, -66,
-51, -48, -105,
-126, -11, -7,
-126, -11, -7,
-51, -48, -105,
-84, -93, 17,
-84, -93, 17,
-81, -76, -60,
-11, -120, -38,
-11, -120, -38,
19, -88, -89,
41, -115, -33,
41, -115, -33,
-9, -63, -109,
73, -62, -82,
31, 111, 52,
-65, 93, 56,
-1, 119, 43,
77, 20, -98,
90, 36, -81,
108, -41, -50,
125, -10, -18,
89, -84, 33,
92, -78, 36,
92, -78, 36,
89, -84, 33,
-11, -125, 14,
-11, -125, 14,
-68, -49, 94,
-67, -46, 97,
-67, -46, 97,
-68, -49, 94,
-102, 44, 61,
-123, 15, 27,
-99, 77, -11,
-106, 63, -28,
-106, 63, -28,
-17, 88, -89,
-25, 73, -100,
-25, 73, -100,
-17, 88, -89,
77, 20, -98,
90, 36, -81,
112, 58, 0,
125, -10, -18,
125, -10, -18,
112, 58, 0,
122, 18, 26,
-68, 63, 85,
-65, 93, 56,
-102, 44, 61,
-102, 44, 61,
-65, 93, 56,
-99, 77, -11,
-99, 77, -11,
5, 123, -29,
-17, 88, -89,
-17, 88, -89,
5, 123, -29,
90, 36, -81,
82, 96, -1,
5, 123, -29,
31, 111, 52,
41, -115, -33,
73, -62, -82,
-17, -86, -91,
-84, -93, 17,
-65, -61, 89,
-70, -79, -69,
-11, -120, -38,
41, -115, -33,
-84, -93, 17,
41, -115, -33,
16, -95, 82,
-84, -93, 17,
-33, -120, 19,
50, -115, -9,
-70, -79, -69,
-70, -79, -69,
-110, 38, -48,
-123, 15, 27,
-123, 15, 27,
-76, -77, 65,
-67, -46, 97,
-67, -46, 97,
50, -115, -9,
-33, -120, 19,
50, -115, -9,
-55, -76, -85,
38, 15, -120,
38, 15, -120,
-55, -76, -85,
-110, 38, -48,
-110, 38, -48,
-55, -76, -85,
-76, -77, 65,
-76, -77, 65,
-55, -76, -85,
50, -115, -9,
-17, -86, -91,
-80, -92, 32,
10, -126, -1,
10, -126, -1,
-80, -92, 32,
92, -78, 36,
92, -78, 36,
70, -105, 11,
108, -41, -50,
108, -41, -50,
58, -2, -112,
-17, -86, -91,
-94, 47, -70,
-44, -77, -90,
-80, -92, 32,
-80, -92, 32,
-44, -77, -90,
70, -105, 11,
70, -105, 11,
-44, -77, -90,
58, -2, -112,
58, -2, -112,
-44, -77, -90,
-94, 47, -70,
-69, -89, -57,
-68, -95, 47,
-17, -86, -91,
-17, -86, -91,
-68, -95, 47,
108, -41, -50,
108, -41, -50,
76, -98, -23,
77, 20, -98,
77, 20, -98,
-42, 44, -111,
-69, -89, -57,
-119, 15, 41,
-65, -71, -82,
-68, -95, 47,
-68, -95, 47,
-65, -71, -82,
76, -98, -23,
76, -98, -23,
-65, -71, -82,
-42, 44, -111,
-42, 44, -111,
-65, -71, -82,
-119, 15, 41,
-106, 63, -28,
-101, -66, 39,
-123, 15, 27,
-123, 15, 27,
49, -116, 6,
-70, -79, -69,
-70, -79, -69,
49, -116, 6,
-20, -96, -79,
-20, -96, -79,
-18, 38, -119,
-106, 63, -28,
-18, 38, -119,
-33, -76, -95,
-101, -66, 39,
-101, -66, 39,
-33, -76, -95,
49, -116, 6,
49, -116, 6,
-33, -76, -95,
112, -43, -40,
112, -43, -40,
-33, -76, -95,
-18, 38, -119,
-38, -93, -77,
45, -107, 50,
-69, -89, -57,
-69, -89, -57,
45, -107, 50,
77, 20, -98,
77, 20, -98,
-78, 42, -90,
-25, 73, -100,
-25, 73, -100,
-78, 42, -90,
-38, -93, -77,
-111, -46, 38,
-40, -118, -19,
45, -107, 50,
45, -107, 50,
-40, -118, -19,
94, -17, -83,
94, -17, -83,
-40, -118, -19,
-78, 42, -90,
-78, 42, -90,
-40, -118, -19,
-111, -46, 38,
-20, -96, -79,
-35, -90, 81,
-38, -93, -77,
-38, -93, -77,
15, 24, -123,
-25, 73, -100,
-25, 73, -100,
15, 24, -123,
-106, 63, -28,
-106, 63, -28,
-35, -90, 81,
-20, -96, -79,
-35, -90, 81,
-24, -120, -30,
84, -89, -30,
84, -89, -30,
-24, -120, -30,
15, 24, -123,
15, 24, -123,
-24, -120, -30,
-124, 23, -2,
-124, 23, -2,
-24, -120, -30,
-35, -90, 81,
39, 50, 109,
44, 48, 108,
-68, 63, 85,
122, 18, 26,
44, 48, 108,
39, 50, 109,
81, -89, 37,
-17, -86, -91,
10, -126, -1,
-65, -61, 89,
-33, -120, 19,
-70, -79, -69,
-65, -61, 89,
-10, -125, 13,
-33, -120, 19,
81, -89, 37,
10, -126, -1,
-10, -125, 13,
-65, -61, 89,
16, -95, 82,
-10, -125, 13,
122, 18, 26,
89, -84, 33,
125, -10, -18,
-102, 44, 61,
-68, -49, 94,
-68, 63, 85,
92, -78, 36,
108, -41, -50,
125, -10, -18,
-102, 44, 61,
-123, 15, 27,
-67, -46, 97,
-13, 24, 123,
-27, -42, 116,
44, 10, 118,
77, -64, 77,
40, 10, 119,
25, -53, 112,
31, 111, 52,
44, 48, 108,
66, 106, 19,
31, 111, 52,
66, 106, 19,
112, 58, 0,
31, 111, 52,
112, 58, 0,
82, 96, -1,
-1, 119, 43,
44, 48, 108,
31, 111, 52,
31, 111, 52,
-30, 117, 37,
-65, 93, 56,
31, 111, 52,
5, 123, -29,
-30, 117, 37,
39, 50, 109,
37, -71, 98,
21, -91, 85,
21, -91, 85,
-41, -58, 104,
-68, -49, 94,
-68, -49, 94,
-38, 40, 114,
-68, 63, 85,
-68, 63, 85,
62, 24, 107,
39, 50, 109,
89, -84, 33,
75, -77, 67,
21, -91, 85,
21, -91, 85,
7, -66, 107,
39, 50, 109,
39, 50, 109,
28, 29, 120,
122, 18, 26,
122, 18, 26,
110, 14, 61,
89, -84, 33,
110, 14, 61,
75, -77, 67,
89, -84, 33,
28, 29, 120,
110, 14, 61,
122, 18, 26,
7, -66, 107,
28, 29, 120,
39, 50, 109,
75, -77, 67,
7, -66, 107,
21, -91, 85,
-68, 63, 85,
-38, 40, 114,
62, 24, 107,
-68, -49, 94,
-41, -58, 104,
-38, 40, 114,
21, -91, 85,
37, -71, 98,
-41, -58, 104,
39, 50, 109,
62, 24, 107,
37, -71, 98,
122, 18, 26,
66, 106, 19,
44, 48, 108,
44, 48, 108,
-1, 119, 43,
-68, 63, 85,
-106, 63, -28,
-124, 23, -2,
-35, -90, 81,
15, 24, -123,
-124, 23, -2,
-106, 63, -28,
-38, -93, -77,
84, -89, -30,
15, 24, -123,
-35, -90, 81,
84, -89, -30,
-38, -93, -77,
-78, 42, -90,
-111, -46, 38,
-38, -93, -77,
77, 20, -98,
94, -17, -83,
-78, 42, -90,
45, -107, 50,
94, -17, -83,
77, 20, -98,
-38, -93, -77,
-111, -46, 38,
45, -107, 50,
-20, -96, -79,
112, -43, -40,
-18, 38, -119,
49, -116, 6,
112, -43, -40,
-20, -96, -79,
-123, 15, 27,
-101, -66, 39,
49, -116, 6,
-106, 63, -28,
-18, 38, -119,
-101, -66, 39,
-42, 44, -111,
-119, 15, 41,
-69, -89, -57,
76, -98, -23,
-42, 44, -111,
77, 20, -98,
-68, -95, 47,
76, -98, -23,
108, -41, -50,
-69, -89, -57,
-119, 15, 41,
-68, -95, 47,
58, -2, -112,
-94, 47, -70,
-17, -86, -91,
70, -105, 11,
58, -2, -112,
108, -41, -50,
-80, -92, 32,
70, -105, 11,
92, -78, 36,
-17, -86, -91,
-94, 47, -70,
-80, -92, 32,
-67, -46, 97,
-76, -77, 65,
50, -115, -9,
-123, 15, 27,
-110, 38, -48,
-76, -77, 65,
-70, -79, -69,
38, 15, -120,
-110, 38, -48,
50, -115, -9,
38, 15, -120,
-70, -79, -69,
16, -95, 82,
-65, -61, 89,
-84, -93, 17,
5, 123, -29,
82, 96, -1,
90, 36, -81,
-99, 77, -11,
-30, 117, 37,
5, 123, -29,
-65, 93, 56,
-30, 117, 37,
-99, 77, -11,
-68, 63, 85,
-1, 119, 43,
-65, 93, 56,
112, 58, 0,
66, 106, 19,
122, 18, 26,
90, 36, -81,
82, 96, -1,
112, 58, 0,
-17, 88, -89,
90, 36, -81,
77, 20, -98,
-106, 63, -28,
-99, 77, -11,
-17, 88, -89,
-123, 15, 27,
-102, 44, 61,
-99, 77, -11,
-11, -125, 14,
21, -91, 85,
-68, -49, 94,
89, -84, 33,
21, -91, 85,
-11, -125, 14,
90, 36, -81,
125, -10, -18,
108, -41, -50,
-9, -63, -109,
19, -88, -89,
-81, -76, -60,
19, -88, -89,
-11, -120, -38,
-81, -76, -60,
-9, -63, -109,
-81, -76, -60,
-51, -48, -105,
41, -115, -33,
19, -88, -89,
-9, -63, -109,
-51, -48, -105,
-81, -76, -60,
-84, -93, 17,
-106, 20, -66,
-112, 20, -54,
-51, -48, -105,
-36, 22, -119,
-3, 26, -124,
-112, 20, -54,
88, -6, -91,
-3, 26, -124,
-36, 22, -119,
-9, -63, -109,
88, -6, -91,
37, -20, -119,
-106, 20, -66,
-126, -11, -7,
-70, -79, -69,
-36, 22, -119,
-106, 20, -66,
-20, -96, -79,
-69, -89, -57,
37, -20, -119,
-36, 22, -119,
-17, -86, -91,
73, -62, -82,
37, -20, -119,
-11, -125, 14,
-10, -125, 13,
10, -126, -1,
-11, -125, 14,
-67, -46, 97,
-33, -120, 19,
16, -95, 82,
81, -89, 37,
-10, -125, 13,
7, -66, 107,
90, 0, 88,
28, 29, 120,
28, 29, 120,
25, -53, 112,
110, 14, 61,
110, 14, 61,
25, -53, 112,
75, -77, 67,
75, -77, 67,
90, 0, 88,
7, -66, 107,
62, 24, 107,
-13, 24, 123,
37, -71, 98,
37, -71, 98,
-13, 24, 123,
-41, -58, 104,
-41, -58, 104,
34, -56, 108,
-38, 40, 114,
-38, 40, 114,
34, -56, 108,
62, 24, 107,
34, -56, 108,
-27, -42, 116,
62, 24, 107,
-41, -58, 104,
44, 10, 118,
34, -56, 108,
-13, 24, 123,
44, 10, 118,
-41, -58, 104,
62, 24, 107,
-27, -42, 116,
-13, 24, 123,
75, -77, 67,
40, 10, 119,
90, 0, 88,
25, -53, 112,
40, 10, 119,
75, -77, 67,
28, 29, 120,
77, -64, 77,
25, -53, 112,
90, 0, 88,
77, -64, 77,
28, 29, 120,
77, -64, 77,
90, 0, 88,
40, 10, 119,
-27, -42, 116,
34, -56, 108,
44, 10, 118,
41, -115, -33,
81, -89, 37,
16, -95, 82,
58, -44, 103,
-14, 55, 113,
-58, -44, 103,
94, 18, -83,
-94, 18, -83,
85, 50, -79,
15, 55, 113,
26, 115, 46,
-14, 55, 113,
-14, 55, 113,
-29, 123, -10,
-48, 107, -46,
-48, 107, -46,
29, 123, -10,
48, 107, -46,
48, 107, -46,
29, 123, -10,
15, 55, 113,
83, -21, 93,
94, 18, -83,
85, 50, -79,
-83, -21, 93,
83, -82, 48,
83, -21, 93,
-85, 50, -79,
-94, 18, -83,
-83, -21, 93,
-65, 36, -102,
-48, 107, -46,
65, 36, -102,
-94, 18, -83,
-83, -82, 48,
-83, -21, 93,
-83, -21, 93,
-83, -82, 48,
83, -82, 48,
83, -21, 93,
83, -82, 48,
94, 18, -83,
29, 123, -10,
-26, 115, 46,
15, 55, 113,
-48, 107, -46,
-29, 123, -10,
29, 123, -10,
-14, 55, 113,
26, 115, 46,
-29, 123, -10,
15, 55, 113,
-26, 115, 46,
26, 115, 46,
-94, 18, -83,
-85, 50, -79,
85, 50, -79,
26, 115, 46,
-9, -63, -109,
-51, -48, -105,
-26, 115, 46,
88, -6, -91,
-9, -63, -109,
29, 123, -10,
-3, 26, -124,
88, -6, -91,
-29, 123, -10,
-112, 20, -54,
-3, 26, -124,
26, 115, 46,
-51, -48, -105,
-112, 20, -54,
29, 123, -10,
-29, 123, -10,
-3, 26, -124,
-29, 123, -10,
26, 115, 46,
-112, 20, -54,
58, -44, 103,
85, 50, -79,
65, 36, -102,
-58, -44, 103,
83, -21, 93,
58, -44, 103,
65, 36, -102,
-85, 50, -79,
-65, 36, -102,
-65, 36, -102,
-85, 50, -79,
-58, -44, 103,
-99, -43, 65,
93, -56, 64,
-50, 49, 105,
42, -45, -110,
-99, 26, -74,
91, 10, -87,
42, -115, 30,
42, -45, -110,
93, -56, 64,
-99, 26, -74,
-50, 49, 105,
-68, 106, -6,
-99, 26, -74,
-99, -43, 65,
-50, 49, 105,
42, -45, -110,
91, 10, -87,
93, -56, 64,
-99, 26, -74,
-68, 106, -6,
91, 10, -87,
-99, -43, 65,
42, -115, 30,
93, -56, 64,
-50, 49, 105,
-58, -44, 103,
-14, 55, 113,
93, -56, 64,
-65, 36, -102,
-58, -44, 103,
91, 10, -87,
-68, 106, -6,
-65, 36, -102,
-68, 106, -6,
-14, 55, 113,
-48, 107, -46,
50, 49, 105,
-93, -56, 64,
99, -43, 65,
-91, 10, -87,
99, 26, -74,
-42, -45, -110,
-93, -56, 64,
-42, -45, -110,
-42, -115, 30,
68, 106, -6,
50, 49, 105,
99, 26, -74,
50, 49, 105,
99, -43, 65,
99, 26, -74,
-93, -56, 64,
-91, 10, -87,
-42, -45, -110,
-91, 10, -87,
68, 106, -6,
99, 26, -74,
-93, -56, 64,
-42, -115, 30,
99, -43, 65,
50, 49, 105,
48, 107, -46,
15, 55, 113,
68, 106, -6,
65, 36, -102,
48, 107, -46,
-91, 10, -87,
-93, -56, 64,
65, 36, -102,
-93, -56, 64,
50, 49, 105,
58, -44, 103,
68, 106, -6,
48, 107, -46,
50, 49, 105,
-14, 55, 113,
-68, 106, -6,
-50, 49, 105,
114, -54, 12,
-65, -100, 42,
118, 20, 41,
97, -5, -81,
61, -27, -107,
-97, -5, -81,
-97, -5, -81,
118, 20, 41,
97, -5, -81,
-97, -5, -81,
114, -54, 12,
118, 20, 41,
-61, -27, -107,
-65, -100, 42,
-94, 18, -83,
-65, -100, 42,
83, -82, 48,
-83, -82, 48,
55, -107, 36,
94, 18, -83,
83, -82, 48,
61, -27, -107,
-94, 18, -83,
94, 18, -83,
-78, -4, 99,
72, -8, 103,
-91, 83, 29,
73, -102, -13,
-88, -28, -86,
90, -21, -86,
72, -8, 103,
73, -102, -13,
84, 93, 16,
-78, -98, -15,
-91, 83, 29,
-88, -28, -86,
-78, -98, -15,
-78, -4, 99,
-91, 83, 29,
73, -102, -13,
90, -21, -86,
84, 93, 16,
73, -102, -13,
-78, -98, -15,
-88, -28, -86,
72, -8, 103,
84, 93, 16,
-91, 83, 29,
-91, 83, 29,
84, 93, 16,
-65, -100, 42,
84, 93, 16,
90, -21, -86,
118, 20, 41,
90, -21, -86,
-61, -27, -107,
97, -5, -81,
-88, -28, -86,
-65, -100, 42,
-61, -27, -107,
87, 86, 29,
-73, -6, 103,
78, -4, 99,
-89, -22, -87,
88, -28, -86,
-73, -102, -13,
-66, 105, -21,
-73, -102, -13,
-73, -6, 103,
88, -28, -86,
87, 86, 29,
78, -98, -15,
87, 86, 29,
78, -4, 99,
78, -98, -15,
-66, 105, -21,
-89, -22, -87,
-73, -102, -13,
88, -28, -86,
78, -98, -15,
-73, -102, -13,
87, 86, 29,
-66, 105, -21,
-73, -6, 103,
87, 86, 29,
88, -28, -86,
55, -107, 36,
-89, -22, -87,
-97, -5, -81,
61, -27, -107,
-89, -22, -87,
114, -54, 12,
-97, -5, -81,
-66, 105, -21,
55, -107, 36,
114, -54, 12,
-42, -45, -110,
38, -88, -82,
-42, -115, 30,
-42, -115, 30,
94, -85, -2,
99, -43, 65,
99, -43, 65,
94, -85, -2,
99, 26, -74,
99, 26, -74,
94, -52, -67,
-42, -45, -110,
42, -115, 30,
-38, -119, -22,
42, -45, -110,
42, -45, -110,
-94, -52, -67,
-99, 26, -74,
-99, 26, -74,
-94, -52, -67,
-99, -43, 65,
-99, -43, 65,
-94, -85, -2,
42, -115, 30,
-75, -92, 44,
80, 13, 97,
38, -119, -22,
80, 13, 97,
94, -52, -67,
94, -85, -2,
80, 85, -47,
38, -88, -82,
94, -52, -67,
-75, -19, -100,
-75, -92, 44,
38, -88, -82,
-80, 13, 97,
-38, -119, -22,
-94, -85, -2,
75, -19, -100,
-94, -52, -67,
-38, -88, -82,
-80, 85, -47,
-80, 13, 97,
-94, -52, -67,
-38, -88, -82,
-38, -119, -22,
75, -19, -100,
-99, -32, 71,
71, -80, 67,
-57, 8, 112,
33, -36, -116,
-92, 45, -74,
81, 10, -96,
31, -119, 28,
33, -36, -116,
71, -80, 67,
-92, 45, -74,
-57, 8, 112,
-53, 104, -49,
-92, 45, -74,
-99, -32, 71,
-57, 8, 112,
33, -36, -116,
81, 10, -96,
71, -80, 67,
-92, 45, -74,
-53, 104, -49,
81, 10, -96,
-99, -32, 71,
31, -119, 28,
71, -80, 67,
33, -36, -116,
-72, -95, -41,
-92, 45, -74,
-92, 45, -74,
-72, -95, -41,
-99, -32, 71,
-99, -32, 71,
-72, -95, -41,
31, -119, 28,
31, -119, 28,
-72, -95, -41,
33, -36, -116,
81, 10, -96,
-80, 85, -47,
75, -19, -100,
-53, 104, -49,
-57, 8, 112,
-80, 85, -47,
-57, 8, 112,
71, -80, 67,
-80, 13, 97,
71, -80, 67,
81, 10, -96,
75, -92, 44,
73, -102, -13,
-26, -110, 57,
-78, -98, -15,
-78, -98, -15,
-26, -110, 57,
-78, -4, 99,
-78, -4, 99,
-33, -75, 96,
72, -8, 103,
72, -8, 103,
35, -72, 98,
73, -102, -13,
-73, -6, 103,
-35, -72, 98,
78, -4, 99,
78, -4, 99,
26, -110, 57,
78, -98, -15,
78, -98, -15,
26, -110, 57,
-73, -102, -13,
-73, -102, -13,
-35, -72, 98,
-73, -6, 103,
89, 41, 79,
78, 42, 90,
-89, 41, 79,
-89, -41, -79,
-92, -68, -53,
89, -41, -79,
-81, 44, 86,
-92, -68, -53,
-89, 41, 79,
89, -73, -51,
78, 42, 90,
89, -41, -79,
89, 41, 79,
49, 116, 14,
89, -41, -79,
89, -41, -79,
73, -1, -103,
-89, -41, -79,
-89, -41, -79,
-97, 80, 10,
-89, 41, 79,
-89, 41, 79,
-97, 80, 10,
89, 41, 79,
-97, 80, 10,
49, 116, 14,
89, 41, 79,
-89, -41, -79,
-89, -22, -87,
-97, 80, 10,
73, -1, -103,
-89, -22, -87,
-89, -41, -79,
49, 116, 14,
73, -1, -103,
89, -41, -79,
78, 42, 90,
89, 41, 79,
89, -41, -79,
-92, -68, -53,
-89, -41, -79,
-89, 41, 79,
-92, -68, -53,
89, -73, -51,
89, -41, -79,
78, 42, 90,
-81, 44, 86,
-89, 41, 79,
-92, -68, -53,
-35, -72, 98,
-27, -111, 54,
-81, 44, 86,
78, 42, 90,
-35, -72, 98,
78, 42, 90,
89, -73, -51,
33, -75, 96,
89, -73, -51,
-27, -111, 54,
26, -110, 57,
89, 41, 79,
-78, 42, 90,
-89, 41, 79,
-89, -41, -79,
92, -68, -53,
89, -41, -79,
89, 41, 79,
92, -68, -53,
81, 44, 86,
-89, -41, -79,
-78, 42, 90,
-89, -73, -51,
-89, -41, -79,
-49, 116, 14,
-89, 41, 79,
89, -41, -79,
-73, -1, -103,
-89, -41, -79,
89, 41, 79,
97, 80, 10,
89, -41, -79,
-89, 41, 79,
97, 80, 10,
89, 41, 79,
-89, 41, 79,
-49, 116, 14,
97, 80, 10,
97, 80, 10,
89, -22, -87,
89, -41, -79,
89, -41, -79,
89, -22, -87,
-73, -1, -103,
-89, -41, -79,
-73, -1, -103,
-49, 116, 14,
-89, -41, -79,
-89, 41, 79,
-78, 42, 90,
89, 41, 79,
89, -41, -79,
92, -68, -53,
-89, -41, -79,
-89, -73, -51,
92, -68, -53,
89, 41, 79,
81, 44, 86,
-78, 42, 90,
-78, 42, 90,
35, -72, 98,
-33, -75, 96,
81, 44, 86,
92, -68, -53,
35, -72, 98,
92, -68, -53,
-89, -73, -51,
27, -111, 54,
-89, -73, -51,
-33, -75, 96,
-26, -110, 57,
86, -88, -27,
-53, -104, -47,
88, -16, -89,
-64, 107, -17,
95, 78, -29,
-91, 61, -63,
99, -61, 49,
77, -36, 94,
-93, -85, 9,
77, -36, 94,
95, 78, -29,
61, 110, 2,
-93, -85, 9,
-101, -42, 63,
-91, 61, -63,
61, 110, 2,
-18, 38, 119,
77, -36, 94,
77, -36, 94,
-18, 38, 119,
-101, -42, 63,
-101, -42, 63,
-18, 38, 119,
-64, 107, -17,
-64, 107, -17,
-18, 38, 119,
61, 110, 2,
99, -61, 49,
86, -88, -27,
95, 78, -29,
-93, -85, 9,
-53, -104, -47,
99, -61, 49,
-91, 61, -63,
-56, -24, -110,
-93, -85, 9,
-56, -24, -110,
-53, -104, -47,
-93, -85, 9,
-53, -104, -47,
86, -88, -27,
99, -61, 49,
86, -88, -27,
88, -16, -89,
95, 78, -29,
-101, -42, 63,
-64, 107, -17,
-91, 61, -63,
77, -36, 94,
99, -61, 49,
95, 78, -29,
77, -36, 94,
-101, -42, 63,
-93, -85, 9,
-64, 107, -17,
61, 110, 2,
95, 78, -29,
-53, -104, -47,
-56, -24, -110,
88, -16, -89,
95, 78, -29,
88, -16, -89,
97, 80, 10,
88, -16, -89,
-56, -24, -110,
89, -22, -87,
-56, -24, -110,
-91, 61, -63,
-73, -1, -103,
-91, 61, -63,
95, 78, -29,
-49, 116, 14,
-88, -16, -89,
53, -104, -47,
-86, -88, -27,
91, 61, -63,
-95, 78, -29,
64, 107, -17,
93, -85, 9,
-77, -36, 94,
-99, -61, 49,
-61, 110, 2,
-95, 78, -29,
-77, -36, 94,
91, 61, -63,
101, -42, 63,
93, -85, 9,
-77, -36, 94,
18, 38, 119,
-61, 110, 2,
101, -42, 63,
18, 38, 119,
-77, -36, 94,
64, 107, -17,
18, 38, 119,
101, -42, 63,
-61, 110, 2,
18, 38, 119,
64, 107, -17,
-95, 78, -29,
-86, -88, -27,
-99, -61, 49,
-99, -61, 49,
53, -104, -47,
93, -85, 9,
93, -85, 9,
56, -24, -110,
91, 61, -63,
93, -85, 9,
53, -104, -47,
56, -24, -110,
-99, -61, 49,
-86, -88, -27,
53, -104, -47,
-95, 78, -29,
-88, -16, -89,
-86, -88, -27,
91, 61, -63,
64, 107, -17,
101, -42, 63,
-95, 78, -29,
-99, -61, 49,
-77, -36, 94,
93, -85, 9,
101, -42, 63,
-77, -36, 94,
-95, 78, -29,
-61, 110, 2,
64, 107, -17,
-88, -16, -89,
56, -24, -110,
53, -104, -47,
-95, 78, -29,
49, 116, 14,
-97, 80, 10,
91, 61, -63,
73, -1, -103,
49, 116, 14,
56, -24, -110,
-89, -22, -87,
73, -1, -103,
-88, -16, -89,
-97, 80, 10,
-89, -22, -87,
61, -27, -107,
88, -28, -86,
-89, -22, -87,
90, -21, -86,
-88, -28, -86,
-61, -27, -107,
80, 85, -47,
-81, 10, -96,
-75, -19, -100,
-75, -19, -100,
-71, -80, 67,
-75, -92, 44,
80, 13, 97,
53, 104, -49,
80, 85, -47,
57, 8, 112,
-71, -80, 67,
99, -32, 71,
-81, 10, -96,
92, 45, -74,
-33, -36, -116,
-71, -80, 67,
-33, -36, -116,
-31, -119, 28,
53, 104, -49,
57, 8, 112,
92, 45, -74,
57, 8, 112,
99, -32, 71,
92, 45, -74,
-71, -80, 67,
-81, 10, -96,
-33, -36, -116,
-81, 10, -96,
53, 104, -49,
92, 45, -74,
-71, -80, 67,
-31, -119, 28,
99, -32, 71,
92, 45, -74,
72, -95, -41,
-33, -36, -116,
99, -32, 71,
72, -95, -41,
92, 45, -74,
-31, -119, 28,
72, -95, -41,
99, -32, 71,
-33, -36, -116,
72, -95, -41,
-31, -119, 28,
-75, -92, 44,
-71, -80, 67,
80, 13, 97,
-71, -80, 67,
57, 8, 112,
80, 13, 97,
80, 13, 97,
57, 8, 112,
53, 104, -49,
-75, -19, -100,
-81, 10, -96,
-71, -80, 67,
80, 85, -47,
53, 104, -49,
-81, 10, -96,
-88, -16, -89,
-95, 78, -29,
-97, 80, 10,
56, -24, -110,
-88, -16, -89,
-89, -22, -87,
91, 61, -63,
56, -24, -110,
73, -1, -103,
-95, 78, -29,
91, 61, -63,
49, 116, 14,
95, 78, -29,
97, 80, 10,
-49, 116, 14,
-91, 61, -63,
-49, 116, 14,
-73, -1, -103,
-56, -24, -110,
-73, -1, -103,
89, -22, -87,
88, -16, -89,
89, -22, -87,
97, 80, 10,
-89, -73, -51,
-78, 42, 90,
-33, -75, 96,
-89, -73, -51,
-26, -110, 57,
27, -111, 54,
92, -68, -53,
27, -111, 54,
35, -72, 98,
-78, 42, 90,
81, 44, 86,
35, -72, 98,
89, -73, -51,
-92, -68, -53,
-27, -111, 54,
89, -73, -51,
26, -110, 57,
33, -75, 96,
78, 42, 90,
33, -75, 96,
-35, -72, 98,
-92, -68, -53,
-81, 44, 86,
-35, -72, 98,
-73, -102, -13,
-27, -111, 54,
-35, -72, 98,
26, -110, 57,
-27, -111, 54,
-73, -102, -13,
78, -4, 99,
33, -75, 96,
26, -110, 57,
-35, -72, 98,
33, -75, 96,
78, -4, 99,
35, -72, 98,
27, -111, 54,
73, -102, -13,
-33, -75, 96,
35, -72, 98,
72, -8, 103,
-26, -110, 57,
-33, -75, 96,
-78, -4, 99,
73, -102, -13,
27, -111, 54,
-26, -110, 57,
81, 10, -96,
75, -19, -100,
75, -92, 44,
71, -80, 67,
75, -92, 44,
-80, 13, 97,
-57, 8, 112,
-80, 13, 97,
-80, 85, -47,
81, 10, -96,
-53, 104, -49,
-80, 85, -47,
-38, -119, -22,
75, -92, 44,
75, -19, -100,
-80, 13, 97,
-94, -85, -2,
-94, -52, -67,
75, -19, -100,
-80, 85, -47,
-94, -52, -67,
-80, 13, 97,
75, -92, 44,
-38, -119, -22,
-75, -92, 44,
38, -119, -22,
38, -88, -82,
80, 85, -47,
-75, -19, -100,
38, -88, -82,
80, 13, 97,
80, 85, -47,
94, -52, -67,
80, 13, 97,
94, -85, -2,
38, -119, -22,
-94, -85, -2,
-38, -119, -22,
42, -115, 30,
-94, -52, -67,
-94, -85, -2,
-99, -43, 65,
42, -45, -110,
-38, -88, -82,
-94, -52, -67,
-38, -119, -22,
-38, -88, -82,
42, -45, -110,
94, -52, -67,
38, -88, -82,
-42, -45, -110,
94, -85, -2,
94, -52, -67,
99, 26, -74,
-42, -115, 30,
38, -119, -22,
94, -85, -2,
38, -88, -82,
38, -119, -22,
-42, -115, 30,
-66, 105, -21,
87, 86, 29,
55, -107, 36,
-89, -22, -87,
-66, 105, -21,
114, -54, 12,
88, -28, -86,
61, -27, -107,
55, -107, 36,
-88, -28, -86,
-91, 83, 29,
-65, -100, 42,
90, -21, -86,
97, -5, -81,
118, 20, 41,
84, 93, 16,
118, 20, 41,
-65, -100, 42,
61, -27, -107,
-61, -27, -107,
-94, 18, -83,
55, -107, 36,
61, -27, -107,
94, 18, -83,
-65, -100, 42,
55, -107, 36,
83, -82, 48,
-65, -100, 42,
-83, -82, 48,
-94, 18, -83,
97, -5, -81,
-61, -27, -107,
61, -27, -107,
114, -54, 12,
55, -107, 36,
-65, -100, 42,
50, 49, 105,
15, 55, 113,
58, -44, 103,
-93, -56, 64,
58, -44, 103,
65, 36, -102,
68, 106, -6,
-91, 10, -87,
65, 36, -102,
-68, 106, -6,
-48, 107, -46,
-65, 36, -102,
93, -56, 64,
91, 10, -87,
-65, 36, -102,
-50, 49, 105,
93, -56, 64,
-58, -44, 103,
-85, 50, -79,
-83, -21, 93,
-58, -44, 103,
65, 36, -102,
85, 50, -79,
-85, 50, -79,
-58, -44, 103,
-83, -21, 93,
83, -21, 93,
58, -44, 103,
83, -21, 93,
85, 50, -79,
-26, 115, 46,
29, 123, -10,
88, -6, -91,
26, 115, 46,
-26, 115, 46,
-9, -63, -109,
-48, 107, -46,
48, 107, -46,
65, 36, -102,
58, -44, 103,
15, 55, 113,
-14, 55, 113,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:19 */
static s8 vtxnvgrp_frake_select_19[]={
-33, -120, 24,
-10, -125, 16,
-11, -125, 18,
-11, -125, 18,
9, -126, 1,
92, -79, 34,
-23, -88, -88,
32, -25, -120,
-74, -90, -50,
-74, -90, -50,
-41, 20, -118,
-42, -95, -72,
-42, -95, -72,
-41, 20, -118,
-26, -98, -75,
-26, -98, -75,
-108, 22, -61,
-75, -80, -63,
-75, -80, -63,
-126, -8, -1,
-85, -91, 24,
-23, -88, -88,
81, -90, 36,
38, -116, -31,
68, -67, -83,
-12, -67, -106,
32, -25, -120,
32, -25, -120,
86, -10, -92,
-41, 20, -118,
-41, 20, -118,
-113, 21, -51,
-108, 22, -61,
-108, 22, -61,
-55, -49, -102,
-126, -8, -1,
-126, -8, -1,
-55, -49, -102,
-85, -91, 24,
-85, -91, 24,
-84, -76, -55,
-12, -122, -32,
-12, -122, -32,
15, -91, -86,
38, -116, -31,
38, -116, -31,
-12, -67, -106,
68, -67, -83,
34, 112, 47,
-61, 96, 55,
3, 120, 39,
72, 15, -103,
86, 31, -87,
105, -45, -53,
123, -15, -23,
88, -85, 31,
92, -79, 34,
92, -79, 34,
88, -85, 31,
-11, -125, 18,
-11, -125, 18,
-64, -45, 99,
-62, -41, 102,
-62, -41, 102,
-64, -45, 99,
-98, 48, 64,
-121, 19, 32,
-98, 79, -9,
-105, 65, -25,
-105, 65, -25,
-20, 86, -90,
-29, 71, -100,
-29, 71, -100,
-20, 86, -90,
72, 15, -103,
86, 31, -87,
113, 56, -7,
123, -15, -23,
123, -15, -23,
113, 56, -7,
124, 15, 20,
-63, 68, 85,
-61, 96, 55,
-98, 48, 64,
-98, 48, 64,
-61, 96, 55,
-98, 79, -9,
-98, 79, -9,
5, 122, -33,
-20, 86, -90,
-20, 86, -90,
5, 122, -33,
86, 31, -87,
83, 95, -8,
5, 122, -33,
34, 112, 47,
38, -116, -31,
68, -67, -83,
-23, -88, -88,
-85, -91, 24,
-62, -56, 94,
-75, -80, -63,
-12, -122, -32,
38, -116, -31,
-85, -91, 24,
38, -116, -31,
19, -92, 84,
-85, -91, 24,
-33, -120, 24,
49, -116, -7,
-75, -80, -63,
-75, -80, -63,
-111, 40, -44,
-121, 19, 32,
-121, 19, 32,
-74, -73, 72,
-62, -41, 102,
-62, -41, 102,
49, -116, -7,
-33, -120, 24,
49, -116, -7,
-61, -77, -79,
33, 10, -122,
33, 10, -122,
-61, -77, -79,
-111, 40, -44,
-111, 40, -44,
-61, -77, -79,
-74, -73, 72,
-74, -73, 72,
-61, -77, -79,
49, -116, -7,
-23, -88, -88,
-80, -90, 38,
9, -126, 1,
9, -126, 1,
-80, -90, 38,
92, -79, 34,
92, -79, 34,
69, -105, 11,
105, -45, -53,
105, -45, -53,
52, -7, -115,
-23, -88, -88,
-96, 47, -67,
-50, -78, -85,
-80, -90, 38,
-80, -90, 38,
-50, -78, -85,
69, -105, 11,
69, -105, 11,
-50, -78, -85,
52, -7, -115,
52, -7, -115,
-50, -78, -85,
-96, 47, -67,
-74, -90, -50,
-68, -92, 54,
-23, -88, -88,
-23, -88, -88,
-68, -92, 54,
105, -45, -53,
105, -45, -53,
73, -100, -23,
72, 15, -103,
72, 15, -103,
-46, 42, -110,
-74, -90, -50,
-116, 20, 46,
-70, -72, -76,
-68, -92, 54,
-68, -92, 54,
-70, -72, -76,
73, -100, -23,
73, -100, -23,
-70, -72, -76,
-46, 42, -110,
-46, 42, -110,
-70, -72, -76,
-116, 20, 46,
-105, 65, -25,
-100, -62, 45,
-121, 19, 32,
-121, 19, 32,
48, -117, 7,
-75, -80, -63,
-75, -80, -63,
48, -117, 7,
-26, -98, -75,
-26, -98, -75,
-22, 34, -120,
-105, 65, -25,
-22, 34, -120,
-40, -78, -91,
-100, -62, 45,
-100, -62, 45,
-40, -78, -91,
48, -117, 7,
48, -117, 7,
-40, -78, -91,
109, -47, -43,
109, -47, -43,
-40, -78, -91,
-22, 34, -120,
-42, -95, -72,
45, -106, 51,
-74, -90, -50,
-74, -90, -50,
45, -106, 51,
72, 15, -103,
72, 15, -103,
-81, 41, -87,
-29, 71, -100,
-29, 71, -100,
-81, 41, -87,
-42, -95, -72,
-110, -42, 45,
-43, -118, -13,
45, -106, 51,
45, -106, 51,
-43, -118, -13,
89, -21, -86,
89, -21, -86,
-43, -118, -13,
-81, 41, -87,
-81, 41, -87,
-43, -118, -13,
-110, -42, 45,
-26, -98, -75,
-32, -87, 86,
-42, -95, -72,
-42, -95, -72,
10, 19, -125,
-29, 71, -100,
-29, 71, -100,
10, 19, -125,
-105, 65, -25,
-105, 65, -25,
-32, -87, 86,
-26, -98, -75,
-32, -87, 86,
-28, -120, -26,
81, -92, -31,
81, -92, -31,
-28, -120, -26,
10, 19, -125,
10, 19, -125,
-28, -120, -26,
-124, 25, 3,
-124, 25, 3,
-28, -120, -26,
-32, -87, 86,
44, 52, 106,
49, 50, 105,
-63, 68, 85,
124, 15, 20,
49, 50, 105,
44, 52, 106,
81, -90, 36,
-23, -88, -88,
9, -126, 1,
-62, -56, 94,
-33, -120, 24,
-75, -80, -63,
-62, -56, 94,
-10, -125, 16,
-33, -120, 24,
81, -90, 36,
9, -126, 1,
-10, -125, 16,
-62, -56, 94,
19, -92, 84,
-10, -125, 16,
124, 15, 20,
88, -85, 31,
123, -15, -23,
-98, 48, 64,
-64, -45, 99,
-63, 68, 85,
92, -79, 34,
105, -45, -53,
123, -15, -23,
-98, 48, 64,
-121, 19, 32,
-62, -41, 102,
-7, 28, 123,
-22, -38, 119,
50, 13, 115,
79, -64, 75,
46, 12, 117,
30, -50, 112,
34, 112, 47,
49, 50, 105,
69, 105, 12,
34, 112, 47,
69, 105, 12,
113, 56, -7,
34, 112, 47,
113, 56, -7,
83, 95, -8,
3, 120, 39,
49, 50, 105,
34, 112, 47,
34, 112, 47,
-27, 119, 34,
-61, 96, 55,
34, 112, 47,
5, 122, -33,
-27, 119, 34,
44, 52, 106,
41, -68, 98,
25, -89, 86,
25, -89, 86,
-37, -54, 108,
-64, -45, 99,
-64, -45, 99,
-32, 44, 114,
-63, 68, 85,
-63, 68, 85,
67, 26, 103,
44, 52, 106,
88, -85, 31,
76, -76, 66,
25, -89, 86,
25, -89, 86,
11, -63, 109,
44, 52, 106,
44, 52, 106,
34, 31, 117,
124, 15, 20,
124, 15, 20,
112, 14, 56,
88, -85, 31,
112, 14, 56,
76, -76, 66,
88, -85, 31,
34, 31, 117,
112, 14, 56,
124, 15, 20,
11, -63, 109,
34, 31, 117,
44, 52, 106,
76, -76, 66,
11, -63, 109,
25, -89, 86,
-63, 68, 85,
-32, 44, 114,
67, 26, 103,
-64, -45, 99,
-37, -54, 108,
-32, 44, 114,
25, -89, 86,
41, -68, 98,
-37, -54, 108,
44, 52, 106,
67, 26, 103,
41, -68, 98,
124, 15, 20,
69, 105, 12,
49, 50, 105,
49, 50, 105,
3, 120, 39,
-63, 68, 85,
-105, 65, -25,
-124, 25, 3,
-32, -87, 86,
10, 19, -125,
-124, 25, 3,
-105, 65, -25,
-42, -95, -72,
81, -92, -31,
10, 19, -125,
-32, -87, 86,
81, -92, -31,
-42, -95, -72,
-81, 41, -87,
-110, -42, 45,
-42, -95, -72,
72, 15, -103,
89, -21, -86,
-81, 41, -87,
45, -106, 51,
89, -21, -86,
72, 15, -103,
-42, -95, -72,
-110, -42, 45,
45, -106, 51,
-26, -98, -75,
109, -47, -43,
-22, 34, -120,
48, -117, 7,
109, -47, -43,
-26, -98, -75,
-121, 19, 32,
-100, -62, 45,
48, -117, 7,
-105, 65, -25,
-22, 34, -120,
-100, -62, 45,
-46, 42, -110,
-116, 20, 46,
-74, -90, -50,
73, -100, -23,
-46, 42, -110,
72, 15, -103,
-68, -92, 54,
73, -100, -23,
105, -45, -53,
-74, -90, -50,
-116, 20, 46,
-68, -92, 54,
52, -7, -115,
-96, 47, -67,
-23, -88, -88,
69, -105, 11,
52, -7, -115,
105, -45, -53,
-80, -90, 38,
69, -105, 11,
92, -79, 34,
-23, -88, -88,
-96, 47, -67,
-80, -90, 38,
-62, -41, 102,
-74, -73, 72,
49, -116, -7,
-121, 19, 32,
-111, 40, -44,
-74, -73, 72,
-75, -80, -63,
33, 10, -122,
-111, 40, -44,
49, -116, -7,
33, 10, -122,
-75, -80, -63,
19, -92, 84,
-62, -56, 94,
-85, -91, 24,
5, 122, -33,
83, 95, -8,
86, 31, -87,
-98, 79, -9,
-27, 119, 34,
5, 122, -33,
-61, 96, 55,
-27, 119, 34,
-98, 79, -9,
-63, 68, 85,
3, 120, 39,
-61, 96, 55,
113, 56, -7,
69, 105, 12,
124, 15, 20,
86, 31, -87,
83, 95, -8,
113, 56, -7,
-20, 86, -90,
86, 31, -87,
72, 15, -103,
-105, 65, -25,
-98, 79, -9,
-20, 86, -90,
-121, 19, 32,
-98, 48, 64,
-98, 79, -9,
-11, -125, 18,
25, -89, 86,
-64, -45, 99,
88, -85, 31,
25, -89, 86,
-11, -125, 18,
86, 31, -87,
123, -15, -23,
105, -45, -53,
-12, -67, -106,
15, -91, -86,
-84, -76, -55,
15, -91, -86,
-12, -122, -32,
-84, -76, -55,
-12, -67, -106,
-84, -76, -55,
-55, -49, -102,
38, -116, -31,
15, -91, -86,
-12, -67, -106,
-55, -49, -102,
-84, -76, -55,
-85, -91, 24,
-108, 22, -61,
-113, 21, -51,
-55, -49, -102,
-41, 20, -118,
-3, 23, -124,
-113, 21, -51,
86, -10, -92,
-3, 23, -124,
-41, 20, -118,
-12, -67, -106,
86, -10, -92,
32, -25, -120,
-108, 22, -61,
-126, -8, -1,
-75, -80, -63,
-41, 20, -118,
-108, 22, -61,
-26, -98, -75,
-74, -90, -50,
32, -25, -120,
-41, 20, -118,
-23, -88, -88,
68, -67, -83,
32, -25, -120,
-11, -125, 18,
-10, -125, 16,
9, -126, 1,
-11, -125, 18,
-62, -41, 102,
-33, -120, 24,
19, -92, 84,
81, -90, 36,
-10, -125, 16,
11, -63, 109,
94, 0, 84,
34, 31, 117,
34, 31, 117,
30, -50, 112,
112, 14, 56,
112, 14, 56,
30, -50, 112,
76, -76, 66,
76, -76, 66,
94, 0, 84,
11, -63, 109,
67, 26, 103,
-7, 28, 123,
41, -68, 98,
41, -68, 98,
-7, 28, 123,
-37, -54, 108,
-37, -54, 108,
38, -53, 108,
-32, 44, 114,
-32, 44, 114,
38, -53, 108,
67, 26, 103,
38, -53, 108,
-22, -38, 119,
67, 26, 103,
-37, -54, 108,
50, 13, 115,
38, -53, 108,
-7, 28, 123,
50, 13, 115,
-37, -54, 108,
67, 26, 103,
-22, -38, 119,
-7, 28, 123,
76, -76, 66,
46, 12, 117,
94, 0, 84,
30, -50, 112,
46, 12, 117,
76, -76, 66,
34, 31, 117,
79, -64, 75,
30, -50, 112,
94, 0, 84,
79, -64, 75,
34, 31, 117,
79, -64, 75,
94, 0, 84,
46, 12, 117,
-22, -38, 119,
38, -53, 108,
50, 13, 115,
38, -116, -31,
81, -90, 36,
19, -92, 84,
58, -43, 103,
-14, 56, 112,
-58, -43, 103,
94, 17, -83,
-94, 17, -83,
85, 49, -79,
15, 56, 112,
24, 116, 43,
-14, 56, 112,
-14, 56, 112,
-29, 122, -12,
-48, 107, -47,
-48, 107, -47,
29, 122, -12,
48, 107, -47,
48, 107, -47,
29, 122, -12,
15, 56, 112,
83, -19, 93,
94, 17, -83,
85, 49, -79,
-83, -19, 93,
83, -82, 49,
83, -19, 93,
-85, 49, -79,
-94, 17, -83,
-83, -19, 93,
-65, 35, -102,
-48, 107, -47,
65, 35, -102,
-94, 17, -83,
-83, -82, 49,
-83, -19, 93,
-83, -19, 93,
-83, -82, 49,
83, -82, 49,
83, -19, 93,
83, -82, 49,
94, 17, -83,
29, 122, -12,
-24, 116, 43,
15, 56, 112,
-48, 107, -47,
-29, 122, -12,
29, 122, -12,
-14, 56, 112,
24, 116, 43,
-29, 122, -12,
15, 56, 112,
-24, 116, 43,
24, 116, 43,
-94, 17, -83,
-85, 49, -79,
85, 49, -79,
24, 116, 43,
-12, -67, -106,
-55, -49, -102,
-24, 116, 43,
86, -10, -92,
-12, -67, -106,
29, 122, -12,
-3, 23, -124,
86, -10, -92,
-29, 122, -12,
-113, 21, -51,
-3, 23, -124,
24, 116, 43,
-55, -49, -102,
-113, 21, -51,
29, 122, -12,
-29, 122, -12,
-3, 23, -124,
-29, 122, -12,
24, 116, 43,
-113, 21, -51,
58, -43, 103,
85, 49, -79,
65, 35, -102,
-58, -43, 103,
83, -19, 93,
58, -43, 103,
65, 35, -102,
-85, 49, -79,
-65, 35, -102,
-65, 35, -102,
-85, 49, -79,
-58, -43, 103,
-99, -43, 66,
93, -55, 65,
-50, 51, 104,
42, -46, -110,
-99, 25, -74,
91, 9, -87,
42, -115, 31,
42, -46, -110,
93, -55, 65,
-99, 25, -74,
-50, 51, 104,
-68, 106, -7,
-99, 25, -74,
-99, -43, 66,
-50, 51, 104,
42, -46, -110,
91, 9, -87,
93, -55, 65,
-99, 25, -74,
-68, 106, -7,
91, 9, -87,
-99, -43, 66,
42, -115, 31,
93, -55, 65,
-50, 51, 104,
-58, -43, 103,
-14, 56, 112,
93, -55, 65,
-65, 35, -102,
-58, -43, 103,
91, 9, -87,
-68, 106, -7,
-65, 35, -102,
-68, 106, -7,
-14, 56, 112,
-48, 107, -47,
50, 51, 104,
-93, -55, 65,
99, -43, 66,
-91, 9, -87,
99, 25, -74,
-42, -46, -110,
-93, -55, 65,
-42, -46, -110,
-42, -115, 31,
68, 106, -7,
50, 51, 104,
99, 25, -74,
50, 51, 104,
99, -43, 66,
99, 25, -74,
-93, -55, 65,
-91, 9, -87,
-42, -46, -110,
-91, 9, -87,
68, 106, -7,
99, 25, -74,
-93, -55, 65,
-42, -115, 31,
99, -43, 66,
50, 51, 104,
48, 107, -47,
15, 56, 112,
68, 106, -7,
65, 35, -102,
48, 107, -47,
-91, 9, -87,
-93, -55, 65,
65, 35, -102,
-93, -55, 65,
50, 51, 104,
58, -43, 103,
68, 106, -7,
48, 107, -47,
50, 51, 104,
-14, 56, 112,
-68, 106, -7,
-50, 51, 104,
114, -53, 10,
-64, -100, 43,
118, 20, 41,
97, -5, -81,
61, -27, -107,
-97, -5, -81,
-97, -5, -81,
118, 20, 41,
97, -5, -81,
-97, -5, -81,
114, -53, 10,
118, 20, 41,
-61, -27, -107,
-64, -100, 43,
-94, 17, -83,
-64, -100, 43,
83, -82, 49,
-83, -82, 49,
54, -108, 37,
94, 17, -83,
83, -82, 49,
61, -27, -107,
-94, 17, -83,
94, 17, -83,
-78, -6, 99,
72, -10, 103,
-91, 82, 30,
73, -102, -15,
-89, -26, -86,
90, -19, -86,
72, -10, 103,
73, -102, -15,
84, 92, 18,
-78, -98, -17,
-91, 82, 30,
-89, -26, -86,
-78, -98, -17,
-78, -6, 99,
-91, 82, 30,
73, -102, -15,
90, -19, -86,
84, 92, 18,
73, -102, -15,
-78, -98, -17,
-89, -26, -86,
72, -10, 103,
84, 92, 18,
-91, 82, 30,
-91, 82, 30,
84, 92, 18,
-64, -100, 43,
84, 92, 18,
90, -19, -86,
118, 20, 41,
90, -19, -86,
-61, -27, -107,
97, -5, -81,
-89, -26, -86,
-64, -100, 43,
-61, -27, -107,
87, 86, 31,
-73, -8, 103,
78, -6, 99,
-89, -20, -87,
89, -26, -86,
-73, -102, -15,
-67, 105, -19,
-73, -102, -15,
-73, -8, 103,
89, -26, -86,
87, 86, 31,
78, -98, -17,
87, 86, 31,
78, -6, 99,
78, -98, -17,
-67, 105, -19,
-89, -20, -87,
-73, -102, -15,
89, -26, -86,
78, -98, -17,
-73, -102, -15,
87, 86, 31,
-67, 105, -19,
-73, -8, 103,
87, 86, 31,
89, -26, -86,
54, -108, 37,
-89, -20, -87,
-97, -5, -81,
61, -27, -107,
-89, -20, -87,
114, -53, 10,
-97, -5, -81,
-67, 105, -19,
54, -108, 37,
114, -53, 10,
-42, -46, -110,
38, -89, -81,
-42, -115, 31,
-42, -115, 31,
94, -85, -1,
99, -43, 66,
99, -43, 66,
94, -85, -1,
99, 25, -74,
99, 25, -74,
93, -53, -66,
-42, -46, -110,
42, -115, 31,
-38, -119, -20,
42, -46, -110,
42, -46, -110,
-93, -53, -66,
-99, 25, -74,
-99, 25, -74,
-93, -53, -66,
-99, -43, 66,
-99, -43, 66,
-94, -85, -1,
42, -115, 31,
-75, -91, 45,
80, 14, 97,
38, -119, -20,
80, 14, 97,
93, -53, -66,
94, -85, -1,
80, 85, -48,
38, -89, -81,
93, -53, -66,
-75, -20, -100,
-75, -91, 45,
38, -89, -81,
-80, 14, 97,
-38, -119, -20,
-94, -85, -1,
75, -20, -100,
-93, -53, -66,
-38, -89, -81,
-80, 85, -48,
-80, 14, 97,
-93, -53, -66,
-38, -89, -81,
-38, -119, -20,
75, -20, -100,
-99, -31, 72,
71, -79, 68,
-57, 9, 112,
33, -38, -116,
-92, 44, -74,
81, 9, -96,
31, -119, 29,
33, -38, -116,
71, -79, 68,
-92, 44, -74,
-57, 9, 112,
-52, 103, -50,
-92, 44, -74,
-99, -31, 72,
-57, 9, 112,
33, -38, -116,
81, 9, -96,
71, -79, 68,
-92, 44, -74,
-52, 103, -50,
81, 9, -96,
-99, -31, 72,
31, -119, 29,
71, -79, 68,
33, -38, -116,
-72, -96, -39,
-92, 44, -74,
-92, 44, -74,
-72, -96, -39,
-99, -31, 72,
-99, -31, 72,
-72, -96, -39,
31, -119, 29,
31, -119, 29,
-72, -96, -39,
33, -38, -116,
81, 9, -96,
-80, 85, -48,
75, -20, -100,
-52, 103, -50,
-57, 9, 112,
-80, 85, -48,
-57, 9, 112,
71, -79, 68,
-80, 14, 97,
71, -79, 68,
81, 9, -96,
75, -91, 45,
73, -102, -15,
-26, -111, 55,
-78, -98, -17,
-78, -98, -17,
-26, -111, 55,
-78, -6, 99,
-78, -6, 99,
-33, -77, 95,
72, -10, 103,
72, -10, 103,
35, -74, 96,
73, -102, -15,
-73, -8, 103,
-35, -74, 96,
78, -6, 99,
78, -6, 99,
26, -111, 55,
78, -98, -17,
78, -98, -17,
26, -111, 55,
-73, -102, -15,
-73, -102, -15,
-35, -74, 96,
-73, -8, 103,
89, 45, 77,
79, 43, 88,
-89, 45, 77,
-89, -45, -77,
-91, -70, -53,
89, -45, -77,
-82, 45, 85,
-91, -70, -53,
-89, 45, 77,
88, -75, -51,
79, 43, 88,
89, -45, -77,
89, 45, 77,
49, 116, 8,
89, -45, -77,
89, -45, -77,
73, -6, -103,
-89, -45, -77,
-89, -45, -77,
-97, 80, 6,
-89, 45, 77,
-89, 45, 77,
-97, 80, 6,
89, 45, 77,
-97, 80, 6,
49, 116, 8,
89, 45, 77,
-89, -45, -77,
-89, -26, -86,
-97, 80, 6,
73, -6, -103,
-89, -26, -86,
-89, -45, -77,
49, 116, 8,
73, -6, -103,
89, -45, -77,
79, 43, 88,
89, 45, 77,
89, -45, -77,
-91, -70, -53,
-89, -45, -77,
-89, 45, 77,
-91, -70, -53,
88, -75, -51,
89, -45, -77,
79, 43, 88,
-82, 45, 85,
-89, 45, 77,
-91, -70, -53,
-35, -74, 96,
-27, -112, 52,
-82, 45, 85,
79, 43, 88,
-35, -74, 96,
79, 43, 88,
88, -75, -51,
33, -77, 95,
88, -75, -51,
-27, -112, 52,
26, -111, 55,
89, 45, 77,
-79, 43, 88,
-89, 45, 77,
-89, -45, -77,
91, -70, -53,
89, -45, -77,
89, 45, 77,
91, -70, -53,
82, 45, 85,
-89, -45, -77,
-79, 43, 88,
-88, -75, -51,
-89, -45, -77,
-49, 116, 8,
-89, 45, 77,
89, -45, -77,
-73, -6, -103,
-89, -45, -77,
89, 45, 77,
97, 80, 6,
89, -45, -77,
-89, 45, 77,
97, 80, 6,
89, 45, 77,
-89, 45, 77,
-49, 116, 8,
97, 80, 6,
97, 80, 6,
89, -26, -86,
89, -45, -77,
89, -45, -77,
89, -26, -86,
-73, -6, -103,
-89, -45, -77,
-73, -6, -103,
-49, 116, 8,
-89, -45, -77,
-89, 45, 77,
-79, 43, 88,
89, 45, 77,
89, -45, -77,
91, -70, -53,
-89, -45, -77,
-88, -75, -51,
91, -70, -53,
89, 45, 77,
82, 45, 85,
-79, 43, 88,
-79, 43, 88,
35, -74, 96,
-33, -77, 95,
82, 45, 85,
91, -70, -53,
35, -74, 96,
91, -70, -53,
-88, -75, -51,
27, -112, 52,
-88, -75, -51,
-33, -77, 95,
-26, -111, 55,
86, -89, -22,
-53, -107, -42,
88, -21, -88,
-64, 106, -22,
95, 76, -33,
-91, 58, -66,
99, -58, 52,
77, -31, 95,
-93, -84, 13,
77, -31, 95,
95, 76, -33,
61, 110, -3,
-93, -84, 13,
-101, -39, 65,
-91, 58, -66,
61, 110, -3,
-18, 44, 117,
77, -31, 95,
77, -31, 95,
-18, 44, 117,
-101, -39, 65,
-101, -39, 65,
-18, 44, 117,
-64, 106, -22,
-64, 106, -22,
-18, 44, 117,
61, 110, -3,
99, -58, 52,
86, -89, -22,
95, 76, -33,
-93, -84, 13,
-53, -107, -42,
99, -58, 52,
-91, 58, -66,
-56, -29, -109,
-93, -84, 13,
-56, -29, -109,
-53, -107, -42,
-93, -84, 13,
-53, -107, -42,
86, -89, -22,
99, -58, 52,
86, -89, -22,
88, -21, -88,
95, 76, -33,
-101, -39, 65,
-64, 106, -22,
-91, 58, -66,
77, -31, 95,
99, -58, 52,
95, 76, -33,
77, -31, 95,
-101, -39, 65,
-93, -84, 13,
-64, 106, -22,
61, 110, -3,
95, 76, -33,
-53, -107, -42,
-56, -29, -109,
88, -21, -88,
95, 76, -33,
88, -21, -88,
97, 80, 6,
88, -21, -88,
-56, -29, -109,
89, -26, -86,
-56, -29, -109,
-91, 58, -66,
-73, -6, -103,
-91, 58, -66,
95, 76, -33,
-49, 116, 8,
-88, -21, -88,
53, -107, -42,
-86, -89, -22,
91, 58, -66,
-95, 76, -33,
64, 106, -22,
93, -84, 13,
-77, -31, 95,
-99, -58, 52,
-61, 110, -3,
-95, 76, -33,
-77, -31, 95,
91, 58, -66,
101, -39, 65,
93, -84, 13,
-77, -31, 95,
18, 44, 117,
-61, 110, -3,
101, -39, 65,
18, 44, 117,
-77, -31, 95,
64, 106, -22,
18, 44, 117,
101, -39, 65,
-61, 110, -3,
18, 44, 117,
64, 106, -22,
-95, 76, -33,
-86, -89, -22,
-99, -58, 52,
-99, -58, 52,
53, -107, -42,
93, -84, 13,
93, -84, 13,
56, -29, -109,
91, 58, -66,
93, -84, 13,
53, -107, -42,
56, -29, -109,
-99, -58, 52,
-86, -89, -22,
53, -107, -42,
-95, 76, -33,
-88, -21, -88,
-86, -89, -22,
91, 58, -66,
64, 106, -22,
101, -39, 65,
-95, 76, -33,
-99, -58, 52,
-77, -31, 95,
93, -84, 13,
101, -39, 65,
-77, -31, 95,
-95, 76, -33,
-61, 110, -3,
64, 106, -22,
-88, -21, -88,
56, -29, -109,
53, -107, -42,
-95, 76, -33,
49, 116, 8,
-97, 80, 6,
91, 58, -66,
73, -6, -103,
49, 116, 8,
56, -29, -109,
-89, -26, -86,
73, -6, -103,
-88, -21, -88,
-97, 80, 6,
-89, -26, -86,
61, -27, -107,
89, -26, -86,
-89, -20, -87,
90, -19, -86,
-89, -26, -86,
-61, -27, -107,
80, 85, -48,
-81, 9, -96,
-75, -20, -100,
-75, -20, -100,
-71, -79, 68,
-75, -91, 45,
80, 14, 97,
52, 103, -50,
80, 85, -48,
57, 9, 112,
-71, -79, 68,
99, -31, 72,
-81, 9, -96,
92, 44, -74,
-33, -38, -116,
-71, -79, 68,
-33, -38, -116,
-31, -119, 29,
52, 103, -50,
57, 9, 112,
92, 44, -74,
57, 9, 112,
99, -31, 72,
92, 44, -74,
-71, -79, 68,
-81, 9, -96,
-33, -38, -116,
-81, 9, -96,
52, 103, -50,
92, 44, -74,
-71, -79, 68,
-31, -119, 29,
99, -31, 72,
92, 44, -74,
72, -96, -39,
-33, -38, -116,
99, -31, 72,
72, -96, -39,
92, 44, -74,
-31, -119, 29,
72, -96, -39,
99, -31, 72,
-33, -38, -116,
72, -96, -39,
-31, -119, 29,
-75, -91, 45,
-71, -79, 68,
80, 14, 97,
-71, -79, 68,
57, 9, 112,
80, 14, 97,
80, 14, 97,
57, 9, 112,
52, 103, -50,
-75, -20, -100,
-81, 9, -96,
-71, -79, 68,
80, 85, -48,
52, 103, -50,
-81, 9, -96,
-88, -21, -88,
-95, 76, -33,
-97, 80, 6,
56, -29, -109,
-88, -21, -88,
-89, -26, -86,
91, 58, -66,
56, -29, -109,
73, -6, -103,
-95, 76, -33,
91, 58, -66,
49, 116, 8,
95, 76, -33,
97, 80, 6,
-49, 116, 8,
-91, 58, -66,
-49, 116, 8,
-73, -6, -103,
-56, -29, -109,
-73, -6, -103,
89, -26, -86,
88, -21, -88,
89, -26, -86,
97, 80, 6,
-88, -75, -51,
-79, 43, 88,
-33, -77, 95,
-88, -75, -51,
-26, -111, 55,
27, -112, 52,
91, -70, -53,
27, -112, 52,
35, -74, 96,
-79, 43, 88,
82, 45, 85,
35, -74, 96,
88, -75, -51,
-91, -70, -53,
-27, -112, 52,
88, -75, -51,
26, -111, 55,
33, -77, 95,
79, 43, 88,
33, -77, 95,
-35, -74, 96,
-91, -70, -53,
-82, 45, 85,
-35, -74, 96,
-73, -102, -15,
-27, -112, 52,
-35, -74, 96,
26, -111, 55,
-27, -112, 52,
-73, -102, -15,
78, -6, 99,
33, -77, 95,
26, -111, 55,
-35, -74, 96,
33, -77, 95,
78, -6, 99,
35, -74, 96,
27, -112, 52,
73, -102, -15,
-33, -77, 95,
35, -74, 96,
72, -10, 103,
-26, -111, 55,
-33, -77, 95,
-78, -6, 99,
73, -102, -15,
27, -112, 52,
-26, -111, 55,
81, 9, -96,
75, -20, -100,
75, -91, 45,
71, -79, 68,
75, -91, 45,
-80, 14, 97,
-57, 9, 112,
-80, 14, 97,
-80, 85, -48,
81, 9, -96,
-52, 103, -50,
-80, 85, -48,
-38, -119, -20,
75, -91, 45,
75, -20, -100,
-80, 14, 97,
-94, -85, -1,
-93, -53, -66,
75, -20, -100,
-80, 85, -48,
-93, -53, -66,
-80, 14, 97,
75, -91, 45,
-38, -119, -20,
-75, -91, 45,
38, -119, -20,
38, -89, -81,
80, 85, -48,
-75, -20, -100,
38, -89, -81,
80, 14, 97,
80, 85, -48,
93, -53, -66,
80, 14, 97,
94, -85, -1,
38, -119, -20,
-94, -85, -1,
-38, -119, -20,
42, -115, 31,
-93, -53, -66,
-94, -85, -1,
-99, -43, 66,
42, -46, -110,
-38, -89, -81,
-93, -53, -66,
-38, -119, -20,
-38, -89, -81,
42, -46, -110,
93, -53, -66,
38, -89, -81,
-42, -46, -110,
94, -85, -1,
93, -53, -66,
99, 25, -74,
-42, -115, 31,
38, -119, -20,
94, -85, -1,
38, -89, -81,
38, -119, -20,
-42, -115, 31,
-67, 105, -19,
87, 86, 31,
54, -108, 37,
-89, -20, -87,
-67, 105, -19,
114, -53, 10,
89, -26, -86,
61, -27, -107,
54, -108, 37,
-89, -26, -86,
-91, 82, 30,
-64, -100, 43,
90, -19, -86,
97, -5, -81,
118, 20, 41,
84, 92, 18,
118, 20, 41,
-64, -100, 43,
61, -27, -107,
-61, -27, -107,
-94, 17, -83,
54, -108, 37,
61, -27, -107,
94, 17, -83,
-64, -100, 43,
54, -108, 37,
83, -82, 49,
-64, -100, 43,
-83, -82, 49,
-94, 17, -83,
97, -5, -81,
-61, -27, -107,
61, -27, -107,
114, -53, 10,
54, -108, 37,
-64, -100, 43,
50, 51, 104,
15, 56, 112,
58, -43, 103,
-93, -55, 65,
58, -43, 103,
65, 35, -102,
68, 106, -7,
-91, 9, -87,
65, 35, -102,
-68, 106, -7,
-48, 107, -47,
-65, 35, -102,
93, -55, 65,
91, 9, -87,
-65, 35, -102,
-50, 51, 104,
93, -55, 65,
-58, -43, 103,
-85, 49, -79,
-83, -19, 93,
-58, -43, 103,
65, 35, -102,
85, 49, -79,
-85, 49, -79,
-58, -43, 103,
-83, -19, 93,
83, -19, 93,
58, -43, 103,
83, -19, 93,
85, 49, -79,
-24, 116, 43,
29, 122, -12,
86, -10, -92,
24, 116, 43,
-24, 116, 43,
-12, -67, -106,
-48, 107, -47,
48, 107, -47,
65, 35, -102,
58, -43, 103,
15, 56, 112,
-14, 56, 112,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:20 */
static s8 vtxnvgrp_frake_select_20[]={
-31, -119, 29,
-10, -125, 19,
-11, -124, 22,
-11, -124, 22,
8, -126, 4,
92, -80, 32,
-29, -89, -85,
26, -29, -120,
-78, -90, -43,
-78, -90, -43,
-46, 18, -116,
-45, -96, -68,
-45, -96, -68,
-46, 18, -116,
-32, -99, -71,
-32, -99, -71,
-110, 25, -56,
-79, -80, -57,
-79, -80, -57,
-126, -4, 4,
-85, -88, 31,
-29, -89, -85,
81, -90, 35,
35, -118, -28,
63, -71, -83,
-14, -71, -104,
26, -29, -120,
26, -29, -120,
84, -13, -93,
-46, 18, -116,
-46, 18, -116,
-114, 22, -49,
-110, 25, -56,
-110, 25, -56,
-58, -50, -100,
-126, -4, 4,
-126, -4, 4,
-58, -50, -100,
-85, -88, 31,
-85, -88, 31,
-86, -77, -51,
-13, -123, -26,
-13, -123, -26,
12, -95, -83,
35, -118, -28,
35, -118, -28,
-14, -71, -104,
63, -71, -83,
37, 113, 42,
-58, 98, 54,
7, 121, 35,
67, 9, -107,
82, 26, -92,
102, -50, -56,
122, -20, -28,
88, -86, 29,
92, -80, 32,
92, -80, 32,
88, -86, 29,
-11, -124, 22,
-11, -124, 22,
-59, -40, 104,
-58, -37, 106,
-58, -37, 106,
-59, -40, 104,
-94, 53, 66,
-119, 24, 36,
-96, 81, -7,
-105, 67, -22,
-105, 67, -22,
-23, 83, -92,
-33, 69, -101,
-33, 69, -101,
-23, 83, -92,
67, 9, -107,
82, 26, -92,
114, 52, -13,
122, -20, -28,
122, -20, -28,
114, 52, -13,
125, 11, 15,
-58, 73, 85,
-58, 98, 54,
-94, 53, 66,
-94, 53, 66,
-58, 98, 54,
-96, 81, -7,
-96, 81, -7,
4, 121, -37,
-23, 83, -92,
-23, 83, -92,
4, 121, -37,
82, 26, -92,
84, 93, -15,
4, 121, -37,
37, 113, 42,
35, -118, -28,
63, -71, -83,
-29, -89, -85,
-85, -88, 31,
-59, -52, 99,
-79, -80, -57,
-13, -123, -26,
35, -118, -28,
-85, -88, 31,
35, -118, -28,
23, -90, 85,
-85, -88, 31,
-31, -119, 29,
47, -117, -5,
-79, -80, -57,
-79, -80, -57,
-112, 42, -40,
-119, 24, 36,
-119, 24, 36,
-71, -69, 78,
-58, -37, 106,
-58, -37, 106,
47, -117, -5,
-31, -119, 29,
47, -117, -5,
-67, -78, -73,
27, 5, -123,
27, 5, -123,
-67, -78, -73,
-112, 42, -40,
-112, 42, -40,
-67, -78, -73,
-71, -69, 78,
-71, -69, 78,
-67, -78, -73,
47, -117, -5,
-29, -89, -85,
-80, -87, 45,
8, -126, 4,
8, -126, 4,
-80, -87, 45,
92, -80, 32,
92, -80, 32,
68, -106, 11,
102, -50, -56,
102, -50, -56,
46, -12, -117,
-29, -89, -85,
-98, 48, -64,
-56, -80, -80,
-80, -87, 45,
-80, -87, 45,
-56, -80, -80,
68, -106, 11,
68, -106, 11,
-56, -80, -80,
46, -12, -117,
46, -12, -117,
-56, -80, -80,
-98, 48, -64,
-78, -90, -43,
-67, -89, 60,
-29, -89, -85,
-29, -89, -85,
-67, -89, 60,
102, -50, -56,
102, -50, -56,
71, -102, -23,
67, 9, -107,
67, 9, -107,
-49, 39, -109,
-78, -90, -43,
-113, 25, 50,
-76, -73, -69,
-67, -89, 60,
-67, -89, 60,
-76, -73, -69,
71, -102, -23,
71, -102, -23,
-76, -73, -69,
-49, 39, -109,
-49, 39, -109,
-76, -73, -69,
-113, 25, 50,
-105, 67, -22,
-98, -59, 52,
-119, 24, 36,
-119, 24, 36,
47, -117, 9,
-79, -80, -57,
-79, -80, -57,
47, -117, 9,
-32, -99, -71,
-32, -99, -71,
-26, 31, -120,
-105, 67, -22,
-26, 31, -120,
-46, -79, -87,
-98, -59, 52,
-98, -59, 52,
-46, -79, -87,
47, -117, 9,
47, -117, 9,
-46, -79, -87,
106, -52, -45,
106, -52, -45,
-46, -79, -87,
-26, 31, -120,
-45, -96, -68,
46, -105, 52,
-78, -90, -43,
-78, -90, -43,
46, -105, 52,
67, 9, -107,
67, 9, -107,
-84, 41, -85,
-33, 69, -101,
-33, 69, -101,
-84, 41, -85,
-45, -96, -68,
-109, -37, 52,
-46, -118, -8,
46, -105, 52,
46, -105, 52,
-46, -118, -8,
85, -25, -90,
85, -25, -90,
-46, -118, -8,
-84, 41, -85,
-84, 41, -85,
-46, -118, -8,
-109, -37, 52,
-32, -99, -71,
-30, -83, 90,
-45, -96, -68,
-45, -96, -68,
4, 15, -125,
-33, 69, -101,
-33, 69, -101,
4, 15, -125,
-105, 67, -22,
-105, 67, -22,
-30, -83, 90,
-32, -99, -71,
-30, -83, 90,
-33, -120, -21,
78, -94, -31,
78, -94, -31,
-33, -120, -21,
4, 15, -125,
4, 15, -125,
-33, -120, -21,
-123, 28, 8,
-123, 28, 8,
-33, -120, -21,
-30, -83, 90,
48, 54, 103,
55, 52, 101,
-58, 73, 85,
125, 11, 15,
55, 52, 101,
48, 54, 103,
81, -90, 35,
-29, -89, -85,
8, -126, 4,
-59, -52, 99,
-31, -119, 29,
-79, -80, -57,
-59, -52, 99,
-10, -125, 19,
-31, -119, 29,
81, -90, 35,
8, -126, 4,
-10, -125, 19,
-59, -52, 99,
23, -90, 85,
-10, -125, 19,
125, 11, 15,
88, -86, 29,
122, -20, -28,
-94, 53, 66,
-59, -40, 104,
-58, 73, 85,
92, -80, 32,
102, -50, -56,
122, -20, -28,
-94, 53, 66,
-119, 24, 36,
-58, -37, 106,
-1, 31, 122,
-17, -33, 121,
55, 15, 113,
81, -63, 73,
52, 14, 114,
35, -48, 112,
37, 113, 42,
55, 52, 101,
72, 104, 6,
37, 113, 42,
72, 104, 6,
114, 52, -13,
37, 113, 42,
114, 52, -13,
84, 93, -15,
7, 121, 35,
55, 52, 101,
37, 113, 42,
37, 113, 42,
-23, 120, 32,
-58, 98, 54,
37, 113, 42,
4, 121, -37,
-23, 120, 32,
48, 54, 103,
44, -65, 99,
29, -87, 87,
29, -87, 87,
-34, -50, 111,
-59, -40, 104,
-59, -40, 104,
-26, 48, 114,
-58, 73, 85,
-58, 73, 85,
73, 28, 99,
48, 54, 103,
88, -86, 29,
78, -75, 65,
29, -87, 87,
29, -87, 87,
14, -60, 110,
48, 54, 103,
48, 54, 103,
40, 34, 115,
125, 11, 15,
125, 11, 15,
115, 14, 50,
88, -86, 29,
115, 14, 50,
78, -75, 65,
88, -86, 29,
40, 34, 115,
115, 14, 50,
125, 11, 15,
14, -60, 110,
40, 34, 115,
48, 54, 103,
78, -75, 65,
14, -60, 110,
29, -87, 87,
-58, 73, 85,
-26, 48, 114,
73, 28, 99,
-59, -40, 104,
-34, -50, 111,
-26, 48, 114,
29, -87, 87,
44, -65, 99,
-34, -50, 111,
48, 54, 103,
73, 28, 99,
44, -65, 99,
125, 11, 15,
72, 104, 6,
55, 52, 101,
55, 52, 101,
7, 121, 35,
-58, 73, 85,
-105, 67, -22,
-123, 28, 8,
-30, -83, 90,
4, 15, -125,
-123, 28, 8,
-105, 67, -22,
-45, -96, -68,
78, -94, -31,
4, 15, -125,
-30, -83, 90,
78, -94, -31,
-45, -96, -68,
-84, 41, -85,
-109, -37, 52,
-45, -96, -68,
67, 9, -107,
85, -25, -90,
-84, 41, -85,
46, -105, 52,
85, -25, -90,
67, 9, -107,
-45, -96, -68,
-109, -37, 52,
46, -105, 52,
-32, -99, -71,
106, -52, -45,
-26, 31, -120,
47, -117, 9,
106, -52, -45,
-32, -99, -71,
-119, 24, 36,
-98, -59, 52,
47, -117, 9,
-105, 67, -22,
-26, 31, -120,
-98, -59, 52,
-49, 39, -109,
-113, 25, 50,
-78, -90, -43,
71, -102, -23,
-49, 39, -109,
67, 9, -107,
-67, -89, 60,
71, -102, -23,
102, -50, -56,
-78, -90, -43,
-113, 25, 50,
-67, -89, 60,
46, -12, -117,
-98, 48, -64,
-29, -89, -85,
68, -106, 11,
46, -12, -117,
102, -50, -56,
-80, -87, 45,
68, -106, 11,
92, -80, 32,
-29, -89, -85,
-98, 48, -64,
-80, -87, 45,
-58, -37, 106,
-71, -69, 78,
47, -117, -5,
-119, 24, 36,
-112, 42, -40,
-71, -69, 78,
-79, -80, -57,
27, 5, -123,
-112, 42, -40,
47, -117, -5,
27, 5, -123,
-79, -80, -57,
23, -90, 85,
-59, -52, 99,
-85, -88, 31,
4, 121, -37,
84, 93, -15,
82, 26, -92,
-96, 81, -7,
-23, 120, 32,
4, 121, -37,
-58, 98, 54,
-23, 120, 32,
-96, 81, -7,
-58, 73, 85,
7, 121, 35,
-58, 98, 54,
114, 52, -13,
72, 104, 6,
125, 11, 15,
82, 26, -92,
84, 93, -15,
114, 52, -13,
-23, 83, -92,
82, 26, -92,
67, 9, -107,
-105, 67, -22,
-96, 81, -7,
-23, 83, -92,
-119, 24, 36,
-94, 53, 66,
-96, 81, -7,
-11, -124, 22,
29, -87, 87,
-59, -40, 104,
88, -86, 29,
29, -87, 87,
-11, -124, 22,
82, 26, -92,
122, -20, -28,
102, -50, -56,
-14, -71, -104,
12, -95, -83,
-86, -77, -51,
12, -95, -83,
-13, -123, -26,
-86, -77, -51,
-14, -71, -104,
-86, -77, -51,
-58, -50, -100,
35, -118, -28,
12, -95, -83,
-14, -71, -104,
-58, -50, -100,
-86, -77, -51,
-85, -88, 31,
-110, 25, -56,
-114, 22, -49,
-58, -50, -100,
-46, 18, -116,
-4, 19, -125,
-114, 22, -49,
84, -13, -93,
-4, 19, -125,
-46, 18, -116,
-14, -71, -104,
84, -13, -93,
26, -29, -120,
-110, 25, -56,
-126, -4, 4,
-79, -80, -57,
-46, 18, -116,
-110, 25, -56,
-32, -99, -71,
-78, -90, -43,
26, -29, -120,
-46, 18, -116,
-29, -89, -85,
63, -71, -83,
26, -29, -120,
-11, -124, 22,
-10, -125, 19,
8, -126, 4,
-11, -124, 22,
-58, -37, 106,
-31, -119, 29,
23, -90, 85,
81, -90, 35,
-10, -125, 19,
14, -60, 110,
98, 0, 80,
40, 34, 115,
40, 34, 115,
35, -48, 112,
115, 14, 50,
115, 14, 50,
35, -48, 112,
78, -75, 65,
78, -75, 65,
98, 0, 80,
14, -60, 110,
73, 28, 99,
-1, 31, 122,
44, -65, 99,
44, -65, 99,
-1, 31, 122,
-34, -50, 111,
-34, -50, 111,
43, -51, 107,
-26, 48, 114,
-26, 48, 114,
43, -51, 107,
73, 28, 99,
43, -51, 107,
-17, -33, 121,
73, 28, 99,
-34, -50, 111,
55, 15, 113,
43, -51, 107,
-1, 31, 122,
55, 15, 113,
-34, -50, 111,
73, 28, 99,
-17, -33, 121,
-1, 31, 122,
78, -75, 65,
52, 14, 114,
98, 0, 80,
35, -48, 112,
52, 14, 114,
78, -75, 65,
40, 34, 115,
81, -63, 73,
35, -48, 112,
98, 0, 80,
81, -63, 73,
40, 34, 115,
81, -63, 73,
98, 0, 80,
52, 14, 114,
-17, -33, 121,
43, -51, 107,
55, 15, 113,
35, -118, -28,
81, -90, 35,
23, -90, 85,
58, -42, 104,
-14, 58, 111,
-58, -42, 104,
94, 15, -83,
-94, 15, -83,
85, 48, -80,
15, 58, 111,
22, 117, 41,
-14, 58, 111,
-14, 58, 111,
-29, 122, -14,
-48, 106, -49,
-48, 106, -49,
29, 122, -14,
48, 106, -49,
48, 106, -49,
29, 122, -14,
15, 58, 111,
83, -18, 94,
94, 15, -83,
85, 48, -80,
-83, -18, 94,
83, -81, 50,
83, -18, 94,
-85, 48, -80,
-94, 15, -83,
-83, -18, 94,
-65, 34, -103,
-48, 106, -49,
65, 34, -103,
-94, 15, -83,
-83, -81, 50,
-83, -18, 94,
-83, -18, 94,
-83, -81, 50,
83, -81, 50,
83, -18, 94,
83, -81, 50,
94, 15, -83,
29, 122, -14,
-22, 117, 41,
15, 58, 111,
-48, 106, -49,
-29, 122, -14,
29, 122, -14,
-14, 58, 111,
22, 117, 41,
-29, 122, -14,
15, 58, 111,
-22, 117, 41,
22, 117, 41,
-94, 15, -83,
-85, 48, -80,
85, 48, -80,
22, 117, 41,
-14, -71, -104,
-58, -50, -100,
-22, 117, 41,
84, -13, -93,
-14, -71, -104,
29, 122, -14,
-4, 19, -125,
84, -13, -93,
-29, 122, -14,
-114, 22, -49,
-4, 19, -125,
22, 117, 41,
-58, -50, -100,
-114, 22, -49,
29, 122, -14,
-29, 122, -14,
-4, 19, -125,
-29, 122, -14,
22, 117, 41,
-114, 22, -49,
58, -42, 104,
85, 48, -80,
65, 34, -103,
-58, -42, 104,
83, -18, 94,
58, -42, 104,
65, 34, -103,
-85, 48, -80,
-65, 34, -103,
-65, 34, -103,
-85, 48, -80,
-58, -42, 104,
-99, -42, 67,
93, -55, 66,
-50, 52, 104,
42, -47, -109,
-99, 24, -75,
91, 8, -87,
42, -115, 33,
42, -47, -109,
93, -55, 66,
-99, 24, -75,
-50, 52, 104,
-68, 106, -9,
-99, 24, -75,
-99, -42, 67,
-50, 52, 104,
42, -47, -109,
91, 8, -87,
93, -55, 66,
-99, 24, -75,
-68, 106, -9,
91, 8, -87,
-99, -42, 67,
42, -115, 33,
93, -55, 66,
-50, 52, 104,
-58, -42, 104,
-14, 58, 111,
93, -55, 66,
-65, 34, -103,
-58, -42, 104,
91, 8, -87,
-68, 106, -9,
-65, 34, -103,
-68, 106, -9,
-14, 58, 111,
-48, 106, -49,
50, 52, 104,
-93, -55, 66,
99, -42, 67,
-91, 8, -87,
99, 24, -75,
-42, -47, -109,
-93, -55, 66,
-42, -47, -109,
-42, -115, 33,
68, 106, -8,
50, 52, 104,
99, 24, -75,
50, 52, 104,
99, -42, 67,
99, 24, -75,
-93, -55, 66,
-91, 8, -87,
-42, -47, -109,
-91, 8, -87,
68, 106, -8,
99, 24, -75,
-93, -55, 66,
-42, -115, 33,
99, -42, 67,
50, 52, 104,
48, 106, -49,
15, 58, 111,
68, 106, -8,
65, 34, -103,
48, 106, -49,
-91, 8, -87,
-93, -55, 66,
65, 34, -103,
-93, -55, 66,
50, 52, 104,
58, -42, 104,
68, 106, -8,
48, 106, -49,
50, 52, 104,
-14, 58, 111,
-68, 106, -9,
-50, 52, 104,
115, -51, 8,
-63, -100, 44,
118, 19, 42,
97, -4, -81,
61, -28, -107,
-97, -5, -81,
-97, -5, -81,
118, 19, 42,
97, -4, -81,
-97, -5, -81,
115, -51, 8,
118, 19, 42,
-61, -28, -107,
-63, -100, 44,
-94, 15, -83,
-63, -100, 44,
83, -81, 50,
-83, -81, 50,
53, -108, 38,
94, 15, -83,
83, -81, 50,
61, -28, -107,
-94, 15, -83,
94, 15, -83,
-78, -8, 99,
72, -11, 103,
-91, 82, 32,
73, -102, -16,
-89, -25, -86,
90, -17, -87,
72, -11, 103,
73, -102, -16,
84, 92, 20,
-78, -97, -19,
-91, 82, 32,
-89, -25, -86,
-78, -97, -19,
-78, -8, 99,
-91, 82, 32,
73, -102, -16,
90, -17, -87,
84, 92, 20,
73, -102, -16,
-78, -97, -19,
-89, -25, -86,
72, -11, 103,
84, 92, 20,
-91, 82, 32,
-91, 82, 32,
84, 92, 20,
-63, -100, 44,
84, 92, 20,
90, -17, -87,
118, 19, 42,
90, -17, -87,
-61, -28, -107,
97, -4, -81,
-89, -25, -86,
-63, -100, 44,
-61, -28, -107,
87, 85, 32,
-73, -10, 103,
78, -8, 99,
-89, -18, -87,
89, -25, -86,
-73, -102, -16,
-68, 105, -16,
-73, -102, -16,
-73, -10, 103,
89, -25, -86,
87, 85, 32,
78, -97, -19,
87, 85, 32,
78, -8, 99,
78, -97, -19,
-68, 105, -16,
-89, -18, -87,
-73, -102, -16,
89, -25, -86,
78, -97, -19,
-73, -102, -16,
87, 85, 32,
-68, 105, -16,
-73, -10, 103,
87, 85, 32,
89, -25, -86,
53, -108, 38,
-89, -18, -87,
-97, -5, -81,
61, -28, -107,
-89, -18, -87,
115, -51, 8,
-97, -5, -81,
-68, 105, -16,
53, -108, 38,
115, -51, 8,
-42, -47, -109,
38, -90, -80,
-42, -115, 33,
-42, -115, 33,
94, -85, 0,
99, -42, 67,
99, -42, 67,
94, -85, 0,
99, 24, -75,
99, 24, -75,
93, -54, -65,
-42, -47, -109,
42, -115, 33,
-38, -119, -19,
42, -47, -109,
42, -47, -109,
-93, -54, -65,
-99, 24, -75,
-99, 24, -75,
-93, -54, -65,
-99, -42, 67,
-99, -42, 67,
-94, -85, 0,
42, -115, 33,
-75, -91, 46,
80, 15, 96,
38, -119, -19,
80, 15, 96,
93, -54, -65,
94, -85, 0,
80, 84, -49,
38, -90, -80,
93, -54, -65,
-75, -21, -100,
-75, -91, 46,
38, -90, -80,
-80, 15, 96,
-38, -119, -19,
-94, -85, 0,
75, -21, -100,
-93, -54, -65,
-38, -90, -80,
-80, 84, -49,
-80, 15, 96,
-93, -54, -65,
-38, -90, -80,
-38, -119, -19,
75, -21, -100,
-99, -30, 72,
71, -78, 69,
-57, 11, 112,
33, -39, -115,
-92, 43, -75,
81, 8, -97,
31, -118, 31,
33, -39, -115,
71, -78, 69,
-92, 43, -75,
-57, 11, 112,
-52, 103, -51,
-92, 43, -75,
-99, -30, 72,
-57, 11, 112,
33, -39, -115,
81, 8, -97,
71, -78, 69,
-92, 43, -75,
-52, 103, -51,
81, 8, -97,
-99, -30, 72,
31, -118, 31,
71, -78, 69,
33, -39, -115,
-72, -96, -38,
-92, 43, -75,
-92, 43, -75,
-72, -96, -38,
-99, -30, 72,
-99, -30, 72,
-72, -96, -38,
31, -118, 31,
31, -118, 31,
-72, -96, -38,
33, -39, -115,
81, 8, -97,
-80, 84, -49,
75, -21, -100,
-52, 103, -51,
-57, 11, 112,
-80, 84, -49,
-57, 11, 112,
71, -78, 69,
-80, 15, 96,
71, -78, 69,
81, 8, -97,
75, -91, 46,
73, -102, -16,
-25, -112, 52,
-78, -97, -19,
-78, -97, -19,
-25, -112, 52,
-78, -8, 99,
-78, -8, 99,
-33, -79, 93,
72, -11, 103,
72, -11, 103,
35, -76, 95,
73, -102, -16,
-73, -10, 103,
-35, -76, 95,
78, -8, 99,
78, -8, 99,
25, -112, 52,
78, -97, -19,
78, -97, -19,
25, -112, 52,
-73, -102, -16,
-73, -102, -16,
-35, -76, 95,
-73, -10, 103,
89, 49, 75,
80, 43, 87,
-89, 49, 75,
-89, -49, -74,
-89, -71, -53,
89, -49, -74,
-83, 46, 83,
-89, -71, -53,
-89, 49, 75,
86, -77, -51,
80, 43, 87,
89, -49, -74,
89, 49, 75,
49, 116, 3,
89, -49, -74,
89, -49, -74,
73, -11, -103,
-89, -49, -74,
-89, -49, -74,
-97, 81, 2,
-89, 49, 75,
-89, 49, 75,
-97, 81, 2,
89, 49, 75,
-97, 81, 2,
49, 116, 3,
89, 49, 75,
-89, -49, -74,
-89, -30, -84,
-97, 81, 2,
73, -11, -103,
-89, -30, -84,
-89, -49, -74,
49, 116, 3,
73, -11, -103,
89, -49, -74,
80, 43, 87,
89, 49, 75,
89, -49, -74,
-89, -71, -53,
-89, -49, -74,
-89, 49, 75,
-89, -71, -53,
86, -77, -51,
89, -49, -74,
80, 43, 87,
-83, 46, 83,
-89, 49, 75,
-89, -71, -53,
-35, -76, 95,
-27, -113, 50,
-83, 46, 83,
80, 43, 87,
-35, -76, 95,
80, 43, 87,
86, -77, -51,
33, -79, 93,
86, -77, -51,
-27, -113, 50,
25, -112, 52,
89, 49, 75,
-80, 43, 87,
-89, 49, 75,
-89, -49, -74,
89, -71, -53,
89, -49, -74,
89, 49, 75,
89, -71, -53,
83, 46, 83,
-89, -49, -74,
-80, 43, 87,
-86, -77, -51,
-89, -49, -74,
-49, 116, 3,
-89, 49, 75,
89, -49, -74,
-73, -11, -103,
-89, -49, -74,
89, 49, 75,
97, 81, 2,
89, -49, -74,
-89, 49, 75,
97, 81, 2,
89, 49, 75,
-89, 49, 75,
-49, 116, 3,
97, 81, 2,
97, 81, 2,
89, -30, -84,
89, -49, -74,
89, -49, -74,
89, -30, -84,
-73, -11, -103,
-89, -49, -74,
-73, -11, -103,
-49, 116, 3,
-89, -49, -74,
-89, 49, 75,
-80, 43, 87,
89, 49, 75,
89, -49, -74,
89, -71, -53,
-89, -49, -74,
-86, -77, -51,
89, -71, -53,
89, 49, 75,
83, 46, 83,
-80, 43, 87,
-80, 43, 87,
35, -76, 95,
-33, -79, 93,
83, 46, 83,
89, -71, -53,
35, -76, 95,
89, -71, -53,
-86, -77, -51,
27, -113, 50,
-86, -77, -51,
-33, -79, 93,
-25, -112, 52,
86, -90, -18,
-53, -108, -36,
89, -25, -86,
-64, 105, -28,
95, 75, -36,
-91, 54, -68,
99, -56, 55,
77, -27, 97,
-93, -83, 17,
77, -27, 97,
95, 75, -36,
61, 110, -8,
-93, -83, 17,
-101, -36, 67,
-91, 54, -68,
61, 110, -8,
-18, 49, 115,
77, -27, 97,
77, -27, 97,
-18, 49, 115,
-101, -36, 67,
-101, -36, 67,
-18, 49, 115,
-64, 105, -28,
-64, 105, -28,
-18, 49, 115,
61, 110, -8,
99, -56, 55,
86, -90, -18,
95, 75, -36,
-93, -83, 17,
-53, -108, -36,
99, -56, 55,
-91, 54, -68,
-56, -35, -108,
-93, -83, 17,
-56, -35, -108,
-53, -108, -36,
-93, -83, 17,
-53, -108, -36,
86, -90, -18,
99, -56, 55,
86, -90, -18,
89, -25, -86,
95, 75, -36,
-101, -36, 67,
-64, 105, -28,
-91, 54, -68,
77, -27, 97,
99, -56, 55,
95, 75, -36,
77, -27, 97,
-101, -36, 67,
-93, -83, 17,
-64, 105, -28,
61, 110, -8,
95, 75, -36,
-53, -108, -36,
-56, -35, -108,
89, -25, -86,
95, 75, -36,
89, -25, -86,
97, 81, 2,
89, -25, -86,
-56, -35, -108,
89, -30, -84,
-56, -35, -108,
-91, 54, -68,
-73, -11, -103,
-91, 54, -68,
95, 75, -36,
-49, 116, 3,
-89, -25, -86,
53, -108, -36,
-86, -90, -18,
91, 54, -68,
-95, 75, -36,
64, 105, -28,
93, -83, 17,
-77, -27, 97,
-99, -56, 55,
-61, 110, -8,
-95, 75, -36,
-77, -27, 97,
91, 54, -68,
101, -36, 67,
93, -83, 17,
-77, -27, 97,
18, 49, 115,
-61, 110, -8,
101, -36, 67,
18, 49, 115,
-77, -27, 97,
64, 105, -28,
18, 49, 115,
101, -36, 67,
-61, 110, -8,
18, 49, 115,
64, 105, -28,
-95, 75, -36,
-86, -90, -18,
-99, -56, 55,
-99, -56, 55,
53, -108, -36,
93, -83, 17,
93, -83, 17,
56, -35, -108,
91, 54, -68,
93, -83, 17,
53, -108, -36,
56, -35, -108,
-99, -56, 55,
-86, -90, -18,
53, -108, -36,
-95, 75, -36,
-89, -25, -86,
-86, -90, -18,
91, 54, -68,
64, 105, -28,
101, -36, 67,
-95, 75, -36,
-99, -56, 55,
-77, -27, 97,
93, -83, 17,
101, -36, 67,
-77, -27, 97,
-95, 75, -36,
-61, 110, -8,
64, 105, -28,
-89, -25, -86,
56, -35, -108,
53, -108, -36,
-95, 75, -36,
49, 116, 3,
-97, 81, 2,
91, 54, -68,
73, -11, -103,
49, 116, 3,
56, -35, -108,
-89, -30, -84,
73, -11, -103,
-89, -25, -86,
-97, 81, 2,
-89, -30, -84,
61, -28, -107,
89, -25, -86,
-89, -18, -87,
90, -17, -87,
-89, -25, -86,
-61, -28, -107,
80, 84, -49,
-81, 8, -97,
-75, -21, -100,
-75, -21, -100,
-71, -78, 69,
-75, -91, 46,
80, 15, 96,
52, 103, -51,
80, 84, -49,
57, 11, 112,
-71, -78, 69,
99, -30, 72,
-81, 8, -97,
92, 43, -75,
-33, -39, -115,
-71, -78, 69,
-33, -39, -115,
-31, -118, 31,
52, 103, -51,
57, 11, 112,
92, 43, -75,
57, 11, 112,
99, -30, 72,
92, 43, -75,
-71, -78, 69,
-81, 8, -97,
-33, -39, -115,
-81, 8, -97,
52, 103, -51,
92, 43, -75,
-71, -78, 69,
-31, -118, 31,
99, -30, 72,
92, 43, -75,
72, -96, -38,
-33, -39, -115,
99, -30, 72,
72, -96, -38,
92, 43, -75,
-31, -118, 31,
72, -96, -38,
99, -30, 72,
-33, -39, -115,
72, -96, -38,
-31, -118, 31,
-75, -91, 46,
-71, -78, 69,
80, 15, 96,
-71, -78, 69,
57, 11, 112,
80, 15, 96,
80, 15, 96,
57, 11, 112,
52, 103, -51,
-75, -21, -100,
-81, 8, -97,
-71, -78, 69,
80, 84, -49,
52, 103, -51,
-81, 8, -97,
-89, -25, -86,
-95, 75, -36,
-97, 81, 2,
56, -35, -108,
-89, -25, -86,
-89, -30, -84,
91, 54, -68,
56, -35, -108,
73, -11, -103,
-95, 75, -36,
91, 54, -68,
49, 116, 3,
95, 75, -36,
97, 81, 2,
-49, 116, 3,
-91, 54, -68,
-49, 116, 3,
-73, -11, -103,
-56, -35, -108,
-73, -11, -103,
89, -30, -84,
89, -25, -86,
89, -30, -84,
97, 81, 2,
-86, -77, -51,
-80, 43, 87,
-33, -79, 93,
-86, -77, -51,
-25, -112, 52,
27, -113, 50,
89, -71, -53,
27, -113, 50,
35, -76, 95,
-80, 43, 87,
83, 46, 83,
35, -76, 95,
86, -77, -51,
-89, -71, -53,
-27, -113, 50,
86, -77, -51,
25, -112, 52,
33, -79, 93,
80, 43, 87,
33, -79, 93,
-35, -76, 95,
-89, -71, -53,
-83, 46, 83,
-35, -76, 95,
-73, -102, -16,
-27, -113, 50,
-35, -76, 95,
25, -112, 52,
-27, -113, 50,
-73, -102, -16,
78, -8, 99,
33, -79, 93,
25, -112, 52,
-35, -76, 95,
33, -79, 93,
78, -8, 99,
35, -76, 95,
27, -113, 50,
73, -102, -16,
-33, -79, 93,
35, -76, 95,
72, -11, 103,
-25, -112, 52,
-33, -79, 93,
-78, -8, 99,
73, -102, -16,
27, -113, 50,
-25, -112, 52,
81, 8, -97,
75, -21, -100,
75, -91, 46,
71, -78, 69,
75, -91, 46,
-80, 15, 96,
-57, 11, 112,
-80, 15, 96,
-80, 84, -49,
81, 8, -97,
-52, 103, -51,
-80, 84, -49,
-38, -119, -19,
75, -91, 46,
75, -21, -100,
-80, 15, 96,
-94, -85, 0,
-93, -54, -65,
75, -21, -100,
-80, 84, -49,
-93, -54, -65,
-80, 15, 96,
75, -91, 46,
-38, -119, -19,
-75, -91, 46,
38, -119, -19,
38, -90, -80,
80, 84, -49,
-75, -21, -100,
38, -90, -80,
80, 15, 96,
80, 84, -49,
93, -54, -65,
80, 15, 96,
94, -85, 0,
38, -119, -19,
-94, -85, 0,
-38, -119, -19,
42, -115, 33,
-93, -54, -65,
-94, -85, 0,
-99, -42, 67,
42, -47, -109,
-38, -90, -80,
-93, -54, -65,
-38, -119, -19,
-38, -90, -80,
42, -47, -109,
93, -54, -65,
38, -90, -80,
-42, -47, -109,
94, -85, 0,
93, -54, -65,
99, 24, -75,
-42, -115, 33,
38, -119, -19,
94, -85, 0,
38, -90, -80,
38, -119, -19,
-42, -115, 33,
-68, 105, -16,
87, 85, 32,
53, -108, 38,
-89, -18, -87,
-68, 105, -16,
115, -51, 8,
89, -25, -86,
61, -28, -107,
53, -108, 38,
-89, -25, -86,
-91, 82, 32,
-63, -100, 44,
90, -17, -87,
97, -4, -81,
118, 19, 42,
84, 92, 20,
118, 19, 42,
-63, -100, 44,
61, -28, -107,
-61, -28, -107,
-94, 15, -83,
53, -108, 38,
61, -28, -107,
94, 15, -83,
-63, -100, 44,
53, -108, 38,
83, -81, 50,
-63, -100, 44,
-83, -81, 50,
-94, 15, -83,
97, -4, -81,
-61, -28, -107,
61, -28, -107,
115, -51, 8,
53, -108, 38,
-63, -100, 44,
50, 52, 104,
15, 58, 111,
58, -42, 104,
-93, -55, 66,
58, -42, 104,
65, 34, -103,
68, 106, -8,
-91, 8, -87,
65, 34, -103,
-68, 106, -9,
-48, 106, -49,
-65, 34, -103,
93, -55, 66,
91, 8, -87,
-65, 34, -103,
-50, 52, 104,
93, -55, 66,
-58, -42, 104,
-85, 48, -80,
-83, -18, 94,
-58, -42, 104,
65, 34, -103,
85, 48, -80,
-85, 48, -80,
-58, -42, 104,
-83, -18, 94,
83, -18, 94,
58, -42, 104,
83, -18, 94,
85, 48, -80,
-22, 117, 41,
29, 122, -14,
84, -13, -93,
22, 117, 41,
-22, 117, 41,
-14, -71, -104,
-48, 106, -49,
48, 106, -49,
65, 34, -103,
58, -42, 104,
15, 58, 111,
-14, 58, 111,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:21 */
static s8 vtxnvgrp_frake_select_21[]={
-30, -118, 33,
-10, -124, 22,
-11, -123, 25,
-11, -123, 25,
8, -126, 6,
92, -81, 30,
-35, -90, -81,
21, -33, -120,
-82, -89, -36,
-82, -89, -36,
-51, 17, -114,
-49, -98, -64,
-49, -98, -64,
-51, 17, -114,
-38, -100, -67,
-38, -100, -67,
-112, 27, -51,
-83, -81, -50,
-83, -81, -50,
-126, 0, 10,
-85, -86, 37,
-35, -90, -81,
81, -90, 34,
33, -119, -26,
59, -75, -83,
-16, -74, -101,
21, -33, -120,
21, -33, -120,
83, -17, -94,
-51, 17, -114,
-51, 17, -114,
-115, 23, -47,
-112, 27, -51,
-112, 27, -51,
-62, -51, -97,
-126, 0, 10,
-126, 0, 10,
-62, -51, -97,
-85, -86, 37,
-85, -86, 37,
-88, -77, -46,
-14, -124, -21,
-14, -124, -21,
9, -98, -79,
33, -119, -26,
33, -119, -26,
-16, -74, -101,
59, -75, -83,
39, 114, 38,
-55, 101, 53,
11, 122, 32,
62, 4, -110,
78, 21, -97,
98, -55, -57,
120, -24, -32,
87, -87, 28,
92, -81, 30,
92, -81, 30,
87, -87, 28,
-11, -123, 25,
-11, -123, 25,
-54, -35, 108,
-53, -32, 110,
-53, -32, 110,
-54, -35, 108,
-89, 58, 68,
-116, 29, 40,
-95, 83, -6,
-104, 69, -20,
-104, 69, -20,
-26, 81, -93,
-37, 67, -101,
-37, 67, -101,
-26, 81, -93,
62, 4, -110,
78, 21, -97,
115, 49, -19,
120, -24, -32,
120, -24, -32,
115, 49, -19,
126, 8, 10,
-54, 78, 84,
-55, 101, 53,
-89, 58, 68,
-89, 58, 68,
-55, 101, 53,
-95, 83, -6,
-95, 83, -6,
2, 120, -40,
-26, 81, -93,
-26, 81, -93,
2, 120, -40,
78, 21, -97,
85, 90, -21,
2, 120, -40,
39, 114, 38,
33, -119, -26,
59, -75, -83,
-35, -90, -81,
-85, -86, 37,
-55, -48, 103,
-83, -81, -50,
-14, -124, -21,
33, -119, -26,
-85, -86, 37,
33, -119, -26,
26, -88, 86,
-85, -86, 37,
-30, -118, 33,
46, -118, -3,
-83, -81, -50,
-83, -81, -50,
-113, 44, -35,
-116, 29, 40,
-116, 29, 40,
-69, -65, 83,
-53, -32, 110,
-53, -32, 110,
46, -118, -3,
-30, -118, 33,
46, -118, -3,
-72, -79, -67,
21, 0, -125,
21, 0, -125,
-72, -79, -67,
-113, 44, -35,
-113, 44, -35,
-72, -79, -67,
-69, -65, 83,
-69, -65, 83,
-72, -79, -67,
46, -118, -3,
-35, -90, -81,
-80, -84, 51,
8, -126, 6,
8, -126, 6,
-80, -84, 51,
92, -81, 30,
92, -81, 30,
67, -107, 12,
98, -55, -57,
98, -55, -57,
41, -17, -118,
-35, -90, -81,
-99, 49, -60,
-61, -81, -75,
-80, -84, 51,
-80, -84, 51,
-61, -81, -75,
67, -107, 12,
67, -107, 12,
-61, -81, -75,
41, -17, -118,
41, -17, -118,
-61, -81, -75,
-99, 49, -60,
-82, -89, -36,
-65, -85, 66,
-35, -90, -81,
-35, -90, -81,
-65, -85, 66,
98, -55, -57,
98, -55, -57,
68, -104, -22,
62, 4, -110,
62, 4, -110,
-52, 37, -109,
-82, -89, -36,
-110, 31, 53,
-80, -74, -63,
-65, -85, 66,
-65, -85, 66,
-80, -74, -63,
68, -104, -22,
68, -104, -22,
-80, -74, -63,
-52, 37, -109,
-52, 37, -109,
-80, -74, -63,
-110, 31, 53,
-104, 69, -20,
-97, -56, 59,
-116, 29, 40,
-116, 29, 40,
46, -117, 11,
-83, -81, -50,
-83, -81, -50,
46, -117, 11,
-38, -100, -67,
-38, -100, -67,
-30, 28, -120,
-104, 69, -20,
-30, 28, -120,
-52, -81, -82,
-97, -56, 59,
-97, -56, 59,
-52, -81, -82,
46, -117, 11,
46, -117, 11,
-52, -81, -82,
102, -57, -47,
102, -57, -47,
-52, -81, -82,
-30, 28, -120,
-49, -98, -64,
47, -104, 54,
-82, -89, -36,
-82, -89, -36,
47, -104, 54,
62, 4, -110,
62, 4, -110,
-87, 40, -82,
-37, 67, -101,
-37, 67, -101,
-87, 40, -82,
-49, -98, -64,
-107, -33, 58,
-48, -117, -2,
47, -104, 54,
47, -104, 54,
-48, -117, -2,
80, -30, -93,
80, -30, -93,
-48, -117, -2,
-87, 40, -82,
-87, 40, -82,
-48, -117, -2,
-107, -33, 58,
-38, -100, -67,
-26, -80, 94,
-49, -98, -64,
-49, -98, -64,
0, 11, -126,
-37, 67, -101,
-37, 67, -101,
0, 11, -126,
-104, 69, -20,
-104, 69, -20,
-26, -80, 94,
-38, -100, -67,
-26, -80, 94,
-37, -120, -17,
74, -97, -31,
74, -97, -31,
-37, -120, -17,
0, 11, -126,
0, 11, -126,
-37, -120, -17,
-122, 30, 13,
-122, 30, 13,
-37, -120, -17,
-26, -80, 94,
52, 56, 100,
60, 54, 97,
-54, 78, 84,
126, 8, 10,
60, 54, 97,
52, 56, 100,
81, -90, 34,
-35, -90, -81,
8, -126, 6,
-55, -48, 103,
-30, -118, 33,
-83, -81, -50,
-55, -48, 103,
-10, -124, 22,
-30, -118, 33,
81, -90, 34,
8, -126, 6,
-10, -124, 22,
-55, -48, 103,
26, -88, 86,
-10, -124, 22,
126, 8, 10,
87, -87, 28,
120, -24, -32,
-89, 58, 68,
-54, -35, 108,
-54, 78, 84,
92, -81, 30,
98, -55, -57,
120, -24, -32,
-89, 58, 68,
-116, 29, 40,
-53, -32, 110,
4, 35, 121,
-11, -29, 122,
61, 17, 109,
84, -63, 70,
57, 15, 112,
39, -45, 111,
39, 114, 38,
60, 54, 97,
74, 102, 0,
39, 114, 38,
74, 102, 0,
115, 49, -19,
39, 114, 38,
115, 49, -19,
85, 90, -21,
11, 122, 32,
60, 54, 97,
39, 114, 38,
39, 114, 38,
-20, 121, 29,
-55, 101, 53,
39, 114, 38,
2, 120, -40,
-20, 121, 29,
52, 56, 100,
47, -63, 99,
33, -86, 87,
33, -86, 87,
-30, -46, 114,
-54, -35, 108,
-54, -35, 108,
-19, 51, 114,
-54, 78, 84,
-54, 78, 84,
78, 30, 95,
52, 56, 100,
87, -87, 28,
80, -74, 64,
33, -86, 87,
33, -86, 87,
18, -57, 111,
52, 56, 100,
52, 56, 100,
46, 36, 112,
126, 8, 10,
126, 8, 10,
117, 13, 45,
87, -87, 28,
117, 13, 45,
80, -74, 64,
87, -87, 28,
46, 36, 112,
117, 13, 45,
126, 8, 10,
18, -57, 111,
46, 36, 112,
52, 56, 100,
80, -74, 64,
18, -57, 111,
33, -86, 87,
-54, 78, 84,
-19, 51, 114,
78, 30, 95,
-54, -35, 108,
-30, -46, 114,
-19, 51, 114,
33, -86, 87,
47, -63, 99,
-30, -46, 114,
52, 56, 100,
78, 30, 95,
47, -63, 99,
126, 8, 10,
74, 102, 0,
60, 54, 97,
60, 54, 97,
11, 122, 32,
-54, 78, 84,
-104, 69, -20,
-122, 30, 13,
-26, -80, 94,
0, 11, -126,
-122, 30, 13,
-104, 69, -20,
-49, -98, -64,
74, -97, -31,
0, 11, -126,
-26, -80, 94,
74, -97, -31,
-49, -98, -64,
-87, 40, -82,
-107, -33, 58,
-49, -98, -64,
62, 4, -110,
80, -30, -93,
-87, 40, -82,
47, -104, 54,
80, -30, -93,
62, 4, -110,
-49, -98, -64,
-107, -33, 58,
47, -104, 54,
-38, -100, -67,
102, -57, -47,
-30, 28, -120,
46, -117, 11,
102, -57, -47,
-38, -100, -67,
-116, 29, 40,
-97, -56, 59,
46, -117, 11,
-104, 69, -20,
-30, 28, -120,
-97, -56, 59,
-52, 37, -109,
-110, 31, 53,
-82, -89, -36,
68, -104, -22,
-52, 37, -109,
62, 4, -110,
-65, -85, 66,
68, -104, -22,
98, -55, -57,
-82, -89, -36,
-110, 31, 53,
-65, -85, 66,
41, -17, -118,
-99, 49, -60,
-35, -90, -81,
67, -107, 12,
41, -17, -118,
98, -55, -57,
-80, -84, 51,
67, -107, 12,
92, -81, 30,
-35, -90, -81,
-99, 49, -60,
-80, -84, 51,
-53, -32, 110,
-69, -65, 83,
46, -118, -3,
-116, 29, 40,
-113, 44, -35,
-69, -65, 83,
-83, -81, -50,
21, 0, -125,
-113, 44, -35,
46, -118, -3,
21, 0, -125,
-83, -81, -50,
26, -88, 86,
-55, -48, 103,
-85, -86, 37,
2, 120, -40,
85, 90, -21,
78, 21, -97,
-95, 83, -6,
-20, 121, 29,
2, 120, -40,
-55, 101, 53,
-20, 121, 29,
-95, 83, -6,
-54, 78, 84,
11, 122, 32,
-55, 101, 53,
115, 49, -19,
74, 102, 0,
126, 8, 10,
78, 21, -97,
85, 90, -21,
115, 49, -19,
-26, 81, -93,
78, 21, -97,
62, 4, -110,
-104, 69, -20,
-95, 83, -6,
-26, 81, -93,
-116, 29, 40,
-89, 58, 68,
-95, 83, -6,
-11, -123, 25,
33, -86, 87,
-54, -35, 108,
87, -87, 28,
33, -86, 87,
-11, -123, 25,
78, 21, -97,
120, -24, -32,
98, -55, -57,
-16, -74, -101,
9, -98, -79,
-88, -77, -46,
9, -98, -79,
-14, -124, -21,
-88, -77, -46,
-16, -74, -101,
-88, -77, -46,
-62, -51, -97,
33, -119, -26,
9, -98, -79,
-16, -74, -101,
-62, -51, -97,
-88, -77, -46,
-85, -86, 37,
-112, 27, -51,
-115, 23, -47,
-62, -51, -97,
-51, 17, -114,
-4, 16, -125,
-115, 23, -47,
83, -17, -94,
-4, 16, -125,
-51, 17, -114,
-16, -74, -101,
83, -17, -94,
21, -33, -120,
-112, 27, -51,
-126, 0, 10,
-83, -81, -50,
-51, 17, -114,
-112, 27, -51,
-38, -100, -67,
-82, -89, -36,
21, -33, -120,
-51, 17, -114,
-35, -90, -81,
59, -75, -83,
21, -33, -120,
-11, -123, 25,
-10, -124, 22,
8, -126, 6,
-11, -123, 25,
-53, -32, 110,
-30, -118, 33,
26, -88, 86,
81, -90, 34,
-10, -124, 22,
18, -57, 111,
101, 0, 76,
46, 36, 112,
46, 36, 112,
39, -45, 111,
117, 13, 45,
117, 13, 45,
39, -45, 111,
80, -74, 64,
80, -74, 64,
101, 0, 76,
18, -57, 111,
78, 30, 95,
4, 35, 121,
47, -63, 99,
47, -63, 99,
4, 35, 121,
-30, -46, 114,
-30, -46, 114,
47, -49, 106,
-19, 51, 114,
-19, 51, 114,
47, -49, 106,
78, 30, 95,
47, -49, 106,
-11, -29, 122,
78, 30, 95,
-30, -46, 114,
61, 17, 109,
47, -49, 106,
4, 35, 121,
61, 17, 109,
-30, -46, 114,
78, 30, 95,
-11, -29, 122,
4, 35, 121,
80, -74, 64,
57, 15, 112,
101, 0, 76,
39, -45, 111,
57, 15, 112,
80, -74, 64,
46, 36, 112,
84, -63, 70,
39, -45, 111,
101, 0, 76,
84, -63, 70,
46, 36, 112,
84, -63, 70,
101, 0, 76,
57, 15, 112,
-11, -29, 122,
47, -49, 106,
61, 17, 109,
33, -119, -26,
81, -90, 34,
26, -88, 86,
58, -40, 104,
-14, 59, 111,
-58, -40, 104,
94, 14, -83,
-94, 14, -83,
85, 47, -80,
15, 59, 111,
20, 119, 39,
-14, 59, 111,
-14, 59, 111,
-30, 122, -16,
-48, 106, -50,
-48, 106, -50,
30, 122, -16,
48, 106, -50,
48, 106, -50,
30, 122, -16,
15, 59, 111,
83, -17, 94,
94, 14, -83,
85, 47, -80,
-83, -17, 94,
83, -80, 51,
83, -17, 94,
-85, 47, -80,
-94, 14, -83,
-83, -17, 94,
-65, 33, -103,
-48, 106, -50,
65, 33, -103,
-94, 14, -83,
-83, -80, 51,
-83, -17, 94,
-83, -17, 94,
-83, -80, 51,
83, -80, 51,
83, -17, 94,
83, -80, 51,
94, 14, -83,
30, 122, -16,
-20, 119, 39,
15, 59, 111,
-48, 106, -50,
-30, 122, -16,
30, 122, -16,
-14, 59, 111,
20, 119, 39,
-30, 122, -16,
15, 59, 111,
-20, 119, 39,
20, 119, 39,
-94, 14, -83,
-85, 47, -80,
85, 47, -80,
20, 119, 39,
-16, -74, -101,
-62, -51, -97,
-20, 119, 39,
83, -17, -94,
-16, -74, -101,
30, 122, -16,
-4, 16, -125,
83, -17, -94,
-30, 122, -16,
-115, 23, -47,
-4, 16, -125,
20, 119, 39,
-62, -51, -97,
-115, 23, -47,
30, 122, -16,
-30, 122, -16,
-4, 16, -125,
-30, 122, -16,
20, 119, 39,
-115, 23, -47,
58, -40, 104,
85, 47, -80,
65, 33, -103,
-58, -40, 104,
83, -17, 94,
58, -40, 104,
65, 33, -103,
-85, 47, -80,
-65, 33, -103,
-65, 33, -103,
-85, 47, -80,
-58, -40, 104,
-99, -41, 67,
93, -54, 66,
-50, 53, 103,
42, -49, -109,
-99, 23, -75,
91, 7, -87,
42, -114, 34,
42, -49, -109,
93, -54, 66,
-99, 23, -75,
-50, 53, 103,
-68, 106, -10,
-99, 23, -75,
-99, -41, 67,
-50, 53, 103,
42, -49, -109,
91, 7, -87,
93, -54, 66,
-99, 23, -75,
-68, 106, -10,
91, 7, -87,
-99, -41, 67,
42, -114, 34,
93, -54, 66,
-50, 53, 103,
-58, -40, 104,
-14, 59, 111,
93, -54, 66,
-65, 33, -103,
-58, -40, 104,
91, 7, -87,
-68, 106, -10,
-65, 33, -103,
-68, 106, -10,
-14, 59, 111,
-48, 106, -50,
50, 53, 103,
-93, -54, 66,
99, -41, 67,
-91, 7, -87,
99, 23, -75,
-42, -49, -109,
-93, -54, 66,
-42, -49, -109,
-42, -114, 34,
67, 106, -10,
50, 53, 103,
99, 23, -75,
50, 53, 103,
99, -41, 67,
99, 23, -75,
-93, -54, 66,
-91, 7, -87,
-42, -49, -109,
-91, 7, -87,
67, 106, -10,
99, 23, -75,
-93, -54, 66,
-42, -114, 34,
99, -41, 67,
50, 53, 103,
48, 106, -50,
15, 59, 111,
67, 106, -10,
65, 33, -103,
48, 106, -50,
-91, 7, -87,
-93, -54, 66,
65, 33, -103,
-93, -54, 66,
50, 53, 103,
58, -40, 104,
67, 106, -10,
48, 106, -50,
50, 53, 103,
-14, 59, 111,
-68, 106, -10,
-50, 53, 103,
116, -50, 7,
-61, -101, 45,
118, 18, 42,
97, -4, -81,
60, -28, -107,
-97, -4, -81,
-97, -4, -81,
118, 18, 42,
97, -4, -81,
-97, -4, -81,
116, -50, 7,
118, 18, 42,
-60, -28, -107,
-61, -101, 45,
-94, 14, -83,
-61, -101, 45,
83, -80, 51,
-83, -80, 51,
52, -108, 39,
94, 14, -83,
83, -80, 51,
60, -28, -107,
-94, 14, -83,
94, 14, -83,
-78, -10, 99,
72, -13, 103,
-91, 81, 33,
73, -101, -18,
-89, -23, -86,
90, -16, -87,
72, -13, 103,
73, -101, -18,
84, 92, 21,
-78, -97, -20,
-91, 81, 33,
-89, -23, -86,
-78, -97, -20,
-78, -10, 99,
-91, 81, 33,
73, -101, -18,
90, -16, -87,
84, 92, 21,
73, -101, -18,
-78, -97, -20,
-89, -23, -86,
72, -13, 103,
84, 92, 21,
-91, 81, 33,
-91, 81, 33,
84, 92, 21,
-61, -101, 45,
84, 92, 21,
90, -16, -87,
118, 18, 42,
90, -16, -87,
-60, -28, -107,
97, -4, -81,
-89, -23, -86,
-61, -101, 45,
-60, -28, -107,
87, 85, 34,
-73, -12, 102,
78, -10, 99,
-90, -16, -87,
89, -23, -86,
-73, -102, -18,
-69, 105, -13,
-73, -102, -18,
-73, -12, 102,
89, -23, -86,
87, 85, 34,
78, -97, -20,
87, 85, 34,
78, -10, 99,
78, -97, -20,
-69, 105, -13,
-90, -16, -87,
-73, -102, -18,
89, -23, -86,
78, -97, -20,
-73, -102, -18,
87, 85, 34,
-69, 105, -13,
-73, -12, 102,
87, 85, 34,
89, -23, -86,
52, -108, 39,
-90, -16, -87,
-97, -4, -81,
60, -28, -107,
-90, -16, -87,
116, -50, 7,
-97, -4, -81,
-69, 105, -13,
52, -108, 39,
116, -50, 7,
-42, -49, -109,
38, -91, -78,
-42, -114, 34,
-42, -114, 34,
93, -85, 1,
99, -41, 67,
99, -41, 67,
93, -85, 1,
99, 23, -75,
99, 23, -75,
93, -55, -65,
-42, -49, -109,
42, -114, 34,
-38, -119, -17,
42, -49, -109,
42, -49, -109,
-93, -55, -65,
-99, 23, -75,
-99, 23, -75,
-93, -55, -65,
-99, -41, 67,
-99, -41, 67,
-93, -85, 1,
42, -114, 34,
-74, -90, 48,
80, 17, 96,
38, -119, -17,
80, 17, 96,
93, -55, -65,
93, -85, 1,
80, 84, -50,
38, -91, -78,
93, -55, -65,
-74, -23, -99,
-74, -90, 48,
38, -91, -78,
-80, 17, 96,
-38, -119, -17,
-93, -85, 1,
74, -23, -99,
-93, -55, -65,
-38, -91, -78,
-80, 84, -50,
-80, 17, 96,
-93, -55, -65,
-38, -91, -78,
-38, -119, -17,
74, -23, -99,
-99, -29, 72,
71, -77, 70,
-57, 12, 112,
33, -40, -115,
-92, 42, -75,
81, 6, -97,
31, -118, 32,
33, -40, -115,
71, -77, 70,
-92, 42, -75,
-57, 12, 112,
-52, 102, -52,
-92, 42, -75,
-99, -29, 72,
-57, 12, 112,
33, -40, -115,
81, 6, -97,
71, -77, 70,
-92, 42, -75,
-52, 102, -52,
81, 6, -97,
-99, -29, 72,
31, -118, 32,
71, -77, 70,
33, -40, -115,
-72, -97, -37,
-92, 42, -75,
-92, 42, -75,
-72, -97, -37,
-99, -29, 72,
-99, -29, 72,
-72, -97, -37,
31, -118, 32,
31, -118, 32,
-72, -97, -37,
33, -40, -115,
81, 6, -97,
-80, 84, -50,
74, -23, -99,
-52, 102, -52,
-57, 12, 112,
-80, 84, -50,
-57, 12, 112,
71, -77, 70,
-80, 17, 96,
71, -77, 70,
81, 6, -97,
74, -90, 48,
73, -101, -18,
-25, -113, 50,
-78, -97, -20,
-78, -97, -20,
-25, -113, 50,
-78, -10, 99,
-78, -10, 99,
-33, -81, 91,
72, -13, 103,
72, -13, 103,
35, -78, 93,
73, -101, -18,
-73, -12, 102,
-35, -78, 93,
78, -10, 99,
78, -10, 99,
25, -113, 50,
78, -97, -20,
78, -97, -20,
25, -113, 50,
-73, -102, -18,
-73, -102, -18,
-35, -78, 93,
-73, -12, 102,
89, 52, 72,
82, 44, 86,
-89, 52, 72,
-89, -52, -72,
-88, -73, -53,
89, -52, -72,
-84, 46, 82,
-88, -73, -53,
-89, 52, 72,
85, -78, -51,
82, 44, 86,
89, -52, -72,
89, 52, 72,
49, 116, -2,
89, -52, -72,
89, -52, -72,
73, -16, -102,
-89, -52, -72,
-89, -52, -72,
-97, 81, 0,
-89, 52, 72,
-89, 52, 72,
-97, 81, 0,
89, 52, 72,
-97, 81, 0,
49, 116, -2,
89, 52, 72,
-89, -52, -72,
-89, -34, -83,
-97, 81, 0,
73, -16, -102,
-89, -34, -83,
-89, -52, -72,
49, 116, -2,
73, -16, -102,
89, -52, -72,
82, 44, 86,
89, 52, 72,
89, -52, -72,
-88, -73, -53,
-89, -52, -72,
-89, 52, 72,
-88, -73, -53,
85, -78, -51,
89, -52, -72,
82, 44, 86,
-84, 46, 82,
-89, 52, 72,
-88, -73, -53,
-35, -78, 93,
-27, -114, 48,
-84, 46, 82,
82, 44, 86,
-35, -78, 93,
82, 44, 86,
85, -78, -51,
33, -81, 91,
85, -78, -51,
-27, -114, 48,
25, -113, 50,
89, 52, 72,
-82, 44, 86,
-89, 52, 72,
-89, -52, -72,
88, -73, -53,
89, -52, -72,
89, 52, 72,
88, -73, -53,
84, 46, 82,
-89, -52, -72,
-82, 44, 86,
-85, -78, -51,
-89, -52, -72,
-49, 116, -2,
-89, 52, 72,
89, -52, -72,
-73, -16, -102,
-89, -52, -72,
89, 52, 72,
97, 81, 0,
89, -52, -72,
-89, 52, 72,
97, 81, 0,
89, 52, 72,
-89, 52, 72,
-49, 116, -2,
97, 81, 0,
97, 81, 0,
89, -34, -83,
89, -52, -72,
89, -52, -72,
89, -34, -83,
-73, -16, -102,
-89, -52, -72,
-73, -16, -102,
-49, 116, -2,
-89, -52, -72,
-89, 52, 72,
-82, 44, 86,
89, 52, 72,
89, -52, -72,
88, -73, -53,
-89, -52, -72,
-85, -78, -51,
88, -73, -53,
89, 52, 72,
84, 46, 82,
-82, 44, 86,
-82, 44, 86,
35, -78, 93,
-33, -81, 91,
84, 46, 82,
88, -73, -53,
35, -78, 93,
88, -73, -53,
-85, -78, -51,
27, -114, 48,
-85, -78, -51,
-33, -81, 91,
-25, -113, 50,
86, -91, -14,
-53, -110, -31,
89, -29, -85,
-65, 103, -33,
95, 73, -40,
-91, 51, -71,
99, -53, 57,
77, -22, 98,
-93, -82, 22,
77, -22, 98,
95, 73, -40,
61, 109, -13,
-93, -82, 22,
-101, -33, 69,
-91, 51, -71,
61, 109, -13,
-18, 55, 112,
77, -22, 98,
77, -22, 98,
-18, 55, 112,
-101, -33, 69,
-101, -33, 69,
-18, 55, 112,
-65, 103, -33,
-65, 103, -33,
-18, 55, 112,
61, 109, -13,
99, -53, 57,
86, -91, -14,
95, 73, -40,
-93, -82, 22,
-53, -110, -31,
99, -53, 57,
-91, 51, -71,
-56, -40, -106,
-93, -82, 22,
-56, -40, -106,
-53, -110, -31,
-93, -82, 22,
-53, -110, -31,
86, -91, -14,
99, -53, 57,
86, -91, -14,
89, -29, -85,
95, 73, -40,
-101, -33, 69,
-65, 103, -33,
-91, 51, -71,
77, -22, 98,
99, -53, 57,
95, 73, -40,
77, -22, 98,
-101, -33, 69,
-93, -82, 22,
-65, 103, -33,
61, 109, -13,
95, 73, -40,
-53, -110, -31,
-56, -40, -106,
89, -29, -85,
95, 73, -40,
89, -29, -85,
97, 81, 0,
89, -29, -85,
-56, -40, -106,
89, -34, -83,
-56, -40, -106,
-91, 51, -71,
-73, -16, -102,
-91, 51, -71,
95, 73, -40,
-49, 116, -2,
-89, -29, -85,
53, -110, -31,
-86, -91, -14,
91, 51, -71,
-95, 73, -40,
65, 103, -33,
93, -82, 22,
-77, -22, 98,
-99, -53, 57,
-61, 109, -13,
-95, 73, -40,
-77, -22, 98,
91, 51, -71,
101, -33, 69,
93, -82, 22,
-77, -22, 98,
18, 55, 112,
-61, 109, -13,
101, -33, 69,
18, 55, 112,
-77, -22, 98,
65, 103, -33,
18, 55, 112,
101, -33, 69,
-61, 109, -13,
18, 55, 112,
65, 103, -33,
-95, 73, -40,
-86, -91, -14,
-99, -53, 57,
-99, -53, 57,
53, -110, -31,
93, -82, 22,
93, -82, 22,
56, -40, -106,
91, 51, -71,
93, -82, 22,
53, -110, -31,
56, -40, -106,
-99, -53, 57,
-86, -91, -14,
53, -110, -31,
-95, 73, -40,
-89, -29, -85,
-86, -91, -14,
91, 51, -71,
65, 103, -33,
101, -33, 69,
-95, 73, -40,
-99, -53, 57,
-77, -22, 98,
93, -82, 22,
101, -33, 69,
-77, -22, 98,
-95, 73, -40,
-61, 109, -13,
65, 103, -33,
-89, -29, -85,
56, -40, -106,
53, -110, -31,
-95, 73, -40,
49, 116, -2,
-97, 81, 0,
91, 51, -71,
73, -16, -102,
49, 116, -2,
56, -40, -106,
-89, -34, -83,
73, -16, -102,
-89, -29, -85,
-97, 81, 0,
-89, -34, -83,
60, -28, -107,
89, -23, -86,
-90, -16, -87,
90, -16, -87,
-89, -23, -86,
-60, -28, -107,
80, 84, -50,
-81, 6, -97,
-74, -23, -99,
-74, -23, -99,
-71, -77, 70,
-74, -90, 48,
80, 17, 96,
52, 102, -52,
80, 84, -50,
57, 12, 112,
-71, -77, 70,
99, -29, 72,
-81, 6, -97,
92, 42, -75,
-33, -40, -115,
-71, -77, 70,
-33, -40, -115,
-31, -118, 32,
52, 102, -52,
57, 12, 112,
92, 42, -75,
57, 12, 112,
99, -29, 72,
92, 42, -75,
-71, -77, 70,
-81, 6, -97,
-33, -40, -115,
-81, 6, -97,
52, 102, -52,
92, 42, -75,
-71, -77, 70,
-31, -118, 32,
99, -29, 72,
92, 42, -75,
72, -97, -37,
-33, -40, -115,
99, -29, 72,
72, -97, -37,
92, 42, -75,
-31, -118, 32,
72, -97, -37,
99, -29, 72,
-33, -40, -115,
72, -97, -37,
-31, -118, 32,
-74, -90, 48,
-71, -77, 70,
80, 17, 96,
-71, -77, 70,
57, 12, 112,
80, 17, 96,
80, 17, 96,
57, 12, 112,
52, 102, -52,
-74, -23, -99,
-81, 6, -97,
-71, -77, 70,
80, 84, -50,
52, 102, -52,
-81, 6, -97,
-89, -29, -85,
-95, 73, -40,
-97, 81, 0,
56, -40, -106,
-89, -29, -85,
-89, -34, -83,
91, 51, -71,
56, -40, -106,
73, -16, -102,
-95, 73, -40,
91, 51, -71,
49, 116, -2,
95, 73, -40,
97, 81, 0,
-49, 116, -2,
-91, 51, -71,
-49, 116, -2,
-73, -16, -102,
-56, -40, -106,
-73, -16, -102,
89, -34, -83,
89, -29, -85,
89, -34, -83,
97, 81, 0,
-85, -78, -51,
-82, 44, 86,
-33, -81, 91,
-85, -78, -51,
-25, -113, 50,
27, -114, 48,
88, -73, -53,
27, -114, 48,
35, -78, 93,
-82, 44, 86,
84, 46, 82,
35, -78, 93,
85, -78, -51,
-88, -73, -53,
-27, -114, 48,
85, -78, -51,
25, -113, 50,
33, -81, 91,
82, 44, 86,
33, -81, 91,
-35, -78, 93,
-88, -73, -53,
-84, 46, 82,
-35, -78, 93,
-73, -102, -18,
-27, -114, 48,
-35, -78, 93,
25, -113, 50,
-27, -114, 48,
-73, -102, -18,
78, -10, 99,
33, -81, 91,
25, -113, 50,
-35, -78, 93,
33, -81, 91,
78, -10, 99,
35, -78, 93,
27, -114, 48,
73, -101, -18,
-33, -81, 91,
35, -78, 93,
72, -13, 103,
-25, -113, 50,
-33, -81, 91,
-78, -10, 99,
73, -101, -18,
27, -114, 48,
-25, -113, 50,
81, 6, -97,
74, -23, -99,
74, -90, 48,
71, -77, 70,
74, -90, 48,
-80, 17, 96,
-57, 12, 112,
-80, 17, 96,
-80, 84, -50,
81, 6, -97,
-52, 102, -52,
-80, 84, -50,
-38, -119, -17,
74, -90, 48,
74, -23, -99,
-80, 17, 96,
-93, -85, 1,
-93, -55, -65,
74, -23, -99,
-80, 84, -50,
-93, -55, -65,
-80, 17, 96,
74, -90, 48,
-38, -119, -17,
-74, -90, 48,
38, -119, -17,
38, -91, -78,
80, 84, -50,
-74, -23, -99,
38, -91, -78,
80, 17, 96,
80, 84, -50,
93, -55, -65,
80, 17, 96,
93, -85, 1,
38, -119, -17,
-93, -85, 1,
-38, -119, -17,
42, -114, 34,
-93, -55, -65,
-93, -85, 1,
-99, -41, 67,
42, -49, -109,
-38, -91, -78,
-93, -55, -65,
-38, -119, -17,
-38, -91, -78,
42, -49, -109,
93, -55, -65,
38, -91, -78,
-42, -49, -109,
93, -85, 1,
93, -55, -65,
99, 23, -75,
-42, -114, 34,
38, -119, -17,
93, -85, 1,
38, -91, -78,
38, -119, -17,
-42, -114, 34,
-69, 105, -13,
87, 85, 34,
52, -108, 39,
-90, -16, -87,
-69, 105, -13,
116, -50, 7,
89, -23, -86,
60, -28, -107,
52, -108, 39,
-89, -23, -86,
-91, 81, 33,
-61, -101, 45,
90, -16, -87,
97, -4, -81,
118, 18, 42,
84, 92, 21,
118, 18, 42,
-61, -101, 45,
60, -28, -107,
-60, -28, -107,
-94, 14, -83,
52, -108, 39,
60, -28, -107,
94, 14, -83,
-61, -101, 45,
52, -108, 39,
83, -80, 51,
-61, -101, 45,
-83, -80, 51,
-94, 14, -83,
97, -4, -81,
-60, -28, -107,
60, -28, -107,
116, -50, 7,
52, -108, 39,
-61, -101, 45,
50, 53, 103,
15, 59, 111,
58, -40, 104,
-93, -54, 66,
58, -40, 104,
65, 33, -103,
67, 106, -10,
-91, 7, -87,
65, 33, -103,
-68, 106, -10,
-48, 106, -50,
-65, 33, -103,
93, -54, 66,
91, 7, -87,
-65, 33, -103,
-50, 53, 103,
93, -54, 66,
-58, -40, 104,
-85, 47, -80,
-83, -17, 94,
-58, -40, 104,
65, 33, -103,
85, 47, -80,
-85, 47, -80,
-58, -40, 104,
-83, -17, 94,
83, -17, 94,
58, -40, 104,
83, -17, 94,
85, 47, -80,
-20, 119, 39,
30, 122, -16,
83, -17, -94,
20, 119, 39,
-20, 119, 39,
-16, -74, -101,
-48, 106, -50,
48, 106, -50,
65, 33, -103,
58, -40, 104,
15, 59, 111,
-14, 59, 111,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:22 */
static s8 vtxnvgrp_frake_select_22[]={
-24, -116, 43,
-3, -122, 33,
-5, -121, 36,
-5, -121, 36,
15, -124, 18,
94, -73, 41,
-27, -99, -74,
27, -44, -115,
-76, -96, -30,
-76, -96, -30,
-48, 2, -117,
-40, -105, -56,
-40, -105, -56,
-48, 2, -117,
-31, -107, -59,
-31, -107, -59,
-111, 16, -59,
-77, -89, -45,
-77, -89, -45,
-126, -6, 4,
-82, -87, 41,
-27, -99, -74,
84, -82, 46,
39, -119, -13,
65, -80, -72,
-10, -86, -92,
27, -44, -115,
27, -44, -115,
85, -27, -90,
-48, 2, -117,
-48, 2, -117,
-114, 14, -53,
-111, 16, -59,
-111, 16, -59,
-58, -67, -90,
-126, -6, 4,
-126, -6, 4,
-58, -67, -90,
-82, -87, 41,
-82, -87, 41,
-87, -81, -43,
-11, -125, -15,
-11, -125, -15,
14, -104, -70,
39, -119, -13,
39, -119, -13,
-10, -86, -92,
65, -80, -72,
31, 119, 29,
-62, 103, 40,
3, 125, 20,
65, -3, -108,
81, 15, -96,
103, -56, -48,
122, -22, -25,
90, -79, 39,
94, -73, 41,
94, -73, 41,
90, -79, 39,
-5, -121, 36,
-5, -121, 36,
-56, -27, 110,
-55, -24, 111,
-55, -24, 111,
-56, -27, 110,
-94, 60, 58,
-119, 28, 32,
-98, 78, -17,
-106, 62, -31,
-106, 62, -31,
-27, 70, -101,
-37, 54, -108,
-37, 54, -108,
-27, 70, -101,
65, -3, -108,
81, 15, -96,
113, 53, -19,
122, -22, -25,
122, -22, -25,
113, 53, -19,
125, 15, 15,
-61, 83, 73,
-62, 103, 40,
-94, 60, 58,
-94, 60, 58,
-62, 103, 40,
-98, 78, -17,
-98, 78, -17,
-2, 116, -51,
-27, 70, -101,
-27, 70, -101,
-2, 116, -51,
81, 15, -96,
82, 92, -27,
-2, 116, -51,
31, 119, 29,
39, -119, -13,
65, -80, -72,
-27, -99, -74,
-82, -87, 41,
-57, -40, 105,
-77, -89, -45,
-11, -125, -15,
39, -119, -13,
-82, -87, 41,
39, -119, -13,
28, -78, 95,
-82, -87, 41,
-24, -116, 43,
52, -115, 9,
-77, -89, -45,
-77, -89, -45,
-113, 35, -44,
-119, 28, 32,
-119, 28, 32,
-68, -60, 87,
-55, -24, 111,
-55, -24, 111,
52, -115, 9,
-24, -116, 43,
52, -115, 9,
-66, -89, -61,
26, -10, -123,
26, -10, -123,
-66, -89, -61,
-113, 35, -44,
-113, 35, -44,
-66, -89, -61,
-68, -60, 87,
-68, -60, 87,
-66, -89, -61,
52, -115, 9,
-27, -99, -74,
-78, -83, 55,
15, -124, 18,
15, -124, 18,
-78, -83, 55,
94, -73, 41,
94, -73, 41,
71, -101, 25,
103, -56, -48,
103, -56, -48,
46, -27, -115,
-27, -99, -74,
-99, 38, -69,
-54, -91, -69,
-78, -83, 55,
-78, -83, 55,
-54, -91, -69,
71, -101, 25,
71, -101, 25,
-54, -91, -69,
46, -27, -115,
46, -27, -115,
-54, -91, -69,
-99, 38, -69,
-76, -96, -30,
-63, -82, 72,
-27, -99, -74,
-27, -99, -74,
-63, -82, 72,
103, -56, -48,
103, -56, -48,
74, -102, -10,
65, -3, -108,
65, -3, -108,
-49, 24, -114,
-76, -96, -30,
-114, 31, 46,
-75, -84, -58,
-63, -82, 72,
-63, -82, 72,
-75, -84, -58,
74, -102, -10,
74, -102, -10,
-75, -84, -58,
-49, 24, -114,
-49, 24, -114,
-75, -84, -58,
-114, 31, 46,
-106, 62, -31,
-96, -55, 60,
-119, 28, 32,
-119, 28, 32,
52, -113, 24,
-77, -89, -45,
-77, -89, -45,
52, -113, 24,
-31, -107, -59,
-31, -107, -59,
-26, 14, -123,
-106, 62, -31,
-26, 14, -123,
-45, -90, -76,
-96, -55, 60,
-96, -55, 60,
-45, -90, -76,
52, -113, 24,
52, -113, 24,
-45, -90, -76,
106, -57, -37,
106, -57, -37,
-45, -90, -76,
-26, 14, -123,
-40, -105, -56,
50, -96, 65,
-76, -96, -30,
-76, -96, -30,
50, -96, 65,
65, -3, -108,
65, -3, -108,
-86, 27, -88,
-37, 54, -108,
-37, 54, -108,
-86, 27, -88,
-40, -105, -56,
-108, -32, 57,
-42, -119, 7,
50, -96, 65,
50, -96, 65,
-42, -119, 7,
85, -34, -87,
85, -34, -87,
-42, -119, 7,
-86, 27, -88,
-86, 27, -88,
-42, -119, 7,
-108, -32, 57,
-31, -107, -59,
-26, -71, 101,
-40, -105, -56,
-40, -105, -56,
4, 0, -126,
-37, 54, -108,
-37, 54, -108,
4, 0, -126,
-106, 62, -31,
-106, 62, -31,
-26, -71, 101,
-31, -107, -59,
-26, -71, 101,
-30, -123, -7,
80, -96, -19,
80, -96, -19,
-30, -123, -7,
4, 0, -126,
4, 0, -126,
-30, -123, -7,
-124, 25, 6,
-124, 25, 6,
-30, -123, -7,
-26, -71, 101,
44, 68, 96,
53, 66, 94,
-61, 83, 73,
125, 15, 15,
53, 66, 94,
44, 68, 96,
84, -82, 46,
-27, -99, -74,
15, -124, 18,
-57, -40, 105,
-24, -116, 43,
-77, -89, -45,
-57, -40, 105,
-3, -122, 33,
-24, -116, 43,
84, -82, 46,
15, -124, 18,
-3, -122, 33,
-57, -40, 105,
28, -78, 95,
-3, -122, 33,
125, 15, 15,
90, -79, 39,
122, -22, -25,
-94, 60, 58,
-56, -27, 110,
-61, 83, 73,
94, -73, 41,
103, -56, -48,
122, -22, -25,
-94, 60, 58,
-119, 28, 32,
-55, -24, 111,
-1, 47, 117,
-14, -18, 124,
55, 30, 109,
83, -52, 79,
52, 29, 112,
37, -32, 116,
31, 119, 29,
53, 66, 94,
69, 106, -7,
31, 119, 29,
69, 106, -7,
113, 53, -19,
31, 119, 29,
113, 53, -19,
82, 92, -27,
3, 125, 20,
53, 66, 94,
31, 119, 29,
31, 119, 29,
-27, 122, 17,
-62, 103, 40,
31, 119, 29,
-2, 116, -51,
-27, 122, 17,
44, 68, 96,
46, -50, 106,
35, -75, 95,
35, -75, 95,
-32, -37, 116,
-56, -27, 110,
-56, -27, 110,
-27, 61, 108,
-61, 83, 73,
-61, 83, 73,
72, 43, 94,
44, 68, 96,
90, -79, 39,
80, -63, 74,
35, -75, 95,
35, -75, 95,
17, -45, 117,
44, 68, 96,
44, 68, 96,
40, 49, 109,
125, 15, 15,
125, 15, 15,
114, 24, 48,
90, -79, 39,
114, 24, 48,
80, -63, 74,
90, -79, 39,
40, 49, 109,
114, 24, 48,
125, 15, 15,
17, -45, 117,
40, 49, 109,
44, 68, 96,
80, -63, 74,
17, -45, 117,
35, -75, 95,
-61, 83, 73,
-27, 61, 108,
72, 43, 94,
-56, -27, 110,
-32, -37, 116,
-27, 61, 108,
35, -75, 95,
46, -50, 106,
-32, -37, 116,
44, 68, 96,
72, 43, 94,
46, -50, 106,
125, 15, 15,
69, 106, -7,
53, 66, 94,
53, 66, 94,
3, 125, 20,
-61, 83, 73,
-106, 62, -31,
-124, 25, 6,
-26, -71, 101,
4, 0, -126,
-124, 25, 6,
-106, 62, -31,
-40, -105, -56,
80, -96, -19,
4, 0, -126,
-26, -71, 101,
80, -96, -19,
-40, -105, -56,
-86, 27, -88,
-108, -32, 57,
-40, -105, -56,
65, -3, -108,
85, -34, -87,
-86, 27, -88,
50, -96, 65,
85, -34, -87,
65, -3, -108,
-40, -105, -56,
-108, -32, 57,
50, -96, 65,
-31, -107, -59,
106, -57, -37,
-26, 14, -123,
52, -113, 24,
106, -57, -37,
-31, -107, -59,
-119, 28, 32,
-96, -55, 60,
52, -113, 24,
-106, 62, -31,
-26, 14, -123,
-96, -55, 60,
-49, 24, -114,
-114, 31, 46,
-76, -96, -30,
74, -102, -10,
-49, 24, -114,
65, -3, -108,
-63, -82, 72,
74, -102, -10,
103, -56, -48,
-76, -96, -30,
-114, 31, 46,
-63, -82, 72,
46, -27, -115,
-99, 38, -69,
-27, -99, -74,
71, -101, 25,
46, -27, -115,
103, -56, -48,
-78, -83, 55,
71, -101, 25,
94, -73, 41,
-27, -99, -74,
-99, 38, -69,
-78, -83, 55,
-55, -24, 111,
-68, -60, 87,
52, -115, 9,
-119, 28, 32,
-113, 35, -44,
-68, -60, 87,
-77, -89, -45,
26, -10, -123,
-113, 35, -44,
52, -115, 9,
26, -10, -123,
-77, -89, -45,
28, -78, 95,
-57, -40, 105,
-82, -87, 41,
-2, 116, -51,
82, 92, -27,
81, 15, -96,
-98, 78, -17,
-27, 122, 17,
-2, 116, -51,
-62, 103, 40,
-27, 122, 17,
-98, 78, -17,
-61, 83, 73,
3, 125, 20,
-62, 103, 40,
113, 53, -19,
69, 106, -7,
125, 15, 15,
81, 15, -96,
82, 92, -27,
113, 53, -19,
-27, 70, -101,
81, 15, -96,
65, -3, -108,
-106, 62, -31,
-98, 78, -17,
-27, 70, -101,
-119, 28, 32,
-94, 60, 58,
-98, 78, -17,
-5, -121, 36,
35, -75, 95,
-56, -27, 110,
90, -79, 39,
35, -75, 95,
-5, -121, 36,
81, 15, -96,
122, -22, -25,
103, -56, -48,
-10, -86, -92,
14, -104, -70,
-87, -81, -43,
14, -104, -70,
-11, -125, -15,
-87, -81, -43,
-10, -86, -92,
-87, -81, -43,
-58, -67, -90,
39, -119, -13,
14, -104, -70,
-10, -86, -92,
-58, -67, -90,
-87, -81, -43,
-82, -87, 41,
-111, 16, -59,
-114, 14, -53,
-58, -67, -90,
-48, 2, -117,
-3, 3, -126,
-114, 14, -53,
85, -27, -90,
-3, 3, -126,
-48, 2, -117,
-10, -86, -92,
85, -27, -90,
27, -44, -115,
-111, 16, -59,
-126, -6, 4,
-77, -89, -45,
-48, 2, -117,
-111, 16, -59,
-31, -107, -59,
-76, -96, -30,
27, -44, -115,
-48, 2, -117,
-27, -99, -74,
65, -80, -72,
27, -44, -115,
-5, -121, 36,
-3, -122, 33,
15, -124, 18,
-5, -121, 36,
-55, -24, 111,
-24, -116, 43,
28, -78, 95,
84, -82, 46,
-3, -122, 33,
17, -45, 117,
97, 12, 80,
40, 49, 109,
40, 49, 109,
37, -32, 116,
114, 24, 48,
114, 24, 48,
37, -32, 116,
80, -63, 74,
80, -63, 74,
97, 12, 80,
17, -45, 117,
72, 43, 94,
-1, 47, 117,
46, -50, 106,
46, -50, 106,
-1, 47, 117,
-32, -37, 116,
-32, -37, 116,
45, -36, 112,
-27, 61, 108,
-27, 61, 108,
45, -36, 112,
72, 43, 94,
45, -36, 112,
-14, -18, 124,
72, 43, 94,
-32, -37, 116,
55, 30, 109,
45, -36, 112,
-1, 47, 117,
55, 30, 109,
-32, -37, 116,
72, 43, 94,
-14, -18, 124,
-1, 47, 117,
80, -63, 74,
52, 29, 112,
97, 12, 80,
37, -32, 116,
52, 29, 112,
80, -63, 74,
40, 49, 109,
83, -52, 79,
37, -32, 116,
97, 12, 80,
83, -52, 79,
40, 49, 109,
83, -52, 79,
97, 12, 80,
52, 29, 112,
-14, -18, 124,
45, -36, 112,
55, 30, 109,
39, -119, -13,
84, -82, 46,
28, -78, 95,
58, -35, 106,
-14, 64, 108,
-58, -35, 106,
94, 9, -84,
-94, 9, -84,
85, 43, -82,
14, 64, 108,
9, 122, 30,
-14, 64, 108,
-14, 64, 108,
-31, 120, -23,
-47, 103, -55,
-47, 103, -55,
31, 120, -23,
48, 103, -55,
48, 103, -55,
31, 120, -23,
14, 64, 108,
83, -12, 95,
94, 9, -84,
85, 43, -82,
-83, -12, 95,
83, -78, 55,
83, -12, 95,
-85, 43, -82,
-94, 9, -84,
-83, -12, 95,
-65, 27, -105,
-47, 103, -55,
65, 27, -105,
-94, 9, -84,
-83, -78, 55,
-83, -12, 95,
-83, -12, 95,
-83, -78, 55,
83, -78, 55,
83, -12, 95,
83, -78, 55,
94, 9, -84,
31, 120, -23,
-9, 122, 30,
14, 64, 108,
-47, 103, -55,
-31, 120, -23,
31, 120, -23,
-14, 64, 108,
9, 122, 30,
-31, 120, -23,
14, 64, 108,
-9, 122, 30,
9, 122, 30,
-94, 9, -84,
-85, 43, -82,
85, 43, -82,
9, 122, 30,
-10, -86, -92,
-58, -67, -90,
-9, 122, 30,
85, -27, -90,
-10, -86, -92,
31, 120, -23,
-3, 3, -126,
85, -27, -90,
-31, 120, -23,
-114, 14, -53,
-3, 3, -126,
9, 122, 30,
-58, -67, -90,
-114, 14, -53,
31, 120, -23,
-31, 120, -23,
-3, 3, -126,
-31, 120, -23,
9, 122, 30,
-114, 14, -53,
58, -35, 106,
85, 43, -82,
65, 27, -105,
-58, -35, 106,
83, -12, 95,
58, -35, 106,
65, 27, -105,
-85, 43, -82,
-65, 27, -105,
-65, 27, -105,
-85, 43, -82,
-58, -35, 106,
-99, -37, 69,
93, -51, 69,
-50, 58, 100,
42, -54, -106,
-99, 20, -76,
91, 2, -88,
42, -112, 40,
42, -54, -106,
93, -51, 69,
-99, 20, -76,
-50, 58, 100,
-68, 106, -15,
-99, 20, -76,
-99, -37, 69,
-50, 58, 100,
42, -54, -106,
91, 2, -88,
93, -51, 69,
-99, 20, -76,
-68, 106, -15,
91, 2, -88,
-99, -37, 69,
42, -112, 40,
93, -51, 69,
-50, 58, 100,
-58, -35, 106,
-14, 64, 108,
93, -51, 69,
-65, 27, -105,
-58, -35, 106,
91, 2, -88,
-68, 106, -15,
-65, 27, -105,
-68, 106, -15,
-14, 64, 108,
-47, 103, -55,
50, 58, 100,
-93, -51, 69,
99, -37, 69,
-91, 2, -88,
99, 20, -76,
-42, -54, -106,
-93, -51, 69,
-42, -54, -106,
-42, -112, 40,
67, 106, -15,
50, 58, 100,
99, 20, -76,
50, 58, 100,
99, -37, 69,
99, 20, -76,
-93, -51, 69,
-91, 2, -88,
-42, -54, -106,
-91, 2, -88,
67, 106, -15,
99, 20, -76,
-93, -51, 69,
-42, -112, 40,
99, -37, 69,
50, 58, 100,
48, 103, -55,
14, 64, 108,
67, 106, -15,
65, 27, -105,
48, 103, -55,
-91, 2, -88,
-93, -51, 69,
65, 27, -105,
-93, -51, 69,
50, 58, 100,
58, -35, 106,
67, 106, -15,
48, 103, -55,
50, 58, 100,
-14, 64, 108,
-68, 106, -15,
-50, 58, 100,
119, -43, 0,
-56, -102, 49,
118, 16, 44,
97, -3, -81,
59, -29, -108,
-97, -4, -80,
-97, -4, -80,
118, 16, 44,
97, -3, -81,
-97, -4, -80,
119, -43, 0,
118, 16, 44,
-59, -29, -108,
-56, -102, 49,
-94, 9, -84,
-56, -102, 49,
83, -78, 55,
-83, -78, 55,
49, -108, 43,
94, 9, -84,
83, -78, 55,
59, -29, -108,
-94, 9, -84,
94, 9, -84,
-78, -17, 98,
72, -21, 101,
-90, 79, 39,
73, -100, -26,
-90, -17, -87,
91, -8, -87,
72, -21, 101,
73, -100, -26,
84, 90, 28,
-78, -95, -28,
-90, 79, 39,
-90, -17, -87,
-78, -95, -28,
-78, -17, 98,
-90, 79, 39,
73, -100, -26,
91, -8, -87,
84, 90, 28,
73, -100, -26,
-78, -95, -28,
-90, -17, -87,
72, -21, 101,
84, 90, 28,
-90, 79, 39,
-90, 79, 39,
84, 90, 28,
-56, -102, 49,
84, 90, 28,
91, -8, -87,
118, 16, 44,
91, -8, -87,
-59, -29, -108,
97, -3, -81,
-90, -17, -87,
-56, -102, 49,
-59, -29, -108,
87, 82, 40,
-73, -19, 101,
78, -17, 98,
-90, -9, -88,
90, -17, -87,
-73, -100, -26,
-72, 104, -2,
-73, -100, -26,
-73, -19, 101,
90, -17, -87,
87, 82, 40,
78, -95, -28,
87, 82, 40,
78, -17, 98,
78, -95, -28,
-72, 104, -2,
-90, -9, -88,
-73, -100, -26,
90, -17, -87,
78, -95, -28,
-73, -100, -26,
87, 82, 40,
-72, 104, -2,
-73, -19, 101,
87, 82, 40,
90, -17, -87,
49, -108, 43,
-90, -9, -88,
-97, -4, -80,
59, -29, -108,
-90, -9, -88,
119, -43, 0,
-97, -4, -80,
-72, 104, -2,
49, -108, 43,
119, -43, 0,
-42, -54, -106,
37, -95, -74,
-42, -112, 40,
-42, -112, 40,
93, -85, 5,
99, -37, 69,
99, -37, 69,
93, -85, 5,
99, 20, -76,
99, 20, -76,
93, -58, -62,
-42, -54, -106,
42, -112, 40,
-37, -120, -11,
42, -54, -106,
42, -54, -106,
-93, -58, -62,
-99, 20, -76,
-99, 20, -76,
-93, -58, -62,
-99, -37, 69,
-99, -37, 69,
-93, -85, 5,
42, -112, 40,
-74, -88, 52,
80, 21, 95,
37, -120, -11,
80, 21, 95,
93, -58, -62,
93, -85, 5,
80, 81, -54,
37, -95, -74,
93, -58, -62,
-74, -27, -98,
-74, -88, 52,
37, -95, -74,
-80, 21, 95,
-37, -120, -11,
-93, -85, 5,
74, -27, -98,
-93, -58, -62,
-37, -95, -74,
-80, 81, -54,
-80, 21, 95,
-93, -58, -62,
-37, -95, -74,
-37, -120, -11,
74, -27, -98,
-99, -25, 74,
71, -74, 74,
-57, 18, 111,
33, -46, -113,
-92, 38, -77,
81, 2, -97,
31, -116, 38,
33, -46, -113,
71, -74, 74,
-92, 38, -77,
-57, 18, 111,
-52, 100, -57,
-92, 38, -77,
-99, -25, 74,
-57, 18, 111,
33, -46, -113,
81, 2, -97,
71, -74, 74,
-92, 38, -77,
-52, 100, -57,
81, 2, -97,
-99, -25, 74,
31, -116, 38,
71, -74, 74,
33, -46, -113,
-72, -99, -32,
-92, 38, -77,
-92, 38, -77,
-72, -99, -32,
-99, -25, 74,
-99, -25, 74,
-72, -99, -32,
31, -116, 38,
31, -116, 38,
-72, -99, -32,
33, -46, -113,
81, 2, -97,
-80, 81, -54,
74, -27, -98,
-52, 100, -57,
-57, 18, 111,
-80, 81, -54,
-57, 18, 111,
71, -74, 74,
-80, 21, 95,
71, -74, 74,
81, 2, -97,
74, -88, 52,
73, -100, -26,
-25, -116, 42,
-78, -95, -28,
-78, -95, -28,
-25, -116, 42,
-78, -17, 98,
-78, -17, 98,
-33, -87, 85,
72, -21, 101,
72, -21, 101,
35, -84, 87,
73, -100, -26,
-73, -19, 101,
-35, -84, 87,
78, -17, 98,
78, -17, 98,
25, -116, 42,
78, -95, -28,
78, -95, -28,
25, -116, 42,
-73, -100, -26,
-73, -100, -26,
-35, -84, 87,
-73, -19, 101,
89, 47, 76,
82, 37, 89,
-89, 47, 76,
-89, -47, -76,
-88, -69, -58,
89, -47, -76,
-84, 40, 85,
-88, -69, -58,
-89, 47, 76,
85, -74, -57,
82, 37, 89,
89, -47, -76,
89, 47, 76,
49, 116, 5,
89, -47, -76,
89, -47, -76,
73, -8, -103,
-89, -47, -76,
-89, -47, -76,
-97, 81, 4,
-89, 47, 76,
-89, 47, 76,
-97, 81, 4,
89, 47, 76,
-97, 81, 4,
49, 116, 5,
89, 47, 76,
-89, -47, -76,
-89, -28, -85,
-97, 81, 4,
73, -8, -103,
-89, -28, -85,
-89, -47, -76,
49, 116, 5,
73, -8, -103,
89, -47, -76,
82, 37, 89,
89, 47, 76,
89, -47, -76,
-88, -69, -58,
-89, -47, -76,
-89, 47, 76,
-88, -69, -58,
85, -74, -57,
89, -47, -76,
82, 37, 89,
-84, 40, 85,
-89, 47, 76,
-88, -69, -58,
-35, -84, 87,
-26, -117, 39,
-84, 40, 85,
82, 37, 89,
-35, -84, 87,
82, 37, 89,
85, -74, -57,
33, -87, 85,
85, -74, -57,
-26, -117, 39,
25, -116, 42,
89, 47, 76,
-82, 37, 89,
-89, 47, 76,
-89, -47, -76,
88, -69, -58,
89, -47, -76,
89, 47, 76,
88, -69, -58,
84, 40, 85,
-89, -47, -76,
-82, 37, 89,
-85, -74, -57,
-89, -47, -76,
-49, 116, 5,
-89, 47, 76,
89, -47, -76,
-73, -8, -103,
-89, -47, -76,
89, 47, 76,
97, 81, 4,
89, -47, -76,
-89, 47, 76,
97, 81, 4,
89, 47, 76,
-89, 47, 76,
-49, 116, 5,
97, 81, 4,
97, 81, 4,
89, -28, -85,
89, -47, -76,
89, -47, -76,
89, -28, -85,
-73, -8, -103,
-89, -47, -76,
-73, -8, -103,
-49, 116, 5,
-89, -47, -76,
-89, 47, 76,
-82, 37, 89,
89, 47, 76,
89, -47, -76,
88, -69, -58,
-89, -47, -76,
-85, -74, -57,
88, -69, -58,
89, 47, 76,
84, 40, 85,
-82, 37, 89,
-82, 37, 89,
35, -84, 87,
-33, -87, 85,
84, 40, 85,
88, -69, -58,
35, -84, 87,
88, -69, -58,
-85, -74, -57,
26, -117, 39,
-85, -74, -57,
-33, -87, 85,
-25, -116, 42,
86, -90, -20,
-53, -107, -39,
88, -23, -87,
-64, 106, -25,
95, 76, -34,
-91, 56, -67,
99, -57, 53,
77, -29, 96,
-93, -84, 15,
77, -29, 96,
95, 76, -34,
61, 110, -5,
-93, -84, 15,
-101, -38, 66,
-91, 56, -67,
61, 110, -5,
-18, 46, 116,
77, -29, 96,
77, -29, 96,
-18, 46, 116,
-101, -38, 66,
-101, -38, 66,
-18, 46, 116,
-64, 106, -25,
-64, 106, -25,
-18, 46, 116,
61, 110, -5,
99, -57, 53,
86, -90, -20,
95, 76, -34,
-93, -84, 15,
-53, -107, -39,
99, -57, 53,
-91, 56, -67,
-56, -32, -108,
-93, -84, 15,
-56, -32, -108,
-53, -107, -39,
-93, -84, 15,
-53, -107, -39,
86, -90, -20,
99, -57, 53,
86, -90, -20,
88, -23, -87,
95, 76, -34,
-101, -38, 66,
-64, 106, -25,
-91, 56, -67,
77, -29, 96,
99, -57, 53,
95, 76, -34,
77, -29, 96,
-101, -38, 66,
-93, -84, 15,
-64, 106, -25,
61, 110, -5,
95, 76, -34,
-53, -107, -39,
-56, -32, -108,
88, -23, -87,
95, 76, -34,
88, -23, -87,
97, 81, 4,
88, -23, -87,
-56, -32, -108,
89, -28, -85,
-56, -32, -108,
-91, 56, -67,
-73, -8, -103,
-91, 56, -67,
95, 76, -34,
-49, 116, 5,
-88, -23, -87,
53, -107, -39,
-86, -90, -20,
91, 56, -67,
-95, 76, -34,
64, 106, -25,
93, -84, 15,
-77, -29, 96,
-99, -57, 53,
-61, 110, -5,
-95, 76, -34,
-77, -29, 96,
91, 56, -67,
101, -38, 66,
93, -84, 15,
-77, -29, 96,
18, 46, 116,
-61, 110, -5,
101, -38, 66,
18, 46, 116,
-77, -29, 96,
64, 106, -25,
18, 46, 116,
101, -38, 66,
-61, 110, -5,
18, 46, 116,
64, 106, -25,
-95, 76, -34,
-86, -90, -20,
-99, -57, 53,
-99, -57, 53,
53, -107, -39,
93, -84, 15,
93, -84, 15,
56, -32, -108,
91, 56, -67,
93, -84, 15,
53, -107, -39,
56, -32, -108,
-99, -57, 53,
-86, -90, -20,
53, -107, -39,
-95, 76, -34,
-88, -23, -87,
-86, -90, -20,
91, 56, -67,
64, 106, -25,
101, -38, 66,
-95, 76, -34,
-99, -57, 53,
-77, -29, 96,
93, -84, 15,
101, -38, 66,
-77, -29, 96,
-95, 76, -34,
-61, 110, -5,
64, 106, -25,
-88, -23, -87,
56, -32, -108,
53, -107, -39,
-95, 76, -34,
49, 116, 5,
-97, 81, 4,
91, 56, -67,
73, -8, -103,
49, 116, 5,
56, -32, -108,
-89, -28, -85,
73, -8, -103,
-88, -23, -87,
-97, 81, 4,
-89, -28, -85,
59, -29, -108,
90, -17, -87,
-90, -9, -88,
91, -8, -87,
-90, -17, -87,
-59, -29, -108,
80, 81, -54,
-81, 2, -97,
-74, -27, -98,
-74, -27, -98,
-71, -74, 74,
-74, -88, 52,
80, 21, 95,
52, 100, -57,
80, 81, -54,
57, 18, 111,
-71, -74, 74,
99, -25, 74,
-81, 2, -97,
92, 38, -77,
-33, -46, -113,
-71, -74, 74,
-33, -46, -113,
-31, -116, 38,
52, 100, -57,
57, 18, 111,
92, 38, -77,
57, 18, 111,
99, -25, 74,
92, 38, -77,
-71, -74, 74,
-81, 2, -97,
-33, -46, -113,
-81, 2, -97,
52, 100, -57,
92, 38, -77,
-71, -74, 74,
-31, -116, 38,
99, -25, 74,
92, 38, -77,
72, -99, -32,
-33, -46, -113,
99, -25, 74,
72, -99, -32,
92, 38, -77,
-31, -116, 38,
72, -99, -32,
99, -25, 74,
-33, -46, -113,
72, -99, -32,
-31, -116, 38,
-74, -88, 52,
-71, -74, 74,
80, 21, 95,
-71, -74, 74,
57, 18, 111,
80, 21, 95,
80, 21, 95,
57, 18, 111,
52, 100, -57,
-74, -27, -98,
-81, 2, -97,
-71, -74, 74,
80, 81, -54,
52, 100, -57,
-81, 2, -97,
-88, -23, -87,
-95, 76, -34,
-97, 81, 4,
56, -32, -108,
-88, -23, -87,
-89, -28, -85,
91, 56, -67,
56, -32, -108,
73, -8, -103,
-95, 76, -34,
91, 56, -67,
49, 116, 5,
95, 76, -34,
97, 81, 4,
-49, 116, 5,
-91, 56, -67,
-49, 116, 5,
-73, -8, -103,
-56, -32, -108,
-73, -8, -103,
89, -28, -85,
88, -23, -87,
89, -28, -85,
97, 81, 4,
-85, -74, -57,
-82, 37, 89,
-33, -87, 85,
-85, -74, -57,
-25, -116, 42,
26, -117, 39,
88, -69, -58,
26, -117, 39,
35, -84, 87,
-82, 37, 89,
84, 40, 85,
35, -84, 87,
85, -74, -57,
-88, -69, -58,
-26, -117, 39,
85, -74, -57,
25, -116, 42,
33, -87, 85,
82, 37, 89,
33, -87, 85,
-35, -84, 87,
-88, -69, -58,
-84, 40, 85,
-35, -84, 87,
-73, -100, -26,
-26, -117, 39,
-35, -84, 87,
25, -116, 42,
-26, -117, 39,
-73, -100, -26,
78, -17, 98,
33, -87, 85,
25, -116, 42,
-35, -84, 87,
33, -87, 85,
78, -17, 98,
35, -84, 87,
26, -117, 39,
73, -100, -26,
-33, -87, 85,
35, -84, 87,
72, -21, 101,
-25, -116, 42,
-33, -87, 85,
-78, -17, 98,
73, -100, -26,
26, -117, 39,
-25, -116, 42,
81, 2, -97,
74, -27, -98,
74, -88, 52,
71, -74, 74,
74, -88, 52,
-80, 21, 95,
-57, 18, 111,
-80, 21, 95,
-80, 81, -54,
81, 2, -97,
-52, 100, -57,
-80, 81, -54,
-37, -120, -11,
74, -88, 52,
74, -27, -98,
-80, 21, 95,
-93, -85, 5,
-93, -58, -62,
74, -27, -98,
-80, 81, -54,
-93, -58, -62,
-80, 21, 95,
74, -88, 52,
-37, -120, -11,
-74, -88, 52,
37, -120, -11,
37, -95, -74,
80, 81, -54,
-74, -27, -98,
37, -95, -74,
80, 21, 95,
80, 81, -54,
93, -58, -62,
80, 21, 95,
93, -85, 5,
37, -120, -11,
-93, -85, 5,
-37, -120, -11,
42, -112, 40,
-93, -58, -62,
-93, -85, 5,
-99, -37, 69,
42, -54, -106,
-37, -95, -74,
-93, -58, -62,
-37, -120, -11,
-37, -95, -74,
42, -54, -106,
93, -58, -62,
37, -95, -74,
-42, -54, -106,
93, -85, 5,
93, -58, -62,
99, 20, -76,
-42, -112, 40,
37, -120, -11,
93, -85, 5,
37, -95, -74,
37, -120, -11,
-42, -112, 40,
-72, 104, -2,
87, 82, 40,
49, -108, 43,
-90, -9, -88,
-72, 104, -2,
119, -43, 0,
90, -17, -87,
59, -29, -108,
49, -108, 43,
-90, -17, -87,
-90, 79, 39,
-56, -102, 49,
91, -8, -87,
97, -3, -81,
118, 16, 44,
84, 90, 28,
118, 16, 44,
-56, -102, 49,
59, -29, -108,
-59, -29, -108,
-94, 9, -84,
49, -108, 43,
59, -29, -108,
94, 9, -84,
-56, -102, 49,
49, -108, 43,
83, -78, 55,
-56, -102, 49,
-83, -78, 55,
-94, 9, -84,
97, -3, -81,
-59, -29, -108,
59, -29, -108,
119, -43, 0,
49, -108, 43,
-56, -102, 49,
50, 58, 100,
14, 64, 108,
58, -35, 106,
-93, -51, 69,
58, -35, 106,
65, 27, -105,
67, 106, -15,
-91, 2, -88,
65, 27, -105,
-68, 106, -15,
-47, 103, -55,
-65, 27, -105,
93, -51, 69,
91, 2, -88,
-65, 27, -105,
-50, 58, 100,
93, -51, 69,
-58, -35, 106,
-85, 43, -82,
-83, -12, 95,
-58, -35, 106,
65, 27, -105,
85, 43, -82,
-85, 43, -82,
-58, -35, 106,
-83, -12, 95,
83, -12, 95,
58, -35, 106,
83, -12, 95,
85, 43, -82,
-9, 122, 30,
31, 120, -23,
85, -27, -90,
9, 122, 30,
-9, 122, 30,
-10, -86, -92,
-47, 103, -55,
48, 103, -55,
65, 27, -105,
58, -35, 106,
14, 64, 108,
-14, 64, 108,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:23 */
static s8 vtxnvgrp_frake_select_23[]={
-20, -113, 54,
1, -118, 45,
0, -117, 48,
0, -117, 48,
21, -121, 30,
96, -63, 52,
-19, -107, -65,
34, -54, -109,
-70, -103, -23,
-70, -103, -23,
-43, -11, -118,
-32, -113, -47,
-32, -113, -47,
-43, -11, -118,
-23, -114, -49,
-23, -114, -49,
-108, 3, -65,
-70, -98, -39,
-70, -98, -39,
-126, -14, 0,
-79, -87, 46,
-19, -107, -65,
86, -73, 57,
46, -118, 0,
72, -83, -61,
-1, -98, -80,
34, -54, -109,
34, -54, -109,
87, -35, -84,
-43, -11, -118,
-43, -11, -118,
-112, 3, -57,
-108, 3, -65,
-108, 3, -65,
-57, -81, -79,
-126, -14, 0,
-126, -14, 0,
-57, -81, -79,
-79, -87, 46,
-79, -87, 46,
-85, -85, -38,
-8, -126, -7,
-8, -126, -7,
20, -109, -60,
46, -118, 0,
46, -118, 0,
-1, -98, -80,
72, -83, -61,
23, 123, 18,
-68, 102, 27,
-3, 126, 8,
69, -10, -105,
84, 10, -94,
107, -55, -38,
124, -18, -18,
92, -70, 51,
96, -63, 52,
96, -63, 52,
92, -70, 51,
0, -117, 48,
0, -117, 48,
-59, -19, 110,
-58, -16, 111,
-58, -16, 111,
-59, -19, 110,
-100, 61, 48,
-122, 25, 24,
-101, 70, -29,
-107, 53, -41,
-107, 53, -41,
-26, 58, -109,
-35, 41, -114,
-35, 41, -114,
-26, 58, -109,
69, -10, -105,
84, 10, -94,
111, 57, -19,
124, -18, -18,
124, -18, -18,
111, 57, -19,
123, 23, 19,
-68, 87, 62,
-68, 102, 27,
-100, 61, 48,
-100, 61, 48,
-68, 102, 27,
-101, 70, -29,
-101, 70, -29,
-6, 110, -62,
-26, 58, -109,
-26, 58, -109,
-6, 110, -62,
84, 10, -94,
78, 94, -33,
-6, 110, -62,
23, 123, 18,
46, -118, 0,
72, -83, -61,
-19, -107, -65,
-79, -87, 46,
-59, -33, 107,
-70, -98, -39,
-8, -126, -7,
46, -118, 0,
-79, -87, 46,
46, -118, 0,
28, -67, 103,
-79, -87, 46,
-20, -113, 54,
57, -110, 22,
-70, -98, -39,
-70, -98, -39,
-113, 24, -51,
-122, 25, 24,
-122, 25, 24,
-69, -55, 90,
-58, -16, 111,
-58, -16, 111,
57, -110, 22,
-20, -113, 54,
57, -110, 22,
-59, -98, -54,
31, -21, -121,
31, -21, -121,
-59, -98, -54,
-113, 24, -51,
-113, 24, -51,
-59, -98, -54,
-69, -55, 90,
-69, -55, 90,
-59, -98, -54,
57, -110, 22,
-19, -107, -65,
-76, -81, 60,
21, -121, 30,
21, -121, 30,
-76, -81, 60,
96, -63, 52,
96, -63, 52,
75, -94, 37,
107, -55, -38,
107, -55, -38,
52, -36, -109,
-19, -107, -65,
-97, 26, -76,
-47, -100, -61,
-76, -81, 60,
-76, -81, 60,
-47, -100, -61,
75, -94, 37,
75, -94, 37,
-47, -100, -61,
52, -36, -109,
52, -36, -109,
-47, -100, -61,
-97, 26, -76,
-70, -103, -23,
-62, -78, 77,
-19, -107, -65,
-19, -107, -65,
-62, -78, 77,
107, -55, -38,
107, -55, -38,
80, -98, 2,
69, -10, -105,
69, -10, -105,
-45, 10, -117,
-70, -103, -23,
-117, 29, 38,
-68, -93, -52,
-62, -78, 77,
-62, -78, 77,
-68, -93, -52,
80, -98, 2,
80, -98, 2,
-68, -93, -52,
-45, 10, -117,
-45, 10, -117,
-68, -93, -52,
-117, 29, 38,
-107, 53, -41,
-96, -54, 62,
-122, 25, 24,
-122, 25, 24,
56, -107, 37,
-70, -98, -39,
-70, -98, -39,
56, -107, 37,
-23, -114, -49,
-23, -114, -49,
-21, 0, -125,
-107, 53, -41,
-21, 0, -125,
-37, -100, -68,
-96, -54, 62,
-96, -54, 62,
-37, -100, -68,
56, -107, 37,
56, -107, 37,
-37, -100, -68,
110, -55, -27,
110, -55, -27,
-37, -100, -68,
-21, 0, -125,
-32, -113, -47,
52, -86, 76,
-70, -103, -23,
-70, -103, -23,
52, -86, 76,
69, -10, -105,
69, -10, -105,
-83, 14, -94,
-35, 41, -114,
-35, 41, -114,
-83, 14, -94,
-32, -113, -47,
-108, -32, 56,
-36, -120, 18,
52, -86, 76,
52, -86, 76,
-36, -120, 18,
90, -38, -80,
90, -38, -80,
-36, -120, 18,
-83, 14, -94,
-83, 14, -94,
-36, -120, 18,
-108, -32, 56,
-23, -114, -49,
-27, -62, 106,
-32, -113, -47,
-32, -113, -47,
9, -13, -125,
-35, 41, -114,
-35, 41, -114,
9, -13, -125,
-107, 53, -41,
-107, 53, -41,
-27, -62, 106,
-23, -114, -49,
-27, -62, 106,
-23, -124, 3,
85, -93, -6,
85, -93, -6,
-23, -124, 3,
9, -13, -125,
9, -13, -125,
-23, -124, 3,
-125, 18, 0,
-125, 18, 0,
-23, -124, 3,
-27, -62, 106,
36, 80, 91,
45, 77, 89,
-68, 87, 62,
123, 23, 19,
45, 77, 89,
36, 80, 91,
86, -73, 57,
-19, -107, -65,
21, -121, 30,
-59, -33, 107,
-20, -113, 54,
-70, -98, -39,
-59, -33, 107,
1, -118, 45,
-20, -113, 54,
86, -73, 57,
21, -121, 30,
1, -118, 45,
-59, -33, 107,
28, -67, 103,
1, -118, 45,
123, 23, 19,
92, -70, 51,
124, -18, -18,
-100, 61, 48,
-59, -19, 110,
-68, 87, 62,
96, -63, 52,
107, -55, -38,
124, -18, -18,
-100, 61, 48,
-122, 25, 24,
-58, -16, 111,
-9, 58, 112,
-18, -6, 125,
49, 44, 108,
82, -39, 87,
45, 42, 110,
34, -18, 120,
23, 123, 18,
45, 77, 89,
64, 108, -15,
23, 123, 18,
64, 108, -15,
111, 57, -19,
23, 123, 18,
111, 57, -19,
78, 94, -33,
-3, 126, 8,
45, 77, 89,
23, 123, 18,
23, 123, 18,
-34, 122, 3,
-68, 102, 27,
23, 123, 18,
-6, 110, -62,
-34, 122, 3,
36, 80, 91,
44, -37, 112,
35, -63, 104,
35, -63, 104,
-35, -27, 118,
-59, -19, 110,
-59, -19, 110,
-34, 69, 100,
-68, 87, 62,
-68, 87, 62,
66, 56, 92,
36, 80, 91,
92, -70, 51,
80, -51, 83,
35, -63, 104,
35, -63, 104,
14, -32, 121,
36, 80, 91,
36, 80, 91,
33, 61, 105,
123, 23, 19,
123, 23, 19,
111, 35, 50,
92, -70, 51,
111, 35, 50,
80, -51, 83,
92, -70, 51,
33, 61, 105,
111, 35, 50,
123, 23, 19,
14, -32, 121,
33, 61, 105,
36, 80, 91,
80, -51, 83,
14, -32, 121,
35, -63, 104,
-68, 87, 62,
-34, 69, 100,
66, 56, 92,
-59, -19, 110,
-35, -27, 118,
-34, 69, 100,
35, -63, 104,
44, -37, 112,
-35, -27, 118,
36, 80, 91,
66, 56, 92,
44, -37, 112,
123, 23, 19,
64, 108, -15,
45, 77, 89,
45, 77, 89,
-3, 126, 8,
-68, 87, 62,
-107, 53, -41,
-125, 18, 0,
-27, -62, 106,
9, -13, -125,
-125, 18, 0,
-107, 53, -41,
-32, -113, -47,
85, -93, -6,
9, -13, -125,
-27, -62, 106,
85, -93, -6,
-32, -113, -47,
-83, 14, -94,
-108, -32, 56,
-32, -113, -47,
69, -10, -105,
90, -38, -80,
-83, 14, -94,
52, -86, 76,
90, -38, -80,
69, -10, -105,
-32, -113, -47,
-108, -32, 56,
52, -86, 76,
-23, -114, -49,
110, -55, -27,
-21, 0, -125,
56, -107, 37,
110, -55, -27,
-23, -114, -49,
-122, 25, 24,
-96, -54, 62,
56, -107, 37,
-107, 53, -41,
-21, 0, -125,
-96, -54, 62,
-45, 10, -117,
-117, 29, 38,
-70, -103, -23,
80, -98, 2,
-45, 10, -117,
69, -10, -105,
-62, -78, 77,
80, -98, 2,
107, -55, -38,
-70, -103, -23,
-117, 29, 38,
-62, -78, 77,
52, -36, -109,
-97, 26, -76,
-19, -107, -65,
75, -94, 37,
52, -36, -109,
107, -55, -38,
-76, -81, 60,
75, -94, 37,
96, -63, 52,
-19, -107, -65,
-97, 26, -76,
-76, -81, 60,
-58, -16, 111,
-69, -55, 90,
57, -110, 22,
-122, 25, 24,
-113, 24, -51,
-69, -55, 90,
-70, -98, -39,
31, -21, -121,
-113, 24, -51,
57, -110, 22,
31, -21, -121,
-70, -98, -39,
28, -67, 103,
-59, -33, 107,
-79, -87, 46,
-6, 110, -62,
78, 94, -33,
84, 10, -94,
-101, 70, -29,
-34, 122, 3,
-6, 110, -62,
-68, 102, 27,
-34, 122, 3,
-101, 70, -29,
-68, 87, 62,
-3, 126, 8,
-68, 102, 27,
111, 57, -19,
64, 108, -15,
123, 23, 19,
84, 10, -94,
78, 94, -33,
111, 57, -19,
-26, 58, -109,
84, 10, -94,
69, -10, -105,
-107, 53, -41,
-101, 70, -29,
-26, 58, -109,
-122, 25, 24,
-100, 61, 48,
-101, 70, -29,
0, -117, 48,
35, -63, 104,
-59, -19, 110,
92, -70, 51,
35, -63, 104,
0, -117, 48,
84, 10, -94,
124, -18, -18,
107, -55, -38,
-1, -98, -80,
20, -109, -60,
-85, -85, -38,
20, -109, -60,
-8, -126, -7,
-85, -85, -38,
-1, -98, -80,
-85, -85, -38,
-57, -81, -79,
46, -118, 0,
20, -109, -60,
-1, -98, -80,
-57, -81, -79,
-85, -85, -38,
-79, -87, 46,
-108, 3, -65,
-112, 3, -57,
-57, -81, -79,
-43, -11, -118,
-3, -10, -126,
-112, 3, -57,
87, -35, -84,
-3, -10, -126,
-43, -11, -118,
-1, -98, -80,
87, -35, -84,
34, -54, -109,
-108, 3, -65,
-126, -14, 0,
-70, -98, -39,
-43, -11, -118,
-108, 3, -65,
-23, -114, -49,
-70, -103, -23,
34, -54, -109,
-43, -11, -118,
-19, -107, -65,
72, -83, -61,
34, -54, -109,
0, -117, 48,
1, -118, 45,
21, -121, 30,
0, -117, 48,
-58, -16, 111,
-20, -113, 54,
28, -67, 103,
86, -73, 57,
1, -118, 45,
14, -32, 121,
92, 25, 82,
33, 61, 105,
33, 61, 105,
34, -18, 120,
111, 35, 50,
111, 35, 50,
34, -18, 120,
80, -51, 83,
80, -51, 83,
92, 25, 82,
14, -32, 121,
66, 56, 92,
-9, 58, 112,
44, -37, 112,
44, -37, 112,
-9, 58, 112,
-35, -27, 118,
-35, -27, 118,
42, -22, 117,
-34, 69, 100,
-34, 69, 100,
42, -22, 117,
66, 56, 92,
42, -22, 117,
-18, -6, 125,
66, 56, 92,
-35, -27, 118,
49, 44, 108,
42, -22, 117,
-9, 58, 112,
49, 44, 108,
-35, -27, 118,
66, 56, 92,
-18, -6, 125,
-9, 58, 112,
80, -51, 83,
45, 42, 110,
92, 25, 82,
34, -18, 120,
45, 42, 110,
80, -51, 83,
33, 61, 105,
82, -39, 87,
34, -18, 120,
92, 25, 82,
82, -39, 87,
33, 61, 105,
82, -39, 87,
92, 25, 82,
45, 42, 110,
-18, -6, 125,
42, -22, 117,
49, 44, 108,
46, -118, 0,
86, -73, 57,
28, -67, 103,
58, -30, 108,
-14, 70, 104,
-58, -30, 108,
94, 4, -84,
-94, 4, -84,
85, 39, -85,
14, 70, 104,
-2, 123, 28,
-14, 70, 104,
-14, 70, 104,
-32, 118, -31,
-47, 100, -60,
-47, 100, -60,
32, 118, -31,
47, 100, -60,
47, 100, -60,
32, 118, -31,
14, 70, 104,
83, -8, 95,
94, 4, -84,
85, 39, -85,
-83, -8, 95,
83, -75, 59,
83, -8, 95,
-85, 39, -85,
-94, 4, -84,
-83, -8, 95,
-65, 22, -106,
-47, 100, -60,
65, 22, -106,
-94, 4, -84,
-83, -75, 59,
-83, -8, 95,
-83, -8, 95,
-83, -75, 59,
83, -75, 59,
83, -8, 95,
83, -75, 59,
94, 4, -84,
32, 118, -31,
2, 123, 28,
14, 70, 104,
-47, 100, -60,
-32, 118, -31,
32, 118, -31,
-14, 70, 104,
-2, 123, 28,
-32, 118, -31,
14, 70, 104,
2, 123, 28,
-2, 123, 28,
-94, 4, -84,
-85, 39, -85,
85, 39, -85,
-2, 123, 28,
-1, -98, -80,
-57, -81, -79,
2, 123, 28,
87, -35, -84,
-1, -98, -80,
32, 118, -31,
-3, -10, -126,
87, -35, -84,
-32, 118, -31,
-112, 3, -57,
-3, -10, -126,
-2, 123, 28,
-57, -81, -79,
-112, 3, -57,
32, 118, -31,
-32, 118, -31,
-3, -10, -126,
-32, 118, -31,
-2, 123, 28,
-112, 3, -57,
58, -30, 108,
85, 39, -85,
65, 22, -106,
-58, -30, 108,
83, -8, 95,
58, -30, 108,
65, 22, -106,
-85, 39, -85,
-65, 22, -106,
-65, 22, -106,
-85, 39, -85,
-58, -30, 108,
-99, -34, 71,
93, -47, 71,
-50, 63, 97,
42, -59, -103,
-99, 16, -77,
91, -1, -88,
42, -110, 45,
42, -59, -103,
93, -47, 71,
-99, 16, -77,
-50, 63, 97,
-68, 105, -20,
-99, 16, -77,
-99, -34, 71,
-50, 63, 97,
42, -59, -103,
91, -1, -88,
93, -47, 71,
-99, 16, -77,
-68, 105, -20,
91, -1, -88,
-99, -34, 71,
42, -110, 45,
93, -47, 71,
-50, 63, 97,
-58, -30, 108,
-14, 70, 104,
93, -47, 71,
-65, 22, -106,
-58, -30, 108,
91, -1, -88,
-68, 105, -20,
-65, 22, -106,
-68, 105, -20,
-14, 70, 104,
-47, 100, -60,
50, 63, 97,
-93, -47, 71,
99, -34, 71,
-91, -1, -88,
99, 16, -77,
-42, -59, -103,
-93, -47, 71,
-42, -59, -103,
-42, -110, 45,
67, 105, -20,
50, 63, 97,
99, 16, -77,
50, 63, 97,
99, -34, 71,
99, 16, -77,
-93, -47, 71,
-91, -1, -88,
-42, -59, -103,
-91, -1, -88,
67, 105, -20,
99, 16, -77,
-93, -47, 71,
-42, -110, 45,
99, -34, 71,
50, 63, 97,
47, 100, -60,
14, 70, 104,
67, 105, -20,
65, 22, -106,
47, 100, -60,
-91, -1, -88,
-93, -47, 71,
65, 22, -106,
-93, -47, 71,
50, 63, 97,
58, -30, 108,
67, 105, -20,
47, 100, -60,
50, 63, 97,
-14, 70, 104,
-68, 105, -20,
-50, 63, 97,
122, -33, -3,
-51, -103, 53,
118, 12, 45,
98, -3, -80,
57, -30, -108,
-98, -3, -80,
-98, -3, -80,
118, 12, 45,
98, -3, -80,
-98, -3, -80,
122, -33, -3,
118, 12, 45,
-57, -30, -108,
-51, -103, 53,
-94, 4, -84,
-51, -103, 53,
83, -75, 59,
-83, -75, 59,
45, -108, 47,
94, 4, -84,
83, -75, 59,
57, -30, -108,
-94, 4, -84,
94, 4, -84,
-78, -24, 96,
72, -28, 99,
-90, 76, 45,
73, -98, -33,
-90, -10, -88,
91, 0, -87,
72, -28, 99,
73, -98, -33,
84, 88, 34,
-78, -93, -34,
-90, 76, 45,
-90, -10, -88,
-78, -93, -34,
-78, -24, 96,
-90, 76, 45,
73, -98, -33,
91, 0, -87,
84, 88, 34,
73, -98, -33,
-78, -93, -34,
-90, -10, -88,
72, -28, 99,
84, 88, 34,
-90, 76, 45,
-90, 76, 45,
84, 88, 34,
-51, -103, 53,
84, 88, 34,
91, 0, -87,
118, 12, 45,
91, 0, -87,
-57, -30, -108,
98, -3, -80,
-90, -10, -88,
-51, -103, 53,
-57, -30, -108,
87, 79, 46,
-73, -27, 100,
78, -24, 96,
-91, -1, -88,
90, -10, -88,
-73, -98, -33,
-75, 101, 9,
-73, -98, -33,
-73, -27, 100,
90, -10, -88,
87, 79, 46,
78, -93, -34,
87, 79, 46,
78, -24, 96,
78, -93, -34,
-75, 101, 9,
-91, -1, -88,
-73, -98, -33,
90, -10, -88,
78, -93, -34,
-73, -98, -33,
87, 79, 46,
-75, 101, 9,
-73, -27, 100,
87, 79, 46,
90, -10, -88,
45, -108, 47,
-91, -1, -88,
-98, -3, -80,
57, -30, -108,
-91, -1, -88,
122, -33, -3,
-98, -3, -80,
-75, 101, 9,
45, -108, 47,
122, -33, -3,
-42, -59, -103,
37, -99, -69,
-42, -110, 45,
-42, -110, 45,
93, -85, 9,
99, -34, 71,
99, -34, 71,
93, -85, 9,
99, 16, -77,
99, 16, -77,
93, -61, -59,
-42, -59, -103,
42, -110, 45,
-37, -121, -6,
42, -59, -103,
42, -59, -103,
-93, -61, -59,
-99, 16, -77,
-99, 16, -77,
-93, -61, -59,
-99, -34, 71,
-99, -34, 71,
-93, -85, 9,
42, -110, 45,
-74, -85, 56,
80, 26, 94,
37, -121, -6,
80, 26, 94,
93, -61, -59,
93, -85, 9,
80, 79, -58,
37, -99, -69,
93, -61, -59,
-74, -32, -97,
-74, -85, 56,
37, -99, -69,
-80, 26, 94,
-37, -121, -6,
-93, -85, 9,
74, -32, -97,
-93, -61, -59,
-37, -99, -69,
-80, 79, -58,
-80, 26, 94,
-93, -61, -59,
-37, -99, -69,
-37, -121, -6,
74, -32, -97,
-99, -22, 75,
71, -70, 78,
-57, 23, 110,
33, -52, -110,
-92, 34, -79,
81, -2, -97,
31, -114, 44,
33, -52, -110,
71, -70, 78,
-92, 34, -79,
-57, 23, 110,
-52, 97, -62,
-92, 34, -79,
-99, -22, 75,
-57, 23, 110,
33, -52, -110,
81, -2, -97,
71, -70, 78,
-92, 34, -79,
-52, 97, -62,
81, -2, -97,
-99, -22, 75,
31, -114, 44,
71, -70, 78,
33, -52, -110,
-72, -100, -27,
-92, 34, -79,
-92, 34, -79,
-72, -100, -27,
-99, -22, 75,
-99, -22, 75,
-72, -100, -27,
31, -114, 44,
31, -114, 44,
-72, -100, -27,
33, -52, -110,
81, -2, -97,
-80, 79, -58,
74, -32, -97,
-52, 97, -62,
-57, 23, 110,
-80, 79, -58,
-57, 23, 110,
71, -70, 78,
-80, 26, 94,
71, -70, 78,
81, -2, -97,
74, -85, 56,
73, -98, -33,
-25, -119, 33,
-78, -93, -34,
-78, -93, -34,
-25, -119, 33,
-78, -24, 96,
-78, -24, 96,
-33, -93, 79,
72, -28, 99,
72, -28, 99,
35, -91, 81,
73, -98, -33,
-73, -27, 100,
-35, -91, 81,
78, -24, 96,
78, -24, 96,
25, -119, 33,
78, -93, -34,
78, -93, -34,
25, -119, 33,
-73, -98, -33,
-73, -98, -33,
-35, -91, 81,
-73, -27, 100,
89, 41, 79,
82, 30, 91,
-89, 41, 79,
-89, -41, -79,
-88, -64, -63,
89, -41, -79,
-84, 33, 88,
-88, -64, -63,
-89, 41, 79,
85, -70, -62,
82, 30, 91,
89, -41, -79,
89, 41, 79,
49, 116, 14,
89, -41, -79,
89, -41, -79,
73, 0, -103,
-89, -41, -79,
-89, -41, -79,
-97, 80, 10,
-89, 41, 79,
-89, 41, 79,
-97, 80, 10,
89, 41, 79,
-97, 80, 10,
49, 116, 14,
89, 41, 79,
-89, -41, -79,
-89, -22, -87,
-97, 80, 10,
73, 0, -103,
-89, -22, -87,
-89, -41, -79,
49, 116, 14,
73, 0, -103,
89, -41, -79,
82, 30, 91,
89, 41, 79,
89, -41, -79,
-88, -64, -63,
-89, -41, -79,
-89, 41, 79,
-88, -64, -63,
85, -70, -62,
89, -41, -79,
82, 30, 91,
-84, 33, 88,
-89, 41, 79,
-88, -64, -63,
-35, -91, 81,
-26, -120, 31,
-84, 33, 88,
82, 30, 91,
-35, -91, 81,
82, 30, 91,
85, -70, -62,
33, -93, 79,
85, -70, -62,
-26, -120, 31,
25, -119, 33,
89, 41, 79,
-82, 30, 91,
-89, 41, 79,
-89, -41, -79,
88, -64, -63,
89, -41, -79,
89, 41, 79,
88, -64, -63,
84, 33, 88,
-89, -41, -79,
-82, 30, 91,
-85, -70, -62,
-89, -41, -79,
-49, 116, 14,
-89, 41, 79,
89, -41, -79,
-73, 0, -103,
-89, -41, -79,
89, 41, 79,
97, 80, 10,
89, -41, -79,
-89, 41, 79,
97, 80, 10,
89, 41, 79,
-89, 41, 79,
-49, 116, 14,
97, 80, 10,
97, 80, 10,
89, -22, -87,
89, -41, -79,
89, -41, -79,
89, -22, -87,
-73, 0, -103,
-89, -41, -79,
-73, 0, -103,
-49, 116, 14,
-89, -41, -79,
-89, 41, 79,
-82, 30, 91,
89, 41, 79,
89, -41, -79,
88, -64, -63,
-89, -41, -79,
-85, -70, -62,
88, -64, -63,
89, 41, 79,
84, 33, 88,
-82, 30, 91,
-82, 30, 91,
35, -91, 81,
-33, -93, 79,
84, 33, 88,
88, -64, -63,
35, -91, 81,
88, -64, -63,
-85, -70, -62,
26, -120, 31,
-85, -70, -62,
-33, -93, 79,
-25, -119, 33,
86, -88, -27,
-53, -104, -47,
88, -16, -89,
-64, 107, -17,
95, 78, -29,
-91, 61, -63,
99, -61, 49,
77, -36, 93,
-93, -85, 9,
77, -36, 93,
95, 78, -29,
61, 110, 2,
-93, -85, 9,
-101, -42, 63,
-91, 61, -63,
61, 110, 2,
-18, 37, 119,
77, -36, 93,
77, -36, 93,
-18, 37, 119,
-101, -42, 63,
-101, -42, 63,
-18, 37, 119,
-64, 107, -17,
-64, 107, -17,
-18, 37, 119,
61, 110, 2,
99, -61, 49,
86, -88, -27,
95, 78, -29,
-93, -85, 9,
-53, -104, -47,
99, -61, 49,
-91, 61, -63,
-56, -24, -111,
-93, -85, 9,
-56, -24, -111,
-53, -104, -47,
-93, -85, 9,
-53, -104, -47,
86, -88, -27,
99, -61, 49,
86, -88, -27,
88, -16, -89,
95, 78, -29,
-101, -42, 63,
-64, 107, -17,
-91, 61, -63,
77, -36, 93,
99, -61, 49,
95, 78, -29,
77, -36, 93,
-101, -42, 63,
-93, -85, 9,
-64, 107, -17,
61, 110, 2,
95, 78, -29,
-53, -104, -47,
-56, -24, -111,
88, -16, -89,
95, 78, -29,
88, -16, -89,
97, 80, 10,
88, -16, -89,
-56, -24, -111,
89, -22, -87,
-56, -24, -111,
-91, 61, -63,
-73, 0, -103,
-91, 61, -63,
95, 78, -29,
-49, 116, 14,
-88, -16, -89,
53, -104, -47,
-86, -88, -27,
91, 61, -63,
-95, 78, -29,
64, 107, -17,
93, -85, 9,
-77, -36, 93,
-99, -61, 49,
-61, 110, 2,
-95, 78, -29,
-77, -36, 93,
91, 61, -63,
101, -42, 63,
93, -85, 9,
-77, -36, 93,
18, 37, 119,
-61, 110, 2,
101, -42, 63,
18, 37, 119,
-77, -36, 93,
64, 107, -17,
18, 37, 119,
101, -42, 63,
-61, 110, 2,
18, 37, 119,
64, 107, -17,
-95, 78, -29,
-86, -88, -27,
-99, -61, 49,
-99, -61, 49,
53, -104, -47,
93, -85, 9,
93, -85, 9,
56, -24, -111,
91, 61, -63,
93, -85, 9,
53, -104, -47,
56, -24, -111,
-99, -61, 49,
-86, -88, -27,
53, -104, -47,
-95, 78, -29,
-88, -16, -89,
-86, -88, -27,
91, 61, -63,
64, 107, -17,
101, -42, 63,
-95, 78, -29,
-99, -61, 49,
-77, -36, 93,
93, -85, 9,
101, -42, 63,
-77, -36, 93,
-95, 78, -29,
-61, 110, 2,
64, 107, -17,
-88, -16, -89,
56, -24, -111,
53, -104, -47,
-95, 78, -29,
49, 116, 14,
-97, 80, 10,
91, 61, -63,
73, 0, -103,
49, 116, 14,
56, -24, -111,
-89, -22, -87,
73, 0, -103,
-88, -16, -89,
-97, 80, 10,
-89, -22, -87,
57, -30, -108,
90, -10, -88,
-91, -1, -88,
91, 0, -87,
-90, -10, -88,
-57, -30, -108,
80, 79, -58,
-81, -2, -97,
-74, -32, -97,
-74, -32, -97,
-71, -70, 78,
-74, -85, 56,
80, 26, 94,
52, 97, -62,
80, 79, -58,
57, 23, 110,
-71, -70, 78,
99, -22, 75,
-81, -2, -97,
92, 34, -79,
-33, -52, -110,
-71, -70, 78,
-33, -52, -110,
-31, -114, 44,
52, 97, -62,
57, 23, 110,
92, 34, -79,
57, 23, 110,
99, -22, 75,
92, 34, -79,
-71, -70, 78,
-81, -2, -97,
-33, -52, -110,
-81, -2, -97,
52, 97, -62,
92, 34, -79,
-71, -70, 78,
-31, -114, 44,
99, -22, 75,
92, 34, -79,
72, -100, -27,
-33, -52, -110,
99, -22, 75,
72, -100, -27,
92, 34, -79,
-31, -114, 44,
72, -100, -27,
99, -22, 75,
-33, -52, -110,
72, -100, -27,
-31, -114, 44,
-74, -85, 56,
-71, -70, 78,
80, 26, 94,
-71, -70, 78,
57, 23, 110,
80, 26, 94,
80, 26, 94,
57, 23, 110,
52, 97, -62,
-74, -32, -97,
-81, -2, -97,
-71, -70, 78,
80, 79, -58,
52, 97, -62,
-81, -2, -97,
-88, -16, -89,
-95, 78, -29,
-97, 80, 10,
56, -24, -111,
-88, -16, -89,
-89, -22, -87,
91, 61, -63,
56, -24, -111,
73, 0, -103,
-95, 78, -29,
91, 61, -63,
49, 116, 14,
95, 78, -29,
97, 80, 10,
-49, 116, 14,
-91, 61, -63,
-49, 116, 14,
-73, 0, -103,
-56, -24, -111,
-73, 0, -103,
89, -22, -87,
88, -16, -89,
89, -22, -87,
97, 80, 10,
-85, -70, -62,
-82, 30, 91,
-33, -93, 79,
-85, -70, -62,
-25, -119, 33,
26, -120, 31,
88, -64, -63,
26, -120, 31,
35, -91, 81,
-82, 30, 91,
84, 33, 88,
35, -91, 81,
85, -70, -62,
-88, -64, -63,
-26, -120, 31,
85, -70, -62,
25, -119, 33,
33, -93, 79,
82, 30, 91,
33, -93, 79,
-35, -91, 81,
-88, -64, -63,
-84, 33, 88,
-35, -91, 81,
-73, -98, -33,
-26, -120, 31,
-35, -91, 81,
25, -119, 33,
-26, -120, 31,
-73, -98, -33,
78, -24, 96,
33, -93, 79,
25, -119, 33,
-35, -91, 81,
33, -93, 79,
78, -24, 96,
35, -91, 81,
26, -120, 31,
73, -98, -33,
-33, -93, 79,
35, -91, 81,
72, -28, 99,
-25, -119, 33,
-33, -93, 79,
-78, -24, 96,
73, -98, -33,
26, -120, 31,
-25, -119, 33,
81, -2, -97,
74, -32, -97,
74, -85, 56,
71, -70, 78,
74, -85, 56,
-80, 26, 94,
-57, 23, 110,
-80, 26, 94,
-80, 79, -58,
81, -2, -97,
-52, 97, -62,
-80, 79, -58,
-37, -121, -6,
74, -85, 56,
74, -32, -97,
-80, 26, 94,
-93, -85, 9,
-93, -61, -59,
74, -32, -97,
-80, 79, -58,
-93, -61, -59,
-80, 26, 94,
74, -85, 56,
-37, -121, -6,
-74, -85, 56,
37, -121, -6,
37, -99, -69,
80, 79, -58,
-74, -32, -97,
37, -99, -69,
80, 26, 94,
80, 79, -58,
93, -61, -59,
80, 26, 94,
93, -85, 9,
37, -121, -6,
-93, -85, 9,
-37, -121, -6,
42, -110, 45,
-93, -61, -59,
-93, -85, 9,
-99, -34, 71,
42, -59, -103,
-37, -99, -69,
-93, -61, -59,
-37, -121, -6,
-37, -99, -69,
42, -59, -103,
93, -61, -59,
37, -99, -69,
-42, -59, -103,
93, -85, 9,
93, -61, -59,
99, 16, -77,
-42, -110, 45,
37, -121, -6,
93, -85, 9,
37, -99, -69,
37, -121, -6,
-42, -110, 45,
-75, 101, 9,
87, 79, 46,
45, -108, 47,
-91, -1, -88,
-75, 101, 9,
122, -33, -3,
90, -10, -88,
57, -30, -108,
45, -108, 47,
-90, -10, -88,
-90, 76, 45,
-51, -103, 53,
91, 0, -87,
98, -3, -80,
118, 12, 45,
84, 88, 34,
118, 12, 45,
-51, -103, 53,
57, -30, -108,
-57, -30, -108,
-94, 4, -84,
45, -108, 47,
57, -30, -108,
94, 4, -84,
-51, -103, 53,
45, -108, 47,
83, -75, 59,
-51, -103, 53,
-83, -75, 59,
-94, 4, -84,
98, -3, -80,
-57, -30, -108,
57, -30, -108,
122, -33, -3,
45, -108, 47,
-51, -103, 53,
50, 63, 97,
14, 70, 104,
58, -30, 108,
-93, -47, 71,
58, -30, 108,
65, 22, -106,
67, 105, -20,
-91, -1, -88,
65, 22, -106,
-68, 105, -20,
-47, 100, -60,
-65, 22, -106,
93, -47, 71,
91, -1, -88,
-65, 22, -106,
-50, 63, 97,
93, -47, 71,
-58, -30, 108,
-85, 39, -85,
-83, -8, 95,
-58, -30, 108,
65, 22, -106,
85, 39, -85,
-85, 39, -85,
-58, -30, 108,
-83, -8, 95,
83, -8, 95,
58, -30, 108,
83, -8, 95,
85, 39, -85,
2, 123, 28,
32, 118, -31,
87, -35, -84,
-2, 123, 28,
2, 123, 28,
-1, -98, -80,
-47, 100, -60,
47, 100, -60,
65, 22, -106,
58, -30, 108,
14, 70, 104,
-14, 70, 104,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:24 */
static s8 vtxnvgrp_frake_select_24[]={
-16, -108, 64,
5, -113, 57,
3, -112, 59,
3, -112, 59,
25, -116, 43,
97, -52, 61,
-10, -114, -54,
41, -62, -102,
-63, -108, -15,
-63, -108, -15,
-37, -26, -118,
-24, -118, -37,
-24, -118, -37,
-37, -26, -118,
-14, -120, -38,
-14, -120, -38,
-105, -11, -69,
-63, -105, -32,
-63, -105, -32,
-124, -22, -4,
-77, -87, 50,
-10, -114, -54,
87, -62, 67,
52, -114, 13,
79, -85, -50,
10, -107, -66,
41, -62, -102,
41, -62, -102,
89, -43, -78,
-37, -26, -118,
-37, -26, -118,
-111, -8, -60,
-105, -11, -69,
-105, -11, -69,
-57, -92, -65,
-124, -22, -4,
-124, -22, -4,
-57, -92, -65,
-77, -87, 50,
-77, -87, 50,
-82, -90, -34,
-5, -126, 0,
-5, -126, 0,
25, -114, -49,
52, -114, 13,
52, -114, 13,
10, -107, -66,
79, -85, -50,
16, 125, 6,
-75, 101, 14,
-10, 126, -4,
74, -16, -101,
87, 6, -91,
112, -52, -28,
125, -12, -11,
93, -59, 61,
97, -52, 61,
97, -52, 61,
93, -59, 61,
3, -112, 59,
3, -112, 59,
-62, -12, 109,
-62, -8, 110,
-62, -8, 110,
-62, -12, 109,
-105, 59, 38,
-124, 20, 17,
-103, 61, -39,
-108, 42, -50,
-108, 42, -50,
-25, 46, -115,
-32, 28, -119,
-32, 28, -119,
-25, 46, -115,
74, -16, -101,
87, 6, -91,
109, 61, -21,
125, -12, -11,
125, -12, -11,
109, 61, -21,
121, 32, 20,
-75, 88, 50,
-75, 101, 14,
-105, 59, 38,
-105, 59, 38,
-75, 101, 14,
-103, 61, -39,
-103, 61, -39,
-8, 103, -73,
-25, 46, -115,
-25, 46, -115,
-8, 103, -73,
87, 6, -91,
74, 94, -39,
-8, 103, -73,
16, 125, 6,
52, -114, 13,
79, -85, -50,
-10, -114, -54,
-77, -87, 50,
-62, -26, 107,
-63, -105, -32,
-5, -126, 0,
52, -114, 13,
-77, -87, 50,
52, -114, 13,
27, -55, 111,
-77, -87, 50,
-16, -108, 64,
62, -104, 35,
-63, -105, -32,
-63, -105, -32,
-112, 13, -57,
-124, 20, 17,
-124, 20, 17,
-70, -50, 93,
-62, -8, 110,
-62, -8, 110,
62, -104, 35,
-16, -108, 64,
62, -104, 35,
-51, -106, -46,
38, -31, -117,
38, -31, -117,
-51, -106, -46,
-112, 13, -57,
-112, 13, -57,
-51, -106, -46,
-70, -50, 93,
-70, -50, 93,
-51, -106, -46,
62, -104, 35,
-10, -114, -54,
-74, -79, 65,
25, -116, 43,
25, -116, 43,
-74, -79, 65,
97, -52, 61,
97, -52, 61,
78, -86, 49,
112, -52, -28,
112, -52, -28,
58, -43, -103,
-10, -114, -54,
-95, 13, -82,
-39, -108, -53,
-74, -79, 65,
-74, -79, 65,
-39, -108, -53,
78, -86, 49,
78, -86, 49,
-39, -108, -53,
58, -43, -103,
58, -43, -103,
-39, -108, -53,
-95, 13, -82,
-63, -108, -15,
-61, -74, 82,
-10, -114, -54,
-10, -114, -54,
-61, -74, 82,
112, -52, -28,
112, -52, -28,
85, -92, 15,
74, -16, -101,
74, -16, -101,
-41, -3, -120,
-63, -108, -15,
-120, 26, 31,
-61, -101, -45,
-61, -74, 82,
-61, -74, 82,
-61, -101, -45,
85, -92, 15,
85, -92, 15,
-61, -101, -45,
-41, -3, -120,
-41, -3, -120,
-61, -101, -45,
-120, 26, 31,
-108, 42, -50,
-96, -53, 63,
-124, 20, 17,
-124, 20, 17,
60, -99, 50,
-63, -105, -32,
-63, -105, -32,
60, -99, 50,
-14, -120, -38,
-14, -120, -38,
-16, -12, -125,
-108, 42, -50,
-16, -12, -125,
-29, -108, -59,
-96, -53, 63,
-96, -53, 63,
-29, -108, -59,
60, -99, 50,
60, -99, 50,
-29, -108, -59,
114, -51, -18,
114, -51, -18,
-29, -108, -59,
-16, -12, -125,
-24, -118, -37,
53, -75, 86,
-63, -108, -15,
-63, -108, -15,
53, -75, 86,
74, -16, -101,
74, -16, -101,
-80, 0, -98,
-32, 28, -119,
-32, 28, -119,
-80, 0, -98,
-24, -118, -37,
-109, -33, 55,
-31, -119, 28,
53, -75, 86,
53, -75, 86,
-31, -119, 28,
95, -40, -72,
95, -40, -72,
-31, -119, 28,
-80, 0, -98,
-80, 0, -98,
-31, -119, 28,
-109, -33, 55,
-14, -120, -38,
-28, -53, 111,
-24, -118, -37,
-24, -118, -37,
15, -24, -123,
-32, 28, -119,
-32, 28, -119,
15, -24, -123,
-108, 42, -50,
-108, 42, -50,
-28, -53, 111,
-14, -120, -38,
-28, -53, 111,
-17, -124, 15,
90, -88, 5,
90, -88, 5,
-17, -124, 15,
15, -24, -123,
15, -24, -123,
-17, -124, 15,
-126, 11, -7,
-126, 11, -7,
-17, -124, 15,
-28, -53, 111,
28, 90, 84,
38, 88, 82,
-75, 88, 50,
121, 32, 20,
38, 88, 82,
28, 90, 84,
87, -62, 67,
-10, -114, -54,
25, -116, 43,
-62, -26, 107,
-16, -108, 64,
-63, -105, -32,
-62, -26, 107,
5, -113, 57,
-16, -108, 64,
87, -62, 67,
25, -116, 43,
5, -113, 57,
-62, -26, 107,
27, -55, 111,
5, -113, 57,
121, 32, 20,
93, -59, 61,
125, -12, -11,
-105, 59, 38,
-62, -12, 109,
-75, 88, 50,
97, -52, 61,
112, -52, -28,
125, -12, -11,
-105, 59, 38,
-124, 20, 17,
-62, -8, 110,
-17, 68, 105,
-23, 4, 124,
42, 57, 105,
80, -25, 94,
38, 55, 107,
30, -5, 123,
16, 125, 6,
38, 88, 82,
59, 109, -23,
16, 125, 6,
59, 109, -23,
109, 61, -21,
16, 125, 6,
109, 61, -21,
74, 94, -39,
-10, 126, -4,
38, 88, 82,
16, 125, 6,
16, 125, 6,
-40, 119, -9,
-75, 101, 14,
16, 125, 6,
-8, 103, -73,
-40, 119, -9,
28, 90, 84,
41, -23, 117,
33, -51, 111,
33, -51, 111,
-38, -18, 119,
-62, -12, 109,
-62, -12, 109,
-42, 77, 91,
-75, 88, 50,
-75, 88, 50,
59, 68, 88,
28, 90, 84,
93, -59, 61,
79, -38, 91,
33, -51, 111,
33, -51, 111,
10, -19, 125,
28, 90, 84,
28, 90, 84,
25, 73, 100,
121, 32, 20,
121, 32, 20,
107, 45, 50,
93, -59, 61,
107, 45, 50,
79, -38, 91,
93, -59, 61,
25, 73, 100,
107, 45, 50,
121, 32, 20,
10, -19, 125,
25, 73, 100,
28, 90, 84,
79, -38, 91,
10, -19, 125,
33, -51, 111,
-75, 88, 50,
-42, 77, 91,
59, 68, 88,
-62, -12, 109,
-38, -18, 119,
-42, 77, 91,
33, -51, 111,
41, -23, 117,
-38, -18, 119,
28, 90, 84,
59, 68, 88,
41, -23, 117,
121, 32, 20,
59, 109, -23,
38, 88, 82,
38, 88, 82,
-10, 126, -4,
-75, 88, 50,
-108, 42, -50,
-126, 11, -7,
-28, -53, 111,
15, -24, -123,
-126, 11, -7,
-108, 42, -50,
-24, -118, -37,
90, -88, 5,
15, -24, -123,
-28, -53, 111,
90, -88, 5,
-24, -118, -37,
-80, 0, -98,
-109, -33, 55,
-24, -118, -37,
74, -16, -101,
95, -40, -72,
-80, 0, -98,
53, -75, 86,
95, -40, -72,
74, -16, -101,
-24, -118, -37,
-109, -33, 55,
53, -75, 86,
-14, -120, -38,
114, -51, -18,
-16, -12, -125,
60, -99, 50,
114, -51, -18,
-14, -120, -38,
-124, 20, 17,
-96, -53, 63,
60, -99, 50,
-108, 42, -50,
-16, -12, -125,
-96, -53, 63,
-41, -3, -120,
-120, 26, 31,
-63, -108, -15,
85, -92, 15,
-41, -3, -120,
74, -16, -101,
-61, -74, 82,
85, -92, 15,
112, -52, -28,
-63, -108, -15,
-120, 26, 31,
-61, -74, 82,
58, -43, -103,
-95, 13, -82,
-10, -114, -54,
78, -86, 49,
58, -43, -103,
112, -52, -28,
-74, -79, 65,
78, -86, 49,
97, -52, 61,
-10, -114, -54,
-95, 13, -82,
-74, -79, 65,
-62, -8, 110,
-70, -50, 93,
62, -104, 35,
-124, 20, 17,
-112, 13, -57,
-70, -50, 93,
-63, -105, -32,
38, -31, -117,
-112, 13, -57,
62, -104, 35,
38, -31, -117,
-63, -105, -32,
27, -55, 111,
-62, -26, 107,
-77, -87, 50,
-8, 103, -73,
74, 94, -39,
87, 6, -91,
-103, 61, -39,
-40, 119, -9,
-8, 103, -73,
-75, 101, 14,
-40, 119, -9,
-103, 61, -39,
-75, 88, 50,
-10, 126, -4,
-75, 101, 14,
109, 61, -21,
59, 109, -23,
121, 32, 20,
87, 6, -91,
74, 94, -39,
109, 61, -21,
-25, 46, -115,
87, 6, -91,
74, -16, -101,
-108, 42, -50,
-103, 61, -39,
-25, 46, -115,
-124, 20, 17,
-105, 59, 38,
-103, 61, -39,
3, -112, 59,
33, -51, 111,
-62, -12, 109,
93, -59, 61,
33, -51, 111,
3, -112, 59,
87, 6, -91,
125, -12, -11,
112, -52, -28,
10, -107, -66,
25, -114, -49,
-82, -90, -34,
25, -114, -49,
-5, -126, 0,
-82, -90, -34,
10, -107, -66,
-82, -90, -34,
-57, -92, -65,
52, -114, 13,
25, -114, -49,
10, -107, -66,
-57, -92, -65,
-82, -90, -34,
-77, -87, 50,
-105, -11, -69,
-111, -8, -60,
-57, -92, -65,
-37, -26, -118,
-3, -24, -124,
-111, -8, -60,
89, -43, -78,
-3, -24, -124,
-37, -26, -118,
10, -107, -66,
89, -43, -78,
41, -62, -102,
-105, -11, -69,
-124, -22, -4,
-63, -105, -32,
-37, -26, -118,
-105, -11, -69,
-14, -120, -38,
-63, -108, -15,
41, -62, -102,
-37, -26, -118,
-10, -114, -54,
79, -85, -50,
41, -62, -102,
3, -112, 59,
5, -113, 57,
25, -116, 43,
3, -112, 59,
-62, -8, 110,
-16, -108, 64,
27, -55, 111,
87, -62, 67,
5, -113, 57,
10, -19, 125,
88, 38, 82,
25, 73, 100,
25, 73, 100,
30, -5, 123,
107, 45, 50,
107, 45, 50,
30, -5, 123,
79, -38, 91,
79, -38, 91,
88, 38, 82,
10, -19, 125,
59, 68, 88,
-17, 68, 105,
41, -23, 117,
41, -23, 117,
-17, 68, 105,
-38, -18, 119,
-38, -18, 119,
38, -8, 120,
-42, 77, 91,
-42, 77, 91,
38, -8, 120,
59, 68, 88,
38, -8, 120,
-23, 4, 124,
59, 68, 88,
-38, -18, 119,
42, 57, 105,
38, -8, 120,
-17, 68, 105,
42, 57, 105,
-38, -18, 119,
59, 68, 88,
-23, 4, 124,
-17, 68, 105,
79, -38, 91,
38, 55, 107,
88, 38, 82,
30, -5, 123,
38, 55, 107,
79, -38, 91,
25, 73, 100,
80, -25, 94,
30, -5, 123,
88, 38, 82,
80, -25, 94,
25, 73, 100,
80, -25, 94,
88, 38, 82,
38, 55, 107,
-23, 4, 124,
38, -8, 120,
42, 57, 105,
52, -114, 13,
87, -62, 67,
27, -55, 111,
58, -25, 109,
-14, 75, 101,
-58, -25, 109,
95, -1, -84,
-95, -1, -84,
85, 35, -86,
14, 75, 101,
-11, 114, 54,
-14, 75, 101,
-14, 75, 101,
-33, 116, -38,
-47, 97, -65,
-47, 97, -65,
33, 116, -38,
47, 97, -65,
47, 97, -65,
33, 116, -38,
14, 75, 101,
83, -3, 95,
95, -1, -84,
85, 35, -86,
-83, -3, 95,
83, -72, 62,
83, -3, 95,
-85, 35, -86,
-95, -1, -84,
-83, -3, 95,
-65, 17, -107,
-47, 97, -65,
65, 17, -107,
-95, -1, -84,
-83, -72, 62,
-83, -3, 95,
-83, -3, 95,
-83, -72, 62,
83, -72, 62,
83, -3, 95,
83, -72, 62,
95, -1, -84,
33, 116, -38,
11, 114, 54,
14, 75, 101,
-47, 97, -65,
-33, 116, -38,
33, 116, -38,
-14, 75, 101,
-11, 114, 54,
-33, 116, -38,
14, 75, 101,
11, 114, 54,
-11, 114, 54,
-95, -1, -84,
-85, 35, -86,
85, 35, -86,
-11, 114, 54,
10, -107, -66,
-57, -92, -65,
11, 114, 54,
89, -43, -78,
10, -107, -66,
33, 116, -38,
-3, -24, -124,
89, -43, -78,
-33, 116, -38,
-111, -8, -60,
-3, -24, -124,
-11, 114, 54,
-57, -92, -65,
-111, -8, -60,
33, 116, -38,
-33, 116, -38,
-3, -24, -124,
-33, 116, -38,
-11, 114, 54,
-111, -8, -60,
58, -25, 109,
85, 35, -86,
65, 17, -107,
-58, -25, 109,
83, -3, 95,
58, -25, 109,
65, 17, -107,
-85, 35, -86,
-65, 17, -107,
-65, 17, -107,
-85, 35, -86,
-58, -25, 109,
-99, -31, 72,
93, -44, 73,
-50, 68, 94,
42, -64, -100,
-99, 12, -78,
91, -5, -87,
42, -108, 50,
42, -64, -100,
93, -44, 73,
-99, 12, -78,
-50, 68, 94,
-68, 104, -26,
-99, 12, -78,
-99, -31, 72,
-50, 68, 94,
42, -64, -100,
91, -5, -87,
93, -44, 73,
-99, 12, -78,
-68, 104, -26,
91, -5, -87,
-99, -31, 72,
42, -108, 50,
93, -44, 73,
-50, 68, 94,
-58, -25, 109,
-14, 75, 101,
93, -44, 73,
-65, 17, -107,
-58, -25, 109,
91, -5, -87,
-68, 104, -26,
-65, 17, -107,
-68, 104, -26,
-14, 75, 101,
-47, 97, -65,
50, 68, 94,
-93, -44, 73,
99, -31, 72,
-91, -5, -87,
99, 12, -78,
-42, -64, -100,
-93, -44, 73,
-42, -64, -100,
-42, -108, 50,
67, 104, -25,
50, 68, 94,
99, 12, -78,
50, 68, 94,
99, -31, 72,
99, 12, -78,
-93, -44, 73,
-91, -5, -87,
-42, -64, -100,
-91, -5, -87,
67, 104, -25,
99, 12, -78,
-93, -44, 73,
-42, -108, 50,
99, -31, 72,
50, 68, 94,
47, 97, -65,
14, 75, 101,
67, 104, -25,
65, 17, -107,
47, 97, -65,
-91, -5, -87,
-93, -44, 73,
65, 17, -107,
-93, -44, 73,
50, 68, 94,
58, -25, 109,
67, 104, -25,
47, 97, -65,
50, 68, 94,
-14, 75, 101,
-68, 104, -26,
-50, 68, 94,
126, -13, 3,
-47, -103, 56,
118, 9, 45,
99, -3, -79,
56, -31, -109,
-99, -3, -79,
-99, -3, -79,
118, 9, 45,
99, -3, -79,
-99, -3, -79,
126, -13, 3,
118, 9, 45,
-56, -31, -109,
-47, -103, 56,
-95, -1, -84,
-47, -103, 56,
83, -72, 62,
-83, -72, 62,
42, -108, 50,
95, -1, -84,
83, -72, 62,
56, -31, -109,
-95, -1, -84,
95, -1, -84,
-78, -31, 94,
72, -36, 97,
-90, 72, 50,
73, -95, -40,
-91, -3, -88,
91, 7, -87,
72, -36, 97,
73, -95, -40,
84, 85, 41,
-78, -90, -41,
-90, 72, 50,
-91, -3, -88,
-78, -90, -41,
-78, -31, 94,
-90, 72, 50,
73, -95, -40,
91, 7, -87,
84, 85, 41,
73, -95, -40,
-78, -90, -41,
-91, -3, -88,
72, -36, 97,
84, 85, 41,
-90, 72, 50,
-90, 72, 50,
84, 85, 41,
-47, -103, 56,
84, 85, 41,
91, 7, -87,
118, 9, 45,
91, 7, -87,
-56, -31, -109,
99, -3, -79,
-91, -3, -88,
-47, -103, 56,
-56, -31, -109,
88, 75, 51,
-73, -34, 97,
78, -31, 94,
-91, 7, -87,
91, -3, -88,
-73, -95, -40,
-78, 97, 21,
-73, -95, -40,
-73, -34, 97,
91, -3, -88,
88, 75, 51,
78, -90, -41,
88, 75, 51,
78, -31, 94,
78, -90, -41,
-78, 97, 21,
-91, 7, -87,
-73, -95, -40,
91, -3, -88,
78, -90, -41,
-73, -95, -40,
88, 75, 51,
-78, 97, 21,
-73, -34, 97,
88, 75, 51,
91, -3, -88,
42, -108, 50,
-91, 7, -87,
-99, -3, -79,
56, -31, -109,
-91, 7, -87,
126, -13, 3,
-99, -3, -79,
-78, 97, 21,
42, -108, 50,
126, -13, 3,
-42, -64, -100,
37, -102, -64,
-42, -108, 50,
-42, -108, 50,
93, -84, 13,
99, -31, 72,
99, -31, 72,
93, -84, 13,
99, 12, -78,
99, 12, -78,
93, -64, -56,
-42, -64, -100,
42, -108, 50,
-37, -121, 0,
42, -64, -100,
42, -64, -100,
-93, -64, -56,
-99, 12, -78,
-99, 12, -78,
-93, -64, -56,
-99, -31, 72,
-99, -31, 72,
-93, -84, 13,
42, -108, 50,
-74, -82, 60,
80, 31, 93,
37, -121, 0,
80, 31, 93,
93, -64, -56,
93, -84, 13,
80, 76, -62,
37, -102, -64,
93, -64, -56,
-74, -37, -95,
-74, -82, 60,
37, -102, -64,
-80, 31, 93,
-37, -121, 0,
-93, -84, 13,
74, -37, -95,
-93, -64, -56,
-37, -102, -64,
-80, 76, -62,
-80, 31, 93,
-93, -64, -56,
-37, -102, -64,
-37, -121, 0,
74, -37, -95,
-99, -18, 76,
71, -66, 81,
-57, 28, 109,
33, -57, -108,
-92, 30, -81,
81, -7, -97,
31, -112, 49,
33, -57, -108,
71, -66, 81,
-92, 30, -81,
-57, 28, 109,
-52, 94, -67,
-92, 30, -81,
-99, -18, 76,
-57, 28, 109,
33, -57, -108,
81, -7, -97,
71, -66, 81,
-92, 30, -81,
-52, 94, -67,
81, -7, -97,
-99, -18, 76,
31, -112, 49,
71, -66, 81,
33, -57, -108,
-72, -101, -22,
-92, 30, -81,
-92, 30, -81,
-72, -101, -22,
-99, -18, 76,
-99, -18, 76,
-72, -101, -22,
31, -112, 49,
31, -112, 49,
-72, -101, -22,
33, -57, -108,
81, -7, -97,
-80, 76, -62,
74, -37, -95,
-52, 94, -67,
-57, 28, 109,
-80, 76, -62,
-57, 28, 109,
71, -66, 81,
-80, 31, 93,
71, -66, 81,
81, -7, -97,
74, -82, 60,
73, -95, -40,
-25, -121, 24,
-78, -90, -41,
-78, -90, -41,
-25, -121, 24,
-78, -31, 94,
-78, -31, 94,
-33, -99, 71,
72, -36, 97,
72, -36, 97,
35, -96, 74,
73, -95, -40,
-73, -34, 97,
-35, -96, 74,
78, -31, 94,
78, -31, 94,
25, -121, 24,
78, -90, -41,
78, -90, -41,
25, -121, 24,
-73, -95, -40,
-73, -95, -40,
-35, -96, 74,
-73, -34, 97,
89, 35, 82,
82, 24, 93,
-89, 35, 82,
-89, -35, -82,
-88, -59, -68,
89, -35, -82,
-84, 27, 90,
-88, -59, -68,
-89, 35, 82,
85, -65, -67,
82, 24, 93,
89, -35, -82,
89, 35, 82,
49, 114, 23,
89, -35, -82,
89, -35, -82,
73, 6, -103,
-89, -35, -82,
-89, -35, -82,
-97, 79, 16,
-89, 35, 82,
-89, 35, 82,
-97, 79, 16,
89, 35, 82,
-97, 79, 16,
49, 114, 23,
89, 35, 82,
-89, -35, -82,
-89, -15, -88,
-97, 79, 16,
73, 6, -103,
-89, -15, -88,
-89, -35, -82,
49, 114, 23,
73, 6, -103,
89, -35, -82,
82, 24, 93,
89, 35, 82,
89, -35, -82,
-88, -59, -68,
-89, -35, -82,
-89, 35, 82,
-88, -59, -68,
85, -65, -67,
89, -35, -82,
82, 24, 93,
-84, 27, 90,
-89, 35, 82,
-88, -59, -68,
-35, -96, 74,
-26, -122, 22,
-84, 27, 90,
82, 24, 93,
-35, -96, 74,
82, 24, 93,
85, -65, -67,
33, -99, 71,
85, -65, -67,
-26, -122, 22,
25, -121, 24,
89, 35, 82,
-82, 24, 93,
-89, 35, 82,
-89, -35, -82,
88, -59, -68,
89, -35, -82,
89, 35, 82,
88, -59, -68,
84, 27, 90,
-89, -35, -82,
-82, 24, 93,
-85, -65, -67,
-89, -35, -82,
-49, 114, 23,
-89, 35, 82,
89, -35, -82,
-73, 6, -103,
-89, -35, -82,
89, 35, 82,
97, 79, 16,
89, -35, -82,
-89, 35, 82,
97, 79, 16,
89, 35, 82,
-89, 35, 82,
-49, 114, 23,
97, 79, 16,
97, 79, 16,
89, -15, -88,
89, -35, -82,
89, -35, -82,
89, -15, -88,
-73, 6, -103,
-89, -35, -82,
-73, 6, -103,
-49, 114, 23,
-89, -35, -82,
-89, 35, 82,
-82, 24, 93,
89, 35, 82,
89, -35, -82,
88, -59, -68,
-89, -35, -82,
-85, -65, -67,
88, -59, -68,
89, 35, 82,
84, 27, 90,
-82, 24, 93,
-82, 24, 93,
35, -96, 74,
-33, -99, 71,
84, 27, 90,
88, -59, -68,
35, -96, 74,
88, -59, -68,
-85, -65, -67,
26, -122, 22,
-85, -65, -67,
-33, -99, 71,
-25, -121, 24,
86, -86, -33,
-53, -100, -55,
88, -9, -90,
-64, 108, -9,
95, 80, -23,
-91, 66, -58,
99, -64, 44,
77, -43, 90,
-93, -85, 3,
77, -43, 90,
95, 80, -23,
61, 110, 10,
-93, -85, 3,
-101, -47, 60,
-91, 66, -58,
61, 110, 10,
-18, 29, 122,
77, -43, 90,
77, -43, 90,
-18, 29, 122,
-101, -47, 60,
-101, -47, 60,
-18, 29, 122,
-64, 108, -9,
-64, 108, -9,
-18, 29, 122,
61, 110, 10,
99, -64, 44,
86, -86, -33,
95, 80, -23,
-93, -85, 3,
-53, -100, -55,
99, -64, 44,
-91, 66, -58,
-56, -15, -112,
-93, -85, 3,
-56, -15, -112,
-53, -100, -55,
-93, -85, 3,
-53, -100, -55,
86, -86, -33,
99, -64, 44,
86, -86, -33,
88, -9, -90,
95, 80, -23,
-101, -47, 60,
-64, 108, -9,
-91, 66, -58,
77, -43, 90,
99, -64, 44,
95, 80, -23,
77, -43, 90,
-101, -47, 60,
-93, -85, 3,
-64, 108, -9,
61, 110, 10,
95, 80, -23,
-53, -100, -55,
-56, -15, -112,
88, -9, -90,
95, 80, -23,
88, -9, -90,
97, 79, 16,
88, -9, -90,
-56, -15, -112,
89, -15, -88,
-56, -15, -112,
-91, 66, -58,
-73, 6, -103,
-91, 66, -58,
95, 80, -23,
-49, 114, 23,
-88, -9, -90,
53, -100, -55,
-86, -86, -33,
91, 66, -58,
-95, 80, -23,
64, 108, -9,
93, -85, 3,
-77, -43, 90,
-99, -64, 44,
-61, 110, 10,
-95, 80, -23,
-77, -43, 90,
91, 66, -58,
101, -47, 60,
93, -85, 3,
-77, -43, 90,
18, 29, 122,
-61, 110, 10,
101, -47, 60,
18, 29, 122,
-77, -43, 90,
64, 108, -9,
18, 29, 122,
101, -47, 60,
-61, 110, 10,
18, 29, 122,
64, 108, -9,
-95, 80, -23,
-86, -86, -33,
-99, -64, 44,
-99, -64, 44,
53, -100, -55,
93, -85, 3,
93, -85, 3,
56, -15, -112,
91, 66, -58,
93, -85, 3,
53, -100, -55,
56, -15, -112,
-99, -64, 44,
-86, -86, -33,
53, -100, -55,
-95, 80, -23,
-88, -9, -90,
-86, -86, -33,
91, 66, -58,
64, 108, -9,
101, -47, 60,
-95, 80, -23,
-99, -64, 44,
-77, -43, 90,
93, -85, 3,
101, -47, 60,
-77, -43, 90,
-95, 80, -23,
-61, 110, 10,
64, 108, -9,
-88, -9, -90,
56, -15, -112,
53, -100, -55,
-95, 80, -23,
49, 114, 23,
-97, 79, 16,
91, 66, -58,
73, 6, -103,
49, 114, 23,
56, -15, -112,
-89, -15, -88,
73, 6, -103,
-88, -9, -90,
-97, 79, 16,
-89, -15, -88,
56, -31, -109,
91, -3, -88,
-91, 7, -87,
91, 7, -87,
-91, -3, -88,
-56, -31, -109,
80, 76, -62,
-81, -7, -97,
-74, -37, -95,
-74, -37, -95,
-71, -66, 81,
-74, -82, 60,
80, 31, 93,
52, 94, -67,
80, 76, -62,
57, 28, 109,
-71, -66, 81,
99, -18, 76,
-81, -7, -97,
92, 30, -81,
-33, -57, -108,
-71, -66, 81,
-33, -57, -108,
-31, -112, 49,
52, 94, -67,
57, 28, 109,
92, 30, -81,
57, 28, 109,
99, -18, 76,
92, 30, -81,
-71, -66, 81,
-81, -7, -97,
-33, -57, -108,
-81, -7, -97,
52, 94, -67,
92, 30, -81,
-71, -66, 81,
-31, -112, 49,
99, -18, 76,
92, 30, -81,
72, -101, -22,
-33, -57, -108,
99, -18, 76,
72, -101, -22,
92, 30, -81,
-31, -112, 49,
72, -101, -22,
99, -18, 76,
-33, -57, -108,
72, -101, -22,
-31, -112, 49,
-74, -82, 60,
-71, -66, 81,
80, 31, 93,
-71, -66, 81,
57, 28, 109,
80, 31, 93,
80, 31, 93,
57, 28, 109,
52, 94, -67,
-74, -37, -95,
-81, -7, -97,
-71, -66, 81,
80, 76, -62,
52, 94, -67,
-81, -7, -97,
-88, -9, -90,
-95, 80, -23,
-97, 79, 16,
56, -15, -112,
-88, -9, -90,
-89, -15, -88,
91, 66, -58,
56, -15, -112,
73, 6, -103,
-95, 80, -23,
91, 66, -58,
49, 114, 23,
95, 80, -23,
97, 79, 16,
-49, 114, 23,
-91, 66, -58,
-49, 114, 23,
-73, 6, -103,
-56, -15, -112,
-73, 6, -103,
89, -15, -88,
88, -9, -90,
89, -15, -88,
97, 79, 16,
-85, -65, -67,
-82, 24, 93,
-33, -99, 71,
-85, -65, -67,
-25, -121, 24,
26, -122, 22,
88, -59, -68,
26, -122, 22,
35, -96, 74,
-82, 24, 93,
84, 27, 90,
35, -96, 74,
85, -65, -67,
-88, -59, -68,
-26, -122, 22,
85, -65, -67,
25, -121, 24,
33, -99, 71,
82, 24, 93,
33, -99, 71,
-35, -96, 74,
-88, -59, -68,
-84, 27, 90,
-35, -96, 74,
-73, -95, -40,
-26, -122, 22,
-35, -96, 74,
25, -121, 24,
-26, -122, 22,
-73, -95, -40,
78, -31, 94,
33, -99, 71,
25, -121, 24,
-35, -96, 74,
33, -99, 71,
78, -31, 94,
35, -96, 74,
26, -122, 22,
73, -95, -40,
-33, -99, 71,
35, -96, 74,
72, -36, 97,
-25, -121, 24,
-33, -99, 71,
-78, -31, 94,
73, -95, -40,
26, -122, 22,
-25, -121, 24,
81, -7, -97,
74, -37, -95,
74, -82, 60,
71, -66, 81,
74, -82, 60,
-80, 31, 93,
-57, 28, 109,
-80, 31, 93,
-80, 76, -62,
81, -7, -97,
-52, 94, -67,
-80, 76, -62,
-37, -121, 0,
74, -82, 60,
74, -37, -95,
-80, 31, 93,
-93, -84, 13,
-93, -64, -56,
74, -37, -95,
-80, 76, -62,
-93, -64, -56,
-80, 31, 93,
74, -82, 60,
-37, -121, 0,
-74, -82, 60,
37, -121, 0,
37, -102, -64,
80, 76, -62,
-74, -37, -95,
37, -102, -64,
80, 31, 93,
80, 76, -62,
93, -64, -56,
80, 31, 93,
93, -84, 13,
37, -121, 0,
-93, -84, 13,
-37, -121, 0,
42, -108, 50,
-93, -64, -56,
-93, -84, 13,
-99, -31, 72,
42, -64, -100,
-37, -102, -64,
-93, -64, -56,
-37, -121, 0,
-37, -102, -64,
42, -64, -100,
93, -64, -56,
37, -102, -64,
-42, -64, -100,
93, -84, 13,
93, -64, -56,
99, 12, -78,
-42, -108, 50,
37, -121, 0,
93, -84, 13,
37, -102, -64,
37, -121, 0,
-42, -108, 50,
-78, 97, 21,
88, 75, 51,
42, -108, 50,
-91, 7, -87,
-78, 97, 21,
126, -13, 3,
91, -3, -88,
56, -31, -109,
42, -108, 50,
-91, -3, -88,
-90, 72, 50,
-47, -103, 56,
91, 7, -87,
99, -3, -79,
118, 9, 45,
84, 85, 41,
118, 9, 45,
-47, -103, 56,
56, -31, -109,
-56, -31, -109,
-95, -1, -84,
42, -108, 50,
56, -31, -109,
95, -1, -84,
-47, -103, 56,
42, -108, 50,
83, -72, 62,
-47, -103, 56,
-83, -72, 62,
-95, -1, -84,
99, -3, -79,
-56, -31, -109,
56, -31, -109,
126, -13, 3,
42, -108, 50,
-47, -103, 56,
50, 68, 94,
14, 75, 101,
58, -25, 109,
-93, -44, 73,
58, -25, 109,
65, 17, -107,
67, 104, -25,
-91, -5, -87,
65, 17, -107,
-68, 104, -26,
-47, 97, -65,
-65, 17, -107,
93, -44, 73,
91, -5, -87,
-65, 17, -107,
-50, 68, 94,
93, -44, 73,
-58, -25, 109,
-85, 35, -86,
-83, -3, 95,
-58, -25, 109,
65, 17, -107,
85, 35, -86,
-85, 35, -86,
-58, -25, 109,
-83, -3, 95,
83, -3, 95,
58, -25, 109,
83, -3, 95,
85, 35, -86,
11, 114, 54,
33, 116, -38,
89, -43, -78,
-11, 114, 54,
11, 114, 54,
10, -107, -66,
-47, 97, -65,
47, 97, -65,
65, 17, -107,
58, -25, 109,
14, 75, 101,
-14, 75, 101,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:25 */
static s8 vtxnvgrp_frake_select_25[]={
-15, -102, 73,
7, -106, 68,
5, -105, 70,
5, -105, 70,
28, -110, 56,
97, -41, 69,
-2, -119, -43,
49, -69, -94,
-56, -113, -7,
-56, -113, -7,
-31, -40, -116,
-17, -123, -25,
-17, -123, -25,
-31, -40, -116,
-6, -123, -26,
-6, -123, -26,
-101, -26, -71,
-56, -111, -24,
-56, -111, -24,
-122, -32, -7,
-74, -86, 55,
-2, -119, -43,
88, -50, 76,
57, -109, 26,
86, -84, -39,
23, -113, -51,
49, -69, -94,
49, -69, -94,
92, -49, -72,
-31, -40, -116,
-31, -40, -116,
-109, -20, -61,
-101, -26, -71,
-101, -26, -71,
-60, -100, -50,
-122, -32, -7,
-122, -32, -7,
-60, -100, -50,
-74, -86, 55,
-74, -86, 55,
-78, -95, -28,
-3, -126, 7,
-3, -126, 7,
31, -116, -38,
57, -109, 26,
57, -109, 26,
23, -113, -51,
86, -84, -39,
10, 126, -5,
-80, 97, 2,
-16, 124, -17,
80, -21, -95,
91, 2, -88,
115, -48, -19,
126, -6, -6,
94, -48, 69,
97, -41, 69,
97, -41, 69,
94, -48, 69,
5, -105, 70,
5, -105, 70,
-67, -5, 107,
-67, -2, 107,
-67, -2, 107,
-67, -5, 107,
-109, 56, 28,
-125, 14, 11,
-105, 51, -49,
-108, 31, -57,
-108, 31, -57,
-22, 33, -120,
-28, 15, -122,
-28, 15, -122,
-22, 33, -120,
80, -21, -95,
91, 2, -88,
106, 64, -23,
126, -6, -6,
126, -6, -6,
106, 64, -23,
118, 40, 21,
-82, 88, 39,
-80, 97, 2,
-109, 56, 28,
-109, 56, 28,
-80, 97, 2,
-105, 51, -49,
-105, 51, -49,
-10, 94, -83,
-22, 33, -120,
-22, 33, -120,
-10, 94, -83,
91, 2, -88,
71, 94, -45,
-10, 94, -83,
10, 126, -5,
57, -109, 26,
86, -84, -39,
-2, -119, -43,
-74, -86, 55,
-65, -19, 107,
-56, -111, -24,
-3, -126, 7,
57, -109, 26,
-74, -86, 55,
57, -109, 26,
24, -42, 117,
-74, -86, 55,
-15, -102, 73,
65, -97, 47,
-56, -111, -24,
-56, -111, -24,
-110, 1, -63,
-125, 14, 11,
-125, 14, 11,
-71, -45, 94,
-67, -2, 107,
-67, -2, 107,
65, -97, 47,
-15, -102, 73,
65, -97, 47,
-43, -113, -38,
44, -39, -112,
44, -39, -112,
-43, -113, -38,
-110, 1, -63,
-110, 1, -63,
-43, -113, -38,
-71, -45, 94,
-71, -45, 94,
-43, -113, -38,
65, -97, 47,
-2, -119, -43,
-72, -76, 70,
28, -110, 56,
28, -110, 56,
-72, -76, 70,
97, -41, 69,
97, -41, 69,
80, -76, 60,
115, -48, -19,
115, -48, -19,
65, -48, -97,
-2, -119, -43,
-93, 0, -86,
-31, -115, -43,
-72, -76, 70,
-72, -76, 70,
-31, -115, -43,
80, -76, 60,
80, -76, 60,
-31, -115, -43,
65, -48, -97,
65, -48, -97,
-31, -115, -43,
-93, 0, -86,
-56, -113, -7,
-61, -69, 87,
-2, -119, -43,
-2, -119, -43,
-61, -69, 87,
115, -48, -19,
115, -48, -19,
89, -86, 27,
80, -21, -95,
80, -21, -95,
-36, -17, -120,
-56, -113, -7,
-122, 21, 24,
-53, -108, -38,
-61, -69, 87,
-61, -69, 87,
-53, -108, -38,
89, -86, 27,
89, -86, 27,
-53, -108, -38,
-36, -17, -120,
-36, -17, -120,
-53, -108, -38,
-122, 21, 24,
-108, 31, -57,
-95, -52, 64,
-125, 14, 11,
-125, 14, 11,
63, -91, 61,
-56, -111, -24,
-56, -111, -24,
63, -91, 61,
-6, -123, -26,
-6, -123, -26,
-10, -24, -124,
-108, 31, -57,
-10, -24, -124,
-20, -115, -49,
-95, -52, 64,
-95, -52, 64,
-20, -115, -49,
63, -91, 61,
63, -91, 61,
-20, -115, -49,
118, -45, -9,
118, -45, -9,
-20, -115, -49,
-10, -24, -124,
-17, -123, -25,
53, -64, 95,
-56, -113, -7,
-56, -113, -7,
53, -64, 95,
80, -21, -95,
80, -21, -95,
-75, -13, -101,
-28, 15, -122,
-28, 15, -122,
-75, -13, -101,
-17, -123, -25,
-109, -34, 54,
-26, -118, 38,
53, -64, 95,
53, -64, 95,
-26, -118, 38,
100, -41, -64,
100, -41, -64,
-26, -118, 38,
-75, -13, -101,
-75, -13, -101,
-26, -118, 38,
-109, -34, 54,
-6, -123, -26,
-30, -44, 114,
-17, -123, -25,
-17, -123, -25,
22, -34, -120,
-28, 15, -122,
-28, 15, -122,
22, -34, -120,
-108, 31, -57,
-108, 31, -57,
-30, -44, 114,
-6, -123, -26,
-30, -44, 114,
-11, -123, 26,
95, -82, 17,
95, -82, 17,
-11, -123, 26,
22, -34, -120,
22, -34, -120,
-11, -123, 26,
-126, 4, -13,
-126, 4, -13,
-11, -123, 26,
-30, -44, 114,
21, 99, 75,
30, 98, 74,
-82, 88, 39,
118, 40, 21,
30, 98, 74,
21, 99, 75,
88, -50, 76,
-2, -119, -43,
28, -110, 56,
-65, -19, 107,
-15, -102, 73,
-56, -111, -24,
-65, -19, 107,
7, -106, 68,
-15, -102, 73,
88, -50, 76,
28, -110, 56,
7, -106, 68,
-65, -19, 107,
24, -42, 117,
7, -106, 68,
118, 40, 21,
94, -48, 69,
126, -6, -6,
-109, 56, 28,
-67, -5, 107,
-82, 88, 39,
97, -41, 69,
115, -48, -19,
126, -6, -6,
-109, 56, 28,
-125, 14, 11,
-67, -2, 107,
-25, 76, 97,
-29, 14, 122,
34, 69, 100,
78, -12, 99,
31, 67, 102,
24, 7, 124,
10, 126, -5,
30, 98, 74,
54, 110, -32,
10, 126, -5,
54, 110, -32,
106, 64, -23,
10, 126, -5,
106, 64, -23,
71, 94, -45,
-16, 124, -17,
30, 98, 74,
10, 126, -5,
10, 126, -5,
-46, 116, -22,
-80, 97, 2,
10, 126, -5,
-10, 94, -83,
-46, 116, -22,
21, 99, 75,
38, -10, 120,
30, -38, 117,
30, -38, 117,
-43, -8, 119,
-67, -5, 107,
-67, -5, 107,
-50, 82, 81,
-82, 88, 39,
-82, 88, 39,
51, 79, 84,
21, 99, 75,
94, -48, 69,
77, -25, 97,
30, -38, 117,
30, -38, 117,
6, -7, 126,
21, 99, 75,
21, 99, 75,
17, 84, 93,
118, 40, 21,
118, 40, 21,
102, 56, 49,
94, -48, 69,
102, 56, 49,
77, -25, 97,
94, -48, 69,
17, 84, 93,
102, 56, 49,
118, 40, 21,
6, -7, 126,
17, 84, 93,
21, 99, 75,
77, -25, 97,
6, -7, 126,
30, -38, 117,
-82, 88, 39,
-50, 82, 81,
51, 79, 84,
-67, -5, 107,
-43, -8, 119,
-50, 82, 81,
30, -38, 117,
38, -10, 120,
-43, -8, 119,
21, 99, 75,
51, 79, 84,
38, -10, 120,
118, 40, 21,
54, 110, -32,
30, 98, 74,
30, 98, 74,
-16, 124, -17,
-82, 88, 39,
-108, 31, -57,
-126, 4, -13,
-30, -44, 114,
22, -34, -120,
-126, 4, -13,
-108, 31, -57,
-17, -123, -25,
95, -82, 17,
22, -34, -120,
-30, -44, 114,
95, -82, 17,
-17, -123, -25,
-75, -13, -101,
-109, -34, 54,
-17, -123, -25,
80, -21, -95,
100, -41, -64,
-75, -13, -101,
53, -64, 95,
100, -41, -64,
80, -21, -95,
-17, -123, -25,
-109, -34, 54,
53, -64, 95,
-6, -123, -26,
118, -45, -9,
-10, -24, -124,
63, -91, 61,
118, -45, -9,
-6, -123, -26,
-125, 14, 11,
-95, -52, 64,
63, -91, 61,
-108, 31, -57,
-10, -24, -124,
-95, -52, 64,
-36, -17, -120,
-122, 21, 24,
-56, -113, -7,
89, -86, 27,
-36, -17, -120,
80, -21, -95,
-61, -69, 87,
89, -86, 27,
115, -48, -19,
-56, -113, -7,
-122, 21, 24,
-61, -69, 87,
65, -48, -97,
-93, 0, -86,
-2, -119, -43,
80, -76, 60,
65, -48, -97,
115, -48, -19,
-72, -76, 70,
80, -76, 60,
97, -41, 69,
-2, -119, -43,
-93, 0, -86,
-72, -76, 70,
-67, -2, 107,
-71, -45, 94,
65, -97, 47,
-125, 14, 11,
-110, 1, -63,
-71, -45, 94,
-56, -111, -24,
44, -39, -112,
-110, 1, -63,
65, -97, 47,
44, -39, -112,
-56, -111, -24,
24, -42, 117,
-65, -19, 107,
-74, -86, 55,
-10, 94, -83,
71, 94, -45,
91, 2, -88,
-105, 51, -49,
-46, 116, -22,
-10, 94, -83,
-80, 97, 2,
-46, 116, -22,
-105, 51, -49,
-82, 88, 39,
-16, 124, -17,
-80, 97, 2,
106, 64, -23,
54, 110, -32,
118, 40, 21,
91, 2, -88,
71, 94, -45,
106, 64, -23,
-22, 33, -120,
91, 2, -88,
80, -21, -95,
-108, 31, -57,
-105, 51, -49,
-22, 33, -120,
-125, 14, 11,
-109, 56, 28,
-105, 51, -49,
5, -105, 70,
30, -38, 117,
-67, -5, 107,
94, -48, 69,
30, -38, 117,
5, -105, 70,
91, 2, -88,
126, -6, -6,
115, -48, -19,
23, -113, -51,
31, -116, -38,
-78, -95, -28,
31, -116, -38,
-3, -126, 7,
-78, -95, -28,
23, -113, -51,
-78, -95, -28,
-60, -100, -50,
57, -109, 26,
31, -116, -38,
23, -113, -51,
-60, -100, -50,
-78, -95, -28,
-74, -86, 55,
-101, -26, -71,
-109, -20, -61,
-60, -100, -50,
-31, -40, -116,
-2, -37, -121,
-109, -20, -61,
92, -49, -72,
-2, -37, -121,
-31, -40, -116,
23, -113, -51,
92, -49, -72,
49, -69, -94,
-101, -26, -71,
-122, -32, -7,
-56, -111, -24,
-31, -40, -116,
-101, -26, -71,
-6, -123, -26,
-56, -113, -7,
49, -69, -94,
-31, -40, -116,
-2, -119, -43,
86, -84, -39,
49, -69, -94,
5, -105, 70,
7, -106, 68,
28, -110, 56,
5, -105, 70,
-67, -2, 107,
-15, -102, 73,
24, -42, 117,
88, -50, 76,
7, -106, 68,
6, -7, 126,
82, 51, 81,
17, 84, 93,
17, 84, 93,
24, 7, 124,
102, 56, 49,
102, 56, 49,
24, 7, 124,
77, -25, 97,
77, -25, 97,
82, 51, 81,
6, -7, 126,
51, 79, 84,
-25, 76, 97,
38, -10, 120,
38, -10, 120,
-25, 76, 97,
-43, -8, 119,
-43, -8, 119,
33, 4, 122,
-50, 82, 81,
-50, 82, 81,
33, 4, 122,
51, 79, 84,
33, 4, 122,
-29, 14, 122,
51, 79, 84,
-43, -8, 119,
34, 69, 100,
33, 4, 122,
-25, 76, 97,
34, 69, 100,
-43, -8, 119,
51, 79, 84,
-29, 14, 122,
-25, 76, 97,
77, -25, 97,
31, 67, 102,
82, 51, 81,
24, 7, 124,
31, 67, 102,
77, -25, 97,
17, 84, 93,
78, -12, 99,
24, 7, 124,
82, 51, 81,
78, -12, 99,
17, 84, 93,
78, -12, 99,
82, 51, 81,
31, 67, 102,
-29, 14, 122,
33, 4, 122,
34, 69, 100,
57, -109, 26,
88, -50, 76,
24, -42, 117,
58, -19, 110,
-14, 79, 97,
-58, -19, 110,
94, -7, -84,
-94, -7, -84,
85, 31, -88,
15, 80, 97,
-19, 66, 106,
-14, 79, 97,
-14, 79, 97,
-35, 113, -45,
-48, 94, -70,
-48, 94, -70,
35, 113, -45,
48, 94, -70,
48, 94, -70,
35, 113, -45,
15, 80, 97,
83, 1, 95,
94, -7, -84,
85, 31, -88,
-83, 1, 95,
83, -69, 66,
83, 1, 95,
-85, 31, -88,
-94, -7, -84,
-83, 1, 95,
-65, 12, -108,
-48, 94, -70,
65, 12, -108,
-94, -7, -84,
-83, -69, 66,
-83, 1, 95,
-83, 1, 95,
-83, -69, 66,
83, -69, 66,
83, 1, 95,
83, -69, 66,
94, -7, -84,
35, 113, -45,
19, 66, 106,
15, 80, 97,
-48, 94, -70,
-35, 113, -45,
35, 113, -45,
-14, 79, 97,
-19, 66, 106,
-35, 113, -45,
15, 80, 97,
19, 66, 106,
-19, 66, 106,
-94, -7, -84,
-85, 31, -88,
85, 31, -88,
-19, 66, 106,
23, -113, -51,
-60, -100, -50,
19, 66, 106,
92, -49, -72,
23, -113, -51,
35, 113, -45,
-2, -37, -121,
92, -49, -72,
-35, 113, -45,
-109, -20, -61,
-2, -37, -121,
-19, 66, 106,
-60, -100, -50,
-109, -20, -61,
35, 113, -45,
-35, 113, -45,
-2, -37, -121,
-35, 113, -45,
-19, 66, 106,
-109, -20, -61,
58, -19, 110,
85, 31, -88,
65, 12, -108,
-58, -19, 110,
83, 1, 95,
58, -19, 110,
65, 12, -108,
-85, 31, -88,
-65, 12, -108,
-65, 12, -108,
-85, 31, -88,
-58, -19, 110,
-99, -27, 74,
93, -40, 76,
-50, 72, 91,
42, -69, -97,
-99, 8, -78,
91, -10, -87,
42, -105, 56,
42, -69, -97,
93, -40, 76,
-99, 8, -78,
-50, 72, 91,
-68, 102, -30,
-99, 8, -78,
-99, -27, 74,
-50, 72, 91,
42, -69, -97,
91, -10, -87,
93, -40, 76,
-99, 8, -78,
-68, 102, -30,
91, -10, -87,
-99, -27, 74,
42, -105, 56,
93, -40, 76,
-50, 72, 91,
-58, -19, 110,
-14, 79, 97,
93, -40, 76,
-65, 12, -108,
-58, -19, 110,
91, -10, -87,
-68, 102, -30,
-65, 12, -108,
-68, 102, -30,
-14, 79, 97,
-48, 94, -70,
50, 72, 91,
-93, -40, 76,
99, -27, 74,
-91, -10, -87,
99, 8, -78,
-42, -69, -97,
-93, -40, 76,
-42, -69, -97,
-42, -105, 56,
67, 102, -30,
50, 72, 91,
99, 8, -78,
50, 72, 91,
99, -27, 74,
99, 8, -78,
-93, -40, 76,
-91, -10, -87,
-42, -69, -97,
-91, -10, -87,
67, 102, -30,
99, 8, -78,
-93, -40, 76,
-42, -105, 56,
99, -27, 74,
50, 72, 91,
48, 94, -70,
15, 80, 97,
67, 102, -30,
65, 12, -108,
48, 94, -70,
-91, -10, -87,
-93, -40, 76,
65, 12, -108,
-93, -40, 76,
50, 72, 91,
58, -19, 110,
67, 102, -30,
48, 94, -70,
50, 72, 91,
-14, 79, 97,
-68, 102, -30,
-50, 72, 91,
11, 75, 101,
-43, -103, 58,
118, 5, 46,
100, -3, -77,
53, -32, -110,
-100, -4, -77,
-100, -4, -77,
118, 5, 46,
100, -3, -77,
-100, -4, -77,
11, 75, 101,
118, 5, 46,
-53, -32, -110,
-43, -103, 58,
-94, -7, -84,
-43, -103, 58,
83, -69, 66,
-83, -69, 66,
39, -107, 54,
94, -7, -84,
83, -69, 66,
53, -32, -110,
-94, -7, -84,
94, -7, -84,
-78, -38, 92,
72, -43, 94,
-91, 68, 55,
73, -92, -47,
-91, 3, -87,
91, 16, -86,
72, -43, 94,
73, -92, -47,
84, 81, 47,
-78, -87, -48,
-91, 68, 55,
-91, 3, -87,
-78, -87, -48,
-78, -38, 92,
-91, 68, 55,
73, -92, -47,
91, 16, -86,
84, 81, 47,
73, -92, -47,
-78, -87, -48,
-91, 3, -87,
72, -43, 94,
84, 81, 47,
-91, 68, 55,
-91, 68, 55,
84, 81, 47,
-43, -103, 58,
84, 81, 47,
91, 16, -86,
118, 5, 46,
91, 16, -86,
-53, -32, -110,
100, -3, -77,
-91, 3, -87,
-43, -103, 58,
-53, -32, -110,
88, 70, 57,
-73, -41, 94,
78, -38, 92,
-90, 15, -87,
91, 3, -87,
-73, -92, -47,
-80, 92, 32,
-73, -92, -47,
-73, -41, 94,
91, 3, -87,
88, 70, 57,
78, -87, -48,
88, 70, 57,
78, -38, 92,
78, -87, -48,
-80, 92, 32,
-90, 15, -87,
-73, -92, -47,
91, 3, -87,
78, -87, -48,
-73, -92, -47,
88, 70, 57,
-80, 92, 32,
-73, -41, 94,
88, 70, 57,
91, 3, -87,
39, -107, 54,
-90, 15, -87,
-100, -4, -77,
53, -32, -110,
-90, 15, -87,
11, 75, 101,
-100, -4, -77,
-80, 92, 32,
39, -107, 54,
11, 75, 101,
-42, -69, -97,
38, -105, -59,
-42, -105, 56,
-42, -105, 56,
93, -83, 17,
99, -27, 74,
99, -27, 74,
93, -83, 17,
99, 8, -78,
99, 8, -78,
93, -66, -53,
-42, -69, -97,
42, -105, 56,
-38, -121, 5,
42, -69, -97,
42, -69, -97,
-93, -66, -53,
-99, 8, -78,
-99, 8, -78,
-93, -66, -53,
-99, -27, 74,
-99, -27, 74,
-93, -83, 17,
42, -105, 56,
-74, -79, 64,
80, 35, 91,
38, -121, 5,
80, 35, 91,
93, -66, -53,
93, -83, 17,
80, 72, -65,
38, -105, -59,
93, -66, -53,
-74, -41, -93,
-74, -79, 64,
38, -105, -59,
-80, 35, 91,
-38, -121, 5,
-93, -83, 17,
74, -41, -93,
-93, -66, -53,
-38, -105, -59,
-80, 72, -65,
-80, 35, 91,
-93, -66, -53,
-38, -105, -59,
-38, -121, 5,
74, -41, -93,
-99, -14, 77,
71, -62, 84,
-57, 34, 107,
33, -62, -105,
-92, 26, -82,
81, -11, -96,
31, -109, 55,
33, -62, -105,
71, -62, 84,
-92, 26, -82,
-57, 34, 107,
-52, 90, -71,
-92, 26, -82,
-99, -14, 77,
-57, 34, 107,
33, -62, -105,
81, -11, -96,
71, -62, 84,
-92, 26, -82,
-52, 90, -71,
81, -11, -96,
-99, -14, 77,
31, -109, 55,
71, -62, 84,
33, -62, -105,
-72, -102, -17,
-92, 26, -82,
-92, 26, -82,
-72, -102, -17,
-99, -14, 77,
-99, -14, 77,
-72, -102, -17,
31, -109, 55,
31, -109, 55,
-72, -102, -17,
33, -62, -105,
81, -11, -96,
-80, 72, -65,
74, -41, -93,
-52, 90, -71,
-57, 34, 107,
-80, 72, -65,
-57, 34, 107,
71, -62, 84,
-80, 35, 91,
71, -62, 84,
81, -11, -96,
74, -79, 64,
73, -92, -47,
-25, -123, 15,
-78, -87, -48,
-78, -87, -48,
-25, -123, 15,
-78, -38, 92,
-78, -38, 92,
-33, -104, 64,
72, -43, 94,
72, -43, 94,
35, -101, 67,
73, -92, -47,
-73, -41, 94,
-35, -101, 67,
78, -38, 92,
78, -38, 92,
25, -123, 15,
78, -87, -48,
78, -87, -48,
25, -123, 15,
-73, -92, -47,
-73, -92, -47,
-35, -101, 67,
-73, -41, 94,
89, 29, 84,
82, 17, 95,
-89, 29, 84,
-89, -29, -84,
-88, -54, -72,
89, -29, -84,
-84, 20, 92,
-88, -54, -72,
-89, 29, 84,
85, -60, -72,
82, 17, 95,
89, -29, -84,
89, 29, 84,
49, 112, 31,
89, -29, -84,
89, -29, -84,
73, 14, -102,
-89, -29, -84,
-89, -29, -84,
-97, 77, 22,
-89, 29, 84,
-89, 29, 84,
-97, 77, 22,
89, 29, 84,
-97, 77, 22,
49, 112, 31,
89, 29, 84,
-89, -29, -84,
-89, -9, -89,
-97, 77, 22,
73, 14, -102,
-89, -9, -89,
-89, -29, -84,
49, 112, 31,
73, 14, -102,
89, -29, -84,
82, 17, 95,
89, 29, 84,
89, -29, -84,
-88, -54, -72,
-89, -29, -84,
-89, 29, 84,
-88, -54, -72,
85, -60, -72,
89, -29, -84,
82, 17, 95,
-84, 20, 92,
-89, 29, 84,
-88, -54, -72,
-35, -101, 67,
-27, -123, 13,
-84, 20, 92,
82, 17, 95,
-35, -101, 67,
82, 17, 95,
85, -60, -72,
33, -104, 64,
85, -60, -72,
-27, -123, 13,
25, -123, 15,
89, 29, 84,
-82, 17, 95,
-89, 29, 84,
-89, -29, -84,
88, -54, -72,
89, -29, -84,
89, 29, 84,
88, -54, -72,
84, 20, 92,
-89, -29, -84,
-82, 17, 95,
-85, -60, -72,
-89, -29, -84,
-49, 112, 31,
-89, 29, 84,
89, -29, -84,
-73, 14, -102,
-89, -29, -84,
89, 29, 84,
97, 77, 22,
89, -29, -84,
-89, 29, 84,
97, 77, 22,
89, 29, 84,
-89, 29, 84,
-49, 112, 31,
97, 77, 22,
97, 77, 22,
89, -9, -89,
89, -29, -84,
89, -29, -84,
89, -9, -89,
-73, 14, -102,
-89, -29, -84,
-73, 14, -102,
-49, 112, 31,
-89, -29, -84,
-89, 29, 84,
-82, 17, 95,
89, 29, 84,
89, -29, -84,
88, -54, -72,
-89, -29, -84,
-85, -60, -72,
88, -54, -72,
89, 29, 84,
84, 20, 92,
-82, 17, 95,
-82, 17, 95,
35, -101, 67,
-33, -104, 64,
84, 20, 92,
88, -54, -72,
35, -101, 67,
88, -54, -72,
-85, -60, -72,
27, -123, 13,
-85, -60, -72,
-33, -104, 64,
-25, -123, 15,
86, -83, -40,
-53, -96, -62,
89, -3, -90,
-65, 109, -1,
95, 81, -17,
-91, 70, -53,
99, -68, 39,
77, -50, 87,
-93, -85, -2,
77, -50, 87,
95, 81, -17,
61, 109, 18,
-93, -85, -2,
-101, -51, 56,
-91, 70, -53,
61, 109, 18,
-18, 20, 124,
77, -50, 87,
77, -50, 87,
-18, 20, 124,
-101, -51, 56,
-101, -51, 56,
-18, 20, 124,
-65, 109, -1,
-65, 109, -1,
-18, 20, 124,
61, 109, 18,
99, -68, 39,
86, -83, -40,
95, 81, -17,
-93, -85, -2,
-53, -96, -62,
99, -68, 39,
-91, 70, -53,
-56, -7, -113,
-93, -85, -2,
-56, -7, -113,
-53, -96, -62,
-93, -85, -2,
-53, -96, -62,
86, -83, -40,
99, -68, 39,
86, -83, -40,
89, -3, -90,
95, 81, -17,
-101, -51, 56,
-65, 109, -1,
-91, 70, -53,
77, -50, 87,
99, -68, 39,
95, 81, -17,
77, -50, 87,
-101, -51, 56,
-93, -85, -2,
-65, 109, -1,
61, 109, 18,
95, 81, -17,
-53, -96, -62,
-56, -7, -113,
89, -3, -90,
95, 81, -17,
89, -3, -90,
97, 77, 22,
89, -3, -90,
-56, -7, -113,
89, -9, -89,
-56, -7, -113,
-91, 70, -53,
-73, 14, -102,
-91, 70, -53,
95, 81, -17,
-49, 112, 31,
-89, -3, -90,
53, -96, -62,
-86, -83, -40,
91, 70, -53,
-95, 81, -17,
65, 109, -1,
93, -85, -2,
-77, -50, 87,
-99, -68, 39,
-61, 109, 18,
-95, 81, -17,
-77, -50, 87,
91, 70, -53,
101, -51, 56,
93, -85, -2,
-77, -50, 87,
18, 20, 124,
-61, 109, 18,
101, -51, 56,
18, 20, 124,
-77, -50, 87,
65, 109, -1,
18, 20, 124,
101, -51, 56,
-61, 109, 18,
18, 20, 124,
65, 109, -1,
-95, 81, -17,
-86, -83, -40,
-99, -68, 39,
-99, -68, 39,
53, -96, -62,
93, -85, -2,
93, -85, -2,
56, -7, -113,
91, 70, -53,
93, -85, -2,
53, -96, -62,
56, -7, -113,
-99, -68, 39,
-86, -83, -40,
53, -96, -62,
-95, 81, -17,
-89, -3, -90,
-86, -83, -40,
91, 70, -53,
65, 109, -1,
101, -51, 56,
-95, 81, -17,
-99, -68, 39,
-77, -50, 87,
93, -85, -2,
101, -51, 56,
-77, -50, 87,
-95, 81, -17,
-61, 109, 18,
65, 109, -1,
-89, -3, -90,
56, -7, -113,
53, -96, -62,
-95, 81, -17,
49, 112, 31,
-97, 77, 22,
91, 70, -53,
73, 14, -102,
49, 112, 31,
56, -7, -113,
-89, -9, -89,
73, 14, -102,
-89, -3, -90,
-97, 77, 22,
-89, -9, -89,
53, -32, -110,
91, 3, -87,
-90, 15, -87,
91, 16, -86,
-91, 3, -87,
-53, -32, -110,
80, 72, -65,
-81, -11, -96,
-74, -41, -93,
-74, -41, -93,
-71, -62, 84,
-74, -79, 64,
80, 35, 91,
52, 90, -71,
80, 72, -65,
57, 34, 107,
-71, -62, 84,
99, -14, 77,
-81, -11, -96,
92, 26, -82,
-33, -62, -105,
-71, -62, 84,
-33, -62, -105,
-31, -109, 55,
52, 90, -71,
57, 34, 107,
92, 26, -82,
57, 34, 107,
99, -14, 77,
92, 26, -82,
-71, -62, 84,
-81, -11, -96,
-33, -62, -105,
-81, -11, -96,
52, 90, -71,
92, 26, -82,
-71, -62, 84,
-31, -109, 55,
99, -14, 77,
92, 26, -82,
72, -102, -17,
-33, -62, -105,
99, -14, 77,
72, -102, -17,
92, 26, -82,
-31, -109, 55,
72, -102, -17,
99, -14, 77,
-33, -62, -105,
72, -102, -17,
-31, -109, 55,
-74, -79, 64,
-71, -62, 84,
80, 35, 91,
-71, -62, 84,
57, 34, 107,
80, 35, 91,
80, 35, 91,
57, 34, 107,
52, 90, -71,
-74, -41, -93,
-81, -11, -96,
-71, -62, 84,
80, 72, -65,
52, 90, -71,
-81, -11, -96,
-89, -3, -90,
-95, 81, -17,
-97, 77, 22,
56, -7, -113,
-89, -3, -90,
-89, -9, -89,
91, 70, -53,
56, -7, -113,
73, 14, -102,
-95, 81, -17,
91, 70, -53,
49, 112, 31,
95, 81, -17,
97, 77, 22,
-49, 112, 31,
-91, 70, -53,
-49, 112, 31,
-73, 14, -102,
-56, -7, -113,
-73, 14, -102,
89, -9, -89,
89, -3, -90,
89, -9, -89,
97, 77, 22,
-85, -60, -72,
-82, 17, 95,
-33, -104, 64,
-85, -60, -72,
-25, -123, 15,
27, -123, 13,
88, -54, -72,
27, -123, 13,
35, -101, 67,
-82, 17, 95,
84, 20, 92,
35, -101, 67,
85, -60, -72,
-88, -54, -72,
-27, -123, 13,
85, -60, -72,
25, -123, 15,
33, -104, 64,
82, 17, 95,
33, -104, 64,
-35, -101, 67,
-88, -54, -72,
-84, 20, 92,
-35, -101, 67,
-73, -92, -47,
-27, -123, 13,
-35, -101, 67,
25, -123, 15,
-27, -123, 13,
-73, -92, -47,
78, -38, 92,
33, -104, 64,
25, -123, 15,
-35, -101, 67,
33, -104, 64,
78, -38, 92,
35, -101, 67,
27, -123, 13,
73, -92, -47,
-33, -104, 64,
35, -101, 67,
72, -43, 94,
-25, -123, 15,
-33, -104, 64,
-78, -38, 92,
73, -92, -47,
27, -123, 13,
-25, -123, 15,
81, -11, -96,
74, -41, -93,
74, -79, 64,
71, -62, 84,
74, -79, 64,
-80, 35, 91,
-57, 34, 107,
-80, 35, 91,
-80, 72, -65,
81, -11, -96,
-52, 90, -71,
-80, 72, -65,
-38, -121, 5,
74, -79, 64,
74, -41, -93,
-80, 35, 91,
-93, -83, 17,
-93, -66, -53,
74, -41, -93,
-80, 72, -65,
-93, -66, -53,
-80, 35, 91,
74, -79, 64,
-38, -121, 5,
-74, -79, 64,
38, -121, 5,
38, -105, -59,
80, 72, -65,
-74, -41, -93,
38, -105, -59,
80, 35, 91,
80, 72, -65,
93, -66, -53,
80, 35, 91,
93, -83, 17,
38, -121, 5,
-93, -83, 17,
-38, -121, 5,
42, -105, 56,
-93, -66, -53,
-93, -83, 17,
-99, -27, 74,
42, -69, -97,
-38, -105, -59,
-93, -66, -53,
-38, -121, 5,
-38, -105, -59,
42, -69, -97,
93, -66, -53,
38, -105, -59,
-42, -69, -97,
93, -83, 17,
93, -66, -53,
99, 8, -78,
-42, -105, 56,
38, -121, 5,
93, -83, 17,
38, -105, -59,
38, -121, 5,
-42, -105, 56,
-80, 92, 32,
88, 70, 57,
39, -107, 54,
-90, 15, -87,
-80, 92, 32,
11, 75, 101,
91, 3, -87,
53, -32, -110,
39, -107, 54,
-91, 3, -87,
-91, 68, 55,
-43, -103, 58,
91, 16, -86,
100, -3, -77,
118, 5, 46,
84, 81, 47,
118, 5, 46,
-43, -103, 58,
53, -32, -110,
-53, -32, -110,
-94, -7, -84,
39, -107, 54,
53, -32, -110,
94, -7, -84,
-43, -103, 58,
39, -107, 54,
83, -69, 66,
-43, -103, 58,
-83, -69, 66,
-94, -7, -84,
100, -3, -77,
-53, -32, -110,
53, -32, -110,
11, 75, 101,
39, -107, 54,
-43, -103, 58,
50, 72, 91,
15, 80, 97,
58, -19, 110,
-93, -40, 76,
58, -19, 110,
65, 12, -108,
67, 102, -30,
-91, -10, -87,
65, 12, -108,
-68, 102, -30,
-48, 94, -70,
-65, 12, -108,
93, -40, 76,
91, -10, -87,
-65, 12, -108,
-50, 72, 91,
93, -40, 76,
-58, -19, 110,
-85, 31, -88,
-83, 1, 95,
-58, -19, 110,
65, 12, -108,
85, 31, -88,
-85, 31, -88,
-58, -19, 110,
-83, 1, 95,
83, 1, 95,
58, -19, 110,
83, 1, 95,
85, 31, -88,
19, 66, 106,
35, 113, -45,
92, -49, -72,
-19, 66, 106,
19, 66, 106,
23, -113, -51,
-48, 94, -70,
48, 94, -70,
65, 12, -108,
58, -19, 110,
15, 80, 97,
-14, 79, 97,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:26 */
static s8 vtxnvgrp_frake_select_26[]={
-14, -95, 82,
8, -99, 78,
6, -98, 80,
6, -98, 80,
30, -102, 68,
96, -29, 76,
5, -123, -30,
56, -74, -86,
-49, -116, 0,
-49, -116, 0,
-25, -52, -112,
-11, -125, -14,
-11, -125, -14,
-25, -52, -112,
1, -126, -14,
1, -126, -14,
-97, -40, -71,
-50, -115, -15,
-50, -115, -15,
-119, -41, -8,
-73, -84, 59,
5, -123, -30,
87, -39, 83,
61, -103, 38,
92, -82, -29,
35, -116, -35,
56, -74, -86,
56, -74, -86,
94, -54, -65,
-25, -52, -112,
-25, -52, -112,
-107, -32, -59,
-97, -40, -71,
-97, -40, -71,
-61, -105, -35,
-119, -41, -8,
-119, -41, -8,
-61, -105, -35,
-73, -84, 59,
-73, -84, 59,
-73, -100, -22,
-1, -126, 14,
-1, -126, 14,
36, -118, -27,
61, -103, 38,
61, -103, 38,
35, -116, -35,
92, -82, -29,
6, 125, -17,
-85, 93, -8,
-22, 121, -29,
86, -23, -90,
94, 0, -84,
119, -42, -12,
126, 0, -2,
94, -36, 76,
96, -29, 76,
96, -29, 76,
94, -36, 76,
6, -98, 80,
6, -98, 80,
-72, 0, 104,
-72, 2, 104,
-72, 2, 104,
-72, 0, 104,
-114, 51, 20,
-126, 7, 7,
-106, 40, -56,
-108, 19, -63,
-108, 19, -63,
-18, 22, -123,
-23, 3, -124,
-23, 3, -124,
-18, 22, -123,
86, -23, -90,
94, 0, -84,
104, 67, -26,
126, 0, -2,
126, 0, -2,
104, 67, -26,
115, 49, 19,
-88, 86, 29,
-85, 93, -8,
-114, 51, 20,
-114, 51, 20,
-85, 93, -8,
-106, 40, -56,
-106, 40, -56,
-10, 86, -92,
-18, 22, -123,
-18, 22, -123,
-10, 86, -92,
94, 0, -84,
68, 93, -51,
-10, 86, -92,
6, 125, -17,
61, -103, 38,
92, -82, -29,
5, -123, -30,
-73, -84, 59,
-68, -13, 105,
-50, -115, -15,
-1, -126, 14,
61, -103, 38,
-73, -84, 59,
61, -103, 38,
20, -30, 121,
-73, -84, 59,
-14, -95, 82,
68, -89, 58,
-50, -115, -15,
-50, -115, -15,
-107, -11, -66,
-126, 7, 7,
-126, 7, 7,
-73, -40, 95,
-72, 2, 104,
-72, 2, 104,
68, -89, 58,
-14, -95, 82,
68, -89, 58,
-34, -118, -30,
51, -45, -106,
51, -45, -106,
-34, -118, -30,
-107, -11, -66,
-107, -11, -66,
-34, -118, -30,
-73, -40, 95,
-73, -40, 95,
-34, -118, -30,
68, -89, 58,
5, -123, -30,
-71, -72, 75,
30, -102, 68,
30, -102, 68,
-71, -72, 75,
96, -29, 76,
96, -29, 76,
82, -66, 70,
119, -42, -12,
119, -42, -12,
72, -52, -90,
5, -123, -30,
-89, -12, -88,
-22, -120, -34,
-71, -72, 75,
-71, -72, 75,
-22, -120, -34,
82, -66, 70,
82, -66, 70,
-22, -120, -34,
72, -52, -90,
72, -52, -90,
-22, -120, -34,
-89, -12, -88,
-49, -116, 0,
-61, -64, 90,
5, -123, -30,
5, -123, -30,
-61, -64, 90,
119, -42, -12,
119, -42, -12,
92, -78, 38,
86, -23, -90,
86, -23, -90,
-30, -29, -119,
-49, -116, 0,
-124, 16, 19,
-44, -114, -30,
-61, -64, 90,
-61, -64, 90,
-44, -114, -30,
92, -78, 38,
92, -78, 38,
-44, -114, -30,
-30, -29, -119,
-30, -29, -119,
-44, -114, -30,
-124, 16, 19,
-108, 19, -63,
-95, -51, 66,
-126, 7, 7,
-126, 7, 7,
65, -81, 71,
-50, -115, -15,
-50, -115, -15,
65, -81, 71,
1, -126, -14,
1, -126, -14,
-5, -35, -121,
-108, 19, -63,
-5, -35, -121,
-12, -120, -39,
-95, -51, 66,
-95, -51, 66,
-12, -120, -39,
65, -81, 71,
65, -81, 71,
-12, -120, -39,
121, -38, -2,
121, -38, -2,
-12, -120, -39,
-5, -35, -121,
-11, -125, -14,
52, -52, 103,
-49, -116, 0,
-49, -116, 0,
52, -52, 103,
86, -23, -90,
86, -23, -90,
-70, -26, -102,
-23, 3, -124,
-23, 3, -124,
-70, -26, -102,
-11, -125, -14,
-109, -34, 53,
-21, -115, 47,
52, -52, 103,
52, -52, 103,
-21, -115, 47,
105, -41, -56,
105, -41, -56,
-21, -115, 47,
-70, -26, -102,
-70, -26, -102,
-21, -115, 47,
-109, -34, 53,
1, -126, -14,
-32, -36, 117,
-11, -125, -14,
-11, -125, -14,
28, -43, -115,
-23, 3, -124,
-23, 3, -124,
28, -43, -115,
-108, 19, -63,
-108, 19, -63,
-32, -36, 117,
1, -126, -14,
-32, -36, 117,
-6, -121, 37,
99, -74, 27,
99, -74, 27,
-6, -121, 37,
28, -43, -115,
28, -43, -115,
-6, -121, 37,
-125, -3, -18,
-125, -3, -18,
-6, -121, 37,
-32, -36, 117,
15, 107, 66,
22, 105, 66,
-88, 86, 29,
115, 49, 19,
22, 105, 66,
15, 107, 66,
87, -39, 83,
5, -123, -30,
30, -102, 68,
-68, -13, 105,
-14, -95, 82,
-50, -115, -15,
-68, -13, 105,
8, -99, 78,
-14, -95, 82,
87, -39, 83,
30, -102, 68,
8, -99, 78,
-68, -13, 105,
20, -30, 121,
8, -99, 78,
115, 49, 19,
94, -36, 76,
126, 0, -2,
-114, 51, 20,
-72, 0, 104,
-88, 86, 29,
96, -29, 76,
119, -42, -12,
126, 0, -2,
-114, 51, 20,
-126, 7, 7,
-72, 2, 104,
-33, 83, 89,
-36, 22, 119,
27, 79, 95,
75, 0, 102,
23, 78, 97,
18, 20, 123,
6, 125, -17,
22, 105, 66,
49, 109, -39,
6, 125, -17,
49, 109, -39,
104, 67, -26,
6, 125, -17,
104, 67, -26,
68, 93, -51,
-22, 121, -29,
22, 105, 66,
6, 125, -17,
6, 125, -17,
-50, 110, -34,
-85, 93, -8,
6, 125, -17,
-10, 86, -92,
-50, 110, -34,
15, 107, 66,
33, 2, 122,
25, -27, 121,
25, -27, 121,
-47, 0, 117,
-72, 0, 104,
-72, 0, 104,
-57, 87, 71,
-88, 86, 29,
-88, 86, 29,
44, 89, 78,
15, 107, 66,
94, -36, 76,
75, -12, 101,
25, -27, 121,
25, -27, 121,
1, 4, 126,
15, 107, 66,
15, 107, 66,
8, 93, 85,
115, 49, 19,
115, 49, 19,
97, 65, 47,
94, -36, 76,
97, 65, 47,
75, -12, 101,
94, -36, 76,
8, 93, 85,
97, 65, 47,
115, 49, 19,
1, 4, 126,
8, 93, 85,
15, 107, 66,
75, -12, 101,
1, 4, 126,
25, -27, 121,
-88, 86, 29,
-57, 87, 71,
44, 89, 78,
-72, 0, 104,
-47, 0, 117,
-57, 87, 71,
25, -27, 121,
33, 2, 122,
-47, 0, 117,
15, 107, 66,
44, 89, 78,
33, 2, 122,
115, 49, 19,
49, 109, -39,
22, 105, 66,
22, 105, 66,
-22, 121, -29,
-88, 86, 29,
-108, 19, -63,
-125, -3, -18,
-32, -36, 117,
28, -43, -115,
-125, -3, -18,
-108, 19, -63,
-11, -125, -14,
99, -74, 27,
28, -43, -115,
-32, -36, 117,
99, -74, 27,
-11, -125, -14,
-70, -26, -102,
-109, -34, 53,
-11, -125, -14,
86, -23, -90,
105, -41, -56,
-70, -26, -102,
52, -52, 103,
105, -41, -56,
86, -23, -90,
-11, -125, -14,
-109, -34, 53,
52, -52, 103,
1, -126, -14,
121, -38, -2,
-5, -35, -121,
65, -81, 71,
121, -38, -2,
1, -126, -14,
-126, 7, 7,
-95, -51, 66,
65, -81, 71,
-108, 19, -63,
-5, -35, -121,
-95, -51, 66,
-30, -29, -119,
-124, 16, 19,
-49, -116, 0,
92, -78, 38,
-30, -29, -119,
86, -23, -90,
-61, -64, 90,
92, -78, 38,
119, -42, -12,
-49, -116, 0,
-124, 16, 19,
-61, -64, 90,
72, -52, -90,
-89, -12, -88,
5, -123, -30,
82, -66, 70,
72, -52, -90,
119, -42, -12,
-71, -72, 75,
82, -66, 70,
96, -29, 76,
5, -123, -30,
-89, -12, -88,
-71, -72, 75,
-72, 2, 104,
-73, -40, 95,
68, -89, 58,
-126, 7, 7,
-107, -11, -66,
-73, -40, 95,
-50, -115, -15,
51, -45, -106,
-107, -11, -66,
68, -89, 58,
51, -45, -106,
-50, -115, -15,
20, -30, 121,
-68, -13, 105,
-73, -84, 59,
-10, 86, -92,
68, 93, -51,
94, 0, -84,
-106, 40, -56,
-50, 110, -34,
-10, 86, -92,
-85, 93, -8,
-50, 110, -34,
-106, 40, -56,
-88, 86, 29,
-22, 121, -29,
-85, 93, -8,
104, 67, -26,
49, 109, -39,
115, 49, 19,
94, 0, -84,
68, 93, -51,
104, 67, -26,
-18, 22, -123,
94, 0, -84,
86, -23, -90,
-108, 19, -63,
-106, 40, -56,
-18, 22, -123,
-126, 7, 7,
-114, 51, 20,
-106, 40, -56,
6, -98, 80,
25, -27, 121,
-72, 0, 104,
94, -36, 76,
25, -27, 121,
6, -98, 80,
94, 0, -84,
126, 0, -2,
119, -42, -12,
35, -116, -35,
36, -118, -27,
-73, -100, -22,
36, -118, -27,
-1, -126, 14,
-73, -100, -22,
35, -116, -35,
-73, -100, -22,
-61, -105, -35,
61, -103, 38,
36, -118, -27,
35, -116, -35,
-61, -105, -35,
-73, -100, -22,
-73, -84, 59,
-97, -40, -71,
-107, -32, -59,
-61, -105, -35,
-25, -52, -112,
-2, -49, -116,
-107, -32, -59,
94, -54, -65,
-2, -49, -116,
-25, -52, -112,
35, -116, -35,
94, -54, -65,
56, -74, -86,
-97, -40, -71,
-119, -41, -8,
-50, -115, -15,
-25, -52, -112,
-97, -40, -71,
1, -126, -14,
-49, -116, 0,
56, -74, -86,
-25, -52, -112,
5, -123, -30,
92, -82, -29,
56, -74, -86,
6, -98, 80,
8, -99, 78,
30, -102, 68,
6, -98, 80,
-72, 2, 104,
-14, -95, 82,
20, -30, 121,
87, -39, 83,
8, -99, 78,
1, 4, 126,
77, 62, 78,
8, 93, 85,
8, 93, 85,
18, 20, 123,
97, 65, 47,
97, 65, 47,
18, 20, 123,
75, -12, 101,
75, -12, 101,
77, 62, 78,
1, 4, 126,
44, 89, 78,
-33, 83, 89,
33, 2, 122,
33, 2, 122,
-33, 83, 89,
-47, 0, 117,
-47, 0, 117,
28, 17, 122,
-57, 87, 71,
-57, 87, 71,
28, 17, 122,
44, 89, 78,
28, 17, 122,
-36, 22, 119,
44, 89, 78,
-47, 0, 117,
27, 79, 95,
28, 17, 122,
-33, 83, 89,
27, 79, 95,
-47, 0, 117,
44, 89, 78,
-36, 22, 119,
-33, 83, 89,
75, -12, 101,
23, 78, 97,
77, 62, 78,
18, 20, 123,
23, 78, 97,
75, -12, 101,
8, 93, 85,
75, 0, 102,
18, 20, 123,
77, 62, 78,
75, 0, 102,
8, 93, 85,
75, 0, 102,
77, 62, 78,
23, 78, 97,
-36, 22, 119,
28, 17, 122,
27, 79, 95,
61, -103, 38,
87, -39, 83,
20, -30, 121,
59, -14, 111,
-14, 84, 93,
-59, -14, 111,
94, -15, -83,
-94, -15, -83,
85, 26, -89,
15, 84, 93,
-30, 46, 113,
-14, 84, 93,
-14, 84, 93,
-36, 109, -52,
-48, 90, -74,
-48, 90, -74,
36, 109, -52,
48, 90, -74,
48, 90, -74,
36, 109, -52,
15, 84, 93,
83, 5, 95,
94, -15, -83,
85, 26, -89,
-83, 5, 95,
83, -66, 69,
83, 5, 95,
-85, 26, -89,
-94, -15, -83,
-83, 5, 95,
-65, 7, -108,
-48, 90, -74,
65, 7, -108,
-94, -15, -83,
-83, -66, 69,
-83, 5, 95,
-83, 5, 95,
-83, -66, 69,
83, -66, 69,
83, 5, 95,
83, -66, 69,
94, -15, -83,
36, 109, -52,
30, 46, 113,
15, 84, 93,
-48, 90, -74,
-36, 109, -52,
36, 109, -52,
-14, 84, 93,
-30, 46, 113,
-36, 109, -52,
15, 84, 93,
30, 46, 113,
-30, 46, 113,
-94, -15, -83,
-85, 26, -89,
85, 26, -89,
-30, 46, 113,
35, -116, -35,
-61, -105, -35,
30, 46, 113,
94, -54, -65,
35, -116, -35,
36, 109, -52,
-2, -49, -116,
94, -54, -65,
-36, 109, -52,
-107, -32, -59,
-2, -49, -116,
-30, 46, 113,
-61, -105, -35,
-107, -32, -59,
36, 109, -52,
-36, 109, -52,
-2, -49, -116,
-36, 109, -52,
-30, 46, 113,
-107, -32, -59,
59, -14, 111,
85, 26, -89,
65, 7, -108,
-59, -14, 111,
83, 5, 95,
59, -14, 111,
65, 7, -108,
-85, 26, -89,
-65, 7, -108,
-65, 7, -108,
-85, 26, -89,
-59, -14, 111,
-99, -23, 75,
93, -36, 77,
-50, 77, 87,
42, -74, -94,
-99, 5, -79,
91, -14, -86,
42, -102, 61,
42, -74, -94,
93, -36, 77,
-99, 5, -79,
-50, 77, 87,
-68, 100, -35,
-99, 5, -79,
-99, -23, 75,
-50, 77, 87,
42, -74, -94,
91, -14, -86,
93, -36, 77,
-99, 5, -79,
-68, 100, -35,
91, -14, -86,
-99, -23, 75,
42, -102, 61,
93, -36, 77,
-50, 77, 87,
-59, -14, 111,
-14, 84, 93,
93, -36, 77,
-65, 7, -108,
-59, -14, 111,
91, -14, -86,
-68, 100, -35,
-65, 7, -108,
-68, 100, -35,
-14, 84, 93,
-48, 90, -74,
50, 77, 87,
-93, -36, 77,
99, -23, 75,
-91, -14, -86,
99, 5, -79,
-42, -74, -94,
-93, -36, 77,
-42, -74, -94,
-42, -102, 61,
68, 101, -35,
50, 77, 87,
99, 5, -79,
50, 77, 87,
99, -23, 75,
99, 5, -79,
-93, -36, 77,
-91, -14, -86,
-42, -74, -94,
-91, -14, -86,
68, 101, -35,
99, 5, -79,
-93, -36, 77,
-42, -102, 61,
99, -23, 75,
50, 77, 87,
48, 90, -74,
15, 84, 93,
68, 101, -35,
65, 7, -108,
48, 90, -74,
-91, -14, -86,
-93, -36, 77,
65, 7, -108,
-93, -36, 77,
50, 77, 87,
59, -14, 111,
68, 101, -35,
48, 90, -74,
50, 77, 87,
-14, 84, 93,
-68, 100, -35,
-50, 77, 87,
-108, 32, 57,
-39, -104, 60,
118, 1, 46,
102, -4, -75,
51, -34, -110,
-102, -5, -74,
-102, -5, -74,
118, 1, 46,
102, -4, -75,
-102, -5, -74,
-108, 32, 57,
118, 1, 46,
-51, -34, -110,
-39, -104, 60,
-94, -15, -83,
-39, -104, 60,
83, -66, 69,
-83, -66, 69,
36, -107, 57,
94, -15, -83,
83, -66, 69,
51, -34, -110,
-94, -15, -83,
94, -15, -83,
-78, -45, 89,
72, -49, 91,
-91, 63, 60,
73, -88, -54,
-91, 11, -87,
90, 25, -85,
72, -49, 91,
73, -88, -54,
84, 78, 53,
-78, -83, -54,
-91, 63, 60,
-91, 11, -87,
-78, -83, -54,
-78, -45, 89,
-91, 63, 60,
73, -88, -54,
90, 25, -85,
84, 78, 53,
73, -88, -54,
-78, -83, -54,
-91, 11, -87,
72, -49, 91,
84, 78, 53,
-91, 63, 60,
-91, 63, 60,
84, 78, 53,
-39, -104, 60,
84, 78, 53,
90, 25, -85,
118, 1, 46,
90, 25, -85,
-51, -34, -110,
102, -4, -75,
-91, 11, -87,
-39, -104, 60,
-51, -34, -110,
89, 65, 62,
-73, -48, 91,
78, -45, 89,
-90, 25, -85,
91, 11, -87,
-73, -88, -54,
-82, 86, 42,
-73, -88, -54,
-73, -48, 91,
91, 11, -87,
89, 65, 62,
78, -83, -54,
89, 65, 62,
78, -45, 89,
78, -83, -54,
-82, 86, 42,
-90, 25, -85,
-73, -88, -54,
91, 11, -87,
78, -83, -54,
-73, -88, -54,
89, 65, 62,
-82, 86, 42,
-73, -48, 91,
89, 65, 62,
91, 11, -87,
36, -107, 57,
-90, 25, -85,
-102, -5, -74,
51, -34, -110,
-90, 25, -85,
-108, 32, 57,
-102, -5, -74,
-82, 86, 42,
36, -107, 57,
-108, 32, 57,
-42, -74, -94,
38, -108, -54,
-42, -102, 61,
-42, -102, 61,
94, -82, 21,
99, -23, 75,
99, -23, 75,
94, -82, 21,
99, 5, -79,
99, 5, -79,
94, -69, -49,
-42, -74, -94,
42, -102, 61,
-38, -120, 11,
42, -74, -94,
42, -74, -94,
-94, -69, -49,
-99, 5, -79,
-99, 5, -79,
-94, -69, -49,
-99, -23, 75,
-99, -23, 75,
-94, -82, 21,
42, -102, 61,
-75, -76, 68,
80, 39, 89,
38, -120, 11,
80, 39, 89,
94, -69, -49,
94, -82, 21,
80, 69, -69,
38, -108, -54,
94, -69, -49,
-75, -46, -91,
-75, -76, 68,
38, -108, -54,
-80, 39, 89,
-38, -120, 11,
-94, -82, 21,
75, -46, -91,
-94, -69, -49,
-38, -108, -54,
-80, 69, -69,
-80, 39, 89,
-94, -69, -49,
-38, -108, -54,
-38, -120, 11,
75, -46, -91,
-99, -10, 77,
71, -58, 87,
-57, 39, 106,
33, -67, -102,
-92, 22, -83,
81, -16, -95,
31, -107, 60,
33, -67, -102,
71, -58, 87,
-92, 22, -83,
-57, 39, 106,
-52, 86, -75,
-92, 22, -83,
-99, -10, 77,
-57, 39, 106,
33, -67, -102,
81, -16, -95,
71, -58, 87,
-92, 22, -83,
-52, 86, -75,
81, -16, -95,
-99, -10, 77,
31, -107, 60,
71, -58, 87,
33, -67, -102,
-72, -103, -12,
-92, 22, -83,
-92, 22, -83,
-72, -103, -12,
-99, -10, 77,
-99, -10, 77,
-72, -103, -12,
31, -107, 60,
31, -107, 60,
-72, -103, -12,
33, -67, -102,
81, -16, -95,
-80, 69, -69,
75, -46, -91,
-52, 86, -75,
-57, 39, 106,
-80, 69, -69,
-57, 39, 106,
71, -58, 87,
-80, 39, 89,
71, -58, 87,
81, -16, -95,
75, -76, 68,
73, -88, -54,
-25, -124, 6,
-78, -83, -54,
-78, -83, -54,
-25, -124, 6,
-78, -45, 89,
-78, -45, 89,
-33, -108, 57,
72, -49, 91,
72, -49, 91,
35, -106, 59,
73, -88, -54,
-73, -48, 91,
-35, -106, 59,
78, -45, 89,
78, -45, 89,
25, -124, 6,
78, -83, -54,
78, -83, -54,
25, -124, 6,
-73, -88, -54,
-73, -88, -54,
-35, -106, 59,
-73, -48, 91,
89, 23, 86,
82, 10, 96,
-89, 23, 86,
-89, -23, -86,
-88, -49, -76,
89, -23, -86,
-84, 14, 93,
-88, -49, -76,
-89, 23, 86,
85, -54, -76,
82, 10, 96,
89, -23, -86,
89, 23, 86,
49, 110, 39,
89, -23, -86,
89, -23, -86,
73, 21, -101,
-89, -23, -86,
-89, -23, -86,
-97, 75, 28,
-89, 23, 86,
-89, 23, 86,
-97, 75, 28,
89, 23, 86,
-97, 75, 28,
49, 110, 39,
89, 23, 86,
-89, -23, -86,
-89, -2, -89,
-97, 75, 28,
73, 21, -101,
-89, -2, -89,
-89, -23, -86,
49, 110, 39,
73, 21, -101,
89, -23, -86,
82, 10, 96,
89, 23, 86,
89, -23, -86,
-88, -49, -76,
-89, -23, -86,
-89, 23, 86,
-88, -49, -76,
85, -54, -76,
89, -23, -86,
82, 10, 96,
-84, 14, 93,
-89, 23, 86,
-88, -49, -76,
-35, -106, 59,
-27, -124, 4,
-84, 14, 93,
82, 10, 96,
-35, -106, 59,
82, 10, 96,
85, -54, -76,
33, -108, 57,
85, -54, -76,
-27, -124, 4,
25, -124, 6,
89, 23, 86,
-82, 10, 96,
-89, 23, 86,
-89, -23, -86,
88, -49, -76,
89, -23, -86,
89, 23, 86,
88, -49, -76,
84, 14, 93,
-89, -23, -86,
-82, 10, 96,
-85, -54, -76,
-89, -23, -86,
-49, 110, 39,
-89, 23, 86,
89, -23, -86,
-73, 21, -101,
-89, -23, -86,
89, 23, 86,
97, 75, 28,
89, -23, -86,
-89, 23, 86,
97, 75, 28,
89, 23, 86,
-89, 23, 86,
-49, 110, 39,
97, 75, 28,
97, 75, 28,
89, -2, -89,
89, -23, -86,
89, -23, -86,
89, -2, -89,
-73, 21, -101,
-89, -23, -86,
-73, 21, -101,
-49, 110, 39,
-89, -23, -86,
-89, 23, 86,
-82, 10, 96,
89, 23, 86,
89, -23, -86,
88, -49, -76,
-89, -23, -86,
-85, -54, -76,
88, -49, -76,
89, 23, 86,
84, 14, 93,
-82, 10, 96,
-82, 10, 96,
35, -106, 59,
-33, -108, 57,
84, 14, 93,
88, -49, -76,
35, -106, 59,
88, -49, -76,
-85, -54, -76,
27, -124, 4,
-85, -54, -76,
-33, -108, 57,
-25, -124, 6,
86, -80, -45,
-54, -91, -69,
89, 2, -90,
-65, 108, 6,
95, 82, -11,
-91, 73, -47,
99, -71, 34,
77, -56, 83,
-93, -85, -8,
77, -56, 83,
95, 82, -11,
62, 107, 26,
-93, -85, -8,
-101, -56, 52,
-91, 73, -47,
62, 107, 26,
-18, 11, 125,
77, -56, 83,
77, -56, 83,
-18, 11, 125,
-101, -56, 52,
-101, -56, 52,
-18, 11, 125,
-65, 108, 6,
-65, 108, 6,
-18, 11, 125,
62, 107, 26,
99, -71, 34,
86, -80, -45,
95, 82, -11,
-93, -85, -8,
-54, -91, -69,
99, -71, 34,
-91, 73, -47,
-57, 0, -113,
-93, -85, -8,
-57, 0, -113,
-54, -91, -69,
-93, -85, -8,
-54, -91, -69,
86, -80, -45,
99, -71, 34,
86, -80, -45,
89, 2, -90,
95, 82, -11,
-101, -56, 52,
-65, 108, 6,
-91, 73, -47,
77, -56, 83,
99, -71, 34,
95, 82, -11,
77, -56, 83,
-101, -56, 52,
-93, -85, -8,
-65, 108, 6,
62, 107, 26,
95, 82, -11,
-54, -91, -69,
-57, 0, -113,
89, 2, -90,
95, 82, -11,
89, 2, -90,
97, 75, 28,
89, 2, -90,
-57, 0, -113,
89, -2, -89,
-57, 0, -113,
-91, 73, -47,
-73, 21, -101,
-91, 73, -47,
95, 82, -11,
-49, 110, 39,
-89, 2, -90,
54, -91, -69,
-86, -80, -45,
91, 73, -47,
-95, 82, -11,
65, 108, 6,
93, -85, -8,
-77, -56, 83,
-99, -70, 34,
-62, 107, 26,
-95, 82, -11,
-77, -56, 83,
91, 73, -47,
101, -56, 52,
93, -85, -8,
-77, -56, 83,
18, 11, 125,
-62, 107, 26,
101, -56, 52,
18, 11, 125,
-77, -56, 83,
65, 108, 6,
18, 11, 125,
101, -56, 52,
-62, 107, 26,
18, 11, 125,
65, 108, 6,
-95, 82, -11,
-86, -80, -45,
-99, -70, 34,
-99, -70, 34,
54, -91, -69,
93, -85, -8,
93, -85, -8,
57, 0, -113,
91, 73, -47,
93, -85, -8,
54, -91, -69,
57, 0, -113,
-99, -70, 34,
-86, -80, -45,
54, -91, -69,
-95, 82, -11,
-89, 2, -90,
-86, -80, -45,
91, 73, -47,
65, 108, 6,
101, -56, 52,
-95, 82, -11,
-99, -70, 34,
-77, -56, 83,
93, -85, -8,
101, -56, 52,
-77, -56, 83,
-95, 82, -11,
-62, 107, 26,
65, 108, 6,
-89, 2, -90,
57, 0, -113,
54, -91, -69,
-95, 82, -11,
49, 110, 39,
-97, 75, 28,
91, 73, -47,
73, 21, -101,
49, 110, 39,
57, 0, -113,
-89, -2, -89,
73, 21, -101,
-89, 2, -90,
-97, 75, 28,
-89, -2, -89,
51, -34, -110,
91, 11, -87,
-90, 25, -85,
90, 25, -85,
-91, 11, -87,
-51, -34, -110,
80, 69, -69,
-81, -16, -95,
-75, -46, -91,
-75, -46, -91,
-71, -58, 87,
-75, -76, 68,
80, 39, 89,
52, 86, -75,
80, 69, -69,
57, 39, 106,
-71, -58, 87,
99, -10, 77,
-81, -16, -95,
92, 22, -83,
-33, -67, -102,
-71, -58, 87,
-33, -67, -102,
-31, -107, 60,
52, 86, -75,
57, 39, 106,
92, 22, -83,
57, 39, 106,
99, -10, 77,
92, 22, -83,
-71, -58, 87,
-81, -16, -95,
-33, -67, -102,
-81, -16, -95,
52, 86, -75,
92, 22, -83,
-71, -58, 87,
-31, -107, 60,
99, -10, 77,
92, 22, -83,
72, -103, -12,
-33, -67, -102,
99, -10, 77,
72, -103, -12,
92, 22, -83,
-31, -107, 60,
72, -103, -12,
99, -10, 77,
-33, -67, -102,
72, -103, -12,
-31, -107, 60,
-75, -76, 68,
-71, -58, 87,
80, 39, 89,
-71, -58, 87,
57, 39, 106,
80, 39, 89,
80, 39, 89,
57, 39, 106,
52, 86, -75,
-75, -46, -91,
-81, -16, -95,
-71, -58, 87,
80, 69, -69,
52, 86, -75,
-81, -16, -95,
-89, 2, -90,
-95, 82, -11,
-97, 75, 28,
57, 0, -113,
-89, 2, -90,
-89, -2, -89,
91, 73, -47,
57, 0, -113,
73, 21, -101,
-95, 82, -11,
91, 73, -47,
49, 110, 39,
95, 82, -11,
97, 75, 28,
-49, 110, 39,
-91, 73, -47,
-49, 110, 39,
-73, 21, -101,
-57, 0, -113,
-73, 21, -101,
89, -2, -89,
89, 2, -90,
89, -2, -89,
97, 75, 28,
-85, -54, -76,
-82, 10, 96,
-33, -108, 57,
-85, -54, -76,
-25, -124, 6,
27, -124, 4,
88, -49, -76,
27, -124, 4,
35, -106, 59,
-82, 10, 96,
84, 14, 93,
35, -106, 59,
85, -54, -76,
-88, -49, -76,
-27, -124, 4,
85, -54, -76,
25, -124, 6,
33, -108, 57,
82, 10, 96,
33, -108, 57,
-35, -106, 59,
-88, -49, -76,
-84, 14, 93,
-35, -106, 59,
-73, -88, -54,
-27, -124, 4,
-35, -106, 59,
25, -124, 6,
-27, -124, 4,
-73, -88, -54,
78, -45, 89,
33, -108, 57,
25, -124, 6,
-35, -106, 59,
33, -108, 57,
78, -45, 89,
35, -106, 59,
27, -124, 4,
73, -88, -54,
-33, -108, 57,
35, -106, 59,
72, -49, 91,
-25, -124, 6,
-33, -108, 57,
-78, -45, 89,
73, -88, -54,
27, -124, 4,
-25, -124, 6,
81, -16, -95,
75, -46, -91,
75, -76, 68,
71, -58, 87,
75, -76, 68,
-80, 39, 89,
-57, 39, 106,
-80, 39, 89,
-80, 69, -69,
81, -16, -95,
-52, 86, -75,
-80, 69, -69,
-38, -120, 11,
75, -76, 68,
75, -46, -91,
-80, 39, 89,
-94, -82, 21,
-94, -69, -49,
75, -46, -91,
-80, 69, -69,
-94, -69, -49,
-80, 39, 89,
75, -76, 68,
-38, -120, 11,
-75, -76, 68,
38, -120, 11,
38, -108, -54,
80, 69, -69,
-75, -46, -91,
38, -108, -54,
80, 39, 89,
80, 69, -69,
94, -69, -49,
80, 39, 89,
94, -82, 21,
38, -120, 11,
-94, -82, 21,
-38, -120, 11,
42, -102, 61,
-94, -69, -49,
-94, -82, 21,
-99, -23, 75,
42, -74, -94,
-38, -108, -54,
-94, -69, -49,
-38, -120, 11,
-38, -108, -54,
42, -74, -94,
94, -69, -49,
38, -108, -54,
-42, -74, -94,
94, -82, 21,
94, -69, -49,
99, 5, -79,
-42, -102, 61,
38, -120, 11,
94, -82, 21,
38, -108, -54,
38, -120, 11,
-42, -102, 61,
-82, 86, 42,
89, 65, 62,
36, -107, 57,
-90, 25, -85,
-82, 86, 42,
-108, 32, 57,
91, 11, -87,
51, -34, -110,
36, -107, 57,
-91, 11, -87,
-91, 63, 60,
-39, -104, 60,
90, 25, -85,
102, -4, -75,
118, 1, 46,
84, 78, 53,
118, 1, 46,
-39, -104, 60,
51, -34, -110,
-51, -34, -110,
-94, -15, -83,
36, -107, 57,
51, -34, -110,
94, -15, -83,
-39, -104, 60,
36, -107, 57,
83, -66, 69,
-39, -104, 60,
-83, -66, 69,
-94, -15, -83,
102, -4, -75,
-51, -34, -110,
51, -34, -110,
-108, 32, 57,
36, -107, 57,
-39, -104, 60,
50, 77, 87,
15, 84, 93,
59, -14, 111,
-93, -36, 77,
59, -14, 111,
65, 7, -108,
68, 101, -35,
-91, -14, -86,
65, 7, -108,
-68, 100, -35,
-48, 90, -74,
-65, 7, -108,
93, -36, 77,
91, -14, -86,
-65, 7, -108,
-50, 77, 87,
93, -36, 77,
-59, -14, 111,
-85, 26, -89,
-83, 5, 95,
-59, -14, 111,
65, 7, -108,
85, 26, -89,
-85, 26, -89,
-59, -14, 111,
-83, 5, 95,
83, 5, 95,
59, -14, 111,
83, 5, 95,
85, 26, -89,
30, 46, 113,
36, 109, -52,
94, -54, -65,
-30, 46, 113,
30, 46, 113,
35, -116, -35,
-48, 90, -74,
48, 90, -74,
65, 7, -108,
59, -14, 111,
15, 84, 93,
-14, 84, 93,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:27 */
static s8 vtxnvgrp_frake_select_27[]={
-15, -88, 89,
7, -92, 87,
6, -90, 89,
6, -90, 89,
30, -94, 79,
95, -18, 81,
13, -124, -18,
63, -77, -77,
-43, -119, 8,
-43, -119, 8,
-18, -63, -108,
-7, -126, -2,
-7, -126, -2,
-18, -63, -108,
8, -126, -2,
8, -126, -2,
-92, -52, -68,
-44, -118, -7,
-44, -118, -7,
-116, -49, -7,
-71, -82, 64,
13, -124, -18,
86, -27, 88,
65, -97, 49,
97, -79, -20,
43, -117, -20,
63, -77, -77,
63, -77, -77,
96, -57, -58,
-18, -63, -108,
-18, -63, -108,
-105, -42, -56,
-92, -52, -68,
-92, -52, -68,
-61, -109, -21,
-116, -49, -7,
-116, -49, -7,
-61, -109, -21,
-71, -82, 64,
-71, -82, 64,
-68, -106, -15,
0, -125, 21,
0, -125, 21,
41, -118, -16,
65, -97, 49,
65, -97, 49,
43, -117, -20,
97, -79, -20,
2, 123, -29,
-89, 88, -18,
-26, 117, -40,
91, -25, -84,
97, 0, -80,
121, -36, -6,
126, 7, 0,
93, -24, 82,
95, -18, 81,
95, -18, 81,
93, -24, 82,
6, -90, 89,
6, -90, 89,
-77, 2, 100,
-76, 6, 100,
-76, 6, 100,
-77, 2, 100,
-117, 45, 13,
-126, 0, 4,
-106, 29, -62,
-107, 8, -67,
-107, 8, -67,
-13, 11, -125,
-17, -7, -125,
-17, -7, -125,
-13, 11, -125,
91, -25, -84,
97, 0, -80,
101, 69, -30,
126, 7, 0,
126, 7, 0,
101, 69, -30,
112, 56, 16,
-93, 83, 21,
-89, 88, -18,
-117, 45, 13,
-117, 45, 13,
-89, 88, -18,
-106, 29, -62,
-106, 29, -62,
-8, 77, -100,
-13, 11, -125,
-13, 11, -125,
-8, 77, -100,
97, 0, -80,
65, 92, -56,
-8, 77, -100,
2, 123, -29,
65, -97, 49,
97, -79, -20,
13, -124, -18,
-71, -82, 64,
-72, -8, 104,
-44, -118, -7,
0, -125, 21,
65, -97, 49,
-71, -82, 64,
65, -97, 49,
16, -19, 124,
-71, -82, 64,
-15, -88, 89,
70, -80, 68,
-44, -118, -7,
-44, -118, -7,
-104, -22, -69,
-126, 0, 4,
-126, 0, 4,
-75, -36, 95,
-76, 6, 100,
-76, 6, 100,
70, -80, 68,
-15, -88, 89,
70, -80, 68,
-26, -122, -21,
58, -49, -100,
58, -49, -100,
-26, -122, -21,
-104, -22, -69,
-104, -22, -69,
-26, -122, -21,
-75, -36, 95,
-75, -36, 95,
-26, -122, -21,
70, -80, 68,
13, -124, -18,
-70, -69, 79,
30, -94, 79,
30, -94, 79,
-70, -69, 79,
95, -18, 81,
95, -18, 81,
82, -56, 77,
121, -36, -6,
121, -36, -6,
78, -54, -84,
13, -124, -18,
-86, -24, -89,
-14, -123, -24,
-70, -69, 79,
-70, -69, 79,
-14, -123, -24,
82, -56, 77,
82, -56, 77,
-14, -123, -24,
78, -54, -84,
78, -54, -84,
-14, -123, -24,
-86, -24, -89,
-43, -119, 8,
-62, -59, 93,
13, -124, -18,
13, -124, -18,
-62, -59, 93,
121, -36, -6,
121, -36, -6,
94, -70, 48,
91, -25, -84,
91, -25, -84,
-25, -40, -117,
-43, -119, 8,
-125, 9, 15,
-36, -119, -22,
-62, -59, 93,
-62, -59, 93,
-36, -119, -22,
94, -70, 48,
94, -70, 48,
-36, -119, -22,
-25, -40, -117,
-25, -40, -117,
-36, -119, -22,
-125, 9, 15,
-107, 8, -67,
-95, -49, 67,
-126, 0, 4,
-126, 0, 4,
66, -72, 80,
-44, -118, -7,
-44, -118, -7,
66, -72, 80,
8, -126, -2,
8, -126, -2,
0, -45, -118,
-107, 8, -67,
0, -45, -118,
-4, -123, -28,
-95, -49, 67,
-95, -49, 67,
-4, -123, -28,
66, -72, 80,
66, -72, 80,
-4, -123, -28,
123, -30, 3,
123, -30, 3,
-4, -123, -28,
0, -45, -118,
-7, -126, -2,
50, -40, 109,
-43, -119, 8,
-43, -119, 8,
50, -40, 109,
91, -25, -84,
91, -25, -84,
-65, -37, -101,
-17, -7, -125,
-17, -7, -125,
-65, -37, -101,
-7, -126, -2,
-109, -35, 53,
-17, -113, 55,
50, -40, 109,
50, -40, 109,
-17, -113, 55,
109, -40, -49,
109, -40, -49,
-17, -113, 55,
-65, -37, -101,
-65, -37, -101,
-17, -113, 55,
-109, -35, 53,
8, -126, -2,
-35, -28, 118,
-7, -126, -2,
-7, -126, -2,
34, -50, -110,
-17, -7, -125,
-17, -7, -125,
34, -50, -110,
-107, 8, -67,
-107, 8, -67,
-35, -28, 118,
8, -126, -2,
-35, -28, 118,
-2, -117, 48,
102, -65, 36,
102, -65, 36,
-2, -117, 48,
34, -50, -110,
34, -50, -110,
-2, -117, 48,
-124, -11, -23,
-124, -11, -23,
-2, -117, 48,
-35, -28, 118,
9, 113, 56,
15, 112, 57,
-93, 83, 21,
112, 56, 16,
15, 112, 57,
9, 113, 56,
86, -27, 88,
13, -124, -18,
30, -94, 79,
-72, -8, 104,
-15, -88, 89,
-44, -118, -7,
-72, -8, 104,
7, -92, 87,
-15, -88, 89,
86, -27, 88,
30, -94, 79,
7, -92, 87,
-72, -8, 104,
16, -19, 124,
7, -92, 87,
112, 56, 16,
93, -24, 82,
126, 7, 0,
-117, 45, 13,
-77, 2, 100,
-93, 83, 21,
95, -18, 81,
121, -36, -6,
126, 7, 0,
-117, 45, 13,
-126, 0, 4,
-76, 6, 100,
-41, 88, 81,
-43, 29, 115,
20, 88, 88,
71, 12, 103,
16, 87, 90,
12, 30, 122,
2, 123, -29,
15, 112, 57,
45, 108, -47,
2, 123, -29,
45, 108, -47,
101, 69, -30,
2, 123, -29,
101, 69, -30,
65, 92, -56,
-26, 117, -40,
15, 112, 57,
2, 123, -29,
2, 123, -29,
-54, 105, -45,
-89, 88, -18,
2, 123, -29,
-8, 77, -100,
-54, 105, -45,
9, 113, 56,
29, 13, 122,
20, -16, 124,
20, -16, 124,
-52, 8, 115,
-77, 2, 100,
-77, 2, 100,
-64, 90, 62,
-93, 83, 21,
-93, 83, 21,
37, 97, 72,
9, 113, 56,
93, -24, 82,
72, -1, 103,
20, -16, 124,
20, -16, 124,
-3, 15, 126,
9, 113, 56,
9, 113, 56,
0, 100, 77,
112, 56, 16,
112, 56, 16,
92, 74, 45,
93, -24, 82,
92, 74, 45,
72, -1, 103,
93, -24, 82,
0, 100, 77,
92, 74, 45,
112, 56, 16,
-3, 15, 126,
0, 100, 77,
9, 113, 56,
72, -1, 103,
-3, 15, 126,
20, -16, 124,
-93, 83, 21,
-64, 90, 62,
37, 97, 72,
-77, 2, 100,
-52, 8, 115,
-64, 90, 62,
20, -16, 124,
29, 13, 122,
-52, 8, 115,
9, 113, 56,
37, 97, 72,
29, 13, 122,
112, 56, 16,
45, 108, -47,
15, 112, 57,
15, 112, 57,
-26, 117, -40,
-93, 83, 21,
-107, 8, -67,
-124, -11, -23,
-35, -28, 118,
34, -50, -110,
-124, -11, -23,
-107, 8, -67,
-7, -126, -2,
102, -65, 36,
34, -50, -110,
-35, -28, 118,
102, -65, 36,
-7, -126, -2,
-65, -37, -101,
-109, -35, 53,
-7, -126, -2,
91, -25, -84,
109, -40, -49,
-65, -37, -101,
50, -40, 109,
109, -40, -49,
91, -25, -84,
-7, -126, -2,
-109, -35, 53,
50, -40, 109,
8, -126, -2,
123, -30, 3,
0, -45, -118,
66, -72, 80,
123, -30, 3,
8, -126, -2,
-126, 0, 4,
-95, -49, 67,
66, -72, 80,
-107, 8, -67,
0, -45, -118,
-95, -49, 67,
-25, -40, -117,
-125, 9, 15,
-43, -119, 8,
94, -70, 48,
-25, -40, -117,
91, -25, -84,
-62, -59, 93,
94, -70, 48,
121, -36, -6,
-43, -119, 8,
-125, 9, 15,
-62, -59, 93,
78, -54, -84,
-86, -24, -89,
13, -124, -18,
82, -56, 77,
78, -54, -84,
121, -36, -6,
-70, -69, 79,
82, -56, 77,
95, -18, 81,
13, -124, -18,
-86, -24, -89,
-70, -69, 79,
-76, 6, 100,
-75, -36, 95,
70, -80, 68,
-126, 0, 4,
-104, -22, -69,
-75, -36, 95,
-44, -118, -7,
58, -49, -100,
-104, -22, -69,
70, -80, 68,
58, -49, -100,
-44, -118, -7,
16, -19, 124,
-72, -8, 104,
-71, -82, 64,
-8, 77, -100,
65, 92, -56,
97, 0, -80,
-106, 29, -62,
-54, 105, -45,
-8, 77, -100,
-89, 88, -18,
-54, 105, -45,
-106, 29, -62,
-93, 83, 21,
-26, 117, -40,
-89, 88, -18,
101, 69, -30,
45, 108, -47,
112, 56, 16,
97, 0, -80,
65, 92, -56,
101, 69, -30,
-13, 11, -125,
97, 0, -80,
91, -25, -84,
-107, 8, -67,
-106, 29, -62,
-13, 11, -125,
-126, 0, 4,
-117, 45, 13,
-106, 29, -62,
6, -90, 89,
20, -16, 124,
-77, 2, 100,
93, -24, 82,
20, -16, 124,
6, -90, 89,
97, 0, -80,
126, 7, 0,
121, -36, -6,
43, -117, -20,
41, -118, -16,
-68, -106, -15,
41, -118, -16,
0, -125, 21,
-68, -106, -15,
43, -117, -20,
-68, -106, -15,
-61, -109, -21,
65, -97, 49,
41, -118, -16,
43, -117, -20,
-61, -109, -21,
-68, -106, -15,
-71, -82, 64,
-92, -52, -68,
-105, -42, -56,
-61, -109, -21,
-18, -63, -108,
-1, -60, -111,
-105, -42, -56,
96, -57, -58,
-1, -60, -111,
-18, -63, -108,
43, -117, -20,
96, -57, -58,
63, -77, -77,
-92, -52, -68,
-116, -49, -7,
-44, -118, -7,
-18, -63, -108,
-92, -52, -68,
8, -126, -2,
-43, -119, 8,
63, -77, -77,
-18, -63, -108,
13, -124, -18,
97, -79, -20,
63, -77, -77,
6, -90, 89,
7, -92, 87,
30, -94, 79,
6, -90, 89,
-76, 6, 100,
-15, -88, 89,
16, -19, 124,
86, -27, 88,
7, -92, 87,
-3, 15, 126,
73, 72, 74,
0, 100, 77,
0, 100, 77,
12, 30, 122,
92, 74, 45,
92, 74, 45,
12, 30, 122,
72, -1, 103,
72, -1, 103,
73, 72, 74,
-3, 15, 126,
37, 97, 72,
-41, 88, 81,
29, 13, 122,
29, 13, 122,
-41, 88, 81,
-52, 8, 115,
-52, 8, 115,
22, 28, 121,
-64, 90, 62,
-64, 90, 62,
22, 28, 121,
37, 97, 72,
22, 28, 121,
-43, 29, 115,
37, 97, 72,
-52, 8, 115,
20, 88, 88,
22, 28, 121,
-41, 88, 81,
20, 88, 88,
-52, 8, 115,
37, 97, 72,
-43, 29, 115,
-41, 88, 81,
72, -1, 103,
16, 87, 90,
73, 72, 74,
12, 30, 122,
16, 87, 90,
72, -1, 103,
0, 100, 77,
71, 12, 103,
12, 30, 122,
73, 72, 74,
71, 12, 103,
0, 100, 77,
71, 12, 103,
73, 72, 74,
16, 87, 90,
-43, 29, 115,
22, 28, 121,
20, 88, 88,
65, -97, 49,
86, -27, 88,
16, -19, 124,
59, -8, 111,
-15, 88, 89,
-59, -8, 111,
93, -22, -83,
-93, -22, -83,
85, 22, -90,
15, 88, 89,
-39, 45, 111,
-15, 88, 89,
-15, 88, 89,
-38, 105, -59,
-48, 86, -78,
-48, 86, -78,
38, 105, -59,
48, 86, -78,
48, 86, -78,
38, 105, -59,
15, 88, 89,
83, 10, 95,
93, -22, -83,
85, 22, -90,
-83, 10, 95,
83, -62, 72,
83, 10, 95,
-85, 22, -90,
-93, -22, -83,
-83, 10, 95,
-65, 2, -108,
-48, 86, -78,
65, 2, -108,
-93, -22, -83,
-83, -62, 72,
-83, 10, 95,
-83, 10, 95,
-83, -62, 72,
83, -62, 72,
83, 10, 95,
83, -62, 72,
93, -22, -83,
38, 105, -59,
39, 45, 111,
15, 88, 89,
-48, 86, -78,
-38, 105, -59,
38, 105, -59,
-15, 88, 89,
-39, 45, 111,
-38, 105, -59,
15, 88, 89,
39, 45, 111,
-39, 45, 111,
-93, -22, -83,
-85, 22, -90,
85, 22, -90,
-39, 45, 111,
43, -117, -20,
-61, -109, -21,
39, 45, 111,
96, -57, -58,
43, -117, -20,
38, 105, -59,
-1, -60, -111,
96, -57, -58,
-38, 105, -59,
-105, -42, -56,
-1, -60, -111,
-39, 45, 111,
-61, -109, -21,
-105, -42, -56,
38, 105, -59,
-38, 105, -59,
-1, -60, -111,
-38, 105, -59,
-39, 45, 111,
-105, -42, -56,
59, -8, 111,
85, 22, -90,
65, 2, -108,
-59, -8, 111,
83, 10, 95,
59, -8, 111,
65, 2, -108,
-85, 22, -90,
-65, 2, -108,
-65, 2, -108,
-85, 22, -90,
-59, -8, 111,
-99, -20, 76,
93, -32, 79,
-50, 81, 83,
42, -78, -90,
-99, 1, -79,
91, -17, -85,
42, -100, 65,
42, -78, -90,
93, -32, 79,
-99, 1, -79,
-50, 81, 83,
-68, 98, -40,
-99, 1, -79,
-99, -20, 76,
-50, 81, 83,
42, -78, -90,
91, -17, -85,
93, -32, 79,
-99, 1, -79,
-68, 98, -40,
91, -17, -85,
-99, -20, 76,
42, -100, 65,
93, -32, 79,
-50, 81, 83,
-59, -8, 111,
-15, 88, 89,
93, -32, 79,
-65, 2, -108,
-59, -8, 111,
91, -17, -85,
-68, 98, -40,
-65, 2, -108,
-68, 98, -40,
-15, 88, 89,
-48, 86, -78,
50, 81, 83,
-93, -32, 79,
99, -20, 76,
-91, -17, -85,
99, 1, -79,
-42, -78, -90,
-93, -32, 79,
-42, -78, -90,
-42, -100, 65,
68, 99, -40,
50, 81, 83,
99, 1, -79,
50, 81, 83,
99, -20, 76,
99, 1, -79,
-93, -32, 79,
-91, -17, -85,
-42, -78, -90,
-91, -17, -85,
68, 99, -40,
99, 1, -79,
-93, -32, 79,
-42, -100, 65,
99, -20, 76,
50, 81, 83,
48, 86, -78,
15, 88, 89,
68, 99, -40,
65, 2, -108,
48, 86, -78,
-91, -17, -85,
-93, -32, 79,
65, 2, -108,
-93, -32, 79,
50, 81, 83,
59, -8, 111,
68, 99, -40,
48, 86, -78,
50, 81, 83,
-15, 88, 89,
-68, 98, -40,
-50, 81, 83,
-116, 15, 49,
-36, -104, 62,
118, -1, 45,
104, -6, -71,
48, -37, -111,
-104, -7, -71,
-104, -7, -71,
118, -1, 45,
104, -6, -71,
-104, -7, -71,
-116, 15, 49,
118, -1, 45,
-48, -37, -111,
-36, -104, 62,
-93, -22, -83,
-36, -104, 62,
83, -62, 72,
-83, -62, 72,
34, -106, 59,
93, -22, -83,
83, -62, 72,
48, -37, -111,
-93, -22, -83,
93, -22, -83,
-78, -51, 85,
72, -55, 87,
-91, 58, 65,
73, -84, -60,
-91, 19, -86,
88, 34, -83,
72, -55, 87,
73, -84, -60,
84, 73, 58,
-78, -79, -60,
-91, 58, 65,
-91, 19, -86,
-78, -79, -60,
-78, -51, 85,
-91, 58, 65,
73, -84, -60,
88, 34, -83,
84, 73, 58,
73, -84, -60,
-78, -79, -60,
-91, 19, -86,
72, -55, 87,
84, 73, 58,
-91, 58, 65,
-91, 58, 65,
84, 73, 58,
-36, -104, 62,
84, 73, 58,
88, 34, -83,
118, -1, 45,
88, 34, -83,
-48, -37, -111,
104, -6, -71,
-91, 19, -86,
-36, -104, 62,
-48, -37, -111,
90, 59, 66,
-73, -55, 87,
78, -51, 85,
-88, 34, -84,
91, 19, -86,
-73, -84, -60,
-84, 80, 51,
-73, -84, -60,
-73, -55, 87,
91, 19, -86,
90, 59, 66,
78, -79, -60,
90, 59, 66,
78, -51, 85,
78, -79, -60,
-84, 80, 51,
-88, 34, -84,
-73, -84, -60,
91, 19, -86,
78, -79, -60,
-73, -84, -60,
90, 59, 66,
-84, 80, 51,
-73, -55, 87,
90, 59, 66,
91, 19, -86,
34, -106, 59,
-88, 34, -84,
-104, -7, -71,
48, -37, -111,
-88, 34, -84,
-116, 15, 49,
-104, -7, -71,
-84, 80, 51,
34, -106, 59,
-116, 15, 49,
-42, -78, -90,
38, -110, -49,
-42, -100, 65,
-42, -100, 65,
94, -81, 25,
99, -20, 76,
99, -20, 76,
94, -81, 25,
99, 1, -79,
99, 1, -79,
94, -71, -46,
-42, -78, -90,
42, -100, 65,
-38, -119, 17,
42, -78, -90,
42, -78, -90,
-94, -71, -46,
-99, 1, -79,
-99, 1, -79,
-94, -71, -46,
-99, -20, 76,
-99, -20, 76,
-94, -81, 25,
42, -100, 65,
-75, -72, 72,
80, 43, 87,
38, -119, 17,
80, 43, 87,
94, -71, -46,
94, -81, 25,
80, 65, -72,
38, -110, -49,
94, -71, -46,
-75, -50, -88,
-75, -72, 72,
38, -110, -49,
-80, 43, 87,
-38, -119, 17,
-94, -81, 25,
75, -50, -88,
-94, -71, -46,
-38, -110, -49,
-80, 65, -72,
-80, 43, 87,
-94, -71, -46,
-38, -110, -49,
-38, -119, 17,
75, -50, -88,
-99, -7, 78,
71, -53, 90,
-57, 44, 104,
33, -72, -98,
-92, 18, -84,
81, -20, -94,
31, -104, 65,
33, -72, -98,
71, -53, 90,
-92, 18, -84,
-57, 44, 104,
-53, 83, -80,
-92, 18, -84,
-99, -7, 78,
-57, 44, 104,
33, -72, -98,
81, -20, -94,
71, -53, 90,
-92, 18, -84,
-53, 83, -80,
81, -20, -94,
-99, -7, 78,
31, -104, 65,
71, -53, 90,
33, -72, -98,
-72, -103, -8,
-92, 18, -84,
-92, 18, -84,
-72, -103, -8,
-99, -7, 78,
-99, -7, 78,
-72, -103, -8,
31, -104, 65,
31, -104, 65,
-72, -103, -8,
33, -72, -98,
81, -20, -94,
-80, 65, -72,
75, -50, -88,
-53, 83, -80,
-57, 44, 104,
-80, 65, -72,
-57, 44, 104,
71, -53, 90,
-80, 43, 87,
71, -53, 90,
81, -20, -94,
75, -72, 72,
73, -84, -60,
-26, -124, -1,
-78, -79, -60,
-78, -79, -60,
-26, -124, -1,
-78, -51, 85,
-78, -51, 85,
-33, -112, 49,
72, -55, 87,
72, -55, 87,
35, -110, 52,
73, -84, -60,
-73, -55, 87,
-35, -110, 52,
78, -51, 85,
78, -51, 85,
26, -124, -1,
78, -79, -60,
78, -79, -60,
26, -124, -1,
-73, -84, -60,
-73, -84, -60,
-35, -110, 52,
-73, -55, 87,
89, 17, 88,
82, 4, 96,
-89, 17, 88,
-89, -17, -88,
-88, -43, -79,
89, -17, -88,
-84, 7, 94,
-88, -43, -79,
-89, 17, 88,
85, -48, -79,
82, 4, 96,
89, -17, -88,
89, 17, 88,
50, 106, 46,
89, -17, -88,
89, -17, -88,
74, 28, -99,
-89, -17, -88,
-89, -17, -88,
-98, 73, 33,
-89, 17, 88,
-89, 17, 88,
-98, 73, 33,
89, 17, 88,
-98, 73, 33,
50, 106, 46,
89, 17, 88,
-89, -17, -88,
-89, 3, -89,
-98, 73, 33,
74, 28, -99,
-89, 3, -89,
-89, -17, -88,
50, 106, 46,
74, 28, -99,
89, -17, -88,
82, 4, 96,
89, 17, 88,
89, -17, -88,
-88, -43, -79,
-89, -17, -88,
-89, 17, 88,
-88, -43, -79,
85, -48, -79,
89, -17, -88,
82, 4, 96,
-84, 7, 94,
-89, 17, 88,
-88, -43, -79,
-35, -110, 52,
-27, -123, -4,
-84, 7, 94,
82, 4, 96,
-35, -110, 52,
82, 4, 96,
85, -48, -79,
33, -112, 49,
85, -48, -79,
-27, -123, -4,
26, -124, -1,
89, 17, 88,
-82, 4, 96,
-89, 17, 88,
-89, -17, -88,
88, -43, -79,
89, -17, -88,
89, 17, 88,
88, -43, -79,
84, 7, 94,
-89, -17, -88,
-82, 4, 96,
-85, -48, -79,
-89, -17, -88,
-50, 106, 46,
-89, 17, 88,
89, -17, -88,
-74, 28, -99,
-89, -17, -88,
89, 17, 88,
98, 73, 33,
89, -17, -88,
-89, 17, 88,
98, 73, 33,
89, 17, 88,
-89, 17, 88,
-50, 106, 46,
98, 73, 33,
98, 73, 33,
89, 3, -89,
89, -17, -88,
89, -17, -88,
89, 3, -89,
-74, 28, -99,
-89, -17, -88,
-74, 28, -99,
-50, 106, 46,
-89, -17, -88,
-89, 17, 88,
-82, 4, 96,
89, 17, 88,
89, -17, -88,
88, -43, -79,
-89, -17, -88,
-85, -48, -79,
88, -43, -79,
89, 17, 88,
84, 7, 94,
-82, 4, 96,
-82, 4, 96,
35, -110, 52,
-33, -112, 49,
84, 7, 94,
88, -43, -79,
35, -110, 52,
88, -43, -79,
-85, -48, -79,
27, -123, -4,
-85, -48, -79,
-33, -112, 49,
-26, -124, -1,
86, -77, -51,
-54, -86, -75,
89, 8, -89,
-65, 108, 13,
95, 83, -6,
-91, 76, -42,
99, -73, 29,
77, -62, 78,
-93, -84, -13,
77, -62, 78,
95, 83, -6,
62, 105, 33,
-93, -84, -13,
-100, -59, 48,
-91, 76, -42,
62, 105, 33,
-18, 2, 125,
77, -62, 78,
77, -62, 78,
-18, 2, 125,
-100, -59, 48,
-100, -59, 48,
-18, 2, 125,
-65, 108, 13,
-65, 108, 13,
-18, 2, 125,
62, 105, 33,
99, -73, 29,
86, -77, -51,
95, 83, -6,
-93, -84, -13,
-54, -86, -75,
99, -73, 29,
-91, 76, -42,
-57, 8, -113,
-93, -84, -13,
-57, 8, -113,
-54, -86, -75,
-93, -84, -13,
-54, -86, -75,
86, -77, -51,
99, -73, 29,
86, -77, -51,
89, 8, -89,
95, 83, -6,
-100, -59, 48,
-65, 108, 13,
-91, 76, -42,
77, -62, 78,
99, -73, 29,
95, 83, -6,
77, -62, 78,
-100, -59, 48,
-93, -84, -13,
-65, 108, 13,
62, 105, 33,
95, 83, -6,
-54, -86, -75,
-57, 8, -113,
89, 8, -89,
95, 83, -6,
89, 8, -89,
98, 73, 33,
89, 8, -89,
-57, 8, -113,
89, 3, -89,
-57, 8, -113,
-91, 76, -42,
-74, 28, -99,
-91, 76, -42,
95, 83, -6,
-50, 106, 46,
-89, 8, -89,
54, -86, -75,
-86, -77, -51,
91, 76, -42,
-95, 83, -6,
65, 108, 13,
93, -84, -13,
-77, -62, 78,
-99, -73, 29,
-62, 105, 33,
-95, 83, -6,
-77, -62, 78,
91, 76, -42,
100, -59, 48,
93, -84, -13,
-77, -62, 78,
18, 2, 125,
-62, 105, 33,
100, -59, 48,
18, 2, 125,
-77, -62, 78,
65, 108, 13,
18, 2, 125,
100, -59, 48,
-62, 105, 33,
18, 2, 125,
65, 108, 13,
-95, 83, -6,
-86, -77, -51,
-99, -73, 29,
-99, -73, 29,
54, -86, -75,
93, -84, -13,
93, -84, -13,
57, 8, -113,
91, 76, -42,
93, -84, -13,
54, -86, -75,
57, 8, -113,
-99, -73, 29,
-86, -77, -51,
54, -86, -75,
-95, 83, -6,
-89, 8, -89,
-86, -77, -51,
91, 76, -42,
65, 108, 13,
100, -59, 48,
-95, 83, -6,
-99, -73, 29,
-77, -62, 78,
93, -84, -13,
100, -59, 48,
-77, -62, 78,
-95, 83, -6,
-62, 105, 33,
65, 108, 13,
-89, 8, -89,
57, 8, -113,
54, -86, -75,
-95, 83, -6,
50, 106, 46,
-98, 73, 33,
91, 76, -42,
74, 28, -99,
50, 106, 46,
57, 8, -113,
-89, 3, -89,
74, 28, -99,
-89, 8, -89,
-98, 73, 33,
-89, 3, -89,
48, -37, -111,
91, 19, -86,
-88, 34, -84,
88, 34, -83,
-91, 19, -86,
-48, -37, -111,
80, 65, -72,
-81, -20, -94,
-75, -50, -88,
-75, -50, -88,
-71, -53, 90,
-75, -72, 72,
80, 43, 87,
53, 83, -80,
80, 65, -72,
57, 44, 104,
-71, -53, 90,
99, -7, 78,
-81, -20, -94,
92, 18, -84,
-33, -72, -98,
-71, -53, 90,
-33, -72, -98,
-31, -104, 65,
53, 83, -80,
57, 44, 104,
92, 18, -84,
57, 44, 104,
99, -7, 78,
92, 18, -84,
-71, -53, 90,
-81, -20, -94,
-33, -72, -98,
-81, -20, -94,
53, 83, -80,
92, 18, -84,
-71, -53, 90,
-31, -104, 65,
99, -7, 78,
92, 18, -84,
72, -103, -8,
-33, -72, -98,
99, -7, 78,
72, -103, -8,
92, 18, -84,
-31, -104, 65,
72, -103, -8,
99, -7, 78,
-33, -72, -98,
72, -103, -8,
-31, -104, 65,
-75, -72, 72,
-71, -53, 90,
80, 43, 87,
-71, -53, 90,
57, 44, 104,
80, 43, 87,
80, 43, 87,
57, 44, 104,
53, 83, -80,
-75, -50, -88,
-81, -20, -94,
-71, -53, 90,
80, 65, -72,
53, 83, -80,
-81, -20, -94,
-89, 8, -89,
-95, 83, -6,
-98, 73, 33,
57, 8, -113,
-89, 8, -89,
-89, 3, -89,
91, 76, -42,
57, 8, -113,
74, 28, -99,
-95, 83, -6,
91, 76, -42,
50, 106, 46,
95, 83, -6,
98, 73, 33,
-50, 106, 46,
-91, 76, -42,
-50, 106, 46,
-74, 28, -99,
-57, 8, -113,
-74, 28, -99,
89, 3, -89,
89, 8, -89,
89, 3, -89,
98, 73, 33,
-85, -48, -79,
-82, 4, 96,
-33, -112, 49,
-85, -48, -79,
-26, -124, -1,
27, -123, -4,
88, -43, -79,
27, -123, -4,
35, -110, 52,
-82, 4, 96,
84, 7, 94,
35, -110, 52,
85, -48, -79,
-88, -43, -79,
-27, -123, -4,
85, -48, -79,
26, -124, -1,
33, -112, 49,
82, 4, 96,
33, -112, 49,
-35, -110, 52,
-88, -43, -79,
-84, 7, 94,
-35, -110, 52,
-73, -84, -60,
-27, -123, -4,
-35, -110, 52,
26, -124, -1,
-27, -123, -4,
-73, -84, -60,
78, -51, 85,
33, -112, 49,
26, -124, -1,
-35, -110, 52,
33, -112, 49,
78, -51, 85,
35, -110, 52,
27, -123, -4,
73, -84, -60,
-33, -112, 49,
35, -110, 52,
72, -55, 87,
-26, -124, -1,
-33, -112, 49,
-78, -51, 85,
73, -84, -60,
27, -123, -4,
-26, -124, -1,
81, -20, -94,
75, -50, -88,
75, -72, 72,
71, -53, 90,
75, -72, 72,
-80, 43, 87,
-57, 44, 104,
-80, 43, 87,
-80, 65, -72,
81, -20, -94,
-53, 83, -80,
-80, 65, -72,
-38, -119, 17,
75, -72, 72,
75, -50, -88,
-80, 43, 87,
-94, -81, 25,
-94, -71, -46,
75, -50, -88,
-80, 65, -72,
-94, -71, -46,
-80, 43, 87,
75, -72, 72,
-38, -119, 17,
-75, -72, 72,
38, -119, 17,
38, -110, -49,
80, 65, -72,
-75, -50, -88,
38, -110, -49,
80, 43, 87,
80, 65, -72,
94, -71, -46,
80, 43, 87,
94, -81, 25,
38, -119, 17,
-94, -81, 25,
-38, -119, 17,
42, -100, 65,
-94, -71, -46,
-94, -81, 25,
-99, -20, 76,
42, -78, -90,
-38, -110, -49,
-94, -71, -46,
-38, -119, 17,
-38, -110, -49,
42, -78, -90,
94, -71, -46,
38, -110, -49,
-42, -78, -90,
94, -81, 25,
94, -71, -46,
99, 1, -79,
-42, -100, 65,
38, -119, 17,
94, -81, 25,
38, -110, -49,
38, -119, 17,
-42, -100, 65,
-84, 80, 51,
90, 59, 66,
34, -106, 59,
-88, 34, -84,
-84, 80, 51,
-116, 15, 49,
91, 19, -86,
48, -37, -111,
34, -106, 59,
-91, 19, -86,
-91, 58, 65,
-36, -104, 62,
88, 34, -83,
104, -6, -71,
118, -1, 45,
84, 73, 58,
118, -1, 45,
-36, -104, 62,
48, -37, -111,
-48, -37, -111,
-93, -22, -83,
34, -106, 59,
48, -37, -111,
93, -22, -83,
-36, -104, 62,
34, -106, 59,
83, -62, 72,
-36, -104, 62,
-83, -62, 72,
-93, -22, -83,
104, -6, -71,
-48, -37, -111,
48, -37, -111,
-116, 15, 49,
34, -106, 59,
-36, -104, 62,
50, 81, 83,
15, 88, 89,
59, -8, 111,
-93, -32, 79,
59, -8, 111,
65, 2, -108,
68, 99, -40,
-91, -17, -85,
65, 2, -108,
-68, 98, -40,
-48, 86, -78,
-65, 2, -108,
93, -32, 79,
91, -17, -85,
-65, 2, -108,
-50, 81, 83,
93, -32, 79,
-59, -8, 111,
-85, 22, -90,
-83, 10, 95,
-59, -8, 111,
65, 2, -108,
85, 22, -90,
-85, 22, -90,
-59, -8, 111,
-83, 10, 95,
83, 10, 95,
59, -8, 111,
83, 10, 95,
85, 22, -90,
39, 45, 111,
38, 105, -59,
96, -57, -58,
-39, 45, 111,
39, 45, 111,
43, -117, -20,
-48, 86, -78,
48, 86, -78,
65, 2, -108,
59, -8, 111,
15, 88, 89,
-15, 88, 89,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:28 */
static s8 vtxnvgrp_frake_select_28[]={
-17, -82, 95,
6, -84, 94,
5, -82, 96,
5, -82, 96,
29, -86, 88,
93, -8, 85,
19, -125, -6,
70, -79, -69,
-37, -120, 15,
-37, -120, 15,
-11, -72, -103,
-3, -126, 8,
-3, -126, 8,
-11, -72, -103,
15, -125, 8,
15, -125, 8,
-88, -63, -65,
-39, -120, 0,
-39, -120, 0,
-113, -56, -5,
-70, -80, 67,
19, -125, -6,
84, -16, 92,
67, -89, 58,
101, -75, -12,
49, -116, -7,
70, -79, -69,
70, -79, -69,
98, -60, -52,
-11, -72, -103,
-11, -72, -103,
-104, -51, -51,
-88, -63, -65,
-88, -63, -65,
-60, -111, -8,
-113, -56, -5,
-113, -56, -5,
-60, -111, -8,
-70, -80, 67,
-70, -80, 67,
-62, -110, -6,
0, -123, 28,
0, -123, 28,
45, -118, -6,
67, -89, 58,
67, -89, 58,
49, -116, -7,
101, -75, -12,
0, 120, -40,
-92, 82, -27,
-30, 112, -50,
96, -24, -79,
100, -1, -77,
123, -30, -2,
126, 14, 0,
92, -13, 86,
93, -8, 85,
93, -8, 85,
92, -13, 86,
5, -82, 96,
5, -82, 96,
-81, 4, 97,
-81, 8, 97,
-81, 8, 97,
-81, 4, 97,
-120, 39, 7,
-126, -6, 2,
-106, 18, -66,
-106, -2, -69,
-106, -2, -69,
-9, 1, -126,
-11, -16, -125,
-11, -16, -125,
-9, 1, -126,
96, -24, -79,
100, -1, -77,
99, 70, -34,
126, 14, 0,
126, 14, 0,
99, 70, -34,
109, 62, 12,
-98, 79, 13,
-92, 82, -27,
-120, 39, 7,
-120, 39, 7,
-92, 82, -27,
-106, 18, -66,
-106, 18, -66,
-6, 68, -106,
-9, 1, -126,
-9, 1, -126,
-6, 68, -106,
100, -1, -77,
63, 90, -61,
-6, 68, -106,
0, 120, -40,
67, -89, 58,
101, -75, -12,
19, -125, -6,
-70, -80, 67,
-75, -4, 102,
-39, -120, 0,
0, -123, 28,
67, -89, 58,
-70, -80, 67,
67, -89, 58,
11, -9, 126,
-70, -80, 67,
-17, -82, 95,
70, -72, 76,
-39, -120, 0,
-39, -120, 0,
-100, -33, -70,
-126, -6, 2,
-126, -6, 2,
-77, -33, 94,
-81, 8, 97,
-81, 8, 97,
70, -72, 76,
-17, -82, 95,
70, -72, 76,
-18, -124, -13,
65, -52, -95,
65, -52, -95,
-18, -124, -13,
-100, -33, -70,
-100, -33, -70,
-18, -124, -13,
-77, -33, 94,
-77, -33, 94,
-18, -124, -13,
70, -72, 76,
19, -125, -6,
-70, -65, 83,
29, -86, 88,
29, -86, 88,
-70, -65, 83,
93, -8, 85,
93, -8, 85,
82, -46, 84,
123, -30, -2,
123, -30, -2,
83, -54, -78,
19, -125, -6,
-82, -35, -89,
-7, -125, -15,
-70, -65, 83,
-70, -65, 83,
-7, -125, -15,
82, -46, 84,
82, -46, 84,
-7, -125, -15,
83, -54, -78,
83, -54, -78,
-7, -125, -15,
-82, -35, -89,
-37, -120, 15,
-63, -54, 95,
19, -125, -6,
19, -125, -6,
-63, -54, 95,
123, -30, -2,
123, -30, -2,
95, -61, 56,
96, -24, -79,
96, -24, -79,
-20, -50, -114,
-37, -120, 15,
-126, 3, 12,
-28, -122, -15,
-63, -54, 95,
-63, -54, 95,
-28, -122, -15,
95, -61, 56,
95, -61, 56,
-28, -122, -15,
-20, -50, -114,
-20, -50, -114,
-28, -122, -15,
-126, 3, 12,
-106, -2, -69,
-95, -48, 68,
-126, -6, 2,
-126, -6, 2,
66, -63, 87,
-39, -120, 0,
-39, -120, 0,
66, -63, 87,
15, -125, 8,
15, -125, 8,
4, -53, -115,
-106, -2, -69,
4, -53, -115,
2, -125, -19,
-95, -48, 68,
-95, -48, 68,
2, -125, -19,
66, -63, 87,
66, -63, 87,
2, -125, -19,
124, -22, 6,
124, -22, 6,
2, -125, -19,
4, -53, -115,
-3, -126, 8,
48, -30, 113,
-37, -120, 15,
-37, -120, 15,
48, -30, 113,
96, -24, -79,
96, -24, -79,
-60, -48, -100,
-11, -16, -125,
-11, -16, -125,
-60, -48, -100,
-3, -126, 8,
-109, -36, 52,
-13, -109, 61,
48, -30, 113,
48, -30, 113,
-13, -109, 61,
113, -37, -42,
113, -37, -42,
-13, -109, 61,
-60, -48, -100,
-60, -48, -100,
-13, -109, 61,
-109, -36, 52,
15, -125, 8,
-38, -21, 119,
-3, -126, 8,
-3, -126, 8,
40, -56, -106,
-11, -16, -125,
-11, -16, -125,
40, -56, -106,
-106, -2, -69,
-106, -2, -69,
-38, -21, 119,
15, -125, 8,
-38, -21, 119,
1, -113, 57,
105, -56, 43,
105, -56, 43,
1, -113, 57,
40, -56, -106,
40, -56, -106,
1, -113, 57,
-122, -18, -26,
-122, -18, -26,
1, -113, 57,
-38, -21, 119,
5, 118, 46,
9, 116, 48,
-98, 79, 13,
109, 62, 12,
9, 116, 48,
5, 118, 46,
84, -16, 92,
19, -125, -6,
29, -86, 88,
-75, -4, 102,
-17, -82, 95,
-39, -120, 0,
-75, -4, 102,
6, -84, 94,
-17, -82, 95,
84, -16, 92,
29, -86, 88,
6, -84, 94,
-75, -4, 102,
11, -9, 126,
6, -84, 94,
109, 62, 12,
92, -13, 86,
126, 14, 0,
-120, 39, 7,
-81, 4, 97,
-98, 79, 13,
93, -8, 85,
123, -30, -2,
126, 14, 0,
-120, 39, 7,
-126, -6, 2,
-81, 8, 97,
-49, 91, 72,
-50, 35, 111,
13, 95, 82,
68, 23, 104,
9, 95, 83,
6, 40, 120,
0, 120, -40,
9, 116, 48,
41, 106, -54,
0, 120, -40,
41, 106, -54,
99, 70, -34,
0, 120, -40,
99, 70, -34,
63, 90, -61,
-30, 112, -50,
9, 116, 48,
0, 120, -40,
0, 120, -40,
-57, 99, -55,
-92, 82, -27,
0, 120, -40,
-6, 68, -106,
-57, 99, -55,
5, 118, 46,
25, 23, 122,
13, -7, 126,
13, -7, 126,
-56, 15, 112,
-81, 4, 97,
-81, 4, 97,
-70, 91, 52,
-98, 79, 13,
-98, 79, 13,
31, 104, 65,
5, 118, 46,
92, -13, 86,
70, 9, 105,
13, -7, 126,
13, -7, 126,
-8, 24, 124,
5, 118, 46,
5, 118, 46,
-6, 106, 69,
109, 62, 12,
109, 62, 12,
88, 81, 41,
92, -13, 86,
88, 81, 41,
70, 9, 105,
92, -13, 86,
-6, 106, 69,
88, 81, 41,
109, 62, 12,
-8, 24, 124,
-6, 106, 69,
5, 118, 46,
70, 9, 105,
-8, 24, 124,
13, -7, 126,
-98, 79, 13,
-70, 91, 52,
31, 104, 65,
-81, 4, 97,
-56, 15, 112,
-70, 91, 52,
13, -7, 126,
25, 23, 122,
-56, 15, 112,
5, 118, 46,
31, 104, 65,
25, 23, 122,
109, 62, 12,
41, 106, -54,
9, 116, 48,
9, 116, 48,
-30, 112, -50,
-98, 79, 13,
-106, -2, -69,
-122, -18, -26,
-38, -21, 119,
40, -56, -106,
-122, -18, -26,
-106, -2, -69,
-3, -126, 8,
105, -56, 43,
40, -56, -106,
-38, -21, 119,
105, -56, 43,
-3, -126, 8,
-60, -48, -100,
-109, -36, 52,
-3, -126, 8,
96, -24, -79,
113, -37, -42,
-60, -48, -100,
48, -30, 113,
113, -37, -42,
96, -24, -79,
-3, -126, 8,
-109, -36, 52,
48, -30, 113,
15, -125, 8,
124, -22, 6,
4, -53, -115,
66, -63, 87,
124, -22, 6,
15, -125, 8,
-126, -6, 2,
-95, -48, 68,
66, -63, 87,
-106, -2, -69,
4, -53, -115,
-95, -48, 68,
-20, -50, -114,
-126, 3, 12,
-37, -120, 15,
95, -61, 56,
-20, -50, -114,
96, -24, -79,
-63, -54, 95,
95, -61, 56,
123, -30, -2,
-37, -120, 15,
-126, 3, 12,
-63, -54, 95,
83, -54, -78,
-82, -35, -89,
19, -125, -6,
82, -46, 84,
83, -54, -78,
123, -30, -2,
-70, -65, 83,
82, -46, 84,
93, -8, 85,
19, -125, -6,
-82, -35, -89,
-70, -65, 83,
-81, 8, 97,
-77, -33, 94,
70, -72, 76,
-126, -6, 2,
-100, -33, -70,
-77, -33, 94,
-39, -120, 0,
65, -52, -95,
-100, -33, -70,
70, -72, 76,
65, -52, -95,
-39, -120, 0,
11, -9, 126,
-75, -4, 102,
-70, -80, 67,
-6, 68, -106,
63, 90, -61,
100, -1, -77,
-106, 18, -66,
-57, 99, -55,
-6, 68, -106,
-92, 82, -27,
-57, 99, -55,
-106, 18, -66,
-98, 79, 13,
-30, 112, -50,
-92, 82, -27,
99, 70, -34,
41, 106, -54,
109, 62, 12,
100, -1, -77,
63, 90, -61,
99, 70, -34,
-9, 1, -126,
100, -1, -77,
96, -24, -79,
-106, -2, -69,
-106, 18, -66,
-9, 1, -126,
-126, -6, 2,
-120, 39, 7,
-106, 18, -66,
5, -82, 96,
13, -7, 126,
-81, 4, 97,
92, -13, 86,
13, -7, 126,
5, -82, 96,
100, -1, -77,
126, 14, 0,
123, -30, -2,
49, -116, -7,
45, -118, -6,
-62, -110, -6,
45, -118, -6,
0, -123, 28,
-62, -110, -6,
49, -116, -7,
-62, -110, -6,
-60, -111, -8,
67, -89, 58,
45, -118, -6,
49, -116, -7,
-60, -111, -8,
-62, -110, -6,
-70, -80, 67,
-88, -63, -65,
-104, -51, -51,
-60, -111, -8,
-11, -72, -103,
-1, -70, -105,
-104, -51, -51,
98, -60, -52,
-1, -70, -105,
-11, -72, -103,
49, -116, -7,
98, -60, -52,
70, -79, -69,
-88, -63, -65,
-113, -56, -5,
-39, -120, 0,
-11, -72, -103,
-88, -63, -65,
15, -125, 8,
-37, -120, 15,
70, -79, -69,
-11, -72, -103,
19, -125, -6,
101, -75, -12,
70, -79, -69,
5, -82, 96,
6, -84, 94,
29, -86, 88,
5, -82, 96,
-81, 8, 97,
-17, -82, 95,
11, -9, 126,
84, -16, 92,
6, -84, 94,
-8, 24, 124,
68, 81, 68,
-6, 106, 69,
-6, 106, 69,
6, 40, 120,
88, 81, 41,
88, 81, 41,
6, 40, 120,
70, 9, 105,
70, 9, 105,
68, 81, 68,
-8, 24, 124,
31, 104, 65,
-49, 91, 72,
25, 23, 122,
25, 23, 122,
-49, 91, 72,
-56, 15, 112,
-56, 15, 112,
17, 38, 119,
-70, 91, 52,
-70, 91, 52,
17, 38, 119,
31, 104, 65,
17, 38, 119,
-50, 35, 111,
31, 104, 65,
-56, 15, 112,
13, 95, 82,
17, 38, 119,
-49, 91, 72,
13, 95, 82,
-56, 15, 112,
31, 104, 65,
-50, 35, 111,
-49, 91, 72,
70, 9, 105,
9, 95, 83,
68, 81, 68,
6, 40, 120,
9, 95, 83,
70, 9, 105,
-6, 106, 69,
68, 23, 104,
6, 40, 120,
68, 81, 68,
68, 23, 104,
-6, 106, 69,
68, 23, 104,
68, 81, 68,
9, 95, 83,
-50, 35, 111,
17, 38, 119,
13, 95, 82,
67, -89, 58,
84, -16, 92,
11, -9, 126,
59, -3, 112,
-15, 92, 85,
-59, -3, 112,
91, -31, -82,
-91, -31, -82,
85, 18, -91,
15, 92, 85,
-46, 49, 107,
-15, 92, 85,
-15, 92, 85,
-39, 101, -64,
-48, 83, -82,
-48, 83, -82,
39, 101, -64,
48, 83, -82,
48, 83, -82,
39, 101, -64,
15, 92, 85,
83, 14, 94,
91, -31, -82,
85, 18, -91,
-83, 14, 94,
83, -59, 75,
83, 14, 94,
-85, 18, -91,
-91, -31, -82,
-83, 14, 94,
-66, -2, -108,
-48, 83, -82,
66, -2, -108,
-91, -31, -82,
-83, -59, 75,
-83, 14, 94,
-83, 14, 94,
-83, -59, 75,
83, -59, 75,
83, 14, 94,
83, -59, 75,
91, -31, -82,
39, 101, -64,
46, 49, 107,
15, 92, 85,
-48, 83, -82,
-39, 101, -64,
39, 101, -64,
-15, 92, 85,
-46, 49, 107,
-39, 101, -64,
15, 92, 85,
46, 49, 107,
-46, 49, 107,
-91, -31, -82,
-85, 18, -91,
85, 18, -91,
-46, 49, 107,
49, -116, -7,
-60, -111, -8,
46, 49, 107,
98, -60, -52,
49, -116, -7,
39, 101, -64,
-1, -70, -105,
98, -60, -52,
-39, 101, -64,
-104, -51, -51,
-1, -70, -105,
-46, 49, 107,
-60, -111, -8,
-104, -51, -51,
39, 101, -64,
-39, 101, -64,
-1, -70, -105,
-39, 101, -64,
-46, 49, 107,
-104, -51, -51,
59, -3, 112,
85, 18, -91,
66, -2, -108,
-59, -3, 112,
83, 14, 94,
59, -3, 112,
66, -2, -108,
-85, 18, -91,
-66, -2, -108,
-66, -2, -108,
-85, 18, -91,
-59, -3, 112,
-99, -16, 77,
93, -28, 80,
-51, 84, 79,
42, -82, -86,
-99, -2, -79,
91, -21, -84,
42, -96, 70,
42, -82, -86,
93, -28, 80,
-99, -2, -79,
-51, 84, 79,
-69, 96, -44,
-99, -2, -79,
-99, -16, 77,
-51, 84, 79,
42, -82, -86,
91, -21, -84,
93, -28, 80,
-99, -2, -79,
-69, 96, -44,
91, -21, -84,
-99, -16, 77,
42, -96, 70,
93, -28, 80,
-51, 84, 79,
-59, -3, 112,
-15, 92, 85,
93, -28, 80,
-66, -2, -108,
-59, -3, 112,
91, -21, -84,
-69, 96, -44,
-66, -2, -108,
-69, 96, -44,
-15, 92, 85,
-48, 83, -82,
50, 84, 79,
-93, -28, 80,
99, -16, 77,
-91, -21, -84,
99, -2, -79,
-42, -82, -86,
-93, -28, 80,
-42, -82, -86,
-42, -96, 70,
68, 97, -44,
50, 84, 79,
99, -2, -79,
50, 84, 79,
99, -16, 77,
99, -2, -79,
-93, -28, 80,
-91, -21, -84,
-42, -82, -86,
-91, -21, -84,
68, 97, -44,
99, -2, -79,
-93, -28, 80,
-42, -96, 70,
99, -16, 77,
50, 84, 79,
48, 83, -82,
15, 92, 85,
68, 97, -44,
66, -2, -108,
48, 83, -82,
-91, -21, -84,
-93, -28, 80,
66, -2, -108,
-93, -28, 80,
50, 84, 79,
59, -3, 112,
68, 97, -44,
48, 83, -82,
50, 84, 79,
-15, 92, 85,
-69, 96, -44,
-51, 84, 79,
-118, 3, 46,
-33, -104, 64,
118, -5, 44,
107, -10, -66,
44, -41, -111,
-107, -10, -66,
-107, -10, -66,
118, -5, 44,
107, -10, -66,
-107, -10, -66,
-118, 3, 46,
118, -5, 44,
-44, -41, -111,
-33, -104, 64,
-91, -31, -82,
-33, -104, 64,
83, -59, 75,
-83, -59, 75,
32, -105, 62,
91, -31, -82,
83, -59, 75,
44, -41, -111,
-91, -31, -82,
91, -31, -82,
-78, -57, 82,
72, -61, 83,
-91, 53, 69,
73, -80, -65,
-90, 27, -84,
86, 43, -81,
72, -61, 83,
73, -80, -65,
85, 69, 63,
-78, -75, -65,
-91, 53, 69,
-90, 27, -84,
-78, -75, -65,
-78, -57, 82,
-91, 53, 69,
73, -80, -65,
86, 43, -81,
85, 69, 63,
73, -80, -65,
-78, -75, -65,
-90, 27, -84,
72, -61, 83,
85, 69, 63,
-91, 53, 69,
-91, 53, 69,
85, 69, 63,
-33, -104, 64,
85, 69, 63,
86, 43, -81,
118, -5, 44,
86, 43, -81,
-44, -41, -111,
107, -10, -66,
-90, 27, -84,
-33, -104, 64,
-44, -41, -111,
90, 54, 69,
-73, -61, 83,
78, -57, 82,
-86, 43, -81,
90, 27, -84,
-73, -80, -65,
-85, 73, 59,
-73, -80, -65,
-73, -61, 83,
90, 27, -84,
90, 54, 69,
78, -75, -65,
90, 54, 69,
78, -57, 82,
78, -75, -65,
-85, 73, 59,
-86, 43, -81,
-73, -80, -65,
90, 27, -84,
78, -75, -65,
-73, -80, -65,
90, 54, 69,
-85, 73, 59,
-73, -61, 83,
90, 54, 69,
90, 27, -84,
32, -105, 62,
-86, 43, -81,
-107, -10, -66,
44, -41, -111,
-86, 43, -81,
-118, 3, 46,
-107, -10, -66,
-85, 73, 59,
32, -105, 62,
-118, 3, 46,
-42, -82, -86,
39, -112, -44,
-42, -96, 70,
-42, -96, 70,
94, -79, 28,
99, -16, 77,
99, -16, 77,
94, -79, 28,
99, -2, -79,
99, -2, -79,
94, -73, -42,
-42, -82, -86,
42, -96, 70,
-39, -118, 23,
42, -82, -86,
42, -82, -86,
-94, -73, -42,
-99, -2, -79,
-99, -2, -79,
-94, -73, -42,
-99, -16, 77,
-99, -16, 77,
-94, -79, 28,
42, -96, 70,
-76, -68, 75,
81, 47, 85,
39, -118, 23,
81, 47, 85,
94, -73, -42,
94, -79, 28,
81, 61, -75,
39, -112, -44,
94, -73, -42,
-76, -53, -86,
-76, -68, 75,
39, -112, -44,
-81, 47, 85,
-39, -118, 23,
-94, -79, 28,
76, -53, -86,
-94, -73, -42,
-39, -112, -44,
-81, 61, -75,
-81, 47, 85,
-94, -73, -42,
-39, -112, -44,
-39, -118, 23,
76, -53, -86,
-99, -3, 78,
71, -49, 92,
-57, 48, 101,
33, -76, -95,
-92, 14, -85,
82, -24, -93,
31, -101, 70,
33, -76, -95,
71, -49, 92,
-92, 14, -85,
-57, 48, 101,
-53, 79, -83,
-92, 14, -85,
-99, -3, 78,
-57, 48, 101,
33, -76, -95,
82, -24, -93,
71, -49, 92,
-92, 14, -85,
-53, 79, -83,
82, -24, -93,
-99, -3, 78,
31, -101, 70,
71, -49, 92,
33, -76, -95,
-72, -104, -3,
-92, 14, -85,
-92, 14, -85,
-72, -104, -3,
-99, -3, 78,
-99, -3, 78,
-72, -104, -3,
31, -101, 70,
31, -101, 70,
-72, -104, -3,
33, -76, -95,
82, -24, -93,
-81, 61, -75,
76, -53, -86,
-53, 79, -83,
-57, 48, 101,
-81, 61, -75,
-57, 48, 101,
71, -49, 92,
-81, 47, 85,
71, -49, 92,
82, -24, -93,
76, -68, 75,
73, -80, -65,
-26, -123, -10,
-78, -75, -65,
-78, -75, -65,
-26, -123, -10,
-78, -57, 82,
-78, -57, 82,
-33, -114, 42,
72, -61, 83,
72, -61, 83,
35, -113, 44,
73, -80, -65,
-73, -61, 83,
-35, -113, 44,
78, -57, 82,
78, -57, 82,
26, -123, -10,
78, -75, -65,
78, -75, -65,
26, -123, -10,
-73, -80, -65,
-73, -80, -65,
-35, -113, 44,
-73, -61, 83,
89, 11, 89,
82, -2, 96,
-89, 11, 89,
-89, -11, -89,
-89, -37, -82,
89, -11, -89,
-85, 1, 94,
-89, -37, -82,
-89, 11, 89,
85, -43, -82,
82, -2, 96,
89, -11, -89,
89, 11, 89,
50, 103, 53,
89, -11, -89,
89, -11, -89,
74, 34, -96,
-89, -11, -89,
-89, -11, -89,
-98, 70, 38,
-89, 11, 89,
-89, 11, 89,
-98, 70, 38,
89, 11, 89,
-98, 70, 38,
50, 103, 53,
89, 11, 89,
-89, -11, -89,
-89, 9, -89,
-98, 70, 38,
74, 34, -96,
-89, 9, -89,
-89, -11, -89,
50, 103, 53,
74, 34, -96,
89, -11, -89,
82, -2, 96,
89, 11, 89,
89, -11, -89,
-89, -37, -82,
-89, -11, -89,
-89, 11, 89,
-89, -37, -82,
85, -43, -82,
89, -11, -89,
82, -2, 96,
-85, 1, 94,
-89, 11, 89,
-89, -37, -82,
-35, -113, 44,
-27, -123, -12,
-85, 1, 94,
82, -2, 96,
-35, -113, 44,
82, -2, 96,
85, -43, -82,
33, -114, 42,
85, -43, -82,
-27, -123, -12,
26, -123, -10,
89, 11, 89,
-82, -2, 96,
-89, 11, 89,
-89, -11, -89,
89, -37, -82,
89, -11, -89,
89, 11, 89,
89, -37, -82,
85, 1, 94,
-89, -11, -89,
-82, -2, 96,
-85, -43, -82,
-89, -11, -89,
-50, 103, 53,
-89, 11, 89,
89, -11, -89,
-74, 34, -96,
-89, -11, -89,
89, 11, 89,
98, 70, 38,
89, -11, -89,
-89, 11, 89,
98, 70, 38,
89, 11, 89,
-89, 11, 89,
-50, 103, 53,
98, 70, 38,
98, 70, 38,
89, 9, -89,
89, -11, -89,
89, -11, -89,
89, 9, -89,
-74, 34, -96,
-89, -11, -89,
-74, 34, -96,
-50, 103, 53,
-89, -11, -89,
-89, 11, 89,
-82, -2, 96,
89, 11, 89,
89, -11, -89,
89, -37, -82,
-89, -11, -89,
-85, -43, -82,
89, -37, -82,
89, 11, 89,
85, 1, 94,
-82, -2, 96,
-82, -2, 96,
35, -113, 44,
-33, -114, 42,
85, 1, 94,
89, -37, -82,
35, -113, 44,
89, -37, -82,
-85, -43, -82,
27, -123, -12,
-85, -43, -82,
-33, -114, 42,
-26, -123, -10,
86, -73, -56,
-54, -81, -80,
89, 14, -88,
-65, 106, 20,
95, 83, 0,
-92, 79, -36,
99, -75, 24,
77, -67, 74,
-93, -83, -18,
77, -67, 74,
95, 83, 0,
62, 102, 40,
-93, -83, -18,
-100, -63, 44,
-92, 79, -36,
62, 102, 40,
-18, -5, 125,
77, -67, 74,
77, -67, 74,
-18, -5, 125,
-100, -63, 44,
-100, -63, 44,
-18, -5, 125,
-65, 106, 20,
-65, 106, 20,
-18, -5, 125,
62, 102, 40,
99, -75, 24,
86, -73, -56,
95, 83, 0,
-93, -83, -18,
-54, -81, -80,
99, -75, 24,
-92, 79, -36,
-57, 15, -112,
-93, -83, -18,
-57, 15, -112,
-54, -81, -80,
-93, -83, -18,
-54, -81, -80,
86, -73, -56,
99, -75, 24,
86, -73, -56,
89, 14, -88,
95, 83, 0,
-100, -63, 44,
-65, 106, 20,
-92, 79, -36,
77, -67, 74,
99, -75, 24,
95, 83, 0,
77, -67, 74,
-100, -63, 44,
-93, -83, -18,
-65, 106, 20,
62, 102, 40,
95, 83, 0,
-54, -81, -80,
-57, 15, -112,
89, 14, -88,
95, 83, 0,
89, 14, -88,
98, 70, 38,
89, 14, -88,
-57, 15, -112,
89, 9, -89,
-57, 15, -112,
-92, 79, -36,
-74, 34, -96,
-92, 79, -36,
95, 83, 0,
-50, 103, 53,
-89, 14, -88,
54, -81, -80,
-86, -73, -56,
92, 79, -36,
-95, 83, 0,
65, 106, 20,
93, -83, -18,
-77, -67, 74,
-99, -75, 24,
-62, 102, 40,
-95, 83, 0,
-77, -67, 74,
92, 79, -36,
100, -63, 44,
93, -83, -18,
-77, -67, 74,
18, -5, 125,
-62, 102, 40,
100, -63, 44,
18, -5, 125,
-77, -67, 74,
65, 106, 20,
18, -5, 125,
100, -63, 44,
-62, 102, 40,
18, -5, 125,
65, 106, 20,
-95, 83, 0,
-86, -73, -56,
-99, -75, 24,
-99, -75, 24,
54, -81, -80,
93, -83, -18,
93, -83, -18,
57, 15, -112,
92, 79, -36,
93, -83, -18,
54, -81, -80,
57, 15, -112,
-99, -75, 24,
-86, -73, -56,
54, -81, -80,
-95, 83, 0,
-89, 14, -88,
-86, -73, -56,
92, 79, -36,
65, 106, 20,
100, -63, 44,
-95, 83, 0,
-99, -75, 24,
-77, -67, 74,
93, -83, -18,
100, -63, 44,
-77, -67, 74,
-95, 83, 0,
-62, 102, 40,
65, 106, 20,
-89, 14, -88,
57, 15, -112,
54, -81, -80,
-95, 83, 0,
50, 103, 53,
-98, 70, 38,
92, 79, -36,
74, 34, -96,
50, 103, 53,
57, 15, -112,
-89, 9, -89,
74, 34, -96,
-89, 14, -88,
-98, 70, 38,
-89, 9, -89,
44, -41, -111,
90, 27, -84,
-86, 43, -81,
86, 43, -81,
-90, 27, -84,
-44, -41, -111,
81, 61, -75,
-82, -24, -93,
-76, -53, -86,
-76, -53, -86,
-71, -49, 92,
-76, -68, 75,
81, 47, 85,
53, 79, -83,
81, 61, -75,
57, 48, 101,
-71, -49, 92,
99, -3, 78,
-82, -24, -93,
92, 14, -85,
-33, -76, -95,
-71, -49, 92,
-33, -76, -95,
-31, -101, 70,
53, 79, -83,
57, 48, 101,
92, 14, -85,
57, 48, 101,
99, -3, 78,
92, 14, -85,
-71, -49, 92,
-82, -24, -93,
-33, -76, -95,
-82, -24, -93,
53, 79, -83,
92, 14, -85,
-71, -49, 92,
-31, -101, 70,
99, -3, 78,
92, 14, -85,
72, -104, -3,
-33, -76, -95,
99, -3, 78,
72, -104, -3,
92, 14, -85,
-31, -101, 70,
72, -104, -3,
99, -3, 78,
-33, -76, -95,
72, -104, -3,
-31, -101, 70,
-76, -68, 75,
-71, -49, 92,
81, 47, 85,
-71, -49, 92,
57, 48, 101,
81, 47, 85,
81, 47, 85,
57, 48, 101,
53, 79, -83,
-76, -53, -86,
-82, -24, -93,
-71, -49, 92,
81, 61, -75,
53, 79, -83,
-82, -24, -93,
-89, 14, -88,
-95, 83, 0,
-98, 70, 38,
57, 15, -112,
-89, 14, -88,
-89, 9, -89,
92, 79, -36,
57, 15, -112,
74, 34, -96,
-95, 83, 0,
92, 79, -36,
50, 103, 53,
95, 83, 0,
98, 70, 38,
-50, 103, 53,
-92, 79, -36,
-50, 103, 53,
-74, 34, -96,
-57, 15, -112,
-74, 34, -96,
89, 9, -89,
89, 14, -88,
89, 9, -89,
98, 70, 38,
-85, -43, -82,
-82, -2, 96,
-33, -114, 42,
-85, -43, -82,
-26, -123, -10,
27, -123, -12,
89, -37, -82,
27, -123, -12,
35, -113, 44,
-82, -2, 96,
85, 1, 94,
35, -113, 44,
85, -43, -82,
-89, -37, -82,
-27, -123, -12,
85, -43, -82,
26, -123, -10,
33, -114, 42,
82, -2, 96,
33, -114, 42,
-35, -113, 44,
-89, -37, -82,
-85, 1, 94,
-35, -113, 44,
-73, -80, -65,
-27, -123, -12,
-35, -113, 44,
26, -123, -10,
-27, -123, -12,
-73, -80, -65,
78, -57, 82,
33, -114, 42,
26, -123, -10,
-35, -113, 44,
33, -114, 42,
78, -57, 82,
35, -113, 44,
27, -123, -12,
73, -80, -65,
-33, -114, 42,
35, -113, 44,
72, -61, 83,
-26, -123, -10,
-33, -114, 42,
-78, -57, 82,
73, -80, -65,
27, -123, -12,
-26, -123, -10,
82, -24, -93,
76, -53, -86,
76, -68, 75,
71, -49, 92,
76, -68, 75,
-81, 47, 85,
-57, 48, 101,
-81, 47, 85,
-81, 61, -75,
82, -24, -93,
-53, 79, -83,
-81, 61, -75,
-39, -118, 23,
76, -68, 75,
76, -53, -86,
-81, 47, 85,
-94, -79, 28,
-94, -73, -42,
76, -53, -86,
-81, 61, -75,
-94, -73, -42,
-81, 47, 85,
76, -68, 75,
-39, -118, 23,
-76, -68, 75,
39, -118, 23,
39, -112, -44,
81, 61, -75,
-76, -53, -86,
39, -112, -44,
81, 47, 85,
81, 61, -75,
94, -73, -42,
81, 47, 85,
94, -79, 28,
39, -118, 23,
-94, -79, 28,
-39, -118, 23,
42, -96, 70,
-94, -73, -42,
-94, -79, 28,
-99, -16, 77,
42, -82, -86,
-39, -112, -44,
-94, -73, -42,
-39, -118, 23,
-39, -112, -44,
42, -82, -86,
94, -73, -42,
39, -112, -44,
-42, -82, -86,
94, -79, 28,
94, -73, -42,
99, -2, -79,
-42, -96, 70,
39, -118, 23,
94, -79, 28,
39, -112, -44,
39, -118, 23,
-42, -96, 70,
-85, 73, 59,
90, 54, 69,
32, -105, 62,
-86, 43, -81,
-85, 73, 59,
-118, 3, 46,
90, 27, -84,
44, -41, -111,
32, -105, 62,
-90, 27, -84,
-91, 53, 69,
-33, -104, 64,
86, 43, -81,
107, -10, -66,
118, -5, 44,
85, 69, 63,
118, -5, 44,
-33, -104, 64,
44, -41, -111,
-44, -41, -111,
-91, -31, -82,
32, -105, 62,
44, -41, -111,
91, -31, -82,
-33, -104, 64,
32, -105, 62,
83, -59, 75,
-33, -104, 64,
-83, -59, 75,
-91, -31, -82,
107, -10, -66,
-44, -41, -111,
44, -41, -111,
-118, 3, 46,
32, -105, 62,
-33, -104, 64,
50, 84, 79,
15, 92, 85,
59, -3, 112,
-93, -28, 80,
59, -3, 112,
66, -2, -108,
68, 97, -44,
-91, -21, -84,
66, -2, -108,
-69, 96, -44,
-48, 83, -82,
-66, -2, -108,
93, -28, 80,
91, -21, -84,
-66, -2, -108,
-51, 84, 79,
93, -28, 80,
-59, -3, 112,
-85, 18, -91,
-83, 14, 94,
-59, -3, 112,
66, -2, -108,
85, 18, -91,
-85, 18, -91,
-59, -3, 112,
-83, 14, 94,
83, 14, 94,
59, -3, 112,
83, 14, 94,
85, 18, -91,
46, 49, 107,
39, 101, -64,
98, -60, -52,
-46, 49, 107,
46, 49, 107,
49, -116, -7,
-48, 83, -82,
48, 83, -82,
66, -2, -108,
59, -3, 112,
15, 92, 85,
-15, 92, 85,
};

/* ============================================================
          Raw Data Array (Vertex NormalVector)
 ============================================================ */
/* #:29 */
static s8 vtxnvgrp_frake_select_29[]={
-20, -76, 99,
3, -77, 100,
2, -75, 102,
2, -75, 102,
26, -78, 96,
91, 1, 88,
25, -124, 4,
75, -80, -62,
-31, -120, 22,
-31, -120, 22,
-5, -79, -98,
-1, -125, 18,
-1, -125, 18,
-5, -79, -98,
21, -123, 18,
21, -123, 18,
-84, -72, -60,
-34, -121, 7,
-34, -121, 7,
-110, -61, -3,
-70, -78, 71,
25, -124, 4,
83, -7, 95,
69, -82, 67,
105, -70, -5,
53, -115, 3,
75, -80, -62,
75, -80, -62,
100, -62, -46,
-5, -79, -98,
-5, -79, -98,
-103, -57, -46,
-84, -72, -60,
-84, -72, -60,
-57, -112, 3,
-110, -61, -3,
-110, -61, -3,
-57, -112, 3,
-70, -78, 71,
-70, -78, 71,
-57, -113, 1,
0, -121, 35,
0, -121, 35,
49, -116, 2,
69, -82, 67,
69, -82, 67,
53, -115, 3,
105, -70, -5,
0, 116, -49,
-94, 76, -34,
-33, 107, -58,
100, -23, -74,
103, 0, -74,
124, -24, 0,
125, 20, 1,
90, -3, 88,
91, 1, 88,
91, 1, 88,
90, -3, 88,
2, -75, 102,
2, -75, 102,
-85, 5, 93,
-85, 9, 93,
-85, 9, 93,
-85, 5, 93,
-122, 32, 3,
-126, -12, 1,
-105, 9, -69,
-105, -12, -70,
-105, -12, -70,
-4, -6, -126,
-5, -24, -124,
-5, -24, -124,
-4, -6, -126,
100, -23, -74,
103, 0, -74,
98, 71, -37,
125, 20, 1,
125, 20, 1,
98, 71, -37,
107, 67, 8,
-101, 75, 7,
-94, 76, -34,
-122, 32, 3,
-122, 32, 3,
-94, 76, -34,
-105, 9, -69,
-105, 9, -69,
-3, 59, -111,
-4, -6, -126,
-4, -6, -126,
-3, 59, -111,
103, 0, -74,
62, 88, -66,
-3, 59, -111,
0, 116, -49,
69, -82, 67,
105, -70, -5,
25, -124, 4,
-70, -78, 71,
-78, 0, 99,
-34, -121, 7,
0, -121, 35,
69, -82, 67,
-70, -78, 71,
69, -82, 67,
5, 0, 126,
-70, -78, 71,
-20, -76, 99,
71, -64, 82,
-34, -121, 7,
-34, -121, 7,
-96, -43, -70,
-126, -12, 1,
-126, -12, 1,
-79, -30, 94,
-85, 9, 93,
-85, 9, 93,
71, -64, 82,
-20, -76, 99,
71, -64, 82,
-11, -126, -6,
70, -53, -90,
70, -53, -90,
-11, -126, -6,
-96, -43, -70,
-96, -43, -70,
-11, -126, -6,
-79, -30, 94,
-79, -30, 94,
-11, -126, -6,
71, -64, 82,
25, -124, 4,
-70, -61, 86,
26, -78, 96,
26, -78, 96,
-70, -61, 86,
91, 1, 88,
91, 1, 88,
82, -37, 89,
124, -24, 0,
124, -24, 0,
88, -53, -73,
25, -124, 4,
-79, -45, -88,
0, -126, -7,
-70, -61, 86,
-70, -61, 86,
0, -126, -7,
82, -37, 89,
82, -37, 89,
0, -126, -7,
88, -53, -73,
88, -53, -73,
0, -126, -7,
-79, -45, -88,
-31, -120, 22,
-64, -50, 96,
25, -124, 4,
25, -124, 4,
-64, -50, 96,
124, -24, 0,
124, -24, 0,
95, -53, 63,
100, -23, -74,
100, -23, -74,
-16, -58, -111,
-31, -120, 22,
-126, -2, 10,
-21, -124, -7,
-64, -50, 96,
-64, -50, 96,
-21, -124, -7,
95, -53, 63,
95, -53, 63,
-21, -124, -7,
-16, -58, -111,
-16, -58, -111,
-21, -124, -7,
-126, -2, 10,
-105, -12, -70,
-95, -47, 69,
-126, -12, 1,
-126, -12, 1,
66, -54, 93,
-34, -121, 7,
-34, -121, 7,
66, -54, 93,
21, -123, 18,
21, -123, 18,
8, -59, -111,
-105, -12, -70,
8, -59, -111,
8, -126, -9,
-95, -47, 69,
-95, -47, 69,
8, -126, -9,
66, -54, 93,
66, -54, 93,
8, -126, -9,
125, -15, 9,
125, -15, 9,
8, -126, -9,
8, -59, -111,
-1, -125, 18,
45, -20, 116,
-31, -120, 22,
-31, -120, 22,
45, -20, 116,
100, -23, -74,
100, -23, -74,
-54, -57, -99,
-5, -24, -124,
-5, -24, -124,
-54, -57, -99,
-1, -125, 18,
-109, -37, 52,
-10, -106, 67,
45, -20, 116,
45, -20, 116,
-10, -106, 67,
116, -35, -36,
116, -35, -36,
-10, -106, 67,
-54, -57, -99,
-54, -57, -99,
-10, -106, 67,
-109, -37, 52,
21, -123, 18,
-40, -15, 119,
-1, -125, 18,
-1, -125, 18,
45, -61, -101,
-5, -24, -124,
-5, -24, -124,
45, -61, -101,
-105, -12, -70,
-105, -12, -70,
-40, -15, 119,
21, -123, 18,
-40, -15, 119,
4, -108, 65,
107, -47, 48,
107, -47, 48,
4, -108, 65,
45, -61, -101,
45, -61, -101,
4, -108, 65,
-120, -25, -29,
-120, -25, -29,
4, -108, 65,
-40, -15, 119,
2, 121, 37,
4, 120, 40,
-101, 75, 7,
107, 67, 8,
4, 120, 40,
2, 121, 37,
83, -7, 95,
25, -124, 4,
26, -78, 96,
-78, 0, 99,
-20, -76, 99,
-34, -121, 7,
-78, 0, 99,
3, -77, 100,
-20, -76, 99,
83, -7, 95,
26, -78, 96,
3, -77, 100,
-78, 0, 99,
5, 0, 126,
3, -77, 100,
107, 67, 8,
90, -3, 88,
125, 20, 1,
-122, 32, 3,
-85, 5, 93,
-101, 75, 7,
91, 1, 88,
124, -24, 0,
125, 20, 1,
-122, 32, 3,
-126, -12, 1,
-85, 9, 93,
-55, 93, 64,
-56, 38, 106,
8, 101, 76,
65, 33, 103,
2, 101, 76,
0, 47, 117,
0, 116, -49,
4, 120, 40,
38, 104, -60,
0, 116, -49,
38, 104, -60,
98, 71, -37,
0, 116, -49,
98, 71, -37,
62, 88, -66,
-33, 107, -58,
4, 120, 40,
0, 116, -49,
0, 116, -49,
-59, 92, -63,
-94, 76, -34,
0, 116, -49,
-3, 59, -111,
-59, 92, -63,
2, 121, 37,
21, 32, 120,
6, 0, 126,
6, 0, 126,
-60, 21, 109,
-85, 5, 93,
-85, 5, 93,
-75, 92, 43,
-101, 75, 7,
-101, 75, 7,
25, 109, 59,
2, 121, 37,
90, -3, 88,
67, 18, 105,
6, 0, 126,
6, 0, 126,
-13, 33, 121,
2, 121, 37,
2, 121, 37,
-13, 110, 61,
107, 67, 8,
107, 67, 8,
83, 87, 38,
90, -3, 88,
83, 87, 38,
67, 18, 105,
90, -3, 88,
-13, 110, 61,
83, 87, 38,
107, 67, 8,
-13, 33, 121,
-13, 110, 61,
2, 121, 37,
67, 18, 105,
-13, 33, 121,
6, 0, 126,
-101, 75, 7,
-75, 92, 43,
25, 109, 59,
-85, 5, 93,
-60, 21, 109,
-75, 92, 43,
6, 0, 126,
21, 32, 120,
-60, 21, 109,
2, 121, 37,
25, 109, 59,
21, 32, 120,
107, 67, 8,
38, 104, -60,
4, 120, 40,
4, 120, 40,
-33, 107, -58,
-101, 75, 7,
-105, -12, -70,
-120, -25, -29,
-40, -15, 119,
45, -61, -101,
-120, -25, -29,
-105, -12, -70,
-1, -125, 18,
107, -47, 48,
45, -61, -101,
-40, -15, 119,
107, -47, 48,
-1, -125, 18,
-54, -57, -99,
-109, -37, 52,
-1, -125, 18,
100, -23, -74,
116, -35, -36,
-54, -57, -99,
45, -20, 116,
116, -35, -36,
100, -23, -74,
-1, -125, 18,
-109, -37, 52,
45, -20, 116,
21, -123, 18,
125, -15, 9,
8, -59, -111,
66, -54, 93,
125, -15, 9,
21, -123, 18,
-126, -12, 1,
-95, -47, 69,
66, -54, 93,
-105, -12, -70,
8, -59, -111,
-95, -47, 69,
-16, -58, -111,
-126, -2, 10,
-31, -120, 22,
95, -53, 63,
-16, -58, -111,
100, -23, -74,
-64, -50, 96,
95, -53, 63,
124, -24, 0,
-31, -120, 22,
-126, -2, 10,
-64, -50, 96,
88, -53, -73,
-79, -45, -88,
25, -124, 4,
82, -37, 89,
88, -53, -73,
124, -24, 0,
-70, -61, 86,
82, -37, 89,
91, 1, 88,
25, -124, 4,
-79, -45, -88,
-70, -61, 86,
-85, 9, 93,
-79, -30, 94,
71, -64, 82,
-126, -12, 1,
-96, -43, -70,
-79, -30, 94,
-34, -121, 7,
70, -53, -90,
-96, -43, -70,
71, -64, 82,
70, -53, -90,
-34, -121, 7,
5, 0, 126,
-78, 0, 99,
-70, -78, 71,
-3, 59, -111,
62, 88, -66,
103, 0, -74,
-105, 9, -69,
-59, 92, -63,
-3, 59, -111,
-94, 76, -34,
-59, 92, -63,
-105, 9, -69,
-101, 75, 7,
-33, 107, -58,
-94, 76, -34,
98, 71, -37,
38, 104, -60,
107, 67, 8,
103, 0, -74,
62, 88, -66,
98, 71, -37,
-4, -6, -126,
103, 0, -74,
100, -23, -74,
-105, -12, -70,
-105, 9, -69,
-4, -6, -126,
-126, -12, 1,
-122, 32, 3,
-105, 9, -69,
2, -75, 102,
6, 0, 126,
-85, 5, 93,
90, -3, 88,
6, 0, 126,
2, -75, 102,
103, 0, -74,
125, 20, 1,
124, -24, 0,
53, -115, 3,
49, -116, 2,
-57, -113, 1,
49, -116, 2,
0, -121, 35,
-57, -113, 1,
53, -115, 3,
-57, -113, 1,
-57, -112, 3,
69, -82, 67,
49, -116, 2,
53, -115, 3,
-57, -112, 3,
-57, -113, 1,
-70, -78, 71,
-84, -72, -60,
-103, -57, -46,
-57, -112, 3,
-5, -79, -98,
0, -78, -99,
-103, -57, -46,
100, -62, -46,
0, -78, -99,
-5, -79, -98,
53, -115, 3,
100, -62, -46,
75, -80, -62,
-84, -72, -60,
-110, -61, -3,
-34, -121, 7,
-5, -79, -98,
-84, -72, -60,
21, -123, 18,
-31, -120, 22,
75, -80, -62,
-5, -79, -98,
25, -124, 4,
105, -70, -5,
75, -80, -62,
2, -75, 102,
3, -77, 100,
26, -78, 96,
2, -75, 102,
-85, 9, 93,
-20, -76, 99,
5, 0, 126,
83, -7, 95,
3, -77, 100,
-13, 33, 121,
65, 88, 63,
-13, 110, 61,
-13, 110, 61,
0, 47, 117,
83, 87, 38,
83, 87, 38,
0, 47, 117,
67, 18, 105,
67, 18, 105,
65, 88, 63,
-13, 33, 121,
25, 109, 59,
-55, 93, 64,
21, 32, 120,
21, 32, 120,
-55, 93, 64,
-60, 21, 109,
-60, 21, 109,
11, 47, 117,
-75, 92, 43,
-75, 92, 43,
11, 47, 117,
25, 109, 59,
11, 47, 117,
-56, 38, 106,
25, 109, 59,
-60, 21, 109,
8, 101, 76,
11, 47, 117,
-55, 93, 64,
8, 101, 76,
-60, 21, 109,
25, 109, 59,
-56, 38, 106,
-55, 93, 64,
67, 18, 105,
2, 101, 76,
65, 88, 63,
0, 47, 117,
2, 101, 76,
67, 18, 105,
-13, 110, 61,
65, 33, 103,
0, 47, 117,
65, 88, 63,
65, 33, 103,
-13, 110, 61,
65, 33, 103,
65, 88, 63,
2, 101, 76,
-56, 38, 106,
11, 47, 117,
8, 101, 76,
69, -82, 67,
83, -7, 95,
5, 0, 126,
59, 1, 112,
-15, 96, 80,
-59, 1, 112,
89, -40, -80,
-89, -40, -80,
85, 13, -92,
15, 96, 80,
-51, 53, 102,
-15, 96, 80,
-15, 96, 80,
-41, 97, -70,
-49, 79, -86,
-49, 79, -86,
41, 97, -70,
49, 79, -86,
49, 79, -86,
41, 97, -70,
15, 96, 80,
83, 18, 93,
89, -40, -80,
85, 13, -92,
-83, 18, 93,
83, -55, 78,
83, 18, 93,
-85, 13, -92,
-89, -40, -80,
-83, 18, 93,
-66, -7, -107,
-49, 79, -86,
66, -7, -107,
-89, -40, -80,
-83, -55, 78,
-83, 18, 93,
-83, 18, 93,
-83, -55, 78,
83, -55, 78,
83, 18, 93,
83, -55, 78,
89, -40, -80,
41, 97, -70,
51, 53, 102,
15, 96, 80,
-49, 79, -86,
-41, 97, -70,
41, 97, -70,
-15, 96, 80,
-51, 53, 102,
-41, 97, -70,
15, 96, 80,
51, 53, 102,
-51, 53, 102,
-89, -40, -80,
-85, 13, -92,
85, 13, -92,
-51, 53, 102,
53, -115, 3,
-57, -112, 3,
51, 53, 102,
100, -62, -46,
53, -115, 3,
41, 97, -70,
0, -78, -99,
100, -62, -46,
-41, 97, -70,
-103, -57, -46,
0, -78, -99,
-51, 53, 102,
-57, -112, 3,
-103, -57, -46,
41, 97, -70,
-41, 97, -70,
0, -78, -99,
-41, 97, -70,
-51, 53, 102,
-103, -57, -46,
59, 1, 112,
85, 13, -92,
66, -7, -107,
-59, 1, 112,
83, 18, 93,
59, 1, 112,
66, -7, -107,
-85, 13, -92,
-66, -7, -107,
-66, -7, -107,
-85, 13, -92,
-59, 1, 112,
-98, -13, 78,
93, -24, 81,
-51, 88, 75,
41, -86, -82,
-98, -5, -79,
92, -25, -83,
41, -93, 74,
41, -86, -82,
93, -24, 81,
-98, -5, -79,
-51, 88, 75,
-69, 94, -48,
-98, -5, -79,
-98, -13, 78,
-51, 88, 75,
41, -86, -82,
92, -25, -83,
93, -24, 81,
-98, -5, -79,
-69, 94, -48,
92, -25, -83,
-98, -13, 78,
41, -93, 74,
93, -24, 81,
-51, 88, 75,
-59, 1, 112,
-15, 96, 80,
93, -24, 81,
-66, -7, -107,
-59, 1, 112,
92, -25, -83,
-69, 94, -48,
-66, -7, -107,
-69, 94, -48,
-15, 96, 80,
-49, 79, -86,
51, 88, 75,
-93, -24, 81,
98, -13, 78,
-92, -25, -83,
98, -5, -79,
-41, -86, -82,
-93, -24, 81,
-41, -86, -82,
-41, -93, 74,
69, 94, -48,
51, 88, 75,
98, -5, -79,
51, 88, 75,
98, -13, 78,
98, -5, -79,
-93, -24, 81,
-92, -25, -83,
-41, -86, -82,
-92, -25, -83,
69, 94, -48,
98, -5, -79,
-93, -24, 81,
-41, -93, 74,
98, -13, 78,
51, 88, 75,
49, 79, -86,
15, 96, 80,
69, 94, -48,
66, -7, -107,
49, 79, -86,
-92, -25, -83,
-93, -24, 81,
66, -7, -107,
-93, -24, 81,
51, 88, 75,
59, 1, 112,
69, 94, -48,
49, 79, -86,
51, 88, 75,
-15, 96, 80,
-69, 94, -48,
-51, 88, 75,
-119, -5, 43,
-30, -104, 65,
119, -9, 42,
110, -14, -60,
39, -46, -111,
-111, -14, -59,
-111, -14, -59,
119, -9, 42,
110, -14, -60,
-111, -14, -59,
-119, -5, 43,
119, -9, 42,
-39, -46, -111,
-30, -104, 65,
-89, -40, -80,
-30, -104, 65,
83, -55, 78,
-83, -55, 78,
30, -104, 64,
89, -40, -80,
83, -55, 78,
39, -46, -111,
-89, -40, -80,
89, -40, -80,
-78, -62, 78,
72, -66, 79,
-92, 48, 72,
73, -76, -70,
-89, 36, -82,
84, 52, -79,
72, -66, 79,
73, -76, -70,
85, 65, 67,
-78, -71, -69,
-92, 48, 72,
-89, 36, -82,
-78, -71, -69,
-78, -62, 78,
-92, 48, 72,
73, -76, -70,
84, 52, -79,
85, 65, 67,
73, -76, -70,
-78, -71, -69,
-89, 36, -82,
72, -66, 79,
85, 65, 67,
-92, 48, 72,
-92, 48, 72,
85, 65, 67,
-30, -104, 65,
85, 65, 67,
84, 52, -79,
119, -9, 42,
84, 52, -79,
-39, -46, -111,
110, -14, -60,
-89, 36, -82,
-30, -104, 65,
-39, -46, -111,
91, 48, 72,
-73, -66, 79,
78, -62, 78,
-84, 52, -79,
89, 36, -82,
-73, -76, -70,
-85, 66, 65,
-73, -76, -70,
-73, -66, 79,
89, 36, -82,
91, 48, 72,
78, -71, -69,
91, 48, 72,
78, -62, 78,
78, -71, -69,
-85, 66, 65,
-84, 52, -79,
-73, -76, -70,
89, 36, -82,
78, -71, -69,
-73, -76, -70,
91, 48, 72,
-85, 66, 65,
-73, -66, 79,
91, 48, 72,
89, 36, -82,
30, -104, 64,
-84, 52, -79,
-111, -14, -59,
39, -46, -111,
-84, 52, -79,
-119, -5, 43,
-111, -14, -59,
-85, 66, 65,
30, -104, 64,
-119, -5, 43,
-41, -86, -82,
39, -113, -39,
-41, -93, 74,
-41, -93, 74,
95, -77, 31,
98, -13, 78,
98, -13, 78,
95, -77, 31,
98, -5, -79,
98, -5, -79,
95, -74, -38,
-41, -86, -82,
41, -93, 74,
-39, -117, 29,
41, -86, -82,
41, -86, -82,
-95, -74, -38,
-98, -5, -79,
-98, -5, -79,
-95, -74, -38,
-98, -13, 78,
-98, -13, 78,
-95, -77, 31,
41, -93, 74,
-76, -64, 78,
81, 50, 83,
39, -117, 29,
81, 50, 83,
95, -74, -38,
95, -77, 31,
81, 57, -78,
39, -113, -39,
95, -74, -38,
-76, -57, -83,
-76, -64, 78,
39, -113, -39,
-81, 50, 83,
-39, -117, 29,
-95, -77, 31,
76, -57, -83,
-95, -74, -38,
-39, -113, -39,
-81, 57, -78,
-81, 50, 83,
-95, -74, -38,
-39, -113, -39,
-39, -117, 29,
76, -57, -83,
-99, 0, 78,
71, -44, 94,
-58, 53, 99,
33, -81, -91,
-92, 10, -86,
82, -28, -92,
31, -97, 74,
33, -81, -91,
71, -44, 94,
-92, 10, -86,
-58, 53, 99,
-53, 74, -87,
-92, 10, -86,
-99, 0, 78,
-58, 53, 99,
33, -81, -91,
82, -28, -92,
71, -44, 94,
-92, 10, -86,
-53, 74, -87,
82, -28, -92,
-99, 0, 78,
31, -97, 74,
71, -44, 94,
33, -81, -91,
-72, -104, 1,
-92, 10, -86,
-92, 10, -86,
-72, -104, 1,
-99, 0, 78,
-99, 0, 78,
-72, -104, 1,
31, -97, 74,
31, -97, 74,
-72, -104, 1,
33, -81, -91,
82, -28, -92,
-81, 57, -78,
76, -57, -83,
-53, 74, -87,
-58, 53, 99,
-81, 57, -78,
-58, 53, 99,
71, -44, 94,
-81, 50, 83,
71, -44, 94,
82, -28, -92,
76, -64, 78,
73, -76, -70,
-26, -122, -18,
-78, -71, -69,
-78, -71, -69,
-26, -122, -18,
-78, -62, 78,
-78, -62, 78,
-33, -117, 34,
72, -66, 79,
72, -66, 79,
35, -115, 37,
73, -76, -70,
-73, -66, 79,
-35, -115, 37,
78, -62, 78,
78, -62, 78,
26, -122, -18,
78, -71, -69,
78, -71, -69,
26, -122, -18,
-73, -76, -70,
-73, -76, -70,
-35, -115, 37,
-73, -66, 79,
89, 5, 89,
82, -7, 95,
-89, 5, 89,
-89, -5, -89,
-89, -32, -84,
89, -5, -89,
-85, -4, 94,
-89, -32, -84,
-89, 5, 89,
86, -37, -85,
82, -7, 95,
89, -5, -89,
89, 5, 89,
50, 99, 60,
89, -5, -89,
89, -5, -89,
75, 39, -94,
-89, -5, -89,
-89, -5, -89,
-98, 67, 42,
-89, 5, 89,
-89, 5, 89,
-98, 67, 42,
89, 5, 89,
-98, 67, 42,
50, 99, 60,
89, 5, 89,
-89, -5, -89,
-90, 14, -88,
-98, 67, 42,
75, 39, -94,
-90, 14, -88,
-89, -5, -89,
50, 99, 60,
75, 39, -94,
89, -5, -89,
82, -7, 95,
89, 5, 89,
89, -5, -89,
-89, -32, -84,
-89, -5, -89,
-89, 5, 89,
-89, -32, -84,
86, -37, -85,
89, -5, -89,
82, -7, 95,
-85, -4, 94,
-89, 5, 89,
-89, -32, -84,
-35, -115, 37,
-27, -122, -20,
-85, -4, 94,
82, -7, 95,
-35, -115, 37,
82, -7, 95,
86, -37, -85,
33, -117, 34,
86, -37, -85,
-27, -122, -20,
26, -122, -18,
89, 5, 89,
-82, -7, 95,
-89, 5, 89,
-89, -5, -89,
89, -32, -84,
89, -5, -89,
89, 5, 89,
89, -32, -84,
85, -4, 94,
-89, -5, -89,
-82, -7, 95,
-86, -37, -85,
-89, -5, -89,
-50, 99, 60,
-89, 5, 89,
89, -5, -89,
-75, 39, -94,
-89, -5, -89,
89, 5, 89,
98, 67, 42,
89, -5, -89,
-89, 5, 89,
98, 67, 42,
89, 5, 89,
-89, 5, 89,
-50, 99, 60,
98, 67, 42,
98, 67, 42,
90, 14, -88,
89, -5, -89,
89, -5, -89,
90, 14, -88,
-75, 39, -94,
-89, -5, -89,
-75, 39, -94,
-50, 99, 60,
-89, -5, -89,
-89, 5, 89,
-82, -7, 95,
89, 5, 89,
89, -5, -89,
89, -32, -84,
-89, -5, -89,
-86, -37, -85,
89, -32, -84,
89, 5, 89,
85, -4, 94,
-82, -7, 95,
-82, -7, 95,
35, -115, 37,
-33, -117, 34,
85, -4, 94,
89, -32, -84,
35, -115, 37,
89, -32, -84,
-86, -37, -85,
27, -122, -20,
-86, -37, -85,
-33, -117, 34,
-26, -122, -18,
86, -70, -60,
-54, -76, -85,
90, 19, -87,
-66, 105, 26,
96, 82, 4,
-92, 81, -30,
98, -77, 18,
77, -72, 69,
-93, -82, -23,
77, -72, 69,
96, 82, 4,
62, 100, 46,
-93, -82, -23,
-100, -66, 39,
-92, 81, -30,
62, 100, 46,
-18, -13, 124,
77, -72, 69,
77, -72, 69,
-18, -13, 124,
-100, -66, 39,
-100, -66, 39,
-18, -13, 124,
-66, 105, 26,
-66, 105, 26,
-18, -13, 124,
62, 100, 46,
98, -77, 18,
86, -70, -60,
96, 82, 4,
-93, -82, -23,
-54, -76, -85,
98, -77, 18,
-92, 81, -30,
-57, 22, -110,
-93, -82, -23,
-57, 22, -110,
-54, -76, -85,
-93, -82, -23,
-54, -76, -85,
86, -70, -60,
98, -77, 18,
86, -70, -60,
90, 19, -87,
96, 82, 4,
-100, -66, 39,
-66, 105, 26,
-92, 81, -30,
77, -72, 69,
98, -77, 18,
96, 82, 4,
77, -72, 69,
-100, -66, 39,
-93, -82, -23,
-66, 105, 26,
62, 100, 46,
96, 82, 4,
-54, -76, -85,
-57, 22, -110,
90, 19, -87,
96, 82, 4,
90, 19, -87,
98, 67, 42,
90, 19, -87,
-57, 22, -110,
90, 14, -88,
-57, 22, -110,
-92, 81, -30,
-75, 39, -94,
-92, 81, -30,
96, 82, 4,
-50, 99, 60,
-90, 19, -87,
54, -76, -85,
-86, -70, -60,
92, 81, -30,
-96, 82, 4,
66, 105, 26,
93, -82, -23,
-77, -72, 69,
-98, -77, 18,
-62, 100, 46,
-96, 82, 4,
-77, -72, 69,
92, 81, -30,
100, -66, 39,
93, -82, -23,
-77, -72, 69,
18, -13, 124,
-62, 100, 46,
100, -66, 39,
18, -13, 124,
-77, -72, 69,
66, 105, 26,
18, -13, 124,
100, -66, 39,
-62, 100, 46,
18, -13, 124,
66, 105, 26,
-96, 82, 4,
-86, -70, -60,
-98, -77, 18,
-98, -77, 18,
54, -76, -85,
93, -82, -23,
93, -82, -23,
57, 22, -110,
92, 81, -30,
93, -82, -23,
54, -76, -85,
57, 22, -110,
-98, -77, 18,
-86, -70, -60,
54, -76, -85,
-96, 82, 4,
-90, 19, -87,
-86, -70, -60,
92, 81, -30,
66, 105, 26,
100, -66, 39,
-96, 82, 4,
-98, -77, 18,
-77, -72, 69,
93, -82, -23,
100, -66, 39,
-77, -72, 69,
-96, 82, 4,
-62, 100, 46,
66, 105, 26,
-90, 19, -87,
57, 22, -110,
54, -76, -85,
-96, 82, 4,
50, 99, 60,
-98, 67, 42,
92, 81, -30,
75, 39, -94,
50, 99, 60,
57, 22, -110,
-90, 14, -88,
75, 39, -94,
-90, 19, -87,
-98, 67, 42,
-90, 14, -88,
39, -46, -111,
89, 36, -82,
-84, 52, -79,
84, 52, -79,
-89, 36, -82,
-39, -46, -111,
81, 57, -78,
-82, -28, -92,
-76, -57, -83,
-76, -57, -83,
-71, -44, 94,
-76, -64, 78,
81, 50, 83,
53, 74, -87,
81, 57, -78,
58, 53, 99,
-71, -44, 94,
99, 0, 78,
-82, -28, -92,
92, 10, -86,
-33, -81, -91,
-71, -44, 94,
-33, -81, -91,
-31, -97, 74,
53, 74, -87,
58, 53, 99,
92, 10, -86,
58, 53, 99,
99, 0, 78,
92, 10, -86,
-71, -44, 94,
-82, -28, -92,
-33, -81, -91,
-82, -28, -92,
53, 74, -87,
92, 10, -86,
-71, -44, 94,
-31, -97, 74,
99, 0, 78,
92, 10, -86,
72, -104, 1,
-33, -81, -91,
99, 0, 78,
72, -104, 1,
92, 10, -86,
-31, -97, 74,
72, -104, 1,
99, 0, 78,
-33, -81, -91,
72, -104, 1,
-31, -97, 74,
-76, -64, 78,
-71, -44, 94,
81, 50, 83,
-71, -44, 94,
58, 53, 99,
81, 50, 83,
81, 50, 83,
58, 53, 99,
53, 74, -87,
-76, -57, -83,
-82, -28, -92,
-71, -44, 94,
81, 57, -78,
53, 74, -87,
-82, -28, -92,
-90, 19, -87,
-96, 82, 4,
-98, 67, 42,
57, 22, -110,
-90, 19, -87,
-90, 14, -88,
92, 81, -30,
57, 22, -110,
75, 39, -94,
-96, 82, 4,
92, 81, -30,
50, 99, 60,
96, 82, 4,
98, 67, 42,
-50, 99, 60,
-92, 81, -30,
-50, 99, 60,
-75, 39, -94,
-57, 22, -110,
-75, 39, -94,
90, 14, -88,
90, 19, -87,
90, 14, -88,
98, 67, 42,
-86, -37, -85,
-82, -7, 95,
-33, -117, 34,
-86, -37, -85,
-26, -122, -18,
27, -122, -20,
89, -32, -84,
27, -122, -20,
35, -115, 37,
-82, -7, 95,
85, -4, 94,
35, -115, 37,
86, -37, -85,
-89, -32, -84,
-27, -122, -20,
86, -37, -85,
26, -122, -18,
33, -117, 34,
82, -7, 95,
33, -117, 34,
-35, -115, 37,
-89, -32, -84,
-85, -4, 94,
-35, -115, 37,
-73, -76, -70,
-27, -122, -20,
-35, -115, 37,
26, -122, -18,
-27, -122, -20,
-73, -76, -70,
78, -62, 78,
33, -117, 34,
26, -122, -18,
-35, -115, 37,
33, -117, 34,
78, -62, 78,
35, -115, 37,
27, -122, -20,
73, -76, -70,
-33, -117, 34,
35, -115, 37,
72, -66, 79,
-26, -122, -18,
-33, -117, 34,
-78, -62, 78,
73, -76, -70,
27, -122, -20,
-26, -122, -18,
82, -28, -92,
76, -57, -83,
76, -64, 78,
71, -44, 94,
76, -64, 78,
-81, 50, 83,
-58, 53, 99,
-81, 50, 83,
-81, 57, -78,
82, -28, -92,
-53, 74, -87,
-81, 57, -78,
-39, -117, 29,
76, -64, 78,
76, -57, -83,
-81, 50, 83,
-95, -77, 31,
-95, -74, -38,
76, -57, -83,
-81, 57, -78,
-95, -74, -38,
-81, 50, 83,
76, -64, 78,
-39, -117, 29,
-76, -64, 78,
39, -117, 29,
39, -113, -39,
81, 57, -78,
-76, -57, -83,
39, -113, -39,
81, 50, 83,
81, 57, -78,
95, -74, -38,
81, 50, 83,
95, -77, 31,
39, -117, 29,
-95, -77, 31,
-39, -117, 29,
41, -93, 74,
-95, -74, -38,
-95, -77, 31,
-98, -13, 78,
41, -86, -82,
-39, -113, -39,
-95, -74, -38,
-39, -117, 29,
-39, -113, -39,
41, -86, -82,
95, -74, -38,
39, -113, -39,
-41, -86, -82,
95, -77, 31,
95, -74, -38,
98, -5, -79,
-41, -93, 74,
39, -117, 29,
95, -77, 31,
39, -113, -39,
39, -117, 29,
-41, -93, 74,
-85, 66, 65,
91, 48, 72,
30, -104, 64,
-84, 52, -79,
-85, 66, 65,
-119, -5, 43,
89, 36, -82,
39, -46, -111,
30, -104, 64,
-89, 36, -82,
-92, 48, 72,
-30, -104, 65,
84, 52, -79,
110, -14, -60,
119, -9, 42,
85, 65, 67,
119, -9, 42,
-30, -104, 65,
39, -46, -111,
-39, -46, -111,
-89, -40, -80,
30, -104, 64,
39, -46, -111,
89, -40, -80,
-30, -104, 65,
30, -104, 64,
83, -55, 78,
-30, -104, 65,
-83, -55, 78,
-89, -40, -80,
110, -14, -60,
-39, -46, -111,
39, -46, -111,
-119, -5, 43,
30, -104, 64,
-30, -104, 65,
51, 88, 75,
15, 96, 80,
59, 1, 112,
-93, -24, 81,
59, 1, 112,
66, -7, -107,
69, 94, -48,
-92, -25, -83,
66, -7, -107,
-69, 94, -48,
-49, 79, -86,
-66, -7, -107,
93, -24, 81,
92, -25, -83,
-66, -7, -107,
-51, 88, 75,
93, -24, 81,
-59, 1, 112,
-85, 13, -92,
-83, 18, 93,
-59, 1, 112,
66, -7, -107,
85, 13, -92,
-85, 13, -92,
-59, 1, 112,
-83, 18, 93,
83, 18, 93,
59, 1, 112,
83, 18, 93,
85, 13, -92,
51, 53, 102,
41, 97, -70,
100, -62, -46,
-51, 53, 102,
51, 53, 102,
53, -115, 3,
-49, 79, -86,
49, 79, -86,
66, -7, -107,
59, 1, 112,
15, 96, 80,
-15, 96, 80,
};

static Gfx _frake_select_aligner1[] = { gsSPEndDisplayList() };

/* ============================================================
          Vtx
 ============================================================ */
static Vtx vtx_Shape_of___POLYHEDRON_246_[] = {
  {    57,  -150,   346,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*     0 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*     1 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*     2 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*     3 */
  {     0,  -150,   290,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*     4 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*     5 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*     6 */
  {   -65,  -150,   316,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*     7 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0x00,0x41,0x83,0xff }, /*     8 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*     9 */
  {   -73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*    10 */
  {   -65,  -150,   316,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*    11 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*    12 */
  {     0,  -150,   290,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*    13 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*    14 */
  {   -65,  -150,   318,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*    15 */
  {   -66,  -150,   296,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*    16 */
  {   -71,  -150,   318,0, 0x0000,0x0000, 0x00,0x46,0x8d,0xff }, /*    17 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*    18 */
  {   -47,  -150,   305,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*    19 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*    20 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*    21 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*    22 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0x00,0x41,0x83,0xff }, /*    23 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0xd3,0x98,0x6d,0xff }, /*    24 */
  {   -52,  -150,   290,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    25 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*    26 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0xb8,0x85,0x5f,0xff }, /*    27 */
  {    42,  -150,   327,0, 0x0000,0x0000, 0xc2,0x5c,0x3c,0xff }, /*    28 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x90,0x68,0x4b,0xff }, /*    29 */
  {    52,  -150,   290,0, 0x0000,0x0000, 0x9b,0x70,0x50,0xff }, /*    30 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*    31 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0xa2,0x75,0x54,0xff }, /*    32 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0xa2,0x75,0x54,0xff }, /*    33 */
  {    11,  -150,   271,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    34 */
  {     0,  -150,   290,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*    35 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0xc8,0x90,0x68,0xff }, /*    36 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xba,0x86,0x61,0xff }, /*    37 */
  {    11,  -150,   271,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*    38 */
  {     0,  -150,   290,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*    39 */
  {   -11,  -150,   271,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*    40 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xcf,0x96,0x6c,0xff }, /*    41 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    42 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0x9d,0x72,0x52,0xff }, /*    43 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*    44 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*    45 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*    46 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0x9d,0x72,0x52,0xff }, /*    47 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xcf,0x96,0x6c,0xff }, /*    48 */
  {   -15,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    49 */
  {   -52,  -150,   290,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    50 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xea,0xa9,0x79,0xff }, /*    51 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x9e,0x72,0x52,0xff }, /*    52 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*    53 */
  {   -52,  -150,   290,0, 0x0000,0x0000, 0xc0,0x8b,0x64,0xff }, /*    54 */
  {   -15,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    55 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*    56 */
  {   -15,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    57 */
  {   -18,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    58 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*    59 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*    60 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*    61 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xea,0xa9,0x79,0xff }, /*    62 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*    63 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0x9b,0x70,0x50,0xff }, /*    64 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xea,0xa9,0x79,0xff }, /*    65 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*    66 */
  {   -18,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    67 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    68 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*    69 */
  {    18,  -150,   271,0, 0x0000,0x0000, 0xa8,0x7a,0x57,0xff }, /*    70 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x90,0x68,0x4b,0xff }, /*    71 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xa3,0x76,0x55,0xff }, /*    72 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*    73 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x9e,0x5b,0x31,0xff }, /*    74 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0xe1,0xa3,0x75,0xff }, /*    75 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*    76 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0x9d,0x72,0x52,0xff }, /*    77 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x90,0x68,0x4b,0xff }, /*    78 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*    79 */
  {    52,  -150,   290,0, 0x0000,0x0000, 0x9b,0x70,0x50,0xff }, /*    80 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*    81 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0xda,0x9e,0x71,0xff }, /*    82 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0xa2,0x75,0x54,0xff }, /*    83 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x23,0x00,0x46,0xff }, /*    84 */
  {    57,  -150,   359,0, 0x0000,0x0000, 0x1b,0x00,0x36,0xff }, /*    85 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x2e,0x00,0x5c,0xff }, /*    86 */
  {    73,  -150,   372,0, 0x0000,0x0000, 0x33,0x00,0x67,0xff }, /*    87 */
  {    51,  -150,   387,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*    88 */
  {    64,  -150,   362,0, 0x0000,0x0000, 0x3e,0x00,0x7c,0xff }, /*    89 */
  {    64,  -150,   362,0, 0x0000,0x0000, 0x3e,0x00,0x7c,0xff }, /*    90 */
  {    51,  -150,   387,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*    91 */
  {     0,  -150,   368,0, 0x0000,0x0000, 0x2e,0x00,0x5c,0xff }, /*    92 */
  {    51,  -150,   387,0, 0x0000,0x0000, 0x3d,0x00,0x7b,0xff }, /*    93 */
  {     0,  -150,   394,0, 0x0000,0x0000, 0x2f,0x00,0x5f,0xff }, /*    94 */
  {     0,  -150,   368,0, 0x0000,0x0000, 0x2e,0x00,0x5c,0xff }, /*    95 */
  {     0,  -150,   368,0, 0x0000,0x0000, 0x2e,0x00,0x5c,0xff }, /*    96 */
  {   -51,  -150,   387,0, 0x0000,0x0000, 0x34,0x00,0x68,0xff }, /*    97 */
  {   -64,  -150,   362,0, 0x0000,0x0000, 0x35,0x00,0x6b,0xff }, /*    98 */
  {   -64,  -150,   362,0, 0x0000,0x0000, 0x35,0x00,0x6b,0xff }, /*    99 */
  {   -51,  -150,   387,0, 0x0000,0x0000, 0x34,0x00,0x68,0xff }, /*   100 */
  {   -73,  -150,   372,0, 0x0000,0x0000, 0x35,0x00,0x6a,0xff }, /*   101 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x3d,0x00,0x7a,0xff }, /*   102 */
  {   -57,  -150,   359,0, 0x0000,0x0000, 0x43,0x00,0x86,0xff }, /*   103 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x46,0x00,0x8c,0xff }, /*   104 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x46,0x00,0x8c,0xff }, /*   105 */
  {     0,  -150,   350,0, 0x0000,0x0000, 0x31,0x00,0x63,0xff }, /*   106 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x30,0x00,0x60,0xff }, /*   107 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x46,0x00,0x8c,0xff }, /*   108 */
  {   -57,  -150,   359,0, 0x0000,0x0000, 0x43,0x00,0x86,0xff }, /*   109 */
  {     0,  -150,   350,0, 0x0000,0x0000, 0x31,0x00,0x63,0xff }, /*   110 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x30,0x00,0x60,0xff }, /*   111 */
  {     0,  -150,   350,0, 0x0000,0x0000, 0x31,0x00,0x63,0xff }, /*   112 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x23,0x00,0x46,0xff }, /*   113 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x90,0x68,0x4b,0xff }, /*   114 */
  {    52,  -150,   290,0, 0x0000,0x0000, 0x9b,0x70,0x50,0xff }, /*   115 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0xb8,0x85,0x5f,0xff }, /*   116 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*   117 */
  {   -42,  -150,   327,0, 0x0000,0x0000, 0xa7,0x4f,0x34,0xff }, /*   118 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0xd3,0x98,0x6d,0xff }, /*   119 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   120 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0xdd,0xa0,0x73,0xff }, /*   121 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x82,0x5e,0x43,0xff }, /*   122 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xcc,0x93,0x6a,0xff }, /*   123 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*   124 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*   125 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*   126 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*   127 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   128 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xcc,0x93,0x6a,0xff }, /*   129 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*   130 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*   131 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   132 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x90,0x68,0x4b,0xff }, /*   133 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*   134 */
  {   -42,  -150,   362,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   135 */
  {   -56,  -150,   331,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   136 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0x00,0x41,0x83,0xff }, /*   137 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0x00,0x41,0x83,0xff }, /*   138 */
  {   -71,  -150,   318,0, 0x0000,0x0000, 0x00,0x46,0x8d,0xff }, /*   139 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   140 */
  {     0,  -150,   290,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*   141 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   142 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*   143 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   144 */
  {   -64,  -150,   331,0, 0x0000,0x0000, 0x00,0x2d,0x5a,0xff }, /*   145 */
  {   -64,  -150,   362,0, 0x0000,0x0000, 0x00,0x35,0x6b,0xff }, /*   146 */
  {   -64,  -150,   362,0, 0x0000,0x0000, 0x00,0x35,0x6b,0xff }, /*   147 */
  {   -56,  -150,   331,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   148 */
  {   -42,  -150,   362,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   149 */
  {   -56,  -150,   331,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   150 */
  {   -66,  -150,   296,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   151 */
  {   -65,  -150,   318,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   152 */
  {   -71,  -150,   318,0, 0x0000,0x0000, 0x00,0x46,0x8d,0xff }, /*   153 */
  {   -66,  -150,   296,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   154 */
  {   -64,  -150,   331,0, 0x0000,0x0000, 0x00,0x2d,0x5a,0xff }, /*   155 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*   156 */
  {   -57,  -150,   273,0, 0x0000,0x0000, 0x00,0x00,0x40,0xff }, /*   157 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   158 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   159 */
  {    47,  -150,   305,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   160 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   161 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*   162 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*   163 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   164 */
  {   -64,  -150,   331,0, 0x0000,0x0000, 0x00,0x2d,0x5a,0xff }, /*   165 */
  {   -66,  -150,   296,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   166 */
  {   -56,  -150,   331,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   167 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   168 */
  {    56,  -150,   331,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   169 */
  {    42,  -150,   362,0, 0x0000,0x0000, 0x00,0x2c,0x59,0xff }, /*   170 */
  {    42,  -150,   362,0, 0x0000,0x0000, 0x00,0x2c,0x59,0xff }, /*   171 */
  {    56,  -150,   331,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   172 */
  {    64,  -150,   362,0, 0x0000,0x0000, 0x00,0x3e,0x7c,0xff }, /*   173 */
  {    64,  -150,   362,0, 0x0000,0x0000, 0x00,0x3e,0x7c,0xff }, /*   174 */
  {    64,  -150,   331,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   175 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   176 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   177 */
  {    71,  -150,   318,0, 0x0000,0x0000, 0x00,0x30,0x61,0xff }, /*   178 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   179 */
  {    65,  -150,   318,0, 0x0000,0x0000, 0x00,0x47,0x8f,0xff }, /*   180 */
  {    66,  -150,   296,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   181 */
  {    56,  -150,   331,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   182 */
  {    56,  -150,   331,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   183 */
  {    66,  -150,   296,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   184 */
  {    64,  -150,   331,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   185 */
  {    64,  -150,   331,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   186 */
  {    66,  -150,   296,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   187 */
  {    71,  -150,   318,0, 0x0000,0x0000, 0x00,0x30,0x61,0xff }, /*   188 */
  {    56,  -150,   305,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   189 */
  {    28,  -150,   271,0, 0x0000,0x0000, 0x00,0x00,0x4b,0xff }, /*   190 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   191 */
  {    64,  -150,   331,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   192 */
  {    71,  -150,   318,0, 0x0000,0x0000, 0x00,0x30,0x61,0xff }, /*   193 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   194 */
  {    71,  -150,   318,0, 0x0000,0x0000, 0x00,0x30,0x61,0xff }, /*   195 */
  {    66,  -150,   296,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   196 */
  {    65,  -150,   318,0, 0x0000,0x0000, 0x00,0x47,0x8f,0xff }, /*   197 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   198 */
  {    65,  -150,   316,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   199 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   200 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   201 */
  {    65,  -150,   316,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   202 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   203 */
  {    65,  -150,   316,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   204 */
  {    73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   205 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   206 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   207 */
  {    73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   208 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   209 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   210 */
  {    52,  -150,   290,0, 0x0000,0x0000, 0x00,0x30,0x60,0xff }, /*   211 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   212 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   213 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   214 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   215 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x42,0x85,0xff }, /*   216 */
  {    57,  -150,   273,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   217 */
  {    65,  -150,   316,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   218 */
  {    65,  -150,   316,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   219 */
  {    57,  -150,   273,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   220 */
  {    73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   221 */
  {    73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   222 */
  {    57,  -150,   273,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   223 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   224 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   225 */
  {    57,  -150,   273,0, 0x0000,0x0000, 0x00,0x00,0x46,0xff }, /*   226 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x42,0x85,0xff }, /*   227 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   228 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x42,0x85,0xff }, /*   229 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   230 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x00,0x46,0x8c,0xff }, /*   231 */
  {   -73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   232 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   233 */
  {    47,  -150,   305,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   234 */
  {    56,  -150,   305,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   235 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   236 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0x00,0x41,0x83,0xff }, /*   237 */
  {   -65,  -150,   316,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   238 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*   239 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*   240 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   241 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x00,0x46,0x8c,0xff }, /*   242 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   243 */
  {   -57,  -150,   273,0, 0x0000,0x0000, 0x00,0x00,0x40,0xff }, /*   244 */
  {   -73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   245 */
  {   -47,  -150,   305,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   246 */
  {   -28,  -150,   271,0, 0x0000,0x0000, 0x00,0x00,0x49,0xff }, /*   247 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   248 */
  {   -73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   249 */
  {   -57,  -150,   273,0, 0x0000,0x0000, 0x00,0x00,0x40,0xff }, /*   250 */
  {   -65,  -150,   316,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   251 */
  {   -65,  -150,   316,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   252 */
  {   -57,  -150,   273,0, 0x0000,0x0000, 0x00,0x00,0x40,0xff }, /*   253 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*   254 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   255 */
  {    28,  -150,   271,0, 0x0000,0x0000, 0x00,0x00,0x4b,0xff }, /*   256 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   257 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   258 */
  {    47,  -150,   305,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   259 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   260 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   261 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   262 */
  {    47,  -150,   305,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   263 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   264 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   265 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x30,0x60,0xff }, /*   266 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x30,0x60,0xff }, /*   267 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   268 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   269 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   270 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   271 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   272 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x35,0x6a,0xff }, /*   273 */
  {    28,  -150,   271,0, 0x0000,0x0000, 0x00,0x00,0x4b,0xff }, /*   274 */
  {    47,  -150,   305,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   275 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   276 */
  {    65,  -150,   318,0, 0x0000,0x0000, 0x00,0x47,0x8f,0xff }, /*   277 */
  {    56,  -150,   331,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   278 */
  {    47,  -150,   305,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   279 */
  {    28,  -150,   271,0, 0x0000,0x0000, 0x00,0x00,0x4b,0xff }, /*   280 */
  {    56,  -150,   305,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   281 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   282 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   283 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x30,0x60,0xff }, /*   284 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   285 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   286 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   287 */
  {    56,  -150,   331,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   288 */
  {    64,  -150,   331,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   289 */
  {    64,  -150,   362,0, 0x0000,0x0000, 0x00,0x3e,0x7c,0xff }, /*   290 */
  {   -64,  -150,   362,0, 0x0000,0x0000, 0x00,0x35,0x6b,0xff }, /*   291 */
  {   -64,  -150,   331,0, 0x0000,0x0000, 0x00,0x2d,0x5a,0xff }, /*   292 */
  {   -56,  -150,   331,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   293 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x30,0x60,0xff }, /*   294 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   295 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x00,0x46,0x8c,0xff }, /*   296 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x00,0x46,0x8c,0xff }, /*   297 */
  {   -47,  -150,   305,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   298 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*   299 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   300 */
  {   -28,  -150,   271,0, 0x0000,0x0000, 0x00,0x00,0x49,0xff }, /*   301 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   302 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   303 */
  {   -71,  -150,   318,0, 0x0000,0x0000, 0x00,0x46,0x8d,0xff }, /*   304 */
  {   -64,  -150,   331,0, 0x0000,0x0000, 0x00,0x2d,0x5a,0xff }, /*   305 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   306 */
  {   -28,  -150,   271,0, 0x0000,0x0000, 0x00,0x00,0x49,0xff }, /*   307 */
  {   -56,  -150,   305,0, 0x0000,0x0000, 0x00,0x44,0x89,0xff }, /*   308 */
  {   -47,  -150,   305,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   309 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   310 */
  {     0,  -150,   326,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   311 */
  {   -56,  -150,   305,0, 0x0000,0x0000, 0x00,0x44,0x89,0xff }, /*   312 */
  {   -28,  -150,   271,0, 0x0000,0x0000, 0x00,0x00,0x49,0xff }, /*   313 */
  {   -47,  -150,   305,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   314 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   315 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   316 */
  {     0,  -150,   290,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*   317 */
  {    42,  -150,   327,0, 0x0000,0x0000, 0xc2,0x5c,0x3c,0xff }, /*   318 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0xb8,0x85,0x5f,0xff }, /*   319 */
  {    42,  -150,   362,0, 0x0000,0x0000, 0x8f,0x67,0x4a,0xff }, /*   320 */
  {   -42,  -150,   327,0, 0x0000,0x0000, 0xa7,0x4f,0x34,0xff }, /*   321 */
  {   -42,  -150,   362,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*   322 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0xd3,0x98,0x6d,0xff }, /*   323 */
  {    64,  -150,   362,0, 0x0000,0x0000, 0x3e,0x00,0x7c,0xff }, /*   324 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x2e,0x00,0x5c,0xff }, /*   325 */
  {    73,  -150,   372,0, 0x0000,0x0000, 0x33,0x00,0x67,0xff }, /*   326 */
  {   -73,  -150,   372,0, 0x0000,0x0000, 0x35,0x00,0x6a,0xff }, /*   327 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x3d,0x00,0x7a,0xff }, /*   328 */
  {   -64,  -150,   362,0, 0x0000,0x0000, 0x35,0x00,0x6b,0xff }, /*   329 */
  {     0,  -150,   350,0, 0x0000,0x0000, 0x31,0x00,0x63,0xff }, /*   330 */
  {    57,  -150,   359,0, 0x0000,0x0000, 0x1b,0x00,0x36,0xff }, /*   331 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x23,0x00,0x46,0xff }, /*   332 */
  {     0,  -150,   433,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   333 */
  {    -6,  -150,   405,0, 0x0000,0x0000, 0xb7,0x88,0x00,0xff }, /*   334 */
  {     0,  -150,   394,0, 0x0000,0x0000, 0x9f,0x76,0x00,0xff }, /*   335 */
  {     0,  -150,   433,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   336 */
  {    -6,  -150,   437,0, 0x0000,0x0000, 0xfc,0xbb,0x00,0xff }, /*   337 */
  {    -6,  -150,   405,0, 0x0000,0x0000, 0xb7,0x88,0x00,0xff }, /*   338 */
  {     0,  -150,   394,0, 0x0000,0x0000, 0x9f,0x76,0x00,0xff }, /*   339 */
  {   -50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   340 */
  {   -51,  -150,   387,0, 0x0000,0x0000, 0xad,0x81,0x00,0xff }, /*   341 */
  {     0,  -150,   394,0, 0x0000,0x0000, 0x9f,0x76,0x00,0xff }, /*   342 */
  {    -6,  -150,   405,0, 0x0000,0x0000, 0xb7,0x88,0x00,0xff }, /*   343 */
  {   -50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   344 */
  {   -51,  -150,   387,0, 0x0000,0x0000, 0xad,0x81,0x00,0xff }, /*   345 */
  {   -59,  -150,   430,0, 0x0000,0x0000, 0xc0,0x8f,0x00,0xff }, /*   346 */
  {   -59,  -150,   425,0, 0x0000,0x0000, 0xa7,0x7c,0x00,0xff }, /*   347 */
  {   -59,  -150,   425,0, 0x0000,0x0000, 0xa7,0x7c,0x00,0xff }, /*   348 */
  {    -6,  -150,   437,0, 0x0000,0x0000, 0xfc,0xbb,0x00,0xff }, /*   349 */
  {     0,  -150,   433,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   350 */
  {   -59,  -150,   425,0, 0x0000,0x0000, 0xa7,0x7c,0x00,0xff }, /*   351 */
  {   -59,  -150,   430,0, 0x0000,0x0000, 0xc0,0x8f,0x00,0xff }, /*   352 */
  {    -6,  -150,   437,0, 0x0000,0x0000, 0xfc,0xbb,0x00,0xff }, /*   353 */
  {    51,  -150,   387,0, 0x0000,0x0000, 0xce,0x99,0x00,0xff }, /*   354 */
  {    50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   355 */
  {     0,  -150,   394,0, 0x0000,0x0000, 0x9f,0x76,0x00,0xff }, /*   356 */
  {     0,  -150,   394,0, 0x0000,0x0000, 0x9f,0x76,0x00,0xff }, /*   357 */
  {     6,  -150,   405,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   358 */
  {     0,  -150,   433,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   359 */
  {     0,  -150,   433,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   360 */
  {     6,  -150,   437,0, 0x0000,0x0000, 0xe4,0xaa,0x00,0xff }, /*   361 */
  {    59,  -150,   425,0, 0x0000,0x0000, 0xb9,0x89,0x00,0xff }, /*   362 */
  {    59,  -150,   425,0, 0x0000,0x0000, 0xb9,0x89,0x00,0xff }, /*   363 */
  {    59,  -150,   430,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   364 */
  {    51,  -150,   387,0, 0x0000,0x0000, 0xce,0x99,0x00,0xff }, /*   365 */
  {    59,  -150,   430,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   366 */
  {    50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   367 */
  {    51,  -150,   387,0, 0x0000,0x0000, 0xce,0x99,0x00,0xff }, /*   368 */
  {     6,  -150,   405,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   369 */
  {     6,  -150,   437,0, 0x0000,0x0000, 0xe4,0xaa,0x00,0xff }, /*   370 */
  {     0,  -150,   433,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   371 */
  {     6,  -150,   437,0, 0x0000,0x0000, 0xe4,0xaa,0x00,0xff }, /*   372 */
  {    59,  -150,   430,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   373 */
  {    59,  -150,   425,0, 0x0000,0x0000, 0xb9,0x89,0x00,0xff }, /*   374 */
  {    50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   375 */
  {     6,  -150,   405,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   376 */
  {     0,  -150,   394,0, 0x0000,0x0000, 0x9f,0x76,0x00,0xff }, /*   377 */
  {   -51,  -150,   387,0, 0x0000,0x0000, 0xad,0x81,0x00,0xff }, /*   378 */
  {   -50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   379 */
  {   -59,  -150,   430,0, 0x0000,0x0000, 0xc0,0x8f,0x00,0xff }, /*   380 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x00,0x46,0x8c,0xff }, /*   381 */
  {   -56,  -150,   305,0, 0x0000,0x0000, 0x00,0x44,0x89,0xff }, /*   382 */
  {   -47,  -150,   305,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   383 */
  {    -4,  -150,   297,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   384 */
  {   -56,  -150,   305,0, 0x0000,0x0000, 0x00,0x44,0x89,0xff }, /*   385 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x00,0x46,0x8c,0xff }, /*   386 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   387 */
  {    56,  -150,   305,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   388 */
  {     4,  -150,   297,0, 0x0000,0x0000, 0x00,0x37,0x6f,0xff }, /*   389 */
  {   -65,  -150,   316,0, 0x0000,0x0000, 0x00,0x32,0x65,0xff }, /*   390 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x38,0x71,0xff }, /*   391 */
  {   -51,  -150,   335,0, 0x0000,0x0000, 0x00,0x3c,0x79,0xff }, /*   392 */
  {   -53,  -150,   335,0, 0x0000,0x0000, 0x00,0x46,0x8c,0xff }, /*   393 */
  {   -54,  -150,   307,0, 0x0000,0x0000, 0x00,0x3a,0x74,0xff }, /*   394 */
  {   -73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   395 */
  {    73,  -150,   316,0, 0x0000,0x0000, 0x00,0x33,0x67,0xff }, /*   396 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x36,0x6d,0xff }, /*   397 */
  {    53,  -150,   335,0, 0x0000,0x0000, 0x00,0x23,0x46,0xff }, /*   398 */
  {    51,  -150,   335,0, 0x0000,0x0000, 0x00,0x44,0x88,0xff }, /*   399 */
  {    54,  -150,   307,0, 0x0000,0x0000, 0x00,0x42,0x85,0xff }, /*   400 */
  {    65,  -150,   316,0, 0x0000,0x0000, 0x00,0x31,0x63,0xff }, /*   401 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0x00,0x41,0x83,0xff }, /*   402 */
  {   -65,  -150,   318,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   403 */
  {   -71,  -150,   318,0, 0x0000,0x0000, 0x00,0x46,0x8d,0xff }, /*   404 */
  {    71,  -150,   318,0, 0x0000,0x0000, 0x00,0x30,0x61,0xff }, /*   405 */
  {    65,  -150,   318,0, 0x0000,0x0000, 0x00,0x47,0x8f,0xff }, /*   406 */
  {    57,  -150,   346,0, 0x0000,0x0000, 0x00,0x39,0x72,0xff }, /*   407 */
  {   -56,  -150,   331,0, 0x0000,0x0000, 0x00,0x2e,0x5c,0xff }, /*   408 */
  {   -65,  -150,   318,0, 0x0000,0x0000, 0x00,0x3d,0x7a,0xff }, /*   409 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0x00,0x41,0x83,0xff }, /*   410 */
  {   -76,  -150,   346,0, 0x0000,0x0000, 0x3d,0x00,0x7a,0xff }, /*   411 */
  {   -73,  -150,   372,0, 0x0000,0x0000, 0x35,0x00,0x6a,0xff }, /*   412 */
  {   -57,  -150,   359,0, 0x0000,0x0000, 0x43,0x00,0x86,0xff }, /*   413 */
  {     0,  -150,   368,0, 0x0000,0x0000, 0x2e,0x00,0x5c,0xff }, /*   414 */
  {     0,  -150,   394,0, 0x0000,0x0000, 0x2f,0x00,0x5f,0xff }, /*   415 */
  {   -51,  -150,   387,0, 0x0000,0x0000, 0x34,0x00,0x68,0xff }, /*   416 */
  {    57,  -150,   359,0, 0x0000,0x0000, 0x1b,0x00,0x36,0xff }, /*   417 */
  {    73,  -150,   372,0, 0x0000,0x0000, 0x33,0x00,0x67,0xff }, /*   418 */
  {    76,  -150,   346,0, 0x0000,0x0000, 0x2e,0x00,0x5c,0xff }, /*   419 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*   420 */
  {    18,  -150,   271,0, 0x0000,0x0000, 0xa8,0x7a,0x57,0xff }, /*   421 */
  {   -18,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   422 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*   423 */
  {   -18,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   424 */
  {   -15,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   425 */
  {    18,  -150,   271,0, 0x0000,0x0000, 0xa8,0x7a,0x57,0xff }, /*   426 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   427 */
  {   -18,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   428 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*   429 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x98,0x58,0x2f,0xff }, /*   430 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x74,0x43,0x24,0xff }, /*   431 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*   432 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*   433 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*   434 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*   435 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0x9d,0x72,0x52,0xff }, /*   436 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x98,0x58,0x2f,0xff }, /*   437 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*   438 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0xa2,0x75,0x54,0xff }, /*   439 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x98,0x6e,0x4f,0xff }, /*   440 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0x90,0x68,0x4b,0xff }, /*   441 */
  {    18,  -150,   271,0, 0x0000,0x0000, 0xa8,0x7a,0x57,0xff }, /*   442 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*   443 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0xb7,0x84,0x5f,0xff }, /*   444 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   445 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0xb3,0x81,0x5d,0xff }, /*   446 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0xaf,0x7e,0x5b,0xff }, /*   447 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   448 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb2,0x81,0x5c,0xff }, /*   449 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*   450 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0x99,0x6e,0x4f,0xff }, /*   451 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x98,0x58,0x2f,0xff }, /*   452 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0x99,0x6e,0x4f,0xff }, /*   453 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x87,0x4e,0x2a,0xff }, /*   454 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x98,0x58,0x2f,0xff }, /*   455 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0xb7,0x84,0x5f,0xff }, /*   456 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   457 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   458 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0xcf,0x96,0x6c,0xff }, /*   459 */
  {   -11,  -150,   271,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*   460 */
  {   -15,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   461 */
  {     0,  -150,   290,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*   462 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xba,0x86,0x61,0xff }, /*   463 */
  {   -11,  -150,   271,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*   464 */
  {    11,  -150,   271,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*   465 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xba,0x86,0x61,0xff }, /*   466 */
  {     0,  -150,   290,0, 0x0000,0x0000, 0xb6,0x84,0x5f,0xff }, /*   467 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*   468 */
  {    11,  -150,   271,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*   469 */
  {    36,  -150,   290,0, 0x0000,0x0000, 0xa2,0x75,0x54,0xff }, /*   470 */
  {   -36,  -150,   290,0, 0x0000,0x0000, 0x00,0x40,0x81,0xff }, /*   471 */
  {   -52,  -150,   290,0, 0x0000,0x0000, 0x00,0x3c,0x78,0xff }, /*   472 */
  {   -57,  -150,   346,0, 0x0000,0x0000, 0x00,0x41,0x83,0xff }, /*   473 */
  {     6,  -150,   405,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   474 */
  {     9,  -150,   405,0, 0x0000,0x0000, 0xf8,0xb9,0x00,0xff }, /*   475 */
  {     6,  -150,   437,0, 0x0000,0x0000, 0xe4,0xaa,0x00,0xff }, /*   476 */
  {     6,  -150,   437,0, 0x0000,0x0000, 0xe4,0xaa,0x00,0xff }, /*   477 */
  {    53,  -150,   426,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   478 */
  {    59,  -150,   430,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   479 */
  {    59,  -150,   430,0, 0x0000,0x0000, 0xeb,0xaf,0x00,0xff }, /*   480 */
  {    53,  -150,   426,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   481 */
  {    50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   482 */
  {    50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   483 */
  {     9,  -150,   405,0, 0x0000,0x0000, 0xf8,0xb9,0x00,0xff }, /*   484 */
  {     6,  -150,   405,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   485 */
  {    -6,  -150,   437,0, 0x0000,0x0000, 0xfc,0xbb,0x00,0xff }, /*   486 */
  {    -9,  -150,   405,0, 0x0000,0x0000, 0xd9,0xa2,0x00,0xff }, /*   487 */
  {    -6,  -150,   405,0, 0x0000,0x0000, 0xb7,0x88,0x00,0xff }, /*   488 */
  {    -6,  -150,   405,0, 0x0000,0x0000, 0xb7,0x88,0x00,0xff }, /*   489 */
  {    -9,  -150,   405,0, 0x0000,0x0000, 0xd9,0xa2,0x00,0xff }, /*   490 */
  {   -50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   491 */
  {     9,  -150,   405,0, 0x0000,0x0000, 0xf8,0xb9,0x00,0xff }, /*   492 */
  {     9,  -150,   431,0, 0x0000,0x0000, 0xcc,0x98,0x00,0xff }, /*   493 */
  {     6,  -150,   437,0, 0x0000,0x0000, 0xe4,0xaa,0x00,0xff }, /*   494 */
  {   -50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   495 */
  {   -53,  -150,   426,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   496 */
  {   -59,  -150,   430,0, 0x0000,0x0000, 0xc0,0x8f,0x00,0xff }, /*   497 */
  {   -59,  -150,   430,0, 0x0000,0x0000, 0xc0,0x8f,0x00,0xff }, /*   498 */
  {   -53,  -150,   426,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   499 */
  {    -6,  -150,   437,0, 0x0000,0x0000, 0xfc,0xbb,0x00,0xff }, /*   500 */
  {   -53,  -150,   426,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   501 */
  {    -9,  -150,   431,0, 0x0000,0x0000, 0xd3,0x9d,0x00,0xff }, /*   502 */
  {    -6,  -150,   437,0, 0x0000,0x0000, 0xfc,0xbb,0x00,0xff }, /*   503 */
  {   -50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   504 */
  {   -46,  -150,   400,0, 0x0000,0x0000, 0xf3,0xb5,0x00,0xff }, /*   505 */
  {   -53,  -150,   426,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   506 */
  {    -9,  -150,   405,0, 0x0000,0x0000, 0xd9,0xa2,0x00,0xff }, /*   507 */
  {   -46,  -150,   400,0, 0x0000,0x0000, 0xf3,0xb5,0x00,0xff }, /*   508 */
  {   -50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   509 */
  {    -6,  -150,   437,0, 0x0000,0x0000, 0xfc,0xbb,0x00,0xff }, /*   510 */
  {    -9,  -150,   431,0, 0x0000,0x0000, 0xd3,0x9d,0x00,0xff }, /*   511 */
  {    -9,  -150,   405,0, 0x0000,0x0000, 0xd9,0xa2,0x00,0xff }, /*   512 */
  {    50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   513 */
  {    46,  -150,   400,0, 0x0000,0x0000, 0xf0,0xb3,0x00,0xff }, /*   514 */
  {     9,  -150,   405,0, 0x0000,0x0000, 0xf8,0xb9,0x00,0xff }, /*   515 */
  {    53,  -150,   426,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   516 */
  {    46,  -150,   400,0, 0x0000,0x0000, 0xf0,0xb3,0x00,0xff }, /*   517 */
  {    50,  -150,   399,0, 0x0000,0x0000, 0xc7,0x94,0x00,0xff }, /*   518 */
  {     6,  -150,   437,0, 0x0000,0x0000, 0xe4,0xaa,0x00,0xff }, /*   519 */
  {     9,  -150,   431,0, 0x0000,0x0000, 0xcc,0x98,0x00,0xff }, /*   520 */
  {    53,  -150,   426,0, 0x0000,0x0000, 0xcf,0x9a,0x00,0xff }, /*   521 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*   522 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x38,0x9d,0x9d,0xff }, /*   523 */
  {    40,  -150,   189,0, 0x0000,0x0000, 0x47,0x77,0x77,0xff }, /*   524 */
  {    47,  -150,   256,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*   525 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   526 */
  {   -47,  -150,   256,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   527 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   528 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   529 */
  {   -44,  -150,   233,0, 0x0000,0x0000, 0x7a,0xcc,0xcc,0xff }, /*   530 */
  {   -47,  -150,   256,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   531 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0x76,0xc4,0xc4,0xff }, /*   532 */
  {   -46,  -150,   256,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   533 */
  {   -47,  -150,   256,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   534 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   535 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0x76,0xc4,0xc4,0xff }, /*   536 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x91,0xf2,0xf2,0xff }, /*   537 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x61,0xa2,0xa2,0xff }, /*   538 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*   539 */
  {   -46,  -150,   256,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   540 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   541 */
  {    46,  -150,   256,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*   542 */
  {    46,  -150,   256,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*   543 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   544 */
  {    47,  -150,   256,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*   545 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   546 */
  {   -47,  -150,   256,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   547 */
  {   -46,  -150,   256,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   548 */
  {    41,  -150,   189,0, 0x0000,0x0000, 0x86,0xe0,0xe0,0xff }, /*   549 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*   550 */
  {    40,  -150,   189,0, 0x0000,0x0000, 0x47,0x77,0x77,0xff }, /*   551 */
  {    41,  -150,   189,0, 0x0000,0x0000, 0x86,0xe0,0xe0,0xff }, /*   552 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2d,0x7d,0x7d,0xff }, /*   553 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*   554 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x63,0xa5,0xa5,0xff }, /*   555 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x7f,0xd4,0xd4,0xff }, /*   556 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x96,0xfa,0xfa,0xff }, /*   557 */
  {   -41,  -150,   189,0, 0x0000,0x0000, 0x7e,0xd3,0xd3,0xff }, /*   558 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2d,0x7d,0x7d,0xff }, /*   559 */
  {    41,  -150,   189,0, 0x0000,0x0000, 0x86,0xe0,0xe0,0xff }, /*   560 */
  {   -41,  -150,   189,0, 0x0000,0x0000, 0x7e,0xd3,0xd3,0xff }, /*   561 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*   562 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2d,0x7d,0x7d,0xff }, /*   563 */
  {   -40,  -150,   189,0, 0x0000,0x0000, 0x84,0xdd,0xdd,0xff }, /*   564 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x38,0x9d,0x9d,0xff }, /*   565 */
  {   -41,  -150,   189,0, 0x0000,0x0000, 0x7e,0xd3,0xd3,0xff }, /*   566 */
  {   -44,  -150,   233,0, 0x0000,0x0000, 0x7a,0xcc,0xcc,0xff }, /*   567 */
  {   -46,  -150,   256,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   568 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*   569 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*   570 */
  {   -40,  -150,   189,0, 0x0000,0x0000, 0x84,0xdd,0xdd,0xff }, /*   571 */
  {   -44,  -150,   233,0, 0x0000,0x0000, 0x7a,0xcc,0xcc,0xff }, /*   572 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x88,0xe3,0xe3,0xff }, /*   573 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   574 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   575 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*   576 */
  {    40,  -150,   189,0, 0x0000,0x0000, 0x47,0x77,0x77,0xff }, /*   577 */
  {   -40,  -150,   189,0, 0x0000,0x0000, 0x84,0xdd,0xdd,0xff }, /*   578 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x38,0x9d,0x9d,0xff }, /*   579 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*   580 */
  {   -41,  -150,   189,0, 0x0000,0x0000, 0x7e,0xd3,0xd3,0xff }, /*   581 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   582 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0x82,0xd9,0xd9,0xff }, /*   583 */
  {    47,  -150,   256,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*   584 */
  {   -46,  -150,   256,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   585 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0x76,0xc4,0xc4,0xff }, /*   586 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   587 */
  {    47,  -150,   256,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*   588 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0x82,0xd9,0xd9,0xff }, /*   589 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   590 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x38,0x9d,0x9d,0xff }, /*   591 */
  {   -40,  -150,   189,0, 0x0000,0x0000, 0x84,0xdd,0xdd,0xff }, /*   592 */
  {    40,  -150,   189,0, 0x0000,0x0000, 0x47,0x77,0x77,0xff }, /*   593 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*   594 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2d,0x7d,0x7d,0xff }, /*   595 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*   596 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*   597 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*   598 */
  {   -15,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   599 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0xd2,0x97,0x6d,0xff }, /*   600 */
  {    11,  -150,   271,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*   601 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*   602 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0x99,0x6e,0x4f,0xff }, /*   603 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*   604 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x87,0x4e,0x2a,0xff }, /*   605 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   606 */
  {   -11,  -150,   271,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*   607 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xba,0x86,0x61,0xff }, /*   608 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   609 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb2,0x81,0x5c,0xff }, /*   610 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0x9b,0x70,0x50,0xff }, /*   611 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*   612 */
  {   -15,  -150,   271,0, 0x0000,0x0000, 0xc1,0x8c,0x64,0xff }, /*   613 */
  {   -11,  -150,   271,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*   614 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xa3,0x76,0x55,0xff }, /*   615 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*   616 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   617 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*   618 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0xe0,0xa2,0x74,0xff }, /*   619 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   620 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0xc8,0x90,0x68,0xff }, /*   621 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   622 */
  {     0,  -150,   271,0, 0x0000,0x0000, 0xba,0x86,0x61,0xff }, /*   623 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   624 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*   625 */
  {   -11,  -150,   271,0, 0x0000,0x0000, 0xdc,0x9f,0x72,0xff }, /*   626 */
  {    45,  -150,   233,0, 0x0000,0x0000, 0x78,0xc9,0xc9,0xff }, /*   627 */
  {    40,  -150,   189,0, 0x0000,0x0000, 0x47,0x77,0x77,0xff }, /*   628 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*   629 */
  {    29,  -150,   156,0, 0x0000,0x0000, 0x68,0xad,0xad,0xff }, /*   630 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x38,0x9d,0x9d,0xff }, /*   631 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*   632 */
  {    29,  -150,   156,0, 0x0000,0x0000, 0x68,0xad,0xad,0xff }, /*   633 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x57,0x92,0x92,0xff }, /*   634 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x38,0x9d,0x9d,0xff }, /*   635 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x96,0xfa,0xfa,0xff }, /*   636 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x7f,0xd4,0xd4,0xff }, /*   637 */
  {   -45,  -150,   233,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*   638 */
  {    45,  -150,   233,0, 0x0000,0x0000, 0x78,0xc9,0xc9,0xff }, /*   639 */
  {    41,  -150,   189,0, 0x0000,0x0000, 0x86,0xe0,0xe0,0xff }, /*   640 */
  {    40,  -150,   189,0, 0x0000,0x0000, 0x47,0x77,0x77,0xff }, /*   641 */
  {   -44,  -150,   233,0, 0x0000,0x0000, 0x7a,0xcc,0xcc,0xff }, /*   642 */
  {   -40,  -150,   189,0, 0x0000,0x0000, 0x84,0xdd,0xdd,0xff }, /*   643 */
  {   -45,  -150,   233,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*   644 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x96,0xfa,0xfa,0xff }, /*   645 */
  {   -45,  -150,   233,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*   646 */
  {   -47,  -150,   256,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   647 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   648 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x88,0xe3,0xe3,0xff }, /*   649 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   650 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x5b,0x97,0x97,0xff }, /*   651 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   652 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x7f,0xd4,0xd4,0xff }, /*   653 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   654 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   655 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x7f,0xd4,0xd4,0xff }, /*   656 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   657 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x75,0xc4,0xc4,0xff }, /*   658 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x88,0xe3,0xe3,0xff }, /*   659 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x88,0xe3,0xe3,0xff }, /*   660 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x75,0xc4,0xc4,0xff }, /*   661 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x63,0xa5,0xa5,0xff }, /*   662 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x75,0xc4,0xc4,0xff }, /*   663 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x62,0xa4,0xa4,0xff }, /*   664 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x63,0xa5,0xa5,0xff }, /*   665 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x88,0xe3,0xe3,0xff }, /*   666 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x96,0xfa,0xfa,0xff }, /*   667 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   668 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x88,0xe3,0xe3,0xff }, /*   669 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x63,0xa5,0xa5,0xff }, /*   670 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x96,0xfa,0xfa,0xff }, /*   671 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x63,0xa5,0xa5,0xff }, /*   672 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x5b,0x97,0x97,0xff }, /*   673 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x7f,0xd4,0xd4,0xff }, /*   674 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x7f,0xd4,0xd4,0xff }, /*   675 */
  {   -44,  -150,   233,0, 0x0000,0x0000, 0x7a,0xcc,0xcc,0xff }, /*   676 */
  {   -45,  -150,   233,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*   677 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x95,0xf8,0xf8,0xff }, /*   678 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x61,0xa2,0xa2,0xff }, /*   679 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*   680 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x91,0xf2,0xf2,0xff }, /*   681 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x46,0x75,0x75,0xff }, /*   682 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x78,0xc8,0xc8,0xff }, /*   683 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x61,0xa2,0xa2,0xff }, /*   684 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x78,0xc8,0xc8,0xff }, /*   685 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   686 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x61,0xa2,0xa2,0xff }, /*   687 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x91,0xf2,0xf2,0xff }, /*   688 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x78,0xc8,0xc8,0xff }, /*   689 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*   690 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x95,0xf8,0xf8,0xff }, /*   691 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x46,0x75,0x75,0xff }, /*   692 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x95,0xf8,0xf8,0xff }, /*   693 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*   694 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x46,0x75,0x75,0xff }, /*   695 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x91,0xf2,0xf2,0xff }, /*   696 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*   697 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x46,0x75,0x75,0xff }, /*   698 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x61,0xa2,0xa2,0xff }, /*   699 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   700 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*   701 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x95,0xf8,0xf8,0xff }, /*   702 */
  {    46,  -150,   256,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*   703 */
  {    47,  -150,   256,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*   704 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*   705 */
  {    46,  -150,   256,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*   706 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x95,0xf8,0xf8,0xff }, /*   707 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*   708 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*   709 */
  {    46,  -150,   256,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*   710 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x61,0xa2,0xa2,0xff }, /*   711 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x95,0xf8,0xf8,0xff }, /*   712 */
  {    45,  -150,   233,0, 0x0000,0x0000, 0x78,0xc9,0xc9,0xff }, /*   713 */
  {   -47,  -150,   256,0, 0x0000,0x0000, 0x92,0xf4,0xf4,0xff }, /*   714 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*   715 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x96,0xfa,0xfa,0xff }, /*   716 */
  {     5,  -150,   149,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   717 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   718 */
  {    -5,  -150,   149,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*   719 */
  {     5,  -150,   149,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   720 */
  {    30,  -150,   156,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   721 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   722 */
  {    -5,  -150,   150,0, 0x0000,0x0000, 0x00,0x29,0x00,0xff }, /*   723 */
  {    29,  -150,   156,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   724 */
  {     6,  -150,   150,0, 0x0000,0x0000, 0x00,0x4f,0x00,0xff }, /*   725 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*   726 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*   727 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   728 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   729 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*   730 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   731 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   732 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   733 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   734 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x37,0x00,0xff }, /*   735 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   736 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   737 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x37,0x00,0xff }, /*   738 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x00,0x29,0x00,0xff }, /*   739 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   740 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   741 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   742 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   743 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*   744 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x00,0x2d,0x00,0xff }, /*   745 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   746 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   747 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x00,0x2d,0x00,0xff }, /*   748 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x00,0x27,0x00,0xff }, /*   749 */
  {    -5,  -150,   150,0, 0x0000,0x0000, 0x00,0x29,0x00,0xff }, /*   750 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x2f,0x00,0xff }, /*   751 */
  {    29,  -150,   156,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   752 */
  {     6,  -150,   150,0, 0x0000,0x0000, 0x00,0x4f,0x00,0xff }, /*   753 */
  {    -5,  -150,   149,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*   754 */
  {    -5,  -150,   150,0, 0x0000,0x0000, 0x00,0x29,0x00,0xff }, /*   755 */
  {     6,  -150,   150,0, 0x0000,0x0000, 0x00,0x4f,0x00,0xff }, /*   756 */
  {     5,  -150,   149,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   757 */
  {    -5,  -150,   149,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*   758 */
  {    29,  -150,   156,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   759 */
  {    45,  -150,   141,0, 0x0000,0x0000, 0x00,0x2d,0x00,0xff }, /*   760 */
  {     1,  -150,   148,0, 0x0000,0x0000, 0x00,0x44,0x00,0xff }, /*   761 */
  {    -1,  -150,   148,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   762 */
  {   -45,  -150,   141,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*   763 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x2f,0x00,0xff }, /*   764 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x57,0x92,0x92,0xff }, /*   765 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*   766 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x38,0x9d,0x9d,0xff }, /*   767 */
  {    30,  -150,   156,0, 0x0000,0x0000, 0x5d,0x9b,0x9b,0xff }, /*   768 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*   769 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2d,0x7d,0x7d,0xff }, /*   770 */
  {   -46,  -150,   256,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   771 */
  {    46,  -150,   256,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*   772 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*   773 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*   774 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   775 */
  {   -46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*   776 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   777 */
  {   -45,  -150,   141,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*   778 */
  {    -1,  -150,   148,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   779 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   780 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   781 */
  {   -45,  -150,   141,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*   782 */
  {     1,  -150,   148,0, 0x0000,0x0000, 0x00,0x44,0x00,0xff }, /*   783 */
  {    45,  -150,   141,0, 0x0000,0x0000, 0x00,0x2d,0x00,0xff }, /*   784 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x37,0x00,0xff }, /*   785 */
  {    45,  -150,   141,0, 0x0000,0x0000, 0x00,0x2d,0x00,0xff }, /*   786 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   787 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x37,0x00,0xff }, /*   788 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   789 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   790 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   791 */
  {    45,  -150,   141,0, 0x0000,0x0000, 0x00,0x2d,0x00,0xff }, /*   792 */
  {    46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   793 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   794 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   795 */
  {   -46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*   796 */
  {   -45,  -150,   141,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*   797 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   798 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*   799 */
  {   -46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*   800 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   801 */
  {    -1,  -150,   148,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   802 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   803 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   804 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   805 */
  {   -46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*   806 */
  {    46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   807 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   808 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   809 */
  {    46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   810 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x50,0x00,0xff }, /*   811 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   812 */
  {   -46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*   813 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   814 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   815 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   816 */
  {    -1,  -150,   148,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   817 */
  {    -5,  -150,   149,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*   818 */
  {    -1,  -150,   148,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*   819 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x2f,0x00,0xff }, /*   820 */
  {    -5,  -150,   150,0, 0x0000,0x0000, 0x00,0x29,0x00,0xff }, /*   821 */
  {   -45,  -150,   141,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*   822 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   823 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x2f,0x00,0xff }, /*   824 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x50,0x00,0xff }, /*   825 */
  {    30,  -150,   156,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   826 */
  {     5,  -150,   149,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   827 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x50,0x00,0xff }, /*   828 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x37,0x00,0xff }, /*   829 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   830 */
  {    46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   831 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   832 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   833 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x50,0x00,0xff }, /*   834 */
  {     1,  -150,   148,0, 0x0000,0x0000, 0x00,0x44,0x00,0xff }, /*   835 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x37,0x00,0xff }, /*   836 */
  {    46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*   837 */
  {    45,  -150,   141,0, 0x0000,0x0000, 0x00,0x2d,0x00,0xff }, /*   838 */
  {    30,  -150,   156,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   839 */
  {     1,  -150,   148,0, 0x0000,0x0000, 0x00,0x44,0x00,0xff }, /*   840 */
  {     6,  -150,   150,0, 0x0000,0x0000, 0x00,0x4f,0x00,0xff }, /*   841 */
  {    29,  -150,   156,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   842 */
  {   -45,  -150,   141,0, 0x0000,0x0000, 0x00,0x47,0x00,0xff }, /*   843 */
  {   -46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4b,0x00,0xff }, /*   844 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   845 */
  {     1,  -150,   148,0, 0x0000,0x0000, 0x00,0x44,0x00,0xff }, /*   846 */
  {     5,  -150,   149,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*   847 */
  {     6,  -150,   150,0, 0x0000,0x0000, 0x00,0x4f,0x00,0xff }, /*   848 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x78,0xc8,0xc8,0xff }, /*   849 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x5e,0x9e,0x9e,0xff }, /*   850 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   851 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   852 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   853 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*   854 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x5c,0x9a,0x9a,0xff }, /*   855 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x5e,0x9e,0x9e,0xff }, /*   856 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x78,0xc8,0xc8,0xff }, /*   857 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   858 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x5c,0x9a,0x9a,0xff }, /*   859 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x46,0x75,0x75,0xff }, /*   860 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   861 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   862 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   863 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x5e,0x9e,0x9e,0xff }, /*   864 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   865 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   866 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x7d,0xd1,0xd1,0xff }, /*   867 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*   868 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x46,0x75,0x75,0xff }, /*   869 */
  {    81,  -150,   227,0, 0x0000,0x0000, 0x46,0x75,0x75,0xff }, /*   870 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x5c,0x9a,0x9a,0xff }, /*   871 */
  {    51,  -150,   206,0, 0x0000,0x0000, 0x78,0xc8,0xc8,0xff }, /*   872 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x62,0xa4,0xa4,0xff }, /*   873 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0x73,0xbf,0xbf,0xff }, /*   874 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x5b,0x97,0x97,0xff }, /*   875 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x5b,0x97,0x97,0xff }, /*   876 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0x73,0xbf,0xbf,0xff }, /*   877 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   878 */
  {   -81,  -150,   227,0, 0x0000,0x0000, 0x63,0xa5,0xa5,0xff }, /*   879 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x62,0xa4,0xa4,0xff }, /*   880 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x5b,0x97,0x97,0xff }, /*   881 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0x73,0xbf,0xbf,0xff }, /*   882 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0x6f,0xb9,0xb9,0xff }, /*   883 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*   884 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0xda,0x9e,0x71,0xff }, /*   885 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x95,0x6c,0x4d,0xff }, /*   886 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0xa2,0x75,0x54,0xff }, /*   887 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0xdd,0xa0,0x73,0xff }, /*   888 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   889 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   890 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0xd2,0x97,0x6d,0xff }, /*   891 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0xc8,0x90,0x68,0xff }, /*   892 */
  {    11,  -150,   271,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*   893 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0x81,0x5d,0x43,0xff }, /*   894 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x98,0x6e,0x4f,0xff }, /*   895 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x95,0x6c,0x4d,0xff }, /*   896 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xcc,0x93,0x6a,0xff }, /*   897 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*   898 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x98,0x6e,0x4f,0xff }, /*   899 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   900 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0xd2,0x97,0x6d,0xff }, /*   901 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0x60,0x45,0x32,0xff }, /*   902 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xea,0xa9,0x79,0xff }, /*   903 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0xb9,0x85,0x60,0xff }, /*   904 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x9e,0x72,0x52,0xff }, /*   905 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xea,0xa9,0x79,0xff }, /*   906 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0x9b,0x70,0x50,0xff }, /*   907 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0xb9,0x85,0x60,0xff }, /*   908 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   909 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xea,0xa9,0x79,0xff }, /*   910 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   911 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0xb3,0x81,0x5d,0xff }, /*   912 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0xb9,0x85,0x60,0xff }, /*   913 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0xb7,0x84,0x5f,0xff }, /*   914 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*   915 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   916 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*   917 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*   918 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*   919 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   920 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*   921 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0xaf,0x7e,0x5b,0xff }, /*   922 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   923 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0xb9,0x85,0x60,0xff }, /*   924 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0x9b,0x70,0x50,0xff }, /*   925 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0xb7,0x84,0x5f,0xff }, /*   926 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   927 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*   928 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xa5,0x78,0x56,0xff }, /*   929 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   930 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*   931 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*   932 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0xaf,0x7e,0x5b,0xff }, /*   933 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb2,0x81,0x5c,0xff }, /*   934 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*   935 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   936 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xa5,0x78,0x56,0xff }, /*   937 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb2,0x81,0x5c,0xff }, /*   938 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0xaf,0x7e,0x5b,0xff }, /*   939 */
  {  -124,  -150,   137,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*   940 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   941 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   942 */
  {  -124,  -150,   137,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*   943 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*   944 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0xda,0x9e,0x71,0xff }, /*   945 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0x81,0x5d,0x43,0xff }, /*   946 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0x95,0x6c,0x4d,0xff }, /*   947 */
  {  -127,  -150,   147,0, 0x0000,0x0000, 0xac,0x7d,0x59,0xff }, /*   948 */
  {  -124,  -150,   137,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*   949 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*   950 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*   951 */
  {  -124,  -150,   137,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*   952 */
  {  -113,  -150,   137,0, 0x0000,0x0000, 0xaf,0x7e,0x5b,0xff }, /*   953 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb2,0x81,0x5c,0xff }, /*   954 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   955 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0xb7,0x84,0x5f,0xff }, /*   956 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xa5,0x78,0x56,0xff }, /*   957 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*   958 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*   959 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*   960 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x00,0x27,0x00,0xff }, /*   961 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   962 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*   963 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x00,0x27,0x00,0xff }, /*   964 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*   965 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*   966 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*   967 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   968 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x31,0x00,0xff }, /*   969 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*   970 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x37,0x00,0xff }, /*   971 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*   972 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x00,0x29,0x00,0xff }, /*   973 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x37,0x00,0xff }, /*   974 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0xe0,0xa2,0x74,0xff }, /*   975 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*   976 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x82,0x5e,0x43,0xff }, /*   977 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*   978 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*   979 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x82,0x5e,0x43,0xff }, /*   980 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x89,0x44,0x00,0xff }, /*   981 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x96,0x4b,0x00,0xff }, /*   982 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x50,0x28,0x00,0xff }, /*   983 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x96,0x4b,0x00,0xff }, /*   984 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*   985 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x50,0x28,0x00,0xff }, /*   986 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x50,0x28,0x00,0xff }, /*   987 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*   988 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0x8b,0x45,0x00,0xff }, /*   989 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*   990 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x8e,0x47,0x00,0xff }, /*   991 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0x8b,0x45,0x00,0xff }, /*   992 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0x8b,0x45,0x00,0xff }, /*   993 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*   994 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0x6e,0x37,0x00,0xff }, /*   995 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0x8b,0x45,0x00,0xff }, /*   996 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x8e,0x47,0x00,0xff }, /*   997 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*   998 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0x6e,0x37,0x00,0xff }, /*   999 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1000 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x89,0x44,0x00,0xff }, /*  1001 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1002 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x96,0x4b,0x00,0xff }, /*  1003 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x89,0x44,0x00,0xff }, /*  1004 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*  1005 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*  1006 */
  {    38,  -150,    53,0, 0x0000,0x0000, 0x82,0x5e,0x43,0xff }, /*  1007 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*  1008 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xa3,0x76,0x55,0xff }, /*  1009 */
  {    13,  -150,    53,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*  1010 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*  1011 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x9e,0x5b,0x31,0xff }, /*  1012 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x7c,0x48,0x26,0xff }, /*  1013 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*  1014 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*  1015 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x9b,0x59,0x30,0xff }, /*  1016 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*  1017 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x8a,0x50,0x2b,0xff }, /*  1018 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x9b,0x59,0x30,0xff }, /*  1019 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*  1020 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x7c,0x48,0x26,0xff }, /*  1021 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x8a,0x50,0x2b,0xff }, /*  1022 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0x91,0x69,0x4b,0xff }, /*  1023 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*  1024 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x7c,0x48,0x26,0xff }, /*  1025 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0x81,0x5d,0x43,0xff }, /*  1026 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xcc,0x93,0x6a,0xff }, /*  1027 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0x98,0x6e,0x4f,0xff }, /*  1028 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0xe1,0xa3,0x75,0xff }, /*  1029 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0x9d,0x72,0x52,0xff }, /*  1030 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*  1031 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*  1032 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0x99,0x6e,0x4f,0xff }, /*  1033 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*  1034 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0xe1,0xa3,0x75,0xff }, /*  1035 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0x99,0x6e,0x4f,0xff }, /*  1036 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*  1037 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1038 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1039 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0x6e,0x37,0x00,0xff }, /*  1040 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1041 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0x83,0x41,0x00,0xff }, /*  1042 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1043 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1044 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0x83,0x41,0x00,0xff }, /*  1045 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1046 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1047 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*  1048 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0x83,0x41,0x00,0xff }, /*  1049 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0x8c,0x46,0x00,0xff }, /*  1050 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1051 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1052 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1053 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*  1054 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1055 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0x6e,0x37,0x00,0xff }, /*  1056 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1057 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0x8c,0x46,0x00,0xff }, /*  1058 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0x6e,0x37,0x00,0xff }, /*  1059 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1060 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1061 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0xe1,0xa3,0x75,0xff }, /*  1062 */
  {   -13,  -150,    53,0, 0x0000,0x0000, 0x8e,0x67,0x4a,0xff }, /*  1063 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0x99,0x6e,0x4f,0xff }, /*  1064 */
  {   -38,  -150,    53,0, 0x0000,0x0000, 0xd8,0x9c,0x70,0xff }, /*  1065 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*  1066 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0x99,0x6e,0x4f,0xff }, /*  1067 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*  1068 */
  {   124,  -150,   137,0, 0x0000,0x0000, 0xab,0x7b,0x59,0xff }, /*  1069 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0xd2,0x97,0x6d,0xff }, /*  1070 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb2,0x81,0x5c,0xff }, /*  1071 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xa5,0x78,0x56,0xff }, /*  1072 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*  1073 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0x9d,0x72,0x52,0xff }, /*  1074 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x98,0x58,0x2f,0xff }, /*  1075 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x98,0x58,0x2f,0xff }, /*  1076 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0x9d,0x72,0x52,0xff }, /*  1077 */
  {   -13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*  1078 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x98,0x58,0x2f,0xff }, /*  1079 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*  1080 */
  {   -44,  -150,     6,0, 0x0000,0x0000, 0x4b,0x25,0x00,0xff }, /*  1081 */
  {   -10,  -150,    28,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1082 */
  {   -52,  -150,    48,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1083 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1084 */
  {   -55,  -150,    38,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1085 */
  {   -52,  -150,    48,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1086 */
  {   -18,  -150,    48,0, 0x0000,0x0000, 0x94,0x4a,0x00,0xff }, /*  1087 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1088 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*  1089 */
  {   -13,  -150,     6,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*  1090 */
  {   -59,  -150,     6,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*  1091 */
  {   -59,  -150,     6,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*  1092 */
  {   -44,  -150,     6,0, 0x0000,0x0000, 0x4b,0x25,0x00,0xff }, /*  1093 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*  1094 */
  {   -13,  -150,     6,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*  1095 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1096 */
  {   -18,  -150,    48,0, 0x0000,0x0000, 0x94,0x4a,0x00,0xff }, /*  1097 */
  {   -59,  -150,     6,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*  1098 */
  {   -65,  -150,     6,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1099 */
  {   -55,  -150,    38,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1100 */
  {   -18,  -150,    48,0, 0x0000,0x0000, 0x94,0x4a,0x00,0xff }, /*  1101 */
  {   -39,  -150,    19,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1102 */
  {   -13,  -150,     6,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*  1103 */
  {   -13,  -150,     6,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*  1104 */
  {   -39,  -150,    19,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1105 */
  {   -65,  -150,     6,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1106 */
  {   -65,  -150,     6,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1107 */
  {   -39,  -150,    19,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1108 */
  {   -52,  -150,    48,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1109 */
  {   -10,  -150,    28,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1110 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*  1111 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1112 */
  {   -52,  -150,    48,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1113 */
  {   -39,  -150,    19,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1114 */
  {   -18,  -150,    48,0, 0x0000,0x0000, 0x94,0x4a,0x00,0xff }, /*  1115 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*  1116 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*  1117 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1118 */
  {   -55,  -150,    38,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1119 */
  {   -41,  -150,    28,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*  1120 */
  {   -59,  -150,     6,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*  1121 */
  {   -13,  -150,     6,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*  1122 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*  1123 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1124 */
  {    52,  -150,    48,0, 0x0000,0x0000, 0x92,0x49,0x00,0xff }, /*  1125 */
  {    39,  -150,    19,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*  1126 */
  {    65,  -150,     6,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*  1127 */
  {   -41,  -150,    28,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*  1128 */
  {   -44,  -150,     6,0, 0x0000,0x0000, 0x4b,0x25,0x00,0xff }, /*  1129 */
  {   -59,  -150,     6,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*  1130 */
  {   -44,  -150,     6,0, 0x0000,0x0000, 0x4b,0x25,0x00,0xff }, /*  1131 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*  1132 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x6a,0x35,0x00,0xff }, /*  1133 */
  {    -5,  -150,     6,0, 0x0000,0x0000, 0x59,0x2c,0x00,0xff }, /*  1134 */
  {   -10,  -150,    28,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1135 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1136 */
  {    55,  -150,    38,0, 0x0000,0x0000, 0x74,0x3a,0x00,0xff }, /*  1137 */
  {    52,  -150,    48,0, 0x0000,0x0000, 0x92,0x49,0x00,0xff }, /*  1138 */
  {    65,  -150,     6,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*  1139 */
  {   -65,  -150,     6,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1140 */
  {   -52,  -150,    48,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1141 */
  {   -55,  -150,    38,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1142 */
  {   -13,  -150,     6,0, 0x0000,0x0000, 0x60,0x30,0x00,0xff }, /*  1143 */
  {   -65,  -150,     6,0, 0x0000,0x0000, 0x58,0x2c,0x00,0xff }, /*  1144 */
  {   -59,  -150,     6,0, 0x0000,0x0000, 0x53,0x29,0x00,0xff }, /*  1145 */
  {   -44,  -150,     6,0, 0x0000,0x0000, 0x4b,0x25,0x00,0xff }, /*  1146 */
  {   -41,  -150,    28,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*  1147 */
  {   -10,  -150,    28,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1148 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1149 */
  {   -10,  -150,    28,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1150 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1151 */
  {   -10,  -150,    28,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1152 */
  {   -41,  -150,    28,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*  1153 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*  1154 */
  {   -41,  -150,    28,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*  1155 */
  {   -55,  -150,    38,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1156 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0x83,0x41,0x00,0xff }, /*  1157 */
  {   -55,  -150,    38,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1158 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1159 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1160 */
  {    10,  -150,    28,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*  1161 */
  {    44,  -150,     6,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1162 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x65,0x32,0x00,0xff }, /*  1163 */
  {    41,  -150,    28,0, 0x0000,0x0000, 0x48,0x24,0x00,0xff }, /*  1164 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x8e,0x47,0x00,0xff }, /*  1165 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*  1166 */
  {    55,  -150,    38,0, 0x0000,0x0000, 0x74,0x3a,0x00,0xff }, /*  1167 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1168 */
  {    52,  -150,    48,0, 0x0000,0x0000, 0x92,0x49,0x00,0xff }, /*  1169 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1170 */
  {    18,  -150,    48,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1171 */
  {    52,  -150,    48,0, 0x0000,0x0000, 0x92,0x49,0x00,0xff }, /*  1172 */
  {    59,  -150,     6,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*  1173 */
  {    13,  -150,     6,0, 0x0000,0x0000, 0x4d,0x26,0x00,0xff }, /*  1174 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1175 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1176 */
  {    44,  -150,     6,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1177 */
  {    59,  -150,     6,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*  1178 */
  {    18,  -150,    48,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1179 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1180 */
  {    13,  -150,     6,0, 0x0000,0x0000, 0x4d,0x26,0x00,0xff }, /*  1181 */
  {    55,  -150,    38,0, 0x0000,0x0000, 0x74,0x3a,0x00,0xff }, /*  1182 */
  {    65,  -150,     6,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*  1183 */
  {    59,  -150,     6,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*  1184 */
  {    55,  -150,    38,0, 0x0000,0x0000, 0x74,0x3a,0x00,0xff }, /*  1185 */
  {    41,  -150,    28,0, 0x0000,0x0000, 0x48,0x24,0x00,0xff }, /*  1186 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*  1187 */
  {    13,  -150,     6,0, 0x0000,0x0000, 0x4d,0x26,0x00,0xff }, /*  1188 */
  {    39,  -150,    19,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*  1189 */
  {    18,  -150,    48,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1190 */
  {    65,  -150,     6,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*  1191 */
  {    39,  -150,    19,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*  1192 */
  {    13,  -150,     6,0, 0x0000,0x0000, 0x4d,0x26,0x00,0xff }, /*  1193 */
  {    18,  -150,    48,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1194 */
  {    39,  -150,    19,0, 0x0000,0x0000, 0x56,0x2b,0x00,0xff }, /*  1195 */
  {    52,  -150,    48,0, 0x0000,0x0000, 0x92,0x49,0x00,0xff }, /*  1196 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1197 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x65,0x32,0x00,0xff }, /*  1198 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1199 */
  {    59,  -150,     6,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*  1200 */
  {    41,  -150,    28,0, 0x0000,0x0000, 0x48,0x24,0x00,0xff }, /*  1201 */
  {    55,  -150,    38,0, 0x0000,0x0000, 0x74,0x3a,0x00,0xff }, /*  1202 */
  {    59,  -150,     6,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*  1203 */
  {    44,  -150,     6,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1204 */
  {    41,  -150,    28,0, 0x0000,0x0000, 0x48,0x24,0x00,0xff }, /*  1205 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1206 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x65,0x32,0x00,0xff }, /*  1207 */
  {    44,  -150,     6,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1208 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1209 */
  {    10,  -150,    28,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*  1210 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x65,0x32,0x00,0xff }, /*  1211 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1212 */
  {     5,  -150,     6,0, 0x0000,0x0000, 0x51,0x28,0x00,0xff }, /*  1213 */
  {    13,  -150,     6,0, 0x0000,0x0000, 0x4d,0x26,0x00,0xff }, /*  1214 */
  {    59,  -150,     6,0, 0x0000,0x0000, 0x63,0x31,0x00,0xff }, /*  1215 */
  {    65,  -150,     6,0, 0x0000,0x0000, 0x67,0x33,0x00,0xff }, /*  1216 */
  {    13,  -150,     6,0, 0x0000,0x0000, 0x4d,0x26,0x00,0xff }, /*  1217 */
  {    10,  -150,    28,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*  1218 */
  {    41,  -150,    28,0, 0x0000,0x0000, 0x48,0x24,0x00,0xff }, /*  1219 */
  {    44,  -150,     6,0, 0x0000,0x0000, 0x5a,0x2d,0x00,0xff }, /*  1220 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1221 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x96,0x4b,0x00,0xff }, /*  1222 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1223 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1224 */
  {    55,  -150,    38,0, 0x0000,0x0000, 0x74,0x3a,0x00,0xff }, /*  1225 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x96,0x4b,0x00,0xff }, /*  1226 */
  {   -10,  -150,    38,0, 0x0000,0x0000, 0x86,0x43,0x00,0xff }, /*  1227 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1228 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1229 */
  {    55,  -150,    38,0, 0x0000,0x0000, 0x74,0x3a,0x00,0xff }, /*  1230 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*  1231 */
  {    38,  -150,    42,0, 0x0000,0x0000, 0x96,0x4b,0x00,0xff }, /*  1232 */
  {    10,  -150,    28,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*  1233 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1234 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x8e,0x47,0x00,0xff }, /*  1235 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0x81,0x5d,0x43,0xff }, /*  1236 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*  1237 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xcc,0x93,0x6a,0xff }, /*  1238 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0xda,0x9e,0x71,0xff }, /*  1239 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*  1240 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0x81,0x5d,0x43,0xff }, /*  1241 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0xda,0x9e,0x71,0xff }, /*  1242 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*  1243 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*  1244 */
  {    38,  -150,    77,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*  1245 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x9b,0x59,0x30,0xff }, /*  1246 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x9e,0x5b,0x31,0xff }, /*  1247 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*  1248 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*  1249 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0xd2,0x97,0x6d,0xff }, /*  1250 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*  1251 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*  1252 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0xd2,0x97,0x6d,0xff }, /*  1253 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*  1254 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0x60,0x45,0x32,0xff }, /*  1255 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*  1256 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*  1257 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*  1258 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0x60,0x45,0x32,0xff }, /*  1259 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*  1260 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*  1261 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0x60,0x45,0x32,0xff }, /*  1262 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0x60,0x45,0x32,0xff }, /*  1263 */
  {   124,  -150,   137,0, 0x0000,0x0000, 0xab,0x7b,0x59,0xff }, /*  1264 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*  1265 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0xd2,0x97,0x6d,0xff }, /*  1266 */
  {   124,  -150,   137,0, 0x0000,0x0000, 0xab,0x7b,0x59,0xff }, /*  1267 */
  {   127,  -150,   147,0, 0x0000,0x0000, 0x60,0x45,0x32,0xff }, /*  1268 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*  1269 */
  {   124,  -150,   137,0, 0x0000,0x0000, 0xab,0x7b,0x59,0xff }, /*  1270 */
  {   113,  -150,   137,0, 0x0000,0x0000, 0xb1,0x80,0x5c,0xff }, /*  1271 */
  {   -11,  -150,   265,0, 0x0000,0x0000, 0xec,0xaa,0x7a,0xff }, /*  1272 */
  {    11,  -150,   265,0, 0x0000,0x0000, 0xd2,0x97,0x6d,0xff }, /*  1273 */
  {    15,  -150,   271,0, 0x0000,0x0000, 0xa9,0x7a,0x58,0xff }, /*  1274 */
  {    94,  -150,   161,0, 0x0000,0x0000, 0xa0,0x74,0x53,0xff }, /*  1275 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*  1276 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0xda,0x9e,0x71,0xff }, /*  1277 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0x8b,0x65,0x48,0xff }, /*  1278 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xce,0x95,0x6b,0xff }, /*  1279 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0xda,0x9e,0x71,0xff }, /*  1280 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0x81,0x5d,0x43,0xff }, /*  1281 */
  {   116,  -150,   161,0, 0x0000,0x0000, 0xa6,0x78,0x56,0xff }, /*  1282 */
  {   103,  -150,   152,0, 0x0000,0x0000, 0xdf,0xa1,0x74,0xff }, /*  1283 */
  {    10,  -150,    28,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*  1284 */
  {    10,  -150,    38,0, 0x0000,0x0000, 0xae,0x57,0x00,0xff }, /*  1285 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x98,0x4c,0x00,0xff }, /*  1286 */
  {    41,  -150,    28,0, 0x0000,0x0000, 0x48,0x24,0x00,0xff }, /*  1287 */
  {    10,  -150,    28,0, 0x0000,0x0000, 0x8f,0x47,0x00,0xff }, /*  1288 */
  {    13,  -150,    42,0, 0x0000,0x0000, 0x8e,0x47,0x00,0xff }, /*  1289 */
  {   -55,  -150,    38,0, 0x0000,0x0000, 0xa6,0x53,0x00,0xff }, /*  1290 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0xab,0x55,0x00,0xff }, /*  1291 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0x83,0x41,0x00,0xff }, /*  1292 */
  {   -41,  -150,    28,0, 0x0000,0x0000, 0x75,0x3a,0x00,0xff }, /*  1293 */
  {   -38,  -150,    42,0, 0x0000,0x0000, 0x83,0x41,0x00,0xff }, /*  1294 */
  {   -13,  -150,    42,0, 0x0000,0x0000, 0x57,0x2b,0x00,0xff }, /*  1295 */
  {   -38,  -150,    77,0, 0x0000,0x0000, 0xc9,0x91,0x68,0xff }, /*  1296 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x74,0x43,0x24,0xff }, /*  1297 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x87,0x4e,0x2a,0xff }, /*  1298 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xd5,0x9a,0x6f,0xff }, /*  1299 */
  {    13,  -150,    77,0, 0x0000,0x0000, 0xa3,0x76,0x55,0xff }, /*  1300 */
  {    11,  -150,    87,0, 0x0000,0x0000, 0x9e,0x5b,0x31,0xff }, /*  1301 */
  {    53,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*  1302 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x00,0x34,0x00,0xff }, /*  1303 */
  {    41,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*  1304 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*  1305 */
  {   -11,  -150,    87,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*  1306 */
  {     0,  -150,    87,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*  1307 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x00,0x27,0x00,0xff }, /*  1308 */
  {   -41,  -150,    87,0, 0x0000,0x0000, 0x00,0x33,0x00,0xff }, /*  1309 */
  {   -53,  -150,    87,0, 0x0000,0x0000, 0x00,0x2e,0x00,0xff }, /*  1310 */
  {  -103,  -150,   152,0, 0x0000,0x0000, 0xb2,0x81,0x5c,0xff }, /*  1311 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0xb7,0x84,0x5f,0xff }, /*  1312 */
  {   -94,  -150,   161,0, 0x0000,0x0000, 0x9b,0x70,0x50,0xff }, /*  1313 */
  {   110,  -150,   172,0, 0x0000,0x0000, 0xda,0x9e,0x71,0xff }, /*  1314 */
  {    78,  -150,   225,0, 0x0000,0x0000, 0xa2,0x75,0x54,0xff }, /*  1315 */
  {    55,  -150,   208,0, 0x0000,0x0000, 0xa2,0x75,0x54,0xff }, /*  1316 */
  {  -116,  -150,   161,0, 0x0000,0x0000, 0xf5,0xb1,0x7f,0xff }, /*  1317 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xea,0xa9,0x79,0xff }, /*  1318 */
  {  -110,  -150,   172,0, 0x0000,0x0000, 0xbd,0x89,0x62,0xff }, /*  1319 */
  {   -51,  -150,   206,0, 0x0000,0x0000, 0x71,0xbd,0xbd,0xff }, /*  1320 */
  {   -55,  -150,   208,0, 0x0000,0x0000, 0x6f,0xb9,0xb9,0xff }, /*  1321 */
  {   -78,  -150,   225,0, 0x0000,0x0000, 0x75,0xc4,0xc4,0xff }, /*  1322 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x50,0x00,0xff }, /*  1323 */
  {    46,  -150,   141,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*  1324 */
  {    30,  -150,   156,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*  1325 */
  {     1,  -150,   148,0, 0x0000,0x0000, 0x00,0x44,0x00,0xff }, /*  1326 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x50,0x00,0xff }, /*  1327 */
  {     5,  -150,   149,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*  1328 */
  {    45,  -150,   141,0, 0x0000,0x0000, 0x00,0x2d,0x00,0xff }, /*  1329 */
  {    29,  -150,   156,0, 0x0000,0x0000, 0x00,0x38,0x00,0xff }, /*  1330 */
  {    30,  -150,   156,0, 0x0000,0x0000, 0x00,0x32,0x00,0xff }, /*  1331 */
  {    -1,  -150,   148,0, 0x0000,0x0000, 0x00,0x36,0x00,0xff }, /*  1332 */
  {    -5,  -150,   150,0, 0x0000,0x0000, 0x00,0x29,0x00,0xff }, /*  1333 */
  {    -5,  -150,   149,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*  1334 */
  {     0,  -150,   148,0, 0x0000,0x0000, 0x00,0x4e,0x00,0xff }, /*  1335 */
  {    -5,  -150,   149,0, 0x0000,0x0000, 0x00,0x45,0x00,0xff }, /*  1336 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x00,0x3a,0x00,0xff }, /*  1337 */
  {    30,  -150,   156,0, 0x0000,0x0000, 0x5d,0x9b,0x9b,0xff }, /*  1338 */
  {    29,  -150,   156,0, 0x0000,0x0000, 0x68,0xad,0xad,0xff }, /*  1339 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*  1340 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*  1341 */
  {    30,  -150,   156,0, 0x0000,0x0000, 0x5d,0x9b,0x9b,0xff }, /*  1342 */
  {    44,  -150,   162,0, 0x0000,0x0000, 0x2d,0x7d,0x7d,0xff }, /*  1343 */
  {   -30,  -150,   156,0, 0x0000,0x0000, 0x6a,0xb2,0xb2,0xff }, /*  1344 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x2a,0x74,0x74,0xff }, /*  1345 */
  {   -44,  -150,   162,0, 0x0000,0x0000, 0x38,0x9d,0x9d,0xff }, /*  1346 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x95,0xf8,0xf8,0xff }, /*  1347 */
  {    47,  -150,   256,0, 0x0000,0x0000, 0x94,0xf7,0xf7,0xff }, /*  1348 */
  {    45,  -150,   233,0, 0x0000,0x0000, 0x78,0xc9,0xc9,0xff }, /*  1349 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x61,0xa2,0xa2,0xff }, /*  1350 */
  {    45,  -150,   233,0, 0x0000,0x0000, 0x78,0xc9,0xc9,0xff }, /*  1351 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*  1352 */
  {    57,  -150,   255,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*  1353 */
  {    49,  -150,   222,0, 0x0000,0x0000, 0x91,0xf2,0xf2,0xff }, /*  1354 */
  {    44,  -150,   233,0, 0x0000,0x0000, 0x59,0x94,0x94,0xff }, /*  1355 */
  {   -57,  -150,   255,0, 0x0000,0x0000, 0x7c,0xcf,0xcf,0xff }, /*  1356 */
  {   -46,  -150,   256,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*  1357 */
  {   -44,  -150,   233,0, 0x0000,0x0000, 0x7a,0xcc,0xcc,0xff }, /*  1358 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x7f,0xd4,0xd4,0xff }, /*  1359 */
  {   -49,  -150,   222,0, 0x0000,0x0000, 0x65,0xa9,0xa9,0xff }, /*  1360 */
  {   -44,  -150,   233,0, 0x0000,0x0000, 0x7a,0xcc,0xcc,0xff }, /*  1361 */
  {   -40,  -150,   189,0, 0x0000,0x0000, 0x84,0xdd,0xdd,0xff }, /*  1362 */
  {   -41,  -150,   189,0, 0x0000,0x0000, 0x7e,0xd3,0xd3,0xff }, /*  1363 */
  {   -45,  -150,   233,0, 0x0000,0x0000, 0x75,0xc3,0xc3,0xff }, /*  1364 */
  {   -42,  -150,   362,0, 0x01f0,0xfdf1, 0x9b,0x9b,0x9b,0xff }, /*  1365 */
  {     0,  -150,   368,0, 0x02cf,0xfe41, 0x93,0x93,0x93,0xff }, /*  1366 */
  {     0,  -150,   368,0, 0x02cf,0xfdb4, 0x8b,0x8b,0x8b,0xff }, /*  1367 */
  {    59,  -150,   425,0, 0x0445,0x0269, 0xa6,0xa6,0xa6,0xff }, /*  1368 */
  {    51,  -150,   387,0, 0x03f8,0xff5b, 0xb9,0xb9,0xb9,0xff }, /*  1369 */
  {    73,  -150,   372,0, 0x051f,0xfff2, 0x9a,0x9a,0x9a,0xff }, /*  1370 */
  {     0,  -150,   368,0, 0x02cf,0xfdb4, 0x8b,0x8b,0x8b,0xff }, /*  1371 */
  {    42,  -150,   362,0, 0x0400,0xfdf1, 0x85,0x85,0x85,0xff }, /*  1372 */
  {    64,  -150,   362,0, 0x045a,0xfdfd, 0xbb,0xbb,0xbb,0xff }, /*  1373 */
  {     0,  -150,   460,0, 0x06cf,0x073d, 0xab,0xab,0xab,0xff }, /*  1374 */
  {   -23,  -150,   458,0, 0x079f,0x073c, 0x70,0x54,0x8c,0xff }, /*  1375 */
  {   -20,  -150,   477,0, 0x07d7,0x082f, 0x99,0x99,0x99,0xff }, /*  1376 */
  {    57,  -150,   359,0, 0x0622,0x01a6, 0x51,0x51,0x51,0xff }, /*  1377 */
  {    23,  -150,   458,0, 0x062d,0x073c, 0x64,0x4b,0x7d,0xff }, /*  1378 */
  {    73,  -150,   372,0, 0x051f,0xfff2, 0x9a,0x9a,0x9a,0xff }, /*  1379 */
  {    73,  -150,   372,0, 0x051f,0xfff2, 0x9a,0x9a,0x9a,0xff }, /*  1380 */
  {    23,  -150,   458,0, 0x062d,0x073c, 0x64,0x4b,0x7d,0xff }, /*  1381 */
  {    59,  -150,   425,0, 0x0445,0x0269, 0xa6,0xa6,0xa6,0xff }, /*  1382 */
  {   -59,  -150,   425,0, 0x01c4,0x0269, 0x96,0x96,0x96,0xff }, /*  1383 */
  {   -23,  -150,   458,0, 0xffa0,0x073c, 0x70,0x54,0x8c,0xff }, /*  1384 */
  {   -73,  -150,   372,0, 0x011b,0xfff2, 0x9f,0x9f,0x9f,0xff }, /*  1385 */
  {   -73,  -150,   372,0, 0x011b,0xfff2, 0x9f,0x9f,0x9f,0xff }, /*  1386 */
  {   -23,  -150,   458,0, 0xffa0,0x073c, 0x70,0x54,0x8c,0xff }, /*  1387 */
  {   -57,  -150,   359,0, 0xffb1,0x01a6, 0xca,0xca,0xca,0xff }, /*  1388 */
  {   -57,  -150,   359,0, 0x07b0,0x01a6, 0xca,0xca,0xca,0xff }, /*  1389 */
  {     0,  -150,   450,0, 0x06cf,0x0784, 0x65,0x4c,0x7f,0xff }, /*  1390 */
  {     0,  -150,   350,0, 0x06cf,0x0230, 0x96,0x96,0x96,0xff }, /*  1391 */
  {     0,  -150,   350,0, 0x06cf,0x0230, 0x96,0x96,0x96,0xff }, /*  1392 */
  {     0,  -150,   450,0, 0x06cf,0x0784, 0x65,0x4c,0x7f,0xff }, /*  1393 */
  {    57,  -150,   359,0, 0x0622,0x01a6, 0x51,0x51,0x51,0xff }, /*  1394 */
  {    23,  -150,   460,0, 0x0654,0x07ec, 0x72,0x56,0x8f,0xff }, /*  1395 */
  {     0,  -150,   450,0, 0x06cf,0x0784, 0x65,0x4c,0x7f,0xff }, /*  1396 */
  {     0,  -150,   460,0, 0x06cf,0x073d, 0xab,0xab,0xab,0xff }, /*  1397 */
  {     0,  -150,   433,0, 0x02cf,0x0289, 0xd4,0xd4,0xd4,0xff }, /*  1398 */
  {     0,  -150,   471,0, 0xfed0,0x06f6, 0xaa,0x7f,0xd5,0xff }, /*  1399 */
  {   -59,  -150,   425,0, 0x01c4,0x0269, 0x96,0x96,0x96,0xff }, /*  1400 */
  {    59,  -150,   425,0, 0x0c45,0x0269, 0xa6,0xa6,0xa6,0xff }, /*  1401 */
  {     0,  -150,   471,0, 0x06cf,0x06f6, 0xaa,0x7f,0xd5,0xff }, /*  1402 */
  {     0,  -150,   433,0, 0x0acf,0x0289, 0xd4,0xd4,0xd4,0xff }, /*  1403 */
  {     0,  -150,   368,0, 0x02cf,0xfdb4, 0x8b,0x8b,0x8b,0xff }, /*  1404 */
  {     0,  -150,   368,0, 0x02cf,0xfe41, 0x93,0x93,0x93,0xff }, /*  1405 */
  {    42,  -150,   362,0, 0x0400,0xfdf1, 0x85,0x85,0x85,0xff }, /*  1406 */
  {   -73,  -150,   372,0, 0x011b,0xfff2, 0x9f,0x9f,0x9f,0xff }, /*  1407 */
  {   -51,  -150,   387,0, 0x01f4,0xff5b, 0x9b,0x9b,0x9b,0xff }, /*  1408 */
  {   -59,  -150,   425,0, 0x01c4,0x0269, 0x96,0x96,0x96,0xff }, /*  1409 */
  {     0,  -150,   460,0, 0x06cf,0x073d, 0xab,0xab,0xab,0xff }, /*  1410 */
  {     0,  -150,   471,0, 0x06cf,0x06f6, 0xaa,0x7f,0xd5,0xff }, /*  1411 */
  {    20,  -150,   477,0, 0x0609,0x082f, 0x80,0x60,0xa0,0xff }, /*  1412 */
  {     0,  -150,   460,0, 0x06cf,0x073d, 0xab,0xab,0xab,0xff }, /*  1413 */
  {    20,  -150,   477,0, 0x0609,0x082f, 0x80,0x60,0xa0,0xff }, /*  1414 */
  {    23,  -150,   458,0, 0x062d,0x073c, 0x64,0x4b,0x7d,0xff }, /*  1415 */
  {     0,  -150,   460,0, 0x06cf,0x073d, 0xab,0xab,0xab,0xff }, /*  1416 */
  {    23,  -150,   458,0, 0x062d,0x073c, 0x64,0x4b,0x7d,0xff }, /*  1417 */
  {    23,  -150,   460,0, 0x0654,0x07ec, 0x72,0x56,0x8f,0xff }, /*  1418 */
  {   -20,  -150,   477,0, 0x07d7,0x082f, 0x99,0x99,0x99,0xff }, /*  1419 */
  {     0,  -150,   471,0, 0x06cf,0x06f6, 0xaa,0x7f,0xd5,0xff }, /*  1420 */
  {     0,  -150,   460,0, 0x06cf,0x073d, 0xab,0xab,0xab,0xff }, /*  1421 */
  {     0,  -150,   460,0, 0x06cf,0x073d, 0xab,0xab,0xab,0xff }, /*  1422 */
  {   -23,  -150,   460,0, 0x0764,0x07ec, 0x69,0x4f,0x84,0xff }, /*  1423 */
  {   -23,  -150,   458,0, 0x079f,0x073c, 0x70,0x54,0x8c,0xff }, /*  1424 */
  {     0,  -150,   460,0, 0x06cf,0x073d, 0xab,0xab,0xab,0xff }, /*  1425 */
  {     0,  -150,   450,0, 0x06cf,0x0784, 0x65,0x4c,0x7f,0xff }, /*  1426 */
  {   -23,  -150,   460,0, 0x0764,0x07ec, 0x69,0x4f,0x84,0xff }, /*  1427 */
  {    59,  -150,   425,0, 0x0445,0x0269, 0xa6,0xa6,0xa6,0xff }, /*  1428 */
  {    20,  -150,   477,0, 0x0609,0x082f, 0x80,0x60,0xa0,0xff }, /*  1429 */
  {     0,  -150,   471,0, 0x06cf,0x06f6, 0xaa,0x7f,0xd5,0xff }, /*  1430 */
  {     0,  -150,   471,0, 0x06cf,0x06f6, 0xaa,0x7f,0xd5,0xff }, /*  1431 */
  {   -20,  -150,   477,0, 0x07d7,0x082f, 0x99,0x99,0x99,0xff }, /*  1432 */
  {   -59,  -150,   425,0, 0x09c4,0x0269, 0x96,0x96,0x96,0xff }, /*  1433 */
  {   -23,  -150,   458,0, 0x079f,0x073c, 0x70,0x54,0x8c,0xff }, /*  1434 */
  {   -23,  -150,   460,0, 0x0764,0x07ec, 0x69,0x4f,0x84,0xff }, /*  1435 */
  {   -57,  -150,   359,0, 0x07b0,0x01a6, 0xca,0xca,0xca,0xff }, /*  1436 */
  {     0,  -150,   450,0, 0x06cf,0x0784, 0x65,0x4c,0x7f,0xff }, /*  1437 */
  {    23,  -150,   460,0, 0x0654,0x07ec, 0x72,0x56,0x8f,0xff }, /*  1438 */
  {    57,  -150,   359,0, 0x0622,0x01a6, 0x51,0x51,0x51,0xff }, /*  1439 */
  {   -57,  -150,   359,0, 0x07b0,0x01a6, 0xca,0xca,0xca,0xff }, /*  1440 */
  {   -23,  -150,   460,0, 0x0764,0x07ec, 0x69,0x4f,0x84,0xff }, /*  1441 */
  {     0,  -150,   450,0, 0x06cf,0x0784, 0x65,0x4c,0x7f,0xff }, /*  1442 */
  {   -59,  -150,   425,0, 0x01c4,0x0269, 0x96,0x96,0x96,0xff }, /*  1443 */
  {   -20,  -150,   477,0, 0xffd8,0x082f, 0x99,0x99,0x99,0xff }, /*  1444 */
  {   -23,  -150,   458,0, 0xffa0,0x073c, 0x70,0x54,0x8c,0xff }, /*  1445 */
  {    23,  -150,   458,0, 0x062d,0x073c, 0x64,0x4b,0x7d,0xff }, /*  1446 */
  {    20,  -150,   477,0, 0x0609,0x082f, 0x80,0x60,0xa0,0xff }, /*  1447 */
  {    59,  -150,   425,0, 0x0445,0x0269, 0xa6,0xa6,0xa6,0xff }, /*  1448 */
  {    57,  -150,   359,0, 0x0622,0x01a6, 0x51,0x51,0x51,0xff }, /*  1449 */
  {    23,  -150,   460,0, 0x0654,0x07ec, 0x72,0x56,0x8f,0xff }, /*  1450 */
  {    23,  -150,   458,0, 0x062d,0x073c, 0x64,0x4b,0x7d,0xff }, /*  1451 */
  {     0,  -150,   368,0, 0x02cf,0xfdb4, 0x8b,0x8b,0x8b,0xff }, /*  1452 */
  {   -64,  -150,   362,0, 0x01b7,0xfdfd, 0xa1,0xa1,0xa1,0xff }, /*  1453 */
  {   -42,  -150,   362,0, 0x01f0,0xfdf1, 0x9b,0x9b,0x9b,0xff }, /*  1454 */
  {    36,  -150,   290,0, 0x077e,0x0000, 0x96,0x96,0x96,0xff }, /*  1455 */
  {     0,  -150,   327,0, 0x0400,0x0800, 0x9c,0x7d,0x5e,0xff }, /*  1456 */
  {   -36,  -150,   290,0, 0x0081,0x0000, 0xb3,0xb3,0xb3,0xff }, /*  1457 */
  {     0,  -150,   327,0, 0x0400,0x0800, 0x9c,0x7d,0x5e,0xff }, /*  1458 */
  {   -42,  -150,   327,0, 0x0000,0x0755, 0xad,0x71,0x68,0xff }, /*  1459 */
  {   -36,  -150,   290,0, 0x0081,0x0000, 0xb3,0xb3,0xb3,0xff }, /*  1460 */
  {    36,  -150,   290,0, 0x077e,0x0000, 0x96,0x96,0x96,0xff }, /*  1461 */
  {    42,  -150,   327,0, 0x07ff,0x0755, 0xc9,0x83,0x78,0xff }, /*  1462 */
  {     0,  -150,   327,0, 0x0400,0x0800, 0x9c,0x7d,0x5e,0xff }, /*  1463 */
  {   -42,  -150,   327,0, 0xf800,0x0000, 0xad,0x71,0x68,0xff }, /*  1464 */
  {     0,  -150,   368,0, 0x0000,0x07ff, 0xa4,0xa4,0xa4,0xff }, /*  1465 */
  {   -42,  -150,   362,0, 0xf800,0x06e5, 0xac,0xac,0xac,0xff }, /*  1466 */
  {    42,  -150,   327,0, 0x07ff,0x0000, 0xc9,0x83,0x78,0xff }, /*  1467 */
  {    42,  -150,   362,0, 0x07ff,0x06e5, 0x93,0x93,0x93,0xff }, /*  1468 */
  {     0,  -150,   368,0, 0x0000,0x07ff, 0xa4,0xa4,0xa4,0xff }, /*  1469 */
  {   -42,  -150,   327,0, 0xf800,0x0000, 0xad,0x71,0x68,0xff }, /*  1470 */
  {     0,  -150,   327,0, 0x0000,0x0000, 0x9c,0x7d,0x5e,0xff }, /*  1471 */
  {     0,  -150,   368,0, 0x0000,0x07ff, 0xa4,0xa4,0xa4,0xff }, /*  1472 */
  {     0,  -150,   327,0, 0x0000,0x0000, 0x9c,0x7d,0x5e,0xff }, /*  1473 */
  {    42,  -150,   327,0, 0x07ff,0x0000, 0xc9,0x83,0x78,0xff }, /*  1474 */
  {     0,  -150,   368,0, 0x0000,0x07ff, 0xa4,0xa4,0xa4,0xff }, /*  1475 */
  {    -9,  -150,   405,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1476 */
  {    -9,  -150,   431,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1477 */
  {   -46,  -150,   400,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1478 */
  {     9,  -150,   431,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1479 */
  {    46,  -150,   400,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1480 */
  {    53,  -150,   426,0, 0x0000,0x0000, 0x00,0x81,0x00,0xff }, /*  1481 */
  {     9,  -150,   431,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1482 */
  {     9,  -150,   405,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1483 */
  {    46,  -150,   400,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1484 */
  {    -9,  -150,   431,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1485 */
  {   -53,  -150,   426,0, 0x0000,0x0000, 0x00,0x81,0x00,0xff }, /*  1486 */
  {   -46,  -150,   400,0, 0x0000,0x0000, 0x00,0x82,0x00,0xff }, /*  1487 */
  {    45,  -150,   233,0, 0x07d3,0x04b3, 0xc9,0xc9,0xc9,0xff }, /*  1488 */
  {    47,  -150,   256,0, 0x07ff,0x070b, 0xf7,0xf7,0xf7,0xff }, /*  1489 */
  {   -47,  -150,   256,0, 0x0000,0x070b, 0xf4,0xf4,0xf4,0xff }, /*  1490 */
  {    45,  -150,   233,0, 0x07d3,0x04b3, 0xc9,0xc9,0xc9,0xff }, /*  1491 */
  {   -47,  -150,   256,0, 0x0000,0x070b, 0xf4,0xf4,0xf4,0xff }, /*  1492 */
  {   -45,  -150,   233,0, 0x002c,0x04b3, 0xc3,0xc3,0xc3,0xff }, /*  1493 */
  {   -45,  -150,   233,0, 0x002c,0x04b3, 0xc3,0xc3,0xc3,0xff }, /*  1494 */
  {    41,  -150,   189,0, 0x0779,0x0001, 0xe0,0xe0,0xe0,0xff }, /*  1495 */
  {    45,  -150,   233,0, 0x07d3,0x04b3, 0xc9,0xc9,0xc9,0xff }, /*  1496 */
  {   -45,  -150,   233,0, 0x002c,0x04b3, 0xc3,0xc3,0xc3,0xff }, /*  1497 */
  {   -41,  -150,   189,0, 0x0086,0x0001, 0xd3,0xd3,0xd3,0xff }, /*  1498 */
  {    41,  -150,   189,0, 0x0779,0x0001, 0xe0,0xe0,0xe0,0xff }, /*  1499 */
};

/* ============================================================
          Gfx
 ============================================================ */
static Gfx gfx_Shape_of___POLYHEDRON_246_[] = {
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_OFF),
  gsSPSetGeometryMode( G_SHADE|G_SHADING_SMOOTH ),
  gsDPSetCombineLERP(1, 0, SHADE, 0, 0, 0, 0, SHADE, 1, 0, SHADE, 0, 0, 0, 0, SHADE),
  gsSPVertex( SEGADRS(5, 0), 32, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP2Triangles(  3,  4,  5,  0,  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP2Triangles( 24, 25, 26,  0, 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 512), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP2Triangles( 16, 17, 18,  0, 19, 20, 21,  0),
  gsSP2Triangles( 22, 23, 24,  0, 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 992), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 1024), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP2Triangles(  5,  6,  7,  0,  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP2Triangles( 14, 15, 16,  0, 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 1520), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 1536), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 2000), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 2048), 30, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP2Triangles( 10, 11, 12,  0, 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 2528), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 2560), 31, 0 ),
  gsSP2Triangles( 31,  0,  1,  0,  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 3056), 1, 31 ),
  gsSPVertex( SEGADRS(5, 3072), 29, 0 ),
  gsSP2Triangles( 29, 30, 31,  0,  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 3536), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 3584), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP2Triangles( 19, 20, 21,  0, 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 4064), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 4096), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP2Triangles(  2,  3,  4,  0,  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP2Triangles( 11, 12, 13,  0, 14, 15, 16,  0),
  gsSP2Triangles( 17, 18, 19,  0, 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 4592), 1, 31 ),
  gsSPVertex( SEGADRS(5, 4608), 29, 0 ),
  gsSP2Triangles( 29, 30, 31,  0,  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 5072), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 5120), 13, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSPClearGeometryMode( G_SHADING_SMOOTH ),
  gsSPVertex( SEGADRS(5, 5328), 19, 13 ),
  gsSP2Triangles( 13, 14, 15,  0, 16, 17, 18,  0),
  gsSP2Triangles( 19, 20, 21,  0, 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 5632), 29, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP2Triangles( 14, 15, 16,  0, 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPSetGeometryMode( G_SHADING_SMOOTH ),
  gsSPVertex( SEGADRS(5, 6096), 3, 29 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 6144), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 6608), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 6656), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP2Triangles(  4,  5,  6,  0,  7,  8,  9,  0),
  gsSP2Triangles( 10, 11, 12,  0, 13, 14, 15,  0),
  gsSP2Triangles( 16, 17, 18,  0, 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 7136), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 7168), 26, 0 ),
  gsSP2Triangles( 31,  0,  1,  0,  2,  3,  4,  0),
  gsSP2Triangles(  5,  6,  7,  0,  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSPClearGeometryMode( G_SHADING_SMOOTH ),
  gsSPVertex( SEGADRS(5, 7584), 6, 26 ),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 7680), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 8144), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 8192), 10, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSPSetGeometryMode( G_SHADING_SMOOTH ),
  gsSPVertex( SEGADRS(5, 8352), 22, 10 ),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP2Triangles( 13, 14, 15,  0, 16, 17, 18,  0),
  gsSP2Triangles( 19, 20, 21,  0, 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 8704), 31, 0 ),
  gsSP2Triangles( 31,  0,  1,  0,  2,  3,  4,  0),
  gsSP2Triangles(  5,  6,  7,  0,  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP2Triangles( 14, 15, 16,  0, 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP2Triangles( 23, 24, 25,  0, 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 9200), 1, 31 ),
  gsSPVertex( SEGADRS(5, 9216), 29, 0 ),
  gsSP2Triangles( 29, 30, 31,  0,  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 9680), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 9728), 30, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP2Triangles(  4,  5,  6,  0,  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP2Triangles( 19, 20, 21,  0, 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 10208), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 10240), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP2Triangles(  2,  3,  4,  0,  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP2Triangles( 11, 12, 13,  0, 14, 15, 16,  0),
  gsSP2Triangles( 17, 18, 19,  0, 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 10736), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 10752), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 11216), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 11264), 30, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP2Triangles( 13, 14, 15,  0, 16, 17, 18,  0),
  gsSP2Triangles( 19, 20, 21,  0, 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 11744), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 11776), 31, 0 ),
  gsSP2Triangles( 31,  0,  1,  0,  2,  3,  4,  0),
  gsSP2Triangles(  5,  6,  7,  0,  8,  9, 10,  0),
  gsSP2Triangles( 11, 12, 13,  0, 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP2Triangles( 20, 21, 22,  0, 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 12272), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 12288), 29, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 12752), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 12800), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP2Triangles(  4,  5,  6,  0,  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP2Triangles( 22, 23, 24,  0, 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 13280), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 13312), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP2Triangles(  8,  9, 10,  0, 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP2Triangles( 17, 18, 19,  0, 20, 21, 22,  0),
  gsSP2Triangles( 23, 24, 25,  0, 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 13808), 1, 31 ),
  gsSPVertex( SEGADRS(5, 13824), 29, 0 ),
  gsSP2Triangles( 29, 30, 31,  0,  0,  1,  2,  0),
  gsSP2Triangles(  3,  4,  5,  0,  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP2Triangles( 12, 13, 14,  0, 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 14288), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 14336), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP2Triangles( 19, 20, 21,  0, 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 14816), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 14848), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP2Triangles( 14, 15, 16,  0, 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 15344), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 15360), 29, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 15824), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 15872), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP2Triangles( 22, 23, 24,  0, 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 16352), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 16384), 31, 0 ),
  gsSP2Triangles( 31,  0,  1,  0,  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP2Triangles( 14, 15, 16,  0, 17, 18, 19,  0),
  gsSP2Triangles( 20, 21, 22,  0, 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 16880), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 16896), 29, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP2Triangles( 18, 19, 20,  0, 21, 22, 23,  0),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 17360), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 17408), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP2Triangles(  7,  8,  9,  0, 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP2Triangles( 19, 20, 21,  0, 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 17888), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 17920), 31, 0 ),
  gsSP2Triangles( 31,  0,  1,  0,  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP2Triangles( 14, 15, 16,  0, 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 18416), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 18432), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP2Triangles(  9, 10, 11,  0, 12, 13, 14,  0),
  gsSP2Triangles( 15, 16, 17,  0, 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 18896), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 18944), 30, 0 ),
  gsSP2Triangles( 30, 31,  0,  0,  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 19424), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 19456), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP2Triangles(  5,  6,  7,  0,  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP2Triangles( 23, 24, 25,  0, 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 19952), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 19968), 29, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 20432), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 20480), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSP1Triangle(  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 20960), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 20992), 31, 0 ),
  gsSP2Triangles( 31,  0,  1,  0,  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 21488), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 21504), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsDPPipeSync(),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0, TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0),
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,0), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    0, 0, 5, 5, 0, 0 ),
  gsSP2Triangles( 21, 22, 23,  0, 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 21968), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 22016), 30, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP2Triangles(  1,  2,  3,  0,  4,  5,  6,  0),
  gsSP1Triangle(  7,  8,  9,  0),
  gsSP1Triangle( 10, 11, 12,  0),
  gsSP1Triangle( 13, 14, 15,  0),
  gsSP1Triangle( 16, 17, 18,  0),
  gsSP1Triangle( 19, 20, 21,  0),
  gsSP1Triangle( 22, 23, 24,  0),
  gsSP1Triangle( 25, 26, 27,  0),
  gsSPVertex( SEGADRS(5, 22496), 2, 30 ),
  gsSP1Triangle( 28, 29, 30,  0),
  gsSPVertex( SEGADRS(5, 22528), 31, 0 ),
  gsSP1Triangle( 31,  0,  1,  0),
  gsSP1Triangle(  2,  3,  4,  0),
  gsSP1Triangle(  5,  6,  7,  0),
  gsSP1Triangle(  8,  9, 10,  0),
  gsSP1Triangle( 11, 12, 13,  0),
  gsSP1Triangle( 14, 15, 16,  0),
  gsSP1Triangle( 17, 18, 19,  0),
  gsSP1Triangle( 20, 21, 22,  0),
  gsSP1Triangle( 23, 24, 25,  0),
  gsSP1Triangle( 26, 27, 28,  0),
  gsSPVertex( SEGADRS(5, 23024), 1, 31 ),
  gsSP1Triangle( 29, 30, 31,  0),
  gsSPVertex( SEGADRS(5, 23040), 29, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP1Triangle(  3,  4,  5,  0),
  gsSP1Triangle(  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSP1Triangle( 12, 13, 14,  0),
  gsDPPipeSync(),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,2048), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    1, 1, 5, 5, 0, 0 ),
  gsSP1Triangle( 15, 16, 17,  0),
  gsSP1Triangle( 18, 19, 20,  0),
  gsSP1Triangle( 21, 22, 23,  0),
  gsDPPipeSync(),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,4096), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    1, 1, 5, 5, 0, 0 ),
  gsSP1Triangle( 24, 25, 26,  0),
  gsSPVertex( SEGADRS(5, 23504), 3, 29 ),
  gsSP1Triangle( 27, 28, 29,  0),
  gsSPVertex( SEGADRS(5, 23552), 4, 0 ),
  gsSP1Triangle( 30, 31,  0,  0),
  gsSP1Triangle(  1,  2,  3,  0),
  gsSPSetGeometryMode( G_LIGHTING|G_TEXTURE_GEN ),
  gsDPPipeSync(),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, 0, 0, 0, TEXEL0, TEXEL0, 0, SHADE, 0, 0, 0, 0, TEXEL0),
  gsSPTexture(0x0800, 0x0800, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,6144), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    0, 0, 5, 5, 0, 0 ),
  gsSPVertex( SEGADRS(5, 23616), 12, 0 ),
  gsSP2Triangles(  0,  1,  2,  0,  3,  4,  5,  0),
  gsSP2Triangles(  6,  7,  8,  0,  9, 10, 11,  0),
  gsSPClearGeometryMode( G_LIGHTING|G_TEXTURE_GEN ),
  gsDPPipeSync(),
  gsDPSetCombineLERP(TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0, TEXEL0, 0, SHADE, 0, SHADE, 0, TEXEL0, 0),
  gsSPTexture(0x8000, 0x8000, 0, G_TX_RENDERTILE, G_ON),
  gsDPSetTextureLUT( G_TT_NONE ),
  gsDPLoadMultiBlock( SEGADRS(6,8192), 0, 0,
    G_IM_FMT_RGBA, G_IM_SIZ_16b, 32, 32, 0,
    0, 0, 5, 5, 0, 0 ),
  gsSPVertex( SEGADRS(5, 23808), 12, 0 ),
  gsSP1Triangle(  0,  1,  2,  0),
  gsSP2Triangles(  3,  4,  5,  0,  6,  7,  8,  0),
  gsSP1Triangle(  9, 10, 11,  0),
  gsSPEndDisplayList(),
};

/* ============================================================
          Shape Resource Reference
 ============================================================ */
static s16 shaperef_Shape_of___POLYHEDRON_246_[]={
      11,      5,     -1, /*    0, col */
      17,      6,     -1, /*    1, col */
      12,      7,     -1, /*    2, col */
      12,      7,     -1, /*    3, col */
      18,      8,     -1, /*    4, col */
      13,      9,     -1, /*    5, col */
       4,     61,     -1, /*    6, col */
      65,     65,     -1, /*    7, col */
      15,     12,     -1, /*    8, col */
       4,     61,     -1, /*    9, col */
      64,     78,     -1, /*   10, col */
      65,     65,     -1, /*   11, col */
      13,      9,     -1, /*   12, col */
      18,      8,     -1, /*   13, col */
      14,     10,     -1, /*   14, col */
      50,     61,     -1, /*   15, col */
      57,     64,     -1, /*   16, col */
      51,     60,     -1, /*   17, col */
      14,     10,     -1, /*   18, col */
      73,     82,     -1, /*   19, col */
      13,      9,     -1, /*   20, col */
      14,     10,     -1, /*   21, col */
      19,     11,     -1, /*   22, col */
      15,     12,     -1, /*   23, col */
      15,     13,     -1, /*   24, col */
      20,     14,     -1, /*   25, col */
      21,     15,     -1, /*   26, col */
      11,     16,     -1, /*   27, col */
      48,     17,     -1, /*   28, col */
      22,     18,     -1, /*   29, col */
      16,     19,     -1, /*   30, col */
      23,     20,     -1, /*   31, col */
      17,     21,     -1, /*   32, col */
      17,     21,     -1, /*   33, col */
      24,     22,     -1, /*   34, col */
      18,     23,     -1, /*   35, col */
     111,    147,     -1, /*   36, col */
      25,    114,     -1, /*   37, col */
      24,     22,     -1, /*   38, col */
      18,     23,     -1, /*   39, col */
      26,     24,     -1, /*   40, col */
      19,     25,     -1, /*   41, col */
     211,    238,     -1, /*   42, col */
     202,    237,     -1, /*   43, col */
     207,    241,     -1, /*   44, col */
     211,    238,     -1, /*   45, col */
     210,    206,     -1, /*   46, col */
     202,    237,     -1, /*   47, col */
      19,     25,     -1, /*   48, col */
      27,     26,     -1, /*   49, col */
      20,     14,     -1, /*   50, col */
     168,    200,     -1, /*   51, col */
     167,    202,     -1, /*   52, col */
     166,    204,     -1, /*   53, col */
      20,     14,     -1, /*   54, col */
      27,     26,     -1, /*   55, col */
      21,     15,     -1, /*   56, col */
      27,     26,     -1, /*   57, col */
      28,     27,     -1, /*   58, col */
      21,     15,     -1, /*   59, col */
     173,    207,     -1, /*   60, col */
     174,    206,     -1, /*   61, col */
     168,    200,     -1, /*   62, col */
     174,    206,     -1, /*   63, col */
     169,    214,     -1, /*   64, col */
     168,    200,     -1, /*   65, col */
      21,     15,     -1, /*   66, col */
      28,     27,     -1, /*   67, col */
      29,     26,     -1, /*   68, col */
      29,     26,     -1, /*   69, col */
      30,     28,     -1, /*   70, col */
      22,     18,     -1, /*   71, col */
     191,    222,     -1, /*   72, col */
     190,    218,     -1, /*   73, col */
     185,    232,     -1, /*   74, col */
     209,    236,     -1, /*   75, col */
     203,    220,     -1, /*   76, col */
     202,    237,     -1, /*   77, col */
      22,     18,     -1, /*   78, col */
      23,     20,     -1, /*   79, col */
      16,     19,     -1, /*   80, col */
     240,    194,     -1, /*   81, col */
     239,    195,     -1, /*   82, col */
     161,     21,     -1, /*   83, col */
       1,     32,     -1, /*   84, col */
      31,     33,     -1, /*   85, col */
       0,     34,     -1, /*   86, col */
      32,     35,     -1, /*   87, col */
      33,     36,     -1, /*   88, col */
       7,     37,     -1, /*   89, col */
       7,     37,     -1, /*   90, col */
      33,     36,     -1, /*   91, col */
       6,     34,     -1, /*   92, col */
      33,     36,     -1, /*   93, col */
      34,    113,     -1, /*   94, col */
       6,     34,     -1, /*   95, col */
       6,     34,     -1, /*   96, col */
      35,     38,     -1, /*   97, col */
       5,     39,     -1, /*   98, col */
       5,     39,     -1, /*   99, col */
      35,     38,     -1, /*  100, col */
      36,     40,     -1, /*  101, col */
       4,     41,     -1, /*  102, col */
      37,     42,     -1, /*  103, col */
       3,     43,     -1, /*  104, col */
       3,     43,     -1, /*  105, col */
      38,     44,     -1, /*  106, col */
       2,     45,     -1, /*  107, col */
       3,     43,     -1, /*  108, col */
      37,     42,     -1, /*  109, col */
      38,     44,     -1, /*  110, col */
       2,     45,     -1, /*  111, col */
      38,     44,     -1, /*  112, col */
       1,     32,     -1, /*  113, col */
      22,     18,     -1, /*  114, col */
      16,     19,     -1, /*  115, col */
      11,     16,     -1, /*  116, col */
      21,     15,     -1, /*  117, col */
      47,     55,     -1, /*  118, col */
      15,     13,     -1, /*  119, col */
     190,    218,     -1, /*  120, col */
     198,    217,     -1, /*  121, col */
     199,    221,     -1, /*  122, col */
     241,    199,     -1, /*  123, col */
     245,    213,     -1, /*  124, col */
     240,    194,     -1, /*  125, col */
     245,    213,     -1, /*  126, col */
     247,    277,     -1, /*  127, col */
     246,    206,     -1, /*  128, col */
     241,    199,     -1, /*  129, col */
     248,    274,     -1, /*  130, col */
     245,    213,     -1, /*  131, col */
      29,     26,     -1, /*  132, col */
      22,     18,     -1, /*  133, col */
      21,     15,     -1, /*  134, col */
       8,     58,     -1, /*  135, col */
      49,     59,     -1, /*  136, col */
      15,     12,     -1, /*  137, col */
      15,     12,     -1, /*  138, col */
      51,     60,     -1, /*  139, col */
       4,     61,     -1, /*  140, col */
      18,      8,     -1, /*  141, col */
      19,     11,     -1, /*  142, col */
      14,     10,     -1, /*  143, col */
       4,     61,     -1, /*  144, col */
      52,     62,     -1, /*  145, col */
       5,     63,     -1, /*  146, col */
       5,     63,     -1, /*  147, col */
      49,     59,     -1, /*  148, col */
       8,     58,     -1, /*  149, col */
      49,     59,     -1, /*  150, col */
      57,     64,     -1, /*  151, col */
      50,     61,     -1, /*  152, col */
      51,     60,     -1, /*  153, col */
      57,     64,     -1, /*  154, col */
      52,     62,     -1, /*  155, col */
      66,      8,     -1, /*  156, col */
      68,     80,     -1, /*  157, col */
      63,     79,     -1, /*  158, col */
      12,      7,     -1, /*  159, col */
      70,     81,     -1, /*  160, col */
       1,     74,     -1, /*  161, col */
      14,     10,     -1, /*  162, col */
      66,      8,     -1, /*  163, col */
      63,     79,     -1, /*  164, col */
      52,     62,     -1, /*  165, col */
      57,     64,     -1, /*  166, col */
      49,     59,     -1, /*  167, col */
      11,      5,     -1, /*  168, col */
      54,     65,     -1, /*  169, col */
      10,     66,     -1, /*  170, col */
      10,     66,     -1, /*  171, col */
      54,     65,     -1, /*  172, col */
       7,     67,     -1, /*  173, col */
       7,     67,     -1, /*  174, col */
      55,     68,     -1, /*  175, col */
       0,     69,     -1, /*  176, col */
       0,     69,     -1, /*  177, col */
      56,     70,     -1, /*  178, col */
      11,      5,     -1, /*  179, col */
      53,     71,     -1, /*  180, col */
      58,     72,     -1, /*  181, col */
      54,     65,     -1, /*  182, col */
      54,     65,     -1, /*  183, col */
      58,     72,     -1, /*  184, col */
      55,     68,     -1, /*  185, col */
      55,     68,     -1, /*  186, col */
      58,     72,     -1, /*  187, col */
      56,     70,     -1, /*  188, col */
      71,     86,     -1, /*  189, col */
      78,     85,     -1, /*  190, col */
      72,     82,     -1, /*  191, col */
      55,     68,     -1, /*  192, col */
      56,     70,     -1, /*  193, col */
       0,     69,     -1, /*  194, col */
      56,     70,     -1, /*  195, col */
      58,     72,     -1, /*  196, col */
      53,     71,     -1, /*  197, col */
      12,      7,     -1, /*  198, col */
      60,     73,     -1, /*  199, col */
      11,      5,     -1, /*  200, col */
      11,      5,     -1, /*  201, col */
      60,     73,     -1, /*  202, col */
       0,     69,     -1, /*  203, col */
      60,     73,     -1, /*  204, col */
      61,     58,     -1, /*  205, col */
       0,     69,     -1, /*  206, col */
       0,     69,     -1, /*  207, col */
      61,     58,     -1, /*  208, col */
       1,     74,     -1, /*  209, col */
      11,      5,     -1, /*  210, col */
      16,     83,     -1, /*  211, col */
      17,      6,     -1, /*  212, col */
       1,     74,     -1, /*  213, col */
      62,     75,     -1, /*  214, col */
      12,      7,     -1, /*  215, col */
      59,     76,     -1, /*  216, col */
      67,     64,     -1, /*  217, col */
      60,     73,     -1, /*  218, col */
      60,     73,     -1, /*  219, col */
      67,     64,     -1, /*  220, col */
      61,     58,     -1, /*  221, col */
      61,     58,     -1, /*  222, col */
      67,     64,     -1, /*  223, col */
      62,     75,     -1, /*  224, col */
      62,     75,     -1, /*  225, col */
      67,     64,     -1, /*  226, col */
      59,     76,     -1, /*  227, col */
      62,     75,     -1, /*  228, col */
      59,     76,     -1, /*  229, col */
      12,      7,     -1, /*  230, col */
       3,     77,     -1, /*  231, col */
      64,     78,     -1, /*  232, col */
       4,     61,     -1, /*  233, col */
      70,     81,     -1, /*  234, col */
      71,     86,     -1, /*  235, col */
       1,     74,     -1, /*  236, col */
      15,     12,     -1, /*  237, col */
      65,     65,     -1, /*  238, col */
      14,     10,     -1, /*  239, col */
      14,     10,     -1, /*  240, col */
      63,     79,     -1, /*  241, col */
       3,     77,     -1, /*  242, col */
      63,     79,     -1, /*  243, col */
      68,     80,     -1, /*  244, col */
      64,     78,     -1, /*  245, col */
      73,     82,     -1, /*  246, col */
      77,     87,     -1, /*  247, col */
      74,      5,     -1, /*  248, col */
      64,     78,     -1, /*  249, col */
      68,     80,     -1, /*  250, col */
      65,     65,     -1, /*  251, col */
      65,     65,     -1, /*  252, col */
      68,     80,     -1, /*  253, col */
      66,      8,     -1, /*  254, col */
      72,     82,     -1, /*  255, col */
      78,     85,     -1, /*  256, col */
      69,     84,     -1, /*  257, col */
      13,      9,     -1, /*  258, col */
      70,     81,     -1, /*  259, col */
      12,      7,     -1, /*  260, col */
      13,      9,     -1, /*  261, col */
      69,     84,     -1, /*  262, col */
      70,     81,     -1, /*  263, col */
       1,     74,     -1, /*  264, col */
      72,     82,     -1, /*  265, col */
       2,     83,     -1, /*  266, col */
       2,     83,     -1, /*  267, col */
      72,     82,     -1, /*  268, col */
      13,      9,     -1, /*  269, col */
      72,     82,     -1, /*  270, col */
      69,     84,     -1, /*  271, col */
      13,      9,     -1, /*  272, col */
      69,     84,     -1, /*  273, col */
      78,     85,     -1, /*  274, col */
      70,     81,     -1, /*  275, col */
      11,      5,     -1, /*  276, col */
      53,     71,     -1, /*  277, col */
      54,     65,     -1, /*  278, col */
      70,     81,     -1, /*  279, col */
      78,     85,     -1, /*  280, col */
      71,     86,     -1, /*  281, col */
      13,      9,     -1, /*  282, col */
      75,     75,     -1, /*  283, col */
       2,     83,     -1, /*  284, col */
      13,      9,     -1, /*  285, col */
      74,      5,     -1, /*  286, col */
      75,     75,     -1, /*  287, col */
      54,     65,     -1, /*  288, col */
      55,     68,     -1, /*  289, col */
       7,     67,     -1, /*  290, col */
       5,     63,     -1, /*  291, col */
      52,     62,     -1, /*  292, col */
      49,     59,     -1, /*  293, col */
       2,     83,     -1, /*  294, col */
      75,     75,     -1, /*  295, col */
       3,     77,     -1, /*  296, col */
       3,     77,     -1, /*  297, col */
      73,     82,     -1, /*  298, col */
      14,     10,     -1, /*  299, col */
      74,      5,     -1, /*  300, col */
      77,     87,     -1, /*  301, col */
      75,     75,     -1, /*  302, col */
       4,     61,     -1, /*  303, col */
      51,     60,     -1, /*  304, col */
      52,     62,     -1, /*  305, col */
      75,     75,     -1, /*  306, col */
      77,     87,     -1, /*  307, col */
      76,     88,     -1, /*  308, col */
      73,     82,     -1, /*  309, col */
      74,      5,     -1, /*  310, col */
      13,      9,     -1, /*  311, col */
      76,     88,     -1, /*  312, col */
      77,     87,     -1, /*  313, col */
      73,     82,     -1, /*  314, col */
      12,      7,     -1, /*  315, col */
      17,      6,     -1, /*  316, col */
      18,      8,     -1, /*  317, col */
      48,     17,     -1, /*  318, col */
      11,     16,     -1, /*  319, col */
      10,     91,     -1, /*  320, col */
      47,     55,     -1, /*  321, col */
       8,     92,     -1, /*  322, col */
      15,     13,     -1, /*  323, col */
       7,     37,     -1, /*  324, col */
       0,     34,     -1, /*  325, col */
      32,     35,     -1, /*  326, col */
      36,     40,     -1, /*  327, col */
       4,     41,     -1, /*  328, col */
       5,     39,     -1, /*  329, col */
      38,     44,     -1, /*  330, col */
      31,     33,     -1, /*  331, col */
       1,     32,     -1, /*  332, col */
      80,    101,     -1, /*  333, col */
      84,    102,     -1, /*  334, col */
      34,    103,     -1, /*  335, col */
      80,    101,     -1, /*  336, col */
      83,    108,     -1, /*  337, col */
      84,    102,     -1, /*  338, col */
      34,    103,     -1, /*  339, col */
      85,    104,     -1, /*  340, col */
      35,    105,     -1, /*  341, col */
      34,    103,     -1, /*  342, col */
      84,    102,     -1, /*  343, col */
      85,    104,     -1, /*  344, col */
      35,    105,     -1, /*  345, col */
      86,    106,     -1, /*  346, col */
      79,    107,     -1, /*  347, col */
      79,    107,     -1, /*  348, col */
      83,    108,     -1, /*  349, col */
      80,    101,     -1, /*  350, col */
      79,    107,     -1, /*  351, col */
      86,    106,     -1, /*  352, col */
      83,    108,     -1, /*  353, col */
      33,    109,     -1, /*  354, col */
      87,    104,     -1, /*  355, col */
      34,    103,     -1, /*  356, col */
      34,    103,     -1, /*  357, col */
      88,    104,     -1, /*  358, col */
      80,    101,     -1, /*  359, col */
      80,    101,     -1, /*  360, col */
      89,    110,     -1, /*  361, col */
      81,    111,     -1, /*  362, col */
      81,    111,     -1, /*  363, col */
      90,    112,     -1, /*  364, col */
      33,    109,     -1, /*  365, col */
      90,    112,     -1, /*  366, col */
      87,    104,     -1, /*  367, col */
      33,    109,     -1, /*  368, col */
      88,    104,     -1, /*  369, col */
      89,    110,     -1, /*  370, col */
      80,    101,     -1, /*  371, col */
      89,    110,     -1, /*  372, col */
      90,    112,     -1, /*  373, col */
      81,    111,     -1, /*  374, col */
      87,    104,     -1, /*  375, col */
      88,    104,     -1, /*  376, col */
      34,    103,     -1, /*  377, col */
      35,    105,     -1, /*  378, col */
      85,    104,     -1, /*  379, col */
      86,    106,     -1, /*  380, col */
       3,     77,     -1, /*  381, col */
      76,     88,     -1, /*  382, col */
      73,     82,     -1, /*  383, col */
      75,     75,     -1, /*  384, col */
      76,     88,     -1, /*  385, col */
       3,     77,     -1, /*  386, col */
       1,     74,     -1, /*  387, col */
      71,     86,     -1, /*  388, col */
      72,     82,     -1, /*  389, col */
      65,     65,     -1, /*  390, col */
      66,      8,     -1, /*  391, col */
      14,     10,     -1, /*  392, col */
       3,     77,     -1, /*  393, col */
      63,     79,     -1, /*  394, col */
      64,     78,     -1, /*  395, col */
      61,     58,     -1, /*  396, col */
      62,     75,     -1, /*  397, col */
       1,     74,     -1, /*  398, col */
      12,      7,     -1, /*  399, col */
      59,     76,     -1, /*  400, col */
      60,     73,     -1, /*  401, col */
      15,     12,     -1, /*  402, col */
      50,     61,     -1, /*  403, col */
      51,     60,     -1, /*  404, col */
      56,     70,     -1, /*  405, col */
      53,     71,     -1, /*  406, col */
      11,      5,     -1, /*  407, col */
      49,     59,     -1, /*  408, col */
      50,     61,     -1, /*  409, col */
      15,     12,     -1, /*  410, col */
       4,     41,     -1, /*  411, col */
      36,     40,     -1, /*  412, col */
      37,     42,     -1, /*  413, col */
       6,     34,     -1, /*  414, col */
      34,    113,     -1, /*  415, col */
      35,     38,     -1, /*  416, col */
      31,     33,     -1, /*  417, col */
      32,     35,     -1, /*  418, col */
       0,     34,     -1, /*  419, col */
      23,     20,     -1, /*  420, col */
      30,     28,     -1, /*  421, col */
      28,     27,     -1, /*  422, col */
      23,     20,     -1, /*  423, col */
      28,     27,     -1, /*  424, col */
      27,     26,     -1, /*  425, col */
      30,     28,     -1, /*  426, col */
      29,     26,     -1, /*  427, col */
      28,     27,     -1, /*  428, col */
     207,    241,     -1, /*  429, col */
     183,    250,     -1, /*  430, col */
     182,    252,     -1, /*  431, col */
     245,    213,     -1, /*  432, col */
     248,    274,     -1, /*  433, col */
     247,    277,     -1, /*  434, col */
     207,    241,     -1, /*  435, col */
     202,    237,     -1, /*  436, col */
     183,    250,     -1, /*  437, col */
     240,    194,     -1, /*  438, col */
     161,     21,     -1, /*  439, col */
     160,    198,     -1, /*  440, col */
      22,     18,     -1, /*  441, col */
      30,     28,     -1, /*  442, col */
      23,     20,     -1, /*  443, col */
     170,    203,     -1, /*  444, col */
     166,    204,     -1, /*  445, col */
     165,    205,     -1, /*  446, col */
     176,    208,     -1, /*  447, col */
     179,    209,     -1, /*  448, col */
     177,    210,     -1, /*  449, col */
     203,    220,     -1, /*  450, col */
     206,    239,     -1, /*  451, col */
     184,    249,     -1, /*  452, col */
     206,    239,     -1, /*  453, col */
     181,    251,     -1, /*  454, col */
     184,    249,     -1, /*  455, col */
     170,    203,     -1, /*  456, col */
     171,    148,     -1, /*  457, col */
     166,    204,     -1, /*  458, col */
      19,     25,     -1, /*  459, col */
      26,     24,     -1, /*  460, col */
      27,     26,     -1, /*  461, col */
      18,     23,     -1, /*  462, col */
      25,    114,     -1, /*  463, col */
      26,     24,     -1, /*  464, col */
      24,     22,     -1, /*  465, col */
      25,    114,     -1, /*  466, col */
      18,     23,     -1, /*  467, col */
      23,     20,     -1, /*  468, col */
      24,     22,     -1, /*  469, col */
      17,     21,     -1, /*  470, col */
      19,     11,     -1, /*  471, col */
      20,    115,     -1, /*  472, col */
      15,     12,     -1, /*  473, col */
      88,    104,     -1, /*  474, col */
      92,    117,     -1, /*  475, col */
      89,    110,     -1, /*  476, col */
      89,    110,     -1, /*  477, col */
      94,    118,     -1, /*  478, col */
      90,    112,     -1, /*  479, col */
      90,    112,     -1, /*  480, col */
      94,    118,     -1, /*  481, col */
      87,    104,     -1, /*  482, col */
      87,    104,     -1, /*  483, col */
      92,    117,     -1, /*  484, col */
      88,    104,     -1, /*  485, col */
      83,    108,     -1, /*  486, col */
      97,    119,     -1, /*  487, col */
      84,    102,     -1, /*  488, col */
      84,    102,     -1, /*  489, col */
      97,    119,     -1, /*  490, col */
      85,    104,     -1, /*  491, col */
      92,    117,     -1, /*  492, col */
      93,    124,     -1, /*  493, col */
      89,    110,     -1, /*  494, col */
      85,    104,     -1, /*  495, col */
      99,    120,     -1, /*  496, col */
      86,    106,     -1, /*  497, col */
      86,    106,     -1, /*  498, col */
      99,    120,     -1, /*  499, col */
      83,    108,     -1, /*  500, col */
      99,    120,     -1, /*  501, col */
      96,    121,     -1, /*  502, col */
      83,    108,     -1, /*  503, col */
      85,    104,     -1, /*  504, col */
      98,    122,     -1, /*  505, col */
      99,    120,     -1, /*  506, col */
      97,    119,     -1, /*  507, col */
      98,    122,     -1, /*  508, col */
      85,    104,     -1, /*  509, col */
      83,    108,     -1, /*  510, col */
      96,    121,     -1, /*  511, col */
      97,    119,     -1, /*  512, col */
      87,    104,     -1, /*  513, col */
      95,    123,     -1, /*  514, col */
      92,    117,     -1, /*  515, col */
      94,    118,     -1, /*  516, col */
      95,    123,     -1, /*  517, col */
      87,    104,     -1, /*  518, col */
      89,    110,     -1, /*  519, col */
      93,    124,     -1, /*  520, col */
      94,    118,     -1, /*  521, col */
     104,    128,     -1, /*  522, col */
     107,    129,     -1, /*  523, col */
     114,    130,     -1, /*  524, col */
     102,    131,     -1, /*  525, col */
     109,    132,     -1, /*  526, col */
     101,    133,     -1, /*  527, col */
     125,    135,     -1, /*  528, col */
     126,    136,     -1, /*  529, col */
     119,    142,     -1, /*  530, col */
     101,    133,     -1, /*  531, col */
     110,    134,     -1, /*  532, col */
     106,    135,     -1, /*  533, col */
     101,    133,     -1, /*  534, col */
     109,    132,     -1, /*  535, col */
     110,    134,     -1, /*  536, col */
     133,    161,     -1, /*  537, col */
     130,    159,     -1, /*  538, col */
     117,    143,     -1, /*  539, col */
     106,    135,     -1, /*  540, col */
     111,    136,     -1, /*  541, col */
     105,    137,     -1, /*  542, col */
     105,    137,     -1, /*  543, col */
     111,    136,     -1, /*  544, col */
     102,    131,     -1, /*  545, col */
     126,    136,     -1, /*  546, col */
     101,    133,     -1, /*  547, col */
     106,    135,     -1, /*  548, col */
     112,    138,     -1, /*  549, col */
     104,    128,     -1, /*  550, col */
     114,    130,     -1, /*  551, col */
     112,    138,     -1, /*  552, col */
     103,    140,     -1, /*  553, col */
     104,    128,     -1, /*  554, col */
     120,    152,     -1, /*  555, col */
     122,    153,     -1, /*  556, col */
     121,    154,     -1, /*  557, col */
     113,    139,     -1, /*  558, col */
     103,    140,     -1, /*  559, col */
     112,    138,     -1, /*  560, col */
     113,    139,     -1, /*  561, col */
     100,    128,     -1, /*  562, col */
     103,    140,     -1, /*  563, col */
     115,    141,     -1, /*  564, col */
     107,    129,     -1, /*  565, col */
     113,    139,     -1, /*  566, col */
     119,    142,     -1, /*  567, col */
     106,    135,     -1, /*  568, col */
     117,    143,     -1, /*  569, col */
     117,    143,     -1, /*  570, col */
     115,    141,     -1, /*  571, col */
     119,    142,     -1, /*  572, col */
     127,    156,     -1, /*  573, col */
     126,    136,     -1, /*  574, col */
     125,    135,     -1, /*  575, col */
     117,    143,     -1, /*  576, col */
     114,    130,     -1, /*  577, col */
     115,    141,     -1, /*  578, col */
     107,    129,     -1, /*  579, col */
     100,    128,     -1, /*  580, col */
     113,    139,     -1, /*  581, col */
     111,    136,     -1, /*  582, col */
     108,    144,     -1, /*  583, col */
     102,    131,     -1, /*  584, col */
     106,    135,     -1, /*  585, col */
     110,    134,     -1, /*  586, col */
     111,    136,     -1, /*  587, col */
     102,    131,     -1, /*  588, col */
     108,    144,     -1, /*  589, col */
     109,    132,     -1, /*  590, col */
     107,    129,     -1, /*  591, col */
     115,    141,     -1, /*  592, col */
     114,    130,     -1, /*  593, col */
     136,    137,     -1, /*  594, col */
     103,    140,     -1, /*  595, col */
     100,    128,     -1, /*  596, col */
     109,    145,     -1, /*  597, col */
      23,     20,     -1, /*  598, col */
      27,     26,     -1, /*  599, col */
     108,    146,     -1, /*  600, col */
      24,     22,     -1, /*  601, col */
      23,     20,     -1, /*  602, col */
     206,    239,     -1, /*  603, col */
     207,    241,     -1, /*  604, col */
     181,    251,     -1, /*  605, col */
     110,    148,     -1, /*  606, col */
      26,     24,     -1, /*  607, col */
      25,    114,     -1, /*  608, col */
     174,    206,     -1, /*  609, col */
     177,    210,     -1, /*  610, col */
     169,    214,     -1, /*  611, col */
     109,    145,     -1, /*  612, col */
      27,     26,     -1, /*  613, col */
      26,     24,     -1, /*  614, col */
     191,    222,     -1, /*  615, col */
     194,    220,     -1, /*  616, col */
     197,    206,     -1, /*  617, col */
     194,    220,     -1, /*  618, col */
     200,    219,     -1, /*  619, col */
     197,    206,     -1, /*  620, col */
     111,    147,     -1, /*  621, col */
     110,    148,     -1, /*  622, col */
      25,    114,     -1, /*  623, col */
     110,    148,     -1, /*  624, col */
     109,    145,     -1, /*  625, col */
      26,     24,     -1, /*  626, col */
     116,    149,     -1, /*  627, col */
     114,    130,     -1, /*  628, col */
     117,    143,     -1, /*  629, col */
     138,    172,     -1, /*  630, col */
     107,    129,     -1, /*  631, col */
     104,    128,     -1, /*  632, col */
     138,    172,     -1, /*  633, col */
     139,    170,     -1, /*  634, col */
     107,    129,     -1, /*  635, col */
     121,    154,     -1, /*  636, col */
     122,    153,     -1, /*  637, col */
     118,    151,     -1, /*  638, col */
     116,    149,     -1, /*  639, col */
     112,    138,     -1, /*  640, col */
     114,    130,     -1, /*  641, col */
     119,    142,     -1, /*  642, col */
     115,    141,     -1, /*  643, col */
     118,    151,     -1, /*  644, col */
     121,    154,     -1, /*  645, col */
     118,    151,     -1, /*  646, col */
     101,    133,     -1, /*  647, col */
     124,    155,     -1, /*  648, col */
     127,    156,     -1, /*  649, col */
     125,    135,     -1, /*  650, col */
     123,    157,     -1, /*  651, col */
     124,    155,     -1, /*  652, col */
     122,    153,     -1, /*  653, col */
     124,    155,     -1, /*  654, col */
     125,    135,     -1, /*  655, col */
     122,    153,     -1, /*  656, col */
     124,    155,     -1, /*  657, col */
     166,    192,     -1, /*  658, col */
     127,    156,     -1, /*  659, col */
     127,    156,     -1, /*  660, col */
     166,    192,     -1, /*  661, col */
     120,    152,     -1, /*  662, col */
     166,    192,     -1, /*  663, col */
     167,    193,     -1, /*  664, col */
     120,    152,     -1, /*  665, col */
     127,    156,     -1, /*  666, col */
     121,    154,     -1, /*  667, col */
     126,    136,     -1, /*  668, col */
     127,    156,     -1, /*  669, col */
     120,    152,     -1, /*  670, col */
     121,    154,     -1, /*  671, col */
     120,    152,     -1, /*  672, col */
     123,    157,     -1, /*  673, col */
     122,    153,     -1, /*  674, col */
     122,    153,     -1, /*  675, col */
     119,    142,     -1, /*  676, col */
     118,    151,     -1, /*  677, col */
     129,    158,     -1, /*  678, col */
     130,    159,     -1, /*  679, col */
     128,    160,     -1, /*  680, col */
     133,    161,     -1, /*  681, col */
     135,    162,     -1, /*  682, col */
     132,    163,     -1, /*  683, col */
     130,    159,     -1, /*  684, col */
     132,    163,     -1, /*  685, col */
     131,    164,     -1, /*  686, col */
     130,    159,     -1, /*  687, col */
     133,    161,     -1, /*  688, col */
     132,    163,     -1, /*  689, col */
     134,    151,     -1, /*  690, col */
     129,    158,     -1, /*  691, col */
     135,    162,     -1, /*  692, col */
     129,    158,     -1, /*  693, col */
     128,    160,     -1, /*  694, col */
     135,    162,     -1, /*  695, col */
     133,    161,     -1, /*  696, col */
     134,    151,     -1, /*  697, col */
     135,    162,     -1, /*  698, col */
     130,    159,     -1, /*  699, col */
     131,    164,     -1, /*  700, col */
     128,    160,     -1, /*  701, col */
     129,    158,     -1, /*  702, col */
     105,    137,     -1, /*  703, col */
     102,    131,     -1, /*  704, col */
     134,    151,     -1, /*  705, col */
     105,    137,     -1, /*  706, col */
     129,    158,     -1, /*  707, col */
     134,    151,     -1, /*  708, col */
     117,    143,     -1, /*  709, col */
     105,    137,     -1, /*  710, col */
     130,    159,     -1, /*  711, col */
     129,    158,     -1, /*  712, col */
     116,    149,     -1, /*  713, col */
     101,    133,     -1, /*  714, col */
     126,    136,     -1, /*  715, col */
     121,    154,     -1, /*  716, col */
     141,    165,     -1, /*  717, col */
     136,    165,     -1, /*  718, col */
     140,    166,     -1, /*  719, col */
     141,    165,     -1, /*  720, col */
     137,    174,     -1, /*  721, col */
     136,    165,     -1, /*  722, col */
     143,    167,     -1, /*  723, col */
     138,    168,     -1, /*  724, col */
     142,    169,     -1, /*  725, col */
     144,    173,     -1, /*  726, col */
     183,    216,     -1, /*  727, col */
     147,    174,     -1, /*  728, col */
     147,    174,     -1, /*  729, col */
     184,    216,     -1, /*  730, col */
     148,    176,     -1, /*  731, col */
     155,    183,     -1, /*  732, col */
     185,    178,     -1, /*  733, col */
     152,    174,     -1, /*  734, col */
     156,    186,     -1, /*  735, col */
     185,    178,     -1, /*  736, col */
     155,    183,     -1, /*  737, col */
     156,    186,     -1, /*  738, col */
     188,    167,     -1, /*  739, col */
     185,    178,     -1, /*  740, col */
     185,    178,     -1, /*  741, col */
     186,    176,     -1, /*  742, col */
     152,    174,     -1, /*  743, col */
     184,    216,     -1, /*  744, col */
     181,    279,     -1, /*  745, col */
     148,    176,     -1, /*  746, col */
     148,    176,     -1, /*  747, col */
     181,    279,     -1, /*  748, col */
     182,    215,     -1, /*  749, col */
     143,    167,     -1, /*  750, col */
     139,    181,     -1, /*  751, col */
     138,    168,     -1, /*  752, col */
     142,    169,     -1, /*  753, col */
     140,    166,     -1, /*  754, col */
     143,    167,     -1, /*  755, col */
     142,    169,     -1, /*  756, col */
     141,    165,     -1, /*  757, col */
     140,    166,     -1, /*  758, col */
     138,    168,     -1, /*  759, col */
     158,    185,     -1, /*  760, col */
     157,    184,     -1, /*  761, col */
     149,    178,     -1, /*  762, col */
     150,    177,     -1, /*  763, col */
     139,    181,     -1, /*  764, col */
     139,    170,     -1, /*  765, col */
     136,    137,     -1, /*  766, col */
     107,    129,     -1, /*  767, col */
     137,    171,     -1, /*  768, col */
     104,    128,     -1, /*  769, col */
     103,    140,     -1, /*  770, col */
     106,    135,     -1, /*  771, col */
     105,    137,     -1, /*  772, col */
     117,    143,     -1, /*  773, col */
     144,    173,     -1, /*  774, col */
     147,    174,     -1, /*  775, col */
     145,    175,     -1, /*  776, col */
     148,    176,     -1, /*  777, col */
     150,    177,     -1, /*  778, col */
     149,    178,     -1, /*  779, col */
     148,    176,     -1, /*  780, col */
     151,    180,     -1, /*  781, col */
     150,    177,     -1, /*  782, col */
     157,    184,     -1, /*  783, col */
     158,    185,     -1, /*  784, col */
     156,    186,     -1, /*  785, col */
     158,    185,     -1, /*  786, col */
     159,    188,     -1, /*  787, col */
     156,    186,     -1, /*  788, col */
     147,    174,     -1, /*  789, col */
     148,    176,     -1, /*  790, col */
     146,    179,     -1, /*  791, col */
     158,    185,     -1, /*  792, col */
     153,    182,     -1, /*  793, col */
     159,    188,     -1, /*  794, col */
     151,    180,     -1, /*  795, col */
     145,    175,     -1, /*  796, col */
     150,    177,     -1, /*  797, col */
     151,    180,     -1, /*  798, col */
     144,    173,     -1, /*  799, col */
     145,    175,     -1, /*  800, col */
     148,    176,     -1, /*  801, col */
     149,    178,     -1, /*  802, col */
     146,    179,     -1, /*  803, col */
     147,    174,     -1, /*  804, col */
     146,    179,     -1, /*  805, col */
     145,    175,     -1, /*  806, col */
     153,    182,     -1, /*  807, col */
     155,    183,     -1, /*  808, col */
     152,    174,     -1, /*  809, col */
     153,    182,     -1, /*  810, col */
     154,    187,     -1, /*  811, col */
     155,    183,     -1, /*  812, col */
     145,    175,     -1, /*  813, col */
     146,    179,     -1, /*  814, col */
     136,    165,     -1, /*  815, col */
     146,    179,     -1, /*  816, col */
     149,    178,     -1, /*  817, col */
     140,    166,     -1, /*  818, col */
     149,    178,     -1, /*  819, col */
     139,    181,     -1, /*  820, col */
     143,    167,     -1, /*  821, col */
     150,    177,     -1, /*  822, col */
     136,    165,     -1, /*  823, col */
     139,    181,     -1, /*  824, col */
     154,    187,     -1, /*  825, col */
     137,    174,     -1, /*  826, col */
     141,    165,     -1, /*  827, col */
     154,    187,     -1, /*  828, col */
     156,    186,     -1, /*  829, col */
     155,    183,     -1, /*  830, col */
     153,    182,     -1, /*  831, col */
     152,    174,     -1, /*  832, col */
     159,    188,     -1, /*  833, col */
     154,    187,     -1, /*  834, col */
     157,    184,     -1, /*  835, col */
     156,    186,     -1, /*  836, col */
     153,    182,     -1, /*  837, col */
     158,    185,     -1, /*  838, col */
     137,    174,     -1, /*  839, col */
     157,    184,     -1, /*  840, col */
     142,    169,     -1, /*  841, col */
     138,    168,     -1, /*  842, col */
     150,    177,     -1, /*  843, col */
     145,    175,     -1, /*  844, col */
     136,    165,     -1, /*  845, col */
     157,    184,     -1, /*  846, col */
     141,    165,     -1, /*  847, col */
     142,    169,     -1, /*  848, col */
     132,    163,     -1, /*  849, col */
     160,    189,     -1, /*  850, col */
     131,    164,     -1, /*  851, col */
     131,    164,     -1, /*  852, col */
     162,    135,     -1, /*  853, col */
     128,    160,     -1, /*  854, col */
     163,    190,     -1, /*  855, col */
     160,    189,     -1, /*  856, col */
     132,    163,     -1, /*  857, col */
     162,    135,     -1, /*  858, col */
     163,    190,     -1, /*  859, col */
     135,    162,     -1, /*  860, col */
     131,    164,     -1, /*  861, col */
     161,    135,     -1, /*  862, col */
     162,    135,     -1, /*  863, col */
     160,    189,     -1, /*  864, col */
     161,    135,     -1, /*  865, col */
     131,    164,     -1, /*  866, col */
     128,    160,     -1, /*  867, col */
     162,    135,     -1, /*  868, col */
     135,    162,     -1, /*  869, col */
     135,    162,     -1, /*  870, col */
     163,    190,     -1, /*  871, col */
     132,    163,     -1, /*  872, col */
     167,    193,     -1, /*  873, col */
     164,    191,     -1, /*  874, col */
     123,    157,     -1, /*  875, col */
     123,    157,     -1, /*  876, col */
     164,    191,     -1, /*  877, col */
     124,    155,     -1, /*  878, col */
     120,    152,     -1, /*  879, col */
     167,    193,     -1, /*  880, col */
     123,    157,     -1, /*  881, col */
     164,    191,     -1, /*  882, col */
     165,    280,     -1, /*  883, col */
     124,    155,     -1, /*  884, col */
     239,    195,     -1, /*  885, col */
     163,    196,     -1, /*  886, col */
     162,     21,     -1, /*  887, col */
     198,    217,     -1, /*  888, col */
     190,    218,     -1, /*  889, col */
     197,    206,     -1, /*  890, col */
     108,    146,     -1, /*  891, col */
     111,    147,     -1, /*  892, col */
      24,     22,     -1, /*  893, col */
     242,    197,     -1, /*  894, col */
     160,    198,     -1, /*  895, col */
     163,    196,     -1, /*  896, col */
     241,    199,     -1, /*  897, col */
     240,    194,     -1, /*  898, col */
     160,    198,     -1, /*  899, col */
     244,    209,     -1, /*  900, col */
     243,    146,     -1, /*  901, col */
     250,    276,     -1, /*  902, col */
     168,    200,     -1, /*  903, col */
     164,    201,     -1, /*  904, col */
     167,    202,     -1, /*  905, col */
     168,    200,     -1, /*  906, col */
     169,    214,     -1, /*  907, col */
     164,    201,     -1, /*  908, col */
     171,    148,     -1, /*  909, col */
     168,    200,     -1, /*  910, col */
     166,    204,     -1, /*  911, col */
     165,    205,     -1, /*  912, col */
     164,    201,     -1, /*  913, col */
     170,    203,     -1, /*  914, col */
     172,     15,     -1, /*  915, col */
     174,    206,     -1, /*  916, col */
     173,    207,     -1, /*  917, col */
     172,     15,     -1, /*  918, col */
     175,    211,     -1, /*  919, col */
     174,    206,     -1, /*  920, col */
     175,    211,     -1, /*  921, col */
     176,    208,     -1, /*  922, col */
     174,    206,     -1, /*  923, col */
     164,    201,     -1, /*  924, col */
     169,    214,     -1, /*  925, col */
     170,    203,     -1, /*  926, col */
     179,    209,     -1, /*  927, col */
     173,    207,     -1, /*  928, col */
     178,    212,     -1, /*  929, col */
     179,    209,     -1, /*  930, col */
     172,     15,     -1, /*  931, col */
     173,    207,     -1, /*  932, col */
     176,    208,     -1, /*  933, col */
     177,    210,     -1, /*  934, col */
     174,    206,     -1, /*  935, col */
     179,    209,     -1, /*  936, col */
     178,    212,     -1, /*  937, col */
     177,    210,     -1, /*  938, col */
     176,    208,     -1, /*  939, col */
     180,    213,     -1, /*  940, col */
     179,    209,     -1, /*  941, col */
     179,    209,     -1, /*  942, col */
     180,    213,     -1, /*  943, col */
     172,     15,     -1, /*  944, col */
     239,    195,     -1, /*  945, col */
     242,    197,     -1, /*  946, col */
     163,    196,     -1, /*  947, col */
     172,     15,     -1, /*  948, col */
     180,    213,     -1, /*  949, col */
     175,    211,     -1, /*  950, col */
     175,    211,     -1, /*  951, col */
     180,    213,     -1, /*  952, col */
     176,    208,     -1, /*  953, col */
     177,    210,     -1, /*  954, col */
     171,    148,     -1, /*  955, col */
     170,    203,     -1, /*  956, col */
     178,    212,     -1, /*  957, col */
     173,    207,     -1, /*  958, col */
     171,    148,     -1, /*  959, col */
     148,    176,     -1, /*  960, col */
     182,    215,     -1, /*  961, col */
     151,    180,     -1, /*  962, col */
     151,    180,     -1, /*  963, col */
     182,    215,     -1, /*  964, col */
     144,    173,     -1, /*  965, col */
     152,    174,     -1, /*  966, col */
     187,    173,     -1, /*  967, col */
     159,    188,     -1, /*  968, col */
     159,    188,     -1, /*  969, col */
     187,    173,     -1, /*  970, col */
     156,    186,     -1, /*  971, col */
     187,    173,     -1, /*  972, col */
     188,    167,     -1, /*  973, col */
     156,    186,     -1, /*  974, col */
     200,    219,     -1, /*  975, col */
     194,    220,     -1, /*  976, col */
     199,    221,     -1, /*  977, col */
     195,    223,     -1, /*  978, col */
     190,    218,     -1, /*  979, col */
     199,    221,     -1, /*  980, col */
     198,    224,     -1, /*  981, col */
     189,    225,     -1, /*  982, col */
     199,    226,     -1, /*  983, col */
     189,    225,     -1, /*  984, col */
     196,    227,     -1, /*  985, col */
     199,    226,     -1, /*  986, col */
     199,    226,     -1, /*  987, col */
     196,    227,     -1, /*  988, col */
     200,    228,     -1, /*  989, col */
     196,    227,     -1, /*  990, col */
     193,    231,     -1, /*  991, col */
     200,    228,     -1, /*  992, col */
     200,    228,     -1, /*  993, col */
     192,    229,     -1, /*  994, col */
     197,    230,     -1, /*  995, col */
     200,    228,     -1, /*  996, col */
     193,    231,     -1, /*  997, col */
     192,    229,     -1, /*  998, col */
     197,    230,     -1, /*  999, col */
     192,    229,     -1, /* 1000, col */
     198,    224,     -1, /* 1001, col */
     192,    229,     -1, /* 1002, col */
     189,    225,     -1, /* 1003, col */
     198,    224,     -1, /* 1004, col */
     194,    220,     -1, /* 1005, col */
     195,    223,     -1, /* 1006, col */
     199,    221,     -1, /* 1007, col */
     190,    218,     -1, /* 1008, col */
     191,    222,     -1, /* 1009, col */
     197,    206,     -1, /* 1010, col */
     194,    220,     -1, /* 1011, col */
     185,    232,     -1, /* 1012, col */
     188,    233,     -1, /* 1013, col */
     190,    218,     -1, /* 1014, col */
     195,    223,     -1, /* 1015, col */
     186,    234,     -1, /* 1016, col */
     195,    223,     -1, /* 1017, col */
     187,    235,     -1, /* 1018, col */
     186,    234,     -1, /* 1019, col */
     195,    223,     -1, /* 1020, col */
     188,    233,     -1, /* 1021, col */
     187,    235,     -1, /* 1022, col */
     195,    223,     -1, /* 1023, col */
     194,    220,     -1, /* 1024, col */
     188,    233,     -1, /* 1025, col */
     242,    197,     -1, /* 1026, col */
     241,    199,     -1, /* 1027, col */
     160,    198,     -1, /* 1028, col */
     209,    236,     -1, /* 1029, col */
     202,    237,     -1, /* 1030, col */
     210,    206,     -1, /* 1031, col */
     211,    238,     -1, /* 1032, col */
     206,    239,     -1, /* 1033, col */
     212,    240,     -1, /* 1034, col */
     209,    236,     -1, /* 1035, col */
     206,    239,     -1, /* 1036, col */
     203,    220,     -1, /* 1037, col */
     211,    242,     -1, /* 1038, col */
     201,    243,     -1, /* 1039, col */
     210,    230,     -1, /* 1040, col */
     211,    242,     -1, /* 1041, col */
     208,    245,     -1, /* 1042, col */
     201,    243,     -1, /* 1043, col */
     212,    244,     -1, /* 1044, col */
     208,    245,     -1, /* 1045, col */
     211,    242,     -1, /* 1046, col */
     212,    244,     -1, /* 1047, col */
     205,    248,     -1, /* 1048, col */
     208,    245,     -1, /* 1049, col */
     209,    246,     -1, /* 1050, col */
     204,    247,     -1, /* 1051, col */
     212,    244,     -1, /* 1052, col */
     204,    247,     -1, /* 1053, col */
     205,    248,     -1, /* 1054, col */
     212,    244,     -1, /* 1055, col */
     210,    230,     -1, /* 1056, col */
     204,    247,     -1, /* 1057, col */
     209,    246,     -1, /* 1058, col */
     210,    230,     -1, /* 1059, col */
     201,    243,     -1, /* 1060, col */
     204,    247,     -1, /* 1061, col */
     209,    236,     -1, /* 1062, col */
     212,    240,     -1, /* 1063, col */
     206,    239,     -1, /* 1064, col */
     211,    238,     -1, /* 1065, col */
     207,    241,     -1, /* 1066, col */
     206,    239,     -1, /* 1067, col */
     246,    206,     -1, /* 1068, col */
     251,    278,     -1, /* 1069, col */
     243,    146,     -1, /* 1070, col */
     177,    210,     -1, /* 1071, col */
     178,    212,     -1, /* 1072, col */
     171,    148,     -1, /* 1073, col */
     202,    237,     -1, /* 1074, col */
     184,    249,     -1, /* 1075, col */
     183,    250,     -1, /* 1076, col */
     202,    237,     -1, /* 1077, col */
     203,    220,     -1, /* 1078, col */
     184,    249,     -1, /* 1079, col */
     217,    253,     -1, /* 1080, col */
     220,    254,     -1, /* 1081, col */
     218,    255,     -1, /* 1082, col */
     214,    243,     -1, /* 1083, col */
     222,    242,     -1, /* 1084, col */
     224,    256,     -1, /* 1085, col */
     214,    243,     -1, /* 1086, col */
     215,    260,     -1, /* 1087, col */
     222,    242,     -1, /* 1088, col */
     223,    257,     -1, /* 1089, col */
     216,    258,     -1, /* 1090, col */
     225,    259,     -1, /* 1091, col */
     225,    259,     -1, /* 1092, col */
     220,    254,     -1, /* 1093, col */
     223,    257,     -1, /* 1094, col */
     216,    258,     -1, /* 1095, col */
     222,    242,     -1, /* 1096, col */
     215,    260,     -1, /* 1097, col */
     225,    259,     -1, /* 1098, col */
     213,    244,     -1, /* 1099, col */
     224,    256,     -1, /* 1100, col */
     215,    260,     -1, /* 1101, col */
     221,    261,     -1, /* 1102, col */
     216,    258,     -1, /* 1103, col */
     216,    258,     -1, /* 1104, col */
     221,    261,     -1, /* 1105, col */
     213,    244,     -1, /* 1106, col */
     213,    244,     -1, /* 1107, col */
     221,    261,     -1, /* 1108, col */
     214,    243,     -1, /* 1109, col */
     218,    255,     -1, /* 1110, col */
     205,    248,     -1, /* 1111, col */
     204,    247,     -1, /* 1112, col */
     214,    243,     -1, /* 1113, col */
     221,    261,     -1, /* 1114, col */
     215,    260,     -1, /* 1115, col */
     223,    257,     -1, /* 1116, col */
     217,    253,     -1, /* 1117, col */
     222,    242,     -1, /* 1118, col */
     224,    256,     -1, /* 1119, col */
     219,    262,     -1, /* 1120, col */
     225,    259,     -1, /* 1121, col */
     216,    258,     -1, /* 1122, col */
     223,    257,     -1, /* 1123, col */
     222,    242,     -1, /* 1124, col */
     227,    267,     -1, /* 1125, col */
     234,    272,     -1, /* 1126, col */
     226,    271,     -1, /* 1127, col */
     219,    262,     -1, /* 1128, col */
     220,    254,     -1, /* 1129, col */
     225,    259,     -1, /* 1130, col */
     220,    254,     -1, /* 1131, col */
     217,    253,     -1, /* 1132, col */
     223,    257,     -1, /* 1133, col */
     217,    253,     -1, /* 1134, col */
     218,    255,     -1, /* 1135, col */
     222,    242,     -1, /* 1136, col */
     237,    265,     -1, /* 1137, col */
     227,    267,     -1, /* 1138, col */
     226,    271,     -1, /* 1139, col */
     213,    244,     -1, /* 1140, col */
     214,    243,     -1, /* 1141, col */
     224,    256,     -1, /* 1142, col */
     216,    258,     -1, /* 1143, col */
     213,    244,     -1, /* 1144, col */
     225,    259,     -1, /* 1145, col */
     220,    254,     -1, /* 1146, col */
     219,    262,     -1, /* 1147, col */
     218,    255,     -1, /* 1148, col */
     222,    242,     -1, /* 1149, col */
     218,    255,     -1, /* 1150, col */
     204,    247,     -1, /* 1151, col */
     218,    255,     -1, /* 1152, col */
     219,    262,     -1, /* 1153, col */
     205,    248,     -1, /* 1154, col */
     219,    262,     -1, /* 1155, col */
     224,    256,     -1, /* 1156, col */
     208,    245,     -1, /* 1157, col */
     224,    256,     -1, /* 1158, col */
     222,    242,     -1, /* 1159, col */
     201,    243,     -1, /* 1160, col */
     231,    263,     -1, /* 1161, col */
     233,    255,     -1, /* 1162, col */
     230,    264,     -1, /* 1163, col */
     232,    273,     -1, /* 1164, col */
     193,    231,     -1, /* 1165, col */
     196,    227,     -1, /* 1166, col */
     237,    265,     -1, /* 1167, col */
     235,    266,     -1, /* 1168, col */
     227,    267,     -1, /* 1169, col */
     235,    266,     -1, /* 1170, col */
     228,    270,     -1, /* 1171, col */
     227,    267,     -1, /* 1172, col */
     238,    268,     -1, /* 1173, col */
     229,    269,     -1, /* 1174, col */
     236,    261,     -1, /* 1175, col */
     236,    261,     -1, /* 1176, col */
     233,    255,     -1, /* 1177, col */
     238,    268,     -1, /* 1178, col */
     228,    270,     -1, /* 1179, col */
     235,    266,     -1, /* 1180, col */
     229,    269,     -1, /* 1181, col */
     237,    265,     -1, /* 1182, col */
     226,    271,     -1, /* 1183, col */
     238,    268,     -1, /* 1184, col */
     237,    265,     -1, /* 1185, col */
     232,    273,     -1, /* 1186, col */
     196,    227,     -1, /* 1187, col */
     229,    269,     -1, /* 1188, col */
     234,    272,     -1, /* 1189, col */
     228,    270,     -1, /* 1190, col */
     226,    271,     -1, /* 1191, col */
     234,    272,     -1, /* 1192, col */
     229,    269,     -1, /* 1193, col */
     228,    270,     -1, /* 1194, col */
     234,    272,     -1, /* 1195, col */
     227,    267,     -1, /* 1196, col */
     235,    266,     -1, /* 1197, col */
     230,    264,     -1, /* 1198, col */
     236,    261,     -1, /* 1199, col */
     238,    268,     -1, /* 1200, col */
     232,    273,     -1, /* 1201, col */
     237,    265,     -1, /* 1202, col */
     238,    268,     -1, /* 1203, col */
     233,    255,     -1, /* 1204, col */
     232,    273,     -1, /* 1205, col */
     236,    261,     -1, /* 1206, col */
     230,    264,     -1, /* 1207, col */
     233,    255,     -1, /* 1208, col */
     235,    266,     -1, /* 1209, col */
     231,    263,     -1, /* 1210, col */
     230,    264,     -1, /* 1211, col */
     235,    266,     -1, /* 1212, col */
     236,    261,     -1, /* 1213, col */
     229,    269,     -1, /* 1214, col */
     238,    268,     -1, /* 1215, col */
     226,    271,     -1, /* 1216, col */
     229,    269,     -1, /* 1217, col */
     231,    263,     -1, /* 1218, col */
     232,    273,     -1, /* 1219, col */
     233,    255,     -1, /* 1220, col */
     235,    266,     -1, /* 1221, col */
     189,    225,     -1, /* 1222, col */
     192,    229,     -1, /* 1223, col */
     235,    266,     -1, /* 1224, col */
     237,    265,     -1, /* 1225, col */
     189,    225,     -1, /* 1226, col */
     222,    242,     -1, /* 1227, col */
     204,    247,     -1, /* 1228, col */
     201,    243,     -1, /* 1229, col */
     237,    265,     -1, /* 1230, col */
     196,    227,     -1, /* 1231, col */
     189,    225,     -1, /* 1232, col */
     231,    263,     -1, /* 1233, col */
     192,    229,     -1, /* 1234, col */
     193,    231,     -1, /* 1235, col */
     242,    197,     -1, /* 1236, col */
     248,    274,     -1, /* 1237, col */
     241,    199,     -1, /* 1238, col */
     239,    195,     -1, /* 1239, col */
     249,    275,     -1, /* 1240, col */
     242,    197,     -1, /* 1241, col */
     239,    195,     -1, /* 1242, col */
     244,    209,     -1, /* 1243, col */
     249,    275,     -1, /* 1244, col */
     190,    218,     -1, /* 1245, col */
     186,    234,     -1, /* 1246, col */
     185,    232,     -1, /* 1247, col */
     244,    209,     -1, /* 1248, col */
     245,    213,     -1, /* 1249, col */
     243,    146,     -1, /* 1250, col */
     245,    213,     -1, /* 1251, col */
     246,    206,     -1, /* 1252, col */
     243,    146,     -1, /* 1253, col */
     248,    274,     -1, /* 1254, col */
     250,    276,     -1, /* 1255, col */
     247,    277,     -1, /* 1256, col */
     249,    275,     -1, /* 1257, col */
     244,    209,     -1, /* 1258, col */
     250,    276,     -1, /* 1259, col */
     248,    274,     -1, /* 1260, col */
     249,    275,     -1, /* 1261, col */
     250,    276,     -1, /* 1262, col */
     250,    276,     -1, /* 1263, col */
     251,    278,     -1, /* 1264, col */
     247,    277,     -1, /* 1265, col */
     243,    146,     -1, /* 1266, col */
     251,    278,     -1, /* 1267, col */
     250,    276,     -1, /* 1268, col */
     247,    277,     -1, /* 1269, col */
     251,    278,     -1, /* 1270, col */
     246,    206,     -1, /* 1271, col */
     109,    145,     -1, /* 1272, col */
     108,    146,     -1, /* 1273, col */
      23,     20,     -1, /* 1274, col */
     240,    194,     -1, /* 1275, col */
     245,    213,     -1, /* 1276, col */
     239,    195,     -1, /* 1277, col */
     245,    213,     -1, /* 1278, col */
     244,    209,     -1, /* 1279, col */
     239,    195,     -1, /* 1280, col */
     242,    197,     -1, /* 1281, col */
     249,    275,     -1, /* 1282, col */
     248,    274,     -1, /* 1283, col */
     231,    263,     -1, /* 1284, col */
     235,    266,     -1, /* 1285, col */
     192,    229,     -1, /* 1286, col */
     232,    273,     -1, /* 1287, col */
     231,    263,     -1, /* 1288, col */
     193,    231,     -1, /* 1289, col */
     224,    256,     -1, /* 1290, col */
     201,    243,     -1, /* 1291, col */
     208,    245,     -1, /* 1292, col */
     219,    262,     -1, /* 1293, col */
     208,    245,     -1, /* 1294, col */
     205,    248,     -1, /* 1295, col */
     207,    241,     -1, /* 1296, col */
     182,    252,     -1, /* 1297, col */
     181,    251,     -1, /* 1298, col */
     194,    220,     -1, /* 1299, col */
     191,    222,     -1, /* 1300, col */
     185,    232,     -1, /* 1301, col */
     152,    174,     -1, /* 1302, col */
     186,    176,     -1, /* 1303, col */
     187,    173,     -1, /* 1304, col */
     183,    216,     -1, /* 1305, col */
     184,    216,     -1, /* 1306, col */
     147,    174,     -1, /* 1307, col */
     182,    215,     -1, /* 1308, col */
     183,    216,     -1, /* 1309, col */
     144,    173,     -1, /* 1310, col */
     177,    210,     -1, /* 1311, col */
     170,    203,     -1, /* 1312, col */
     169,    214,     -1, /* 1313, col */
     239,    195,     -1, /* 1314, col */
     162,     21,     -1, /* 1315, col */
     161,     21,     -1, /* 1316, col */
     173,    207,     -1, /* 1317, col */
     168,    200,     -1, /* 1318, col */
     171,    148,     -1, /* 1319, col */
     124,    155,     -1, /* 1320, col */
     165,    280,     -1, /* 1321, col */
     166,    192,     -1, /* 1322, col */
     154,    187,     -1, /* 1323, col */
     153,    182,     -1, /* 1324, col */
     137,    174,     -1, /* 1325, col */
     157,    184,     -1, /* 1326, col */
     154,    187,     -1, /* 1327, col */
     141,    165,     -1, /* 1328, col */
     158,    185,     -1, /* 1329, col */
     138,    168,     -1, /* 1330, col */
     137,    174,     -1, /* 1331, col */
     149,    178,     -1, /* 1332, col */
     143,    167,     -1, /* 1333, col */
     140,    166,     -1, /* 1334, col */
     146,    179,     -1, /* 1335, col */
     140,    166,     -1, /* 1336, col */
     136,    165,     -1, /* 1337, col */
     137,    171,     -1, /* 1338, col */
     138,    172,     -1, /* 1339, col */
     104,    128,     -1, /* 1340, col */
     136,    137,     -1, /* 1341, col */
     137,    171,     -1, /* 1342, col */
     103,    140,     -1, /* 1343, col */
     136,    137,     -1, /* 1344, col */
     100,    128,     -1, /* 1345, col */
     107,    129,     -1, /* 1346, col */
     129,    158,     -1, /* 1347, col */
     102,    131,     -1, /* 1348, col */
     116,    149,     -1, /* 1349, col */
     130,    159,     -1, /* 1350, col */
     116,    149,     -1, /* 1351, col */
     117,    143,     -1, /* 1352, col */
     134,    151,     -1, /* 1353, col */
     133,    161,     -1, /* 1354, col */
     117,    143,     -1, /* 1355, col */
     126,    136,     -1, /* 1356, col */
     106,    135,     -1, /* 1357, col */
     119,    142,     -1, /* 1358, col */
     122,    153,     -1, /* 1359, col */
     125,    135,     -1, /* 1360, col */
     119,    142,     -1, /* 1361, col */
     115,    141,     -1, /* 1362, col */
     113,    139,     -1, /* 1363, col */
     118,    151,     -1, /* 1364, col */
       8,      0,     -1, /* 1365, col */
       9,      1,     -1, /* 1366, col */
       6,      2,     -1, /* 1367, col */
      81,     49,     -1, /* 1368, col */
      33,     97,     -1, /* 1369, col */
      32,     48,     -1, /* 1370, col */
       6,      2,     -1, /* 1371, col */
      10,      3,     -1, /* 1372, col */
       7,      4,     -1, /* 1373, col */
      82,     29,     -1, /* 1374, col */
      44,     30,     -1, /* 1375, col */
      43,     31,     -1, /* 1376, col */
      31,     46,     -1, /* 1377, col */
      40,     47,     -1, /* 1378, col */
      32,     48,     -1, /* 1379, col */
      32,     48,     -1, /* 1380, col */
      40,     47,     -1, /* 1381, col */
      81,     49,     -1, /* 1382, col */
      79,     50,     -1, /* 1383, col */
      44,     30,     -1, /* 1384, col */
      36,     51,     -1, /* 1385, col */
      36,     51,     -1, /* 1386, col */
      44,     30,     -1, /* 1387, col */
      37,     52,     -1, /* 1388, col */
      37,     52,     -1, /* 1389, col */
      46,     53,     -1, /* 1390, col */
      38,     50,     -1, /* 1391, col */
      38,     50,     -1, /* 1392, col */
      46,     53,     -1, /* 1393, col */
      31,     46,     -1, /* 1394, col */
      39,     54,     -1, /* 1395, col */
      46,     53,     -1, /* 1396, col */
      82,     29,     -1, /* 1397, col */
      80,     89,     -1, /* 1398, col */
      42,     90,     -1, /* 1399, col */
      79,     50,     -1, /* 1400, col */
      81,     49,     -1, /* 1401, col */
      42,     90,     -1, /* 1402, col */
      80,     89,     -1, /* 1403, col */
       6,      2,     -1, /* 1404, col */
       9,      1,     -1, /* 1405, col */
      10,      3,     -1, /* 1406, col */
      36,     51,     -1, /* 1407, col */
      35,      0,     -1, /* 1408, col */
      79,     50,     -1, /* 1409, col */
      82,     29,     -1, /* 1410, col */
      42,     90,     -1, /* 1411, col */
      41,     99,     -1, /* 1412, col */
      82,     29,     -1, /* 1413, col */
      41,     99,     -1, /* 1414, col */
      40,     47,     -1, /* 1415, col */
      82,     29,     -1, /* 1416, col */
      40,     47,     -1, /* 1417, col */
      39,     54,     -1, /* 1418, col */
      43,     31,     -1, /* 1419, col */
      42,     90,     -1, /* 1420, col */
      82,     29,     -1, /* 1421, col */
      82,     29,     -1, /* 1422, col */
      45,    100,     -1, /* 1423, col */
      44,     30,     -1, /* 1424, col */
      82,     29,     -1, /* 1425, col */
      46,     53,     -1, /* 1426, col */
      45,    100,     -1, /* 1427, col */
      81,     49,     -1, /* 1428, col */
      41,     99,     -1, /* 1429, col */
      42,     90,     -1, /* 1430, col */
      42,     90,     -1, /* 1431, col */
      43,     31,     -1, /* 1432, col */
      79,     50,     -1, /* 1433, col */
      44,     30,     -1, /* 1434, col */
      45,    100,     -1, /* 1435, col */
      37,     52,     -1, /* 1436, col */
      46,     53,     -1, /* 1437, col */
      39,     54,     -1, /* 1438, col */
      31,     46,     -1, /* 1439, col */
      37,     52,     -1, /* 1440, col */
      45,    100,     -1, /* 1441, col */
      46,     53,     -1, /* 1442, col */
      79,     50,     -1, /* 1443, col */
      43,     31,     -1, /* 1444, col */
      44,     30,     -1, /* 1445, col */
      40,     47,     -1, /* 1446, col */
      41,     99,     -1, /* 1447, col */
      81,     49,     -1, /* 1448, col */
      31,     46,     -1, /* 1449, col */
      39,     54,     -1, /* 1450, col */
      40,     47,     -1, /* 1451, col */
       6,      2,     -1, /* 1452, col */
       5,    116,     -1, /* 1453, col */
       8,      0,     -1, /* 1454, col */
      22,     50,     -1, /* 1455, col */
      91,     56,     -1, /* 1456, col */
      21,     57,     -1, /* 1457, col */
      91,     56,     -1, /* 1458, col */
      47,     93,     -1, /* 1459, col */
      21,     57,     -1, /* 1460, col */
      22,     50,     -1, /* 1461, col */
      48,     96,     -1, /* 1462, col */
      91,     56,     -1, /* 1463, col */
      47,     93,     -1, /* 1464, col */
       9,     94,     -1, /* 1465, col */
       8,     95,     -1, /* 1466, col */
      48,     96,     -1, /* 1467, col */
      10,      1,     -1, /* 1468, col */
       9,     94,     -1, /* 1469, col */
      47,     93,     -1, /* 1470, col */
      91,     56,     -1, /* 1471, col */
       9,     94,     -1, /* 1472, col */
      91,     56,     -1, /* 1473, col */
      48,     96,     -1, /* 1474, col */
       9,     94,     -1, /* 1475, col */
      97,     -1,    285, /* 1476,  nv */
      96,     -1,    286, /* 1477,  nv */
      98,     -1,    287, /* 1478,  nv */
      93,     -1,    288, /* 1479,  nv */
      95,     -1,    289, /* 1480,  nv */
      94,     -1,    290, /* 1481,  nv */
      93,     -1,    570, /* 1482,  nv */
      92,     -1,    571, /* 1483,  nv */
      95,     -1,    572, /* 1484,  nv */
      96,     -1,    573, /* 1485,  nv */
      99,     -1,    574, /* 1486,  nv */
      98,     -1,    575, /* 1487,  nv */
     116,    125,     -1, /* 1488, col */
     102,    282,     -1, /* 1489, col */
     101,    126,     -1, /* 1490, col */
     116,    125,     -1, /* 1491, col */
     101,    126,     -1, /* 1492, col */
     118,    127,     -1, /* 1493, col */
     118,    127,     -1, /* 1494, col */
     112,    150,     -1, /* 1495, col */
     116,    125,     -1, /* 1496, col */
     118,    127,     -1, /* 1497, col */
     113,    281,     -1, /* 1498, col */
     112,    150,     -1, /* 1499, col */
};

/* ============================================================
          Deformation Structure Area
 ============================================================ */
static s16 trigrp_noname0000_vtx_keys[]={ 0,1,2,3,4,5,6,7,8,9,10,11,12,
 13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,};
static s16 trigrp_noname0000_vtx_vlist[]={ 0,1,2,3,4,5,6,7,8,9,10,11,12,
 13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,};
static NDR_DEFORM trigrp_noname0000_vtx_deform={
  trigrp_noname0000_vtx_keys,
  trigrp_noname0000_vtx_vlist,
  30, 252
};

static s16 trigrp_noname0000_vtxnv_keys[]={ 0,1,2,3,4,5,6,7,8,9,10,11,12,
 13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,};
static s16 trigrp_noname0000_vtxnv_vlist[]={ 0,1,2,3,4,5,6,7,8,9,10,11,
 12,13,14,15,16,17,18,19,20,21,22,23,24,25,26,27,28,29,};
static NDR_DEFORM trigrp_noname0000_vtxnv_deform={
  trigrp_noname0000_vtxnv_keys,
  trigrp_noname0000_vtxnv_vlist,
  30, 1500
};

/* ============================================================
          Shape Structure
 ============================================================ */
static NDR_SHAPE shape_Shape_of___POLYHEDRON_246_ = {
  gfx_Shape_of___POLYHEDRON_246_,
  vtx_Shape_of___POLYHEDRON_246_, 1500, 5,
  bmp_frake_select,
  NULL,
  6, 7,
  shaperef_Shape_of___POLYHEDRON_246_,
  &trigrp_noname0000_vtx_deform,
  NULL,
  &trigrp_noname0000_vtxnv_deform
};

/* ============================================================
          Object Structure Area
 ============================================================ */
/* Object #0 */
static NDR_OBJ _dummy_obj={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #1 */
static NDR_OBJ _def_body2={
  NDC_TYPE_3D, 0, 0xd00 + 0x00,
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  0,
  0x0000, 0x00002001, 0xf0800505, 0x00000000,
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  {0x0f,0x0f,0x0f,0x04,0x0f,0x0f,0x0f,0x04},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #2 */
static NDR_OBJ _NULL_OBJECT_1={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #3 */
static NDR_OBJ _NULL_OBJECT_2={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* Object #4 */
static NDR_OBJ _NULL_OBJECT_3={
  NDC_TYPE_NULL, 0, 0x00000000,
  {0,0,0, 0,0,0, 1,1,1},
  -1,
  0x0000, 0x00000000, 0x00000000, 0x00000000,
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  {0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00},
  -1, 0, 0, 0x010203,
  {-1, -1}, 0, NULL
};

/* ============================================================
          Scene Structure Area
 ============================================================ */
static NDR_SCN_INST_OBJ flak_def1_scene_instlist[]={
 {
  {0,0,0, 0,0,0, 1,1,1},
  2 /* NULL_OBJECT_1 */
 },
 {
  {0,0,0, 0,0,0, 1,1,1},
  4 /* NULL_OBJECT_3 */
 },
 {
  {0,0,0, 0,0,0, 1,1,1},
  3 /* NULL_OBJECT_2 */
 },
 {
  {0.000000,0.000000,0.000000,
   0.000000,0.000000,0.000000,
   1.000000,1.000000,1.000000},
  1 /* def_body2 */
 },
};

static NDR_SCN_LIGHT _flak_def1_scene_light[]={
  { 0, 0xffffff00, 0.57735, 0.57735, 0.57735, 0, 0 }
};

static NDR_SCENE flak_def1_scene={
  {950.000000, 1000.000000, 0x4c, 0x4c, 0x4c, 0xff},
  {1, 45.841393, 1.333330, 1.000000, 0, 0, 0, 0, 1, 10000, 0, 1, 2},
  { 0x000000ff, 1, _flak_def1_scene_light },
  0x0000, 0xfffc,
  flak_def1_scene_instlist, 4,
};

/* ============================================================
          Raw Data List
 ============================================================ */
static s16 *rawvtxlist_frake_select[]={
  vtxgrp_frake_select_1,
  vtxgrp_frake_select_2,
  vtxgrp_frake_select_3,
  vtxgrp_frake_select_4,
  vtxgrp_frake_select_5,
  vtxgrp_frake_select_6,
  vtxgrp_frake_select_7,
  vtxgrp_frake_select_8,
  vtxgrp_frake_select_9,
  vtxgrp_frake_select_10,
  vtxgrp_frake_select_11,
  vtxgrp_frake_select_12,
  vtxgrp_frake_select_13,
  vtxgrp_frake_select_14,
  vtxgrp_frake_select_15,
  vtxgrp_frake_select_16,
  vtxgrp_frake_select_17,
  vtxgrp_frake_select_18,
  vtxgrp_frake_select_19,
  vtxgrp_frake_select_20,
  vtxgrp_frake_select_21,
  vtxgrp_frake_select_22,
  vtxgrp_frake_select_23,
  vtxgrp_frake_select_24,
  vtxgrp_frake_select_25,
  vtxgrp_frake_select_26,
  vtxgrp_frake_select_27,
  vtxgrp_frake_select_28,
  vtxgrp_frake_select_29,
  vtxgrp_frake_select_30,
};

static s8 *rawvtxnvlist_frake_select[]={
  vtxnvgrp_frake_select_0,
  vtxnvgrp_frake_select_1,
  vtxnvgrp_frake_select_2,
  vtxnvgrp_frake_select_3,
  vtxnvgrp_frake_select_4,
  vtxnvgrp_frake_select_5,
  vtxnvgrp_frake_select_6,
  vtxnvgrp_frake_select_7,
  vtxnvgrp_frake_select_8,
  vtxnvgrp_frake_select_9,
  vtxnvgrp_frake_select_10,
  vtxnvgrp_frake_select_11,
  vtxnvgrp_frake_select_12,
  vtxnvgrp_frake_select_13,
  vtxnvgrp_frake_select_14,
  vtxnvgrp_frake_select_15,
  vtxnvgrp_frake_select_16,
  vtxnvgrp_frake_select_17,
  vtxnvgrp_frake_select_18,
  vtxnvgrp_frake_select_19,
  vtxnvgrp_frake_select_20,
  vtxnvgrp_frake_select_21,
  vtxnvgrp_frake_select_22,
  vtxnvgrp_frake_select_23,
  vtxnvgrp_frake_select_24,
  vtxnvgrp_frake_select_25,
  vtxnvgrp_frake_select_26,
  vtxnvgrp_frake_select_27,
  vtxnvgrp_frake_select_28,
  vtxnvgrp_frake_select_29,
};

/* ============================================================
          Shape Structure List
 ============================================================ */
static NDR_SHAPE *shapelist_frake_select[] = {
  &shape_Shape_of___POLYHEDRON_246_,
};

/* ============================================================
          Object Struct List
 ============================================================ */
static NDR_OBJ *objlist_frake_select[]={
  &_dummy_obj, /* 0 */
  &_def_body2, /* 1 */
  &_NULL_OBJECT_1, /* 2 */
  &_NULL_OBJECT_2, /* 3 */
  &_NULL_OBJECT_3, /* 4 */
};

/* ############################################################
          Resource Information
 ############################################################ */
NDR_RESINFO resinfo_frake_select={
  &flak_def1_scene,
  20.000000,
  objlist_frake_select,
  shapelist_frake_select,
  NULL,
  rawvtxlist_frake_select,
  NULL,
  rawvtxnvlist_frake_select,
  5, 1, 0, 30, 0, 30
};

